(function( $ ) {
	'use strict';

	/**
	 * All of the code for your public-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note that this assume you're going to use jQuery, so it prepares
	 * the $ function reference to be used within the scope of this
	 * function.
	 *
	 * From here, you're able to define handlers for when the DOM is
	 * ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * Or when the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and so on.
	 *
	 * Remember that ideally, we should not attach any more than a single DOM-ready or window-load handler
	 * for any particular page. Though other scripts in WordPress core, other plugins, and other themes may
	 * be doing this, we should try to minimize doing that in our own work.
	 */

	
})( jQuery );
var $search_map;
var $search_markers = [];
var $markerCluster;
jQuery(document).ready(function($) {
	var $search_item_container = jQuery('.db-main-search-listings');
	jQuery(document).on('click', '.db-find-listings', function() {
		var all_search_fields = {};

		if ( jQuery('#db-search-current_user_time').length ) { // Check current user time
			all_search_fields['current_user_time'] = jQuery('#db-search-current_user_time').val(db_get_current_timestamp());
		}

		jQuery('[class^="db-search-"]').each(function() {
			var setting_name = jQuery(this).attr('class').replace('db-search-', '').replace('-', '_');
			if ( setting_name == 'sort' || jQuery(this).hasClass('db-search-sort') ) {
				return true;
			}
			if ( jQuery(this).attr('type') != 'checkbox' ) {
				if ( jQuery(this).val() != '' ) {
					all_search_fields[setting_name] = jQuery(this).val();
				}
			} else {
				all_search_fields[setting_name] = jQuery(this).prop('checked');
			}
		});
		jQuery('[id^="db-search-"]').each(function() {
			var setting_name = jQuery(this).attr('id').replace('db-search-', '').replace('-', '_');
			if ( setting_name == 'sort' ) {
				return true;
			}
			if ( jQuery(this).attr('type') != 'checkbox' ) {
				if ( jQuery(this).val() != '' ) {
					all_search_fields[setting_name] = jQuery(this).val();
				}
			} else {
				all_search_fields[setting_name] = jQuery(this).prop('checked');
			}
		});

		jQuery('.db-main-search-listings').addClass('loading').scrollTop(0);

		jQuery('.db-search-next-page, .db-search-prev-page').addClass('hidden');

		jQuery.ajax({
			type: 'POST',
			url: db_main.ajaxurl,
			data: { 
				'action': 'db_search_listings',
				'search_terms': JSON.stringify(all_search_fields),
				'db_full_url': window.location.href,
				'db_page': jQuery(this).attr('data-page')
			},
			success: function(data) {
				db_parse_search_data( data );

				setTimeout(function() {
					jQuery('.db-main-search-listings').removeClass('loading');
				}, 600);
			}
		});
	});

	jQuery(document).on('click', '.db-search-next-page', function() {
		jQuery('.db-find-listings').attr('data-page', parseInt(jQuery('.db-find-listings').attr('data-page'))+1).click();
	});

	jQuery(document).on('click', '.db-search-prev-page', function() {
		jQuery('.db-find-listings').attr('data-page', parseInt(jQuery('.db-find-listings').attr('data-page'))-1).click();
	});

	function db_set_search_markers( search_map, search_marker ) {
		if ( search_marker['0'] == '' || search_marker['1'] == '' ) {
			return;
		}

		var marker_location = new google.maps.LatLng(search_marker['0'], search_marker['1']);

		// var marker = new google.maps.Marker({ position: marker_location, map: search_map });

		var marker = new RichMarker({
			position: marker_location,
			map: search_map,
			draggable: false,
			shadow: 'none',
			content: '<div class="db-map-marker '+search_marker['2']+'" data-id="'+search_marker['3']+'"></div>'
		});

		$search_markers.push(marker);

		var infoBubble = new InfoBubble({
			map: search_map,
			content: '<div class="marker-loading marker-id-'+search_marker['3']+'"></div>',
			position: marker_location,
			shadowStyle: 0,
			padding: 0,
			backgroundColor: 'rgb(255,255,255)',
			borderRadius: 4,
			arrowSize: 0,
			borderWidth: 0,
			borderColor: 'transparent',
			disableAutoPan: true,
			hideCloseButton: false,
			arrowPosition: 0,
			backgroundClassName: 'db-marker-window',
			arrowStyle: 2
		});

		google.maps.event.addListener(marker, 'click', function() {
			infoBubble.setMinWidth(70);
			infoBubble.setMinHeight(70)
			infoBubble.setCloseSrc(db_main.template_url+'/images/x-white.png');
			jQuery(infoBubble.close_).hide();
			infoBubble.open(search_map, marker);
			jQuery(infoBubble.content_).parent().attr('class', 'db-marker-window-loading');
			jQuery(infoBubble.content_).parent().parent().addClass('db-marker-perspective');

			jQuery.ajax({
				type: 'POST',
				url: db_main.ajaxurl,
				data: { 
					'action': 'db_marker_window',
					'marker_id': search_marker['3']
				},
				success: function( data ) {
					jQuery('.db-marker-window .marker-id-'+search_marker['3']).html(data).addClass('active');

					infoBubble.setMinWidth(300);
					infoBubble.setMinHeight(400);
					jQuery(infoBubble.content_).parent().attr('class', 'db-marker-window-loaded');
					setTimeout(function() {
						jQuery(infoBubble.close_).show();
					}, 200);
					infoBubble.panToView();
				}
			});
		});

		google.maps.event.addListener(search_map, 'click', function() {
			infoBubble.close();
		});
	}

	function db_clear_markers() {
		if ( $search_markers.length ) {
			jQuery.each($search_markers, function(index, marker) {
				marker.setMap(null);
				$markerCluster.removeMarker(marker);
			});	
		}
		$search_markers = [];
	}

	jQuery( window ).resize(function() {
		whitelab_calculate_side_height();
	});

	function db_parse_search_data( data ) {
		jQuery('.db-main-search-listings').html('<span class="db-search-scrollbar"></span>');
		var parsed_search_data = jQuery.parseJSON(data);
		if ( typeof parsed_search_data.listing_html.length != 'number' ) {
			jQuery('.db-main-search-listings').removeClass('db-no-listings');
			jQuery.each(parsed_search_data.listing_html, function(index, data) {
				jQuery('.db-main-search-listings').append(data);
			});

			var search_height = jQuery('.db-main-search-listings')[0].scrollHeight;
			jQuery('.db-main-search-listings').append('<a href="javascript:void(0)" class="db-search-next-page hidden">'+db_main.next_page+'</a>');
			jQuery('.db-main-search-listings').append('<a href="javascript:void(0)" class="db-search-prev-page hidden">'+db_main.prev_page+'</a>');
			if ( search_height > jQuery('.db-main-search-listings')[0].clientHeight ) {
				jQuery('.db-search-next-page, .db-search-prev-page').css('top', search_height+'px');
			} else {
				jQuery('.db-search-next-page, .db-search-prev-page').css('top', (search_height-50)+'px');
			}

			var scrollbar_height = jQuery('.db-main-search-listings')['0'].clientHeight*(jQuery('.db-main-search-listings')['0'].clientHeight/jQuery('.db-main-search-listings')['0'].scrollHeight);
			if ( scrollbar_height < jQuery('.db-main-search-listings')['0'].scrollHeight ) {
				jQuery('.db-main-search-listings').find('.db-search-scrollbar').css('height', scrollbar_height).show();
			} else {
				jQuery('.db-main-search-listings').find('.db-search-scrollbar').hide();
			}

			db_clear_markers();
			var merker_count = 0;
			jQuery.each(parsed_search_data.marker_data, function(index, marker) {
				db_set_search_markers($search_map, marker);
				merker_count++;
			});

			var options = {
				imagePath: db_main.plugin_url+'public/images/m'
			}

			$markerCluster = new MarkerClusterer($search_map, $search_markers, options);

			if ( jQuery('.db-found-count').length ) {
				jQuery('.db-found-count').attr('data-found', $search_markers.length);
				if ( jQuery('.db-find-listings').attr('data-page') == 1 ) {
					jQuery('.db-found-count').attr('data-total-found', $search_markers.length + ' ' + db_main.search_of + ' ' + parsed_search_data.total);
				} else {
					jQuery('.db-found-count').attr('data-total-found', (parseInt(jQuery('.db-find-listings').attr('data-max'))*(jQuery('.db-find-listings').attr('data-page')-1))+parseInt($search_markers.length) + ' ' + db_main.search_of + ' ' + parsed_search_data.total);
				}
			}
			
			google.maps.event.addListener($search_map, 'dragend', function() {
				var filtered_listings = 0;
				jQuery.each($search_markers, function(index, marker_value) {
					if ( $search_map.getBounds().contains(marker_value.getPosition() ) ) {
						jQuery('.db-main-search-listings .db-main-search-item[data-id="'+jQuery(marker_value.content).attr('data-id')+'"]').removeClass('list-item-hidden');
						setTimeout(function() {
							$search_item_container.isotope( 'revealItemElements', jQuery('.db-main-search-listings .db-main-search-item[data-id="'+jQuery(marker_value.content).attr('data-id')+'"]').show() );
						}, 50);
						filtered_listings++;
					} else {
						jQuery('.db-main-search-listings .db-main-search-item[data-id="'+jQuery(marker_value.content).attr('data-id')+'"]').addClass('list-item-hidden');
						setTimeout(function() {
							$search_item_container.isotope( 'hideItemElements', jQuery('.db-main-search-listings .db-main-search-item[data-id="'+jQuery(marker_value.content).attr('data-id')+'"]') );
						}, 50);
					}
				});
				setTimeout(function() {
					if ( jQuery('.db-found-count').length ) {
						jQuery('.db-found-count').attr('data-found', filtered_listings);
					}
					$search_item_container.isotope('reloadItems').isotope();
					$search_item_container.scrollTop(0);
				}, 250);
			});

			google.maps.event.addListener($search_map, 'zoom_changed', function() {
				var filtered_listings = 0;
				jQuery.each($search_markers, function(index, marker_value) {
					if ( $search_map.getBounds().contains(marker_value.getPosition() ) ) {
						jQuery('.db-main-search-listings .db-main-search-item[data-id="'+jQuery(marker_value.content).attr('data-id')+'"]').removeClass('list-item-hidden');
						setTimeout(function() {
							$search_item_container.isotope( 'revealItemElements', jQuery('.db-main-search-listings .db-main-search-item[data-id="'+jQuery(marker_value.content).attr('data-id')+'"]').show() );
						}, 50);
						filtered_listings++;
					} else {
						jQuery('.db-main-search-listings .db-main-search-item[data-id="'+jQuery(marker_value.content).attr('data-id')+'"]').addClass('list-item-hidden');
						setTimeout(function() {
							$search_item_container.isotope( 'hideItemElements', jQuery('.db-main-search-listings .db-main-search-item[data-id="'+jQuery(marker_value.content).attr('data-id')+'"]') );
						}, 50);
					}
				});
				setTimeout(function() {
					if ( jQuery('.db-found-count').length ) {
						jQuery('.db-found-count').attr('data-found', filtered_listings);
					}
					$search_item_container.isotope('reloadItems').isotope();
					$search_item_container.scrollTop(0);
				}, 250);
			});

			setTimeout(function() {
				var map_bounds = new google.maps.LatLngBounds();

				jQuery.each($search_markers, function(index, marker) {
					map_bounds.extend(marker.position);
				});

				$search_map.fitBounds(map_bounds);
				if ( merker_count == 1 ) {
					$search_map.setZoom(13);
				}
				db_set_isotope();
			}, 200);
			
		} else {
			if ( parsed_search_data.map_changed && parsed_search_data.map_lat != null ) {
				setTimeout(function() {
					$search_map.setCenter(new google.maps.LatLng(parsed_search_data.map_lat, parsed_search_data.map_lng));
					$search_map.setZoom(10);
				}, 100);
			}

			jQuery('.db-main-search-listings').addClass('db-no-listings');
			jQuery('.db-main-search-listings').append('<div class="db-main-search-item full-listing" style="text-align: center;">'+db_main.no_listings+'</div>');
			db_clear_markers();

			if ( jQuery('.db-found-count').length ) {
				jQuery('.db-found-count').attr('data-found', '0').attr('data-total-found', '0');
			}

			if ( parsed_search_data.gmsg != null ) {
				alert( parsed_search_data.gmsg );
			}
		}

		// Change to new url
		history.pushState({page: parsed_search_data.new_url}, '', parsed_search_data.new_url);

		jQuery('.db-search-side-two').removeClass('db-show-pagination');
		var current_listings = parseInt(jQuery('.db-found-count').attr('data-found'));
		var max_listings = parseInt(jQuery('.db-find-listings').attr('data-max'));
		var page = parseInt(jQuery('.db-find-listings').attr('data-page'));
		var total = parseInt(parsed_search_data.total);
		var current_count = ( ( max_listings * ( page - 1) ) + current_listings );

		jQuery('.db-found-count').removeClass('total-hidden');
		if ( current_count < total ) {
			jQuery('.db-search-next-page').removeClass('hidden');
			jQuery('.db-search-prev-page').removeClass('hidden');
		} else if ( current_count == total ) {
			jQuery('.db-search-next-page').addClass('hidden');
			jQuery('.db-search-prev-page').removeClass('hidden');

			if ( jQuery('.db-find-listings').attr('data-page') == 1 ) {
				jQuery('.db-found-count').addClass('total-hidden');
			}
		}

		if ( jQuery('.db-find-listings').attr('data-page') == 1 ) {
			jQuery('.db-search-prev-page').addClass('hidden');
		}

		whitelab_calculate_side_height();
	}

	jQuery(document).on('click', '.db-search-categories a', function() {
		var all_search_fields = {};
		all_search_fields.search_category = jQuery(this).attr('data-term-id')

		jQuery.ajax({
			type: 'POST',
			url: db_main.ajaxurl,
			data: { 
				'action': 'db_search_listings',
				'search_terms': JSON.stringify(all_search_fields),
				'db_full_url': window.location.href
			},
			success: function(data) {
				db_parse_search_data( data );
			}
		});
	});

	var $lastSearchScrollTop = 0;
	jQuery('.db-main-search-listings').scroll(function() {
		var st = jQuery(this).scrollTop();
		var scrolled_percentage = jQuery(this).scrollTop()/(jQuery(this)[0].scrollHeight-jQuery(this).innerHeight())*100;
		var extra_scroll = jQuery(this).find('.db-search-scrollbar').height()*(scrolled_percentage/100);
		var scroll_height = 'calc('+scrolled_percentage+'% - '+extra_scroll+'px + '+jQuery(this).scrollTop()+'px)';

		if ( jQuery(window).outerWidth() > 980 ) {

			if ( st < $lastSearchScrollTop ) {
				var extra_scroll = parseInt(jQuery(this).attr('data-scroll'))-($lastSearchScrollTop - st);
				if ( extra_scroll < 0 ) {
					extra_scroll = 0;
				}
				jQuery(this).attr('data-scroll', extra_scroll);
			}

			var max_search_height = parseInt( jQuery('.db-search-controls')['0'].scrollHeight );
			var current_search_height = max_search_height - ( jQuery(this).scrollTop() - parseInt( jQuery(this).attr('data-scroll') ) );
			if ( current_search_height > max_search_height ) {
				current_search_height = max_search_height;
			}
			var scrolled_value = 1 - ( current_search_height / max_search_height );
			var scrolled_value_rev = current_search_height / max_search_height;
			if ( scrolled_value > 0.7 ) {
				scrolled_value = 1;
			}
			if ( scrolled_value_rev < 0.3 ) {
				scrolled_value_rev = 0;
			}
			jQuery('.db-search-controls').css('height', current_search_height + 'px');

			var showmore_top = -12 * scrolled_value_rev;
			if ( showmore_top > 0 ) {
				showmore_top = 0;
			}
			var showmore_margin_top = 13 * scrolled_value;
			var showmore_margin_bottom = 36 * scrolled_value;
			var showmore_margin_height = 21 * scrolled_value;

			jQuery('.db-show-more-fields').css({
				'margin-bottom': '36px',
				'margin-top': showmore_margin_top + 'px',
				'height': showmore_margin_height + 'px',
				'top': showmore_top + 'px'
			});

			var scrolled_percentage_sec = (jQuery(this).scrollTop()-parseInt( jQuery(this).attr('data-scroll') ))/(jQuery(this)[0].scrollHeight-jQuery(this).innerHeight())*100;
			if ( scrolled_percentage_sec > 0 ) {
				jQuery(this).parent().addClass('db-hide-fields');
				jQuery('.db-show-more-fields').addClass('db-invisible');
			} else {
				jQuery(this).parent().removeClass('db-hide-fields');
				jQuery('.db-show-more-fields').removeClass('db-invisible');
			}

			if ( scrolled_percentage > 95 ) {
				jQuery(this).parent().addClass('db-show-pagination');
			} else {
				jQuery(this).parent().removeClass('db-show-pagination');
			}

			whitelab_calculate_side_height();

		}
		
		jQuery(this).find('.db-search-scrollbar').css('top', scroll_height);

		$lastSearchScrollTop = st;
	});

	if ( jQuery(window).outerWidth() < 1000 ) {
		jQuery('.db-main-search-listings').addClass('db-show-pagination');
	}

	jQuery(document).on('click', '.db-show-more-fields', function() {
		jQuery('.db-search-side-two').removeClass('db-hide-fields');
		jQuery('.db-search-controls').css('height', '');
		jQuery('.db-show-more-fields').css({
			'margin-bottom': '',
			'margin-top': '',
			'height': '',
			'top': ''
		});

		jQuery('.db-main-search-listings').attr('data-scroll', jQuery('.db-main-search-listings').scrollTop());

		setTimeout(function() {
			whitelab_calculate_side_height();
		}, 200);
	});

	function db_set_isotope() {
		if ( typeof $search_item_container.attr('style') == 'undefined' ) {
			$search_item_container.isotope({
				itemSelector: '.db-main-search-item:not(.list-item-hidden)',
				layoutMode: 'masonry',
				masonry: {
					gutter: 30
				},
				getSortData: jQuery.parseJSON(db_main.custom_sorting),
				sortBy: [ 'featured', 'opened', 'name' ],
				sortAscending: jQuery.parseJSON(db_main.custom_sorting_dir),
				transitionDuration: '0.2s',
				hiddenStyle: {
					opacity: 0
				},
				visibleStyle: {
					opacity: 1
				}
			});
		} else {
			$search_item_container.isotope('reloadItems').isotope();
		}
	}

	jQuery(document).on('change', '.db-search-sort, #db-search-sort', function() {
		var sort_by_value = jQuery(this).val();
		$search_item_container.isotope({
			sortBy: [ 'featured', sort_by_value ],
		});
	});

	jQuery(document).on('click', '.db-contact-author', function() {
		jQuery(this).closest('form').find('[type="submit"]').click();
	});

	jQuery(document).on('submit', '.db-contact-author-form', function(e) {
		e.preventDefault();

		var submit = jQuery(this).find('.db-contact-author');
		jQuery.ajax({
			type: 'POST',
			url: db_main.ajaxurl,
			data: { 
				'action': 'db_send_contact_email',
				'db_listing': submit.attr('data-id'),
				'db_message': jQuery('.db-contact-message').val(),
				'db_name': jQuery('.db-contact-name').val(),
				'db_email': jQuery('.db-contact-email').val()
			},
			success: function(data) {
				jQuery('.db-contact-status').html(data);
			}
		});
	});

	jQuery(document).on('change', '#listing_category', function() {
		var category_id = jQuery(this).val();
		jQuery('.db-payment-packages li').each(function() {
			var for_categories = jQuery(this).attr('data-for').split(',');
			if ( jQuery.inArray( category_id, for_categories ) < 0 ) {
				jQuery(this).hide();
			} else {
				jQuery(this).show();
			}
		});

		jQuery('.db-field-row.db-cat-for').each(function() {
			var for_categories = jQuery(this).attr('data-for').split(',');
			if ( jQuery.inArray( category_id, for_categories ) < 0 ) {
				jQuery(this).addClass('field-hidden');
			} else {
				jQuery(this).removeClass('field-hidden');
			}
		});

		if ( jQuery('.db-booking-wrapper').length && ( jQuery('[name="hop-type[]"]:checked').val() == 'always' || jQuery('[name="hop-type[]"]:checked').val() == 'custom' ) ) {
			var active_booking_cat = jQuery('.db-booking-wrapper').attr('data-for').split(',');
			if ( jQuery.inArray( category_id, active_booking_cat ) >= 0 ) {
				jQuery('.db-booking-wrapper').removeClass('hidden');
			} else {
				jQuery('.db-booking-wrapper').addClass('hidden');
			}	
		}

		if ( jQuery('.db-fmenu-row').length ) {
			var active_fmenu_cat = jQuery('.db-fmenu-row').attr('data-for').split(',');
			if ( jQuery.inArray( category_id, active_fmenu_cat ) >= 0 ) {
				jQuery('.db-fmenu-row').removeClass('hidden');
			} else {
				jQuery('.db-fmenu-row').addClass('hidden');
				jQuery('#listing_fmenu').val('');
			}
		}
	});
	jQuery('#listing_category').trigger('change');

	jQuery(document).on('hover', '.db-rating-container span, .db-rating-container svg', function() {
		var selected_rating = jQuery(this).index()+1;
		jQuery(this).parent().removeClass('selected-1').removeClass('selected-2').removeClass('selected-3').removeClass('selected-4').removeClass('selected-5');
		jQuery(this).parent().addClass('selected-'+selected_rating);
	});

	jQuery(document).on('click', '.db-rating-container span, .db-rating-container svg', function() {
		var active_rating = jQuery(this).index()+1;
		jQuery(this).parent().removeClass('active-1').removeClass('active-2').removeClass('active-3').removeClass('active-4').removeClass('active-5');
		jQuery(this).parent().addClass('active-'+active_rating);
		jQuery(this).parent().parent().find('[name^="listing_rat"][value="'+active_rating+'"]').prop('checked', true);

		if ( jQuery('.advanced-reviews').length ) {
			var total = 0;
			var count = 0;

			jQuery('.advanced-reviews .db-rating-stars').each(function() {
				if ( jQuery(this).find('input[type="radio"]:checked').length ) {
					total += parseInt(jQuery(this).find('input[type="radio"]:checked').last().val());
					count ++;
				}
			});

			jQuery('.db-rating-overall').attr('data-overall', Math.floor(total/count));
		}
	});
	
	jQuery(document).on('mouseleave', '.db-rating-container', function(e) {
		jQuery('.db-rating-container').removeClass('selected-1').removeClass('selected-2').removeClass('selected-3').removeClass('selected-4').removeClass('selected-5');
	});

	jQuery(document).on('change', '.db-hop-times-row [type="radio"]', function() {
		jQuery('.db-hop-time-container input[type="hidden"]').val(jQuery(this).val()+'|');
		if ( jQuery(this).val() == 'custom' ) {
			jQuery('.db-add-new-hop').show();
			jQuery('.db-hop-time-container').show();
			jQuery('.db-field-time-row').show();
			jQuery('.db-hop-time-container .db-hop-day-row').remove();
		} else {
			jQuery('.db-hop-time-container [name="hop"]').val('always');
			jQuery('.db-add-new-hop').hide();
			jQuery('.db-hop-time-container').hide();
			jQuery('.db-field-time-row').hide();
			jQuery('.db-hop-time-container .db-hop-day-row').remove();
		}

		if ( jQuery('.db-booking-wrapper').length ) {
			var active_booking_cat = jQuery('.db-booking-wrapper').attr('data-for').split(',');
			if ( jQuery.inArray( jQuery('#listing_category').val(), active_booking_cat ) >= 0 ) {
				jQuery('.db-booking-wrapper').removeClass('hidden');
			} else {
				jQuery('.db-booking-wrapper').addClass('hidden');
			}	
		}
	});

	// jQuery(document).on('click', '.db-add-new-hop', function() {
	// 	jQuery('.db-hop-dialog').show();
	// });

	if ( jQuery('#listing_time_zone').length && !jQuery('.db-edit-listing').length ) {
		var current_date = new Date();
		var current_offset = parseInt(-current_date.getTimezoneOffset() / 60);

		if ( current_offset >= 0 ) {
			var current_utc = 'UTC+'+current_offset;
		} else {
			var current_utc = 'UTC'+current_offset;
		}

		jQuery('#listing_time_zone').attr('value', current_utc);
		jQuery('#listing_time_zone').prev().attr('value', current_utc);
		jQuery('.dt-custom-select-item[data-value="'+current_utc+'"]').addClass('active');
	}

	jQuery(document).on('click', '.db-add-new-hop', function() {
		jQuery('.db-custom-hop-times .db-hop-day-popup, .db-custom-hop-times .db-hop-time-popup').hide();
		if ( jQuery('input[name="hop_format"]:checked').val() == '24h' ) {
			var time_text = '08:00 - 17:00';
			var time_popup = '<div class="db-hop-time-popup"><span class="hop-title">'+db_main.what_hop+'</span><span class="hop-times-from" data-title="'+db_main.hop_from+':"><input type="text" class="hop-add-mask" value="08:00"></span><span class="hop-times-till" data-title="'+db_main.hop_to+':"><input type="text" class="hop-add-mask" value="17:00"></span><a href="javascript:void(0)" class="hop-finish button button-primary button-large">'+db_main.hop_complete+'</a></div>';
		} else {
			var time_text = '8:00 am - 5:00 pm';
			var time_popup = '<div class="db-hop-time-popup"><span class="hop-title">What are your hours of operation?</span><span class="hop-times-from" data-title="'+db_main.hop_from+':"><input type="text" class="hop-add-mask" value="08:00 am"></span><span class="hop-times-till" data-title="'+db_main.hop_to+':"><input type="text" class="hop-add-mask" value="05:00 pm"></span><a href="javascript:void(0)" class="hop-finish button button-primary button-large">'+db_main.hop_complete+'</a></div>';
		}
		var day_popup = '<div class="db-hop-day-popup"><span class="hop-title">'+db_main.hop_days+'</span>'+jQuery('.db-hop-dialog-inner .db-hop-left').html()+'<a href="javascript:void(0)" class="hop-edit-times button button-primary button-large">'+db_main.hop_next+'</a></div>';
		jQuery('.db-hop-time-container').append('<div class="db-hop-day-row">'+day_popup+time_popup+'<span class="db-hop-day-names">Mon - Fri</span><span class="db-hop-day-times" data-open="28800" data-close="61200">'+time_text+'</span><span class="db-hop-remove dbicon-cancel"></span></div>');
		
		set_hop_masks();
	});

	function set_hop_masks() {
		if ( jQuery('input[name="hop_format"]:checked').val() == '12h' ) {
			jQuery('.db-hop-time-popup input').each(function() {
				jQuery(this).mask('00:00 AA', {
					onKeyPress: function(cep, event, currentField, options) {
						if ( cep.length == 8 ) {
							var time_val = cep.split(':');
							var hours = time_val['0'];
							var excess = time_val['1'].split(' ');
							var minutes = excess['0'];
							var ampm = excess['1'];

							if ( hours > 12 ) {
								hours = 12;
							}

							if ( minutes > 59 ) {
								minutes = 59;
							}

							if ( ampm != 'am' && ampm != 'pm' && ampm != 'AM' && ampm != 'PM' ) {
								ampm = 'AM';
							}

							currentField.val(hours+':'+minutes+' '+ampm);
						}
					}
				});
			});
		} else {
			jQuery('.db-hop-time-popup input').each(function() {
				jQuery(this).mask('00:00', {
					onKeyPress: function(cep, event, currentField, options) {
						if ( cep.length == 5 ) {
							var time_val = cep.split(':');

							if ( time_val['0'] > 23 ) {
								time_val['0'] = '23';
							}
							if ( time_val['1'] > 59 ) {
								time_val['1'] = '59';
							}

							currentField.val(time_val.join(':'));
						}
					}
				});
			});
		}
	}

	jQuery(document).on('click', '.hop-edit-times', function() {
		var unique_days = true;
		var added_json = jQuery('input[name="hop"]').val();
		
		if ( added_json != 'custom|' ) {
			var added_times = jQuery.parseJSON(added_json);
			delete added_times['0'];
			delete added_times['1'];

			var weekday = new Array();
				weekday[1] = 'Mon';
				weekday[2] = 'Tue';
				weekday[3] = 'Wed';
				weekday[4] = 'Thu';
				weekday[5] = 'Fri';
				weekday[6] = 'Sat';
				weekday[0] = 'Sun';

			var already_added = [];
			
			jQuery.each(added_times, function(index,day_arr) {
				jQuery.each(day_arr, function(index2,day_data) {
					already_added.push(weekday[new Date(day_data['0']*1000).getUTCDay()]);
				});
			});

			jQuery(this).parent().find('.db-checkbox-label.active').each(function() {
				if ( jQuery.inArray(jQuery(this).text(), already_added) >= 0 ) {
					jQuery(this).addClass('already-added');
					unique_days = false;
				}
			});
		}

		if ( jQuery(this).parent().find('.db-checkbox-label.active').length == 0 ) {
			jQuery(this).parent().parent().remove();
		}

		if ( unique_days === true ) {
			jQuery(this).parent().addClass('hop-slide-out');
			whitelab_check_hop_days( jQuery(this).parent() );
			jQuery(this).parent().next().addClass('hop-slide-in');
		}
	});

	jQuery(document).on('change', '[name="custom-hop-day[]"]', function() {
		if ( jQuery(this).prop('checked') ) {
			jQuery(this).parent().addClass('active');
		} else {
			jQuery(this).parent().removeClass('active');
		}
	});

	jQuery(document).on('click', '.hop-finish', function() {
		var fields_valid = true;
		var time_format = jQuery('input[name="hop_format"]:checked').val();
		jQuery(this).parent().find('input').removeClass('invalid');
		jQuery(this).parent().find('input').each(function() {
			if ( time_format == '12h' ) {
				if ( jQuery(this).val().length != 8 ) {
					fields_valid = false;
					jQuery(this).addClass('invalid');
				}
			} else if ( time_format == '24h' ) {
				if ( jQuery(this).val().length != 5 ) {
					fields_valid = false;
					jQuery(this).addClass('invalid');
				}
			}
		});

		if ( fields_valid == true ) {
			var starting_time = jQuery(this).parent().find('.hop-times-from input').val();
			var starting_time_timestamp = new Date('1970/01/01 '+starting_time+' UTC').getTime()/1000;
			var ending_time = jQuery(this).parent().find('.hop-times-till input').val();
			var ending_time_timestamp = new Date('1970/01/01 '+ending_time+' UTC').getTime()/1000;

			jQuery(this).parent().parent().find('.db-hop-day-times').html(starting_time+' - '+ending_time);
			jQuery(this).parent().parent().find('.db-hop-day-times').attr('data-open', starting_time_timestamp);
			jQuery(this).parent().parent().find('.db-hop-day-times').attr('data-close', ending_time_timestamp);
			jQuery(this).parent().parent().addClass('finished');
			jQuery(this).parent().hide();

			whitelab_check_active_hop();
		}

	});

	function whitelab_check_active_hop() {
		var all_times = {};
		all_times['0'] = jQuery('#listing_time_zone').val();
		all_times['1'] = jQuery('input[name="hop_format"]:checked').val();
		jQuery('.db-hop-day-row.finished').each(function(index, value) {
			all_times[index+2] = get_hop_timestamps( jQuery(value).find('.db-hop-day-names').text(), jQuery(value).find('.db-hop-day-times').text() );
		});

		jQuery('.db-hop-time-container [name="hop"]').val(JSON.stringify(all_times));
	}

	function get_hop_timestamps( hop_days, hop_times ) {
		var given_days = hop_days.split(' - ');
		var given_times = hop_times.split(' - ');
		var hoo_days = { 'mon':'05', 'tue':'06', 'wed':'07', 'thu':'08', 'fri':'09', 'sat':'10', 'sun':'11' };
		var show_days = false;
		var new_days = [];
		jQuery.each(hoo_days, function(day_name,day_num) {
			if ( day_name == given_days['0'] || show_days === true ) {
				new_days.push([new Date('1970/01/'+day_num+' '+given_times['0']+' UTC').getTime()/1000,new Date('1970/01/'+day_num+' '+given_times['1']+' UTC').getTime()/1000]);
				show_days = true;
				if ( day_name == given_days['1'] || typeof given_days['1'] == 'undefined' ) {
					return false;
				}
			}
		});

		return new_days;
	}

	function whitelab_check_hop_days( hop_day_parent ) {
		var hop_indexes = [];
		hop_day_parent.find('label.active').each(function() {
			hop_indexes.push(jQuery(this).index()-1);
		});

		if ( hop_indexes.length > 1 ) {
			var ordered = 'not_ordered';
		} else {
			var ordered = 'ordered';
		}
		
		for (var i = 0; i < hop_indexes.length; i++) {
			if ( i > 0 ) {
				if ( hop_indexes[i] == hop_indexes[i-1]+1 ) {
					ordered = 'ordered';
				} else {
					ordered = 'not_ordered';
					i = 200;
				}
			}
			
		}

		if ( hop_indexes.length == 1 ) {
			var first_value = jQuery(hop_day_parent.find('label').get( hop_indexes['0'] )).find('input').val();
			hop_day_parent.parent().find('.db-hop-day-names').text(first_value);
		} else if ( hop_indexes.length > 1 && ordered == 'ordered' ) {
			var first_value = jQuery(hop_day_parent.find('label').get( hop_indexes['0'] )).find('input').val();
			var last_value = jQuery(hop_day_parent.find('label').get( hop_indexes[hop_indexes.length-1] )).find('input').val();
			hop_day_parent.parent().find('.db-hop-day-names').text(first_value+' - '+last_value);
		} else if ( ordered == 'not_ordered' ) {
			var day_names = '';
			jQuery.each(hop_indexes, function(index, label_index) {
				day_names += jQuery(hop_day_parent.find('label').get( label_index )).find('input').val()+', ';
			});
			hop_day_parent.parent().find('.db-hop-day-names').text(day_names.slice(0,-2));
		}
	}

	jQuery(document).on('click', '.db-hop-add-time', function() {
		if ( !jQuery('.db-hop-dialog .db-hop-left label.active').length ) {
			jQuery('.db-hop-dialog-inner').prepend('<span class="db-hop-error">Please select a day!</span>');
			return;
		} else {
			jQuery('.db-hop-dialog-inner .db-hop-error').remove();
		}
		var appendable_html = '';
		var hop_indexes = [];
		jQuery('.db-hop-dialog .db-hop-left label.active').each(function() {
			hop_indexes.push(jQuery(this).index());
		});

		if ( hop_indexes.length > 1 ) {
			var ordered = 'not_ordered';
		} else {
			var ordered = 'ordered';
		}
		
		for (var i = 0; i < hop_indexes.length; i++) {
			if ( i > 0 ) {
				if ( hop_indexes[i] == hop_indexes[i-1]+1 ) {
					ordered = 'ordered';
				} else {
					ordered = 'not_ordered';
					i = 200;
				}
			}
			
		}

		var time_from = jQuery('.db-hop-from').val();
		var time_till = jQuery('.db-hop-till').val();
		var hidden_value = '';

		if ( hop_indexes.length == 1 ) {
			var first_value = jQuery(jQuery('.db-hop-dialog .db-hop-left label').get( hop_indexes['0'] )).find('input').val();
			appendable_html = '<div class="db-hop-day-row"><span class="db-hop-day-names">'+first_value+'</span><span class="db-hop-day-times">'+time_from+' - '+time_till+'</span><span class="db-hop-remove dbicon-cancel"></span></div>';
			hidden_value = first_value+'=='+time_from+'-'+time_till+'|';
		} else if ( hop_indexes.length > 1 && ordered == 'ordered' ) {
			var first_value = jQuery(jQuery('.db-hop-dialog .db-hop-left label').get( hop_indexes['0'] )).find('input').val();
			var last_value = jQuery(jQuery('.db-hop-dialog .db-hop-left label').get( hop_indexes[hop_indexes.length-1] )).find('input').val();
			appendable_html = '<div class="db-hop-day-row"><span class="db-hop-day-names">'+first_value+' - '+last_value+'</span><span class="db-hop-day-times">'+time_from+' - '+time_till+'</span><span class="db-hop-remove dbicon-cancel"></span></div>';
			hidden_value = first_value+'--'+last_value+'=='+time_from+'-'+time_till+'|';
		} else if ( ordered == 'not_ordered' ) {
			var day_names = '';
			jQuery.each(hop_indexes, function(index, label_index) {
				day_names += jQuery(jQuery('.db-hop-dialog .db-hop-left label').get( label_index )).find('input').val()+', ';
			});
			appendable_html = '<div class="db-hop-day-row"><span class="db-hop-day-names">'+day_names.slice(0,-2)+'</span><span class="db-hop-day-times">'+time_from+' - '+time_till+'</span><span class="db-hop-remove dbicon-cancel"></span></div>';
			hidden_value = day_names.slice(0,-2)+'=='+time_from+'-'+time_till+'|';
		}
		jQuery('.db-hop-time-container').append(appendable_html);
		jQuery('.db-hop-time-container input[type="hidden"]').val(jQuery('.db-hop-time-container input[type="hidden"]').val()+hidden_value);

		jQuery('.db-hop-dialog .db-hop-left label.active input').prop('checked', false);
		jQuery('.db-hop-dialog .db-hop-left label.active').removeClass('active');
		jQuery('.db-hop-from').val('');
		jQuery('.db-hop-till').val('');
		jQuery('.db-hop-dialog').hide();
	});

	jQuery(document).on('click', '.db-hop-remove', function() {
		var time_parent = jQuery(this).parent();
		var day_value = time_parent.find('.db-hop-day-names').html();
		day_value = day_value.replace(' - ', '--');
		var time_value = time_parent.find('.db-hop-day-times').html();
		time_value = time_value.replace(' - ', '-');

		var old_value = jQuery('.db-hop-time-container input[type="hidden"]').val();
		var new_value = old_value.replace(day_value+'=='+time_value+'|', '');
		jQuery('.db-hop-time-container input[type="hidden"]').val(new_value);

		jQuery(this).parent().remove();

		whitelab_check_active_hop();
	});

	jQuery(document).on('click', function(e) {
		if ( !jQuery(e.target).hasClass('db-add-new-hop') ) {
			if ( jQuery('.db-hop-dialog').css('display') == 'block' ) {
				jQuery(".db-hop-dialog").hide();
			}
		}
	});

	jQuery(".db-hop-dialog").click(function(e) {
		if ( !jQuery(e.target).hasClass('db-hop-add-time') ) {
			e.stopPropagation();
		}
	});

	function whitelab_calculate_side_height() {
		if ( jQuery('.db-search-side-two.left').length || jQuery('.db-search-side-two.right').length ) {
			var header = jQuery('header.site-header').outerHeight() + 26;
			var search = jQuery('.db-search-controls').outerHeight();
			var showmore = jQuery('.db-show-more-fields').outerHeight() + parseInt( jQuery('.db-show-more-fields').css('margin-bottom').replace('px', 'px') ) + 13;
			if ( !jQuery('body').hasClass('admin-bar') ) {
				header -= 32;
			}

			var custom_val = 0;
			if ( jQuery('.db-search-side-two').hasClass('db-show-pagination') ) {
				custom_val = 30;
			}

			if ( !jQuery('#whitelab-search-height').length ) {
				jQuery('body').append('<style type="text/css" id="whitelab-search-height">@media (min-width: 992px) {body .db-main-search-listings{height: calc(100vh - '+(header+search+showmore+custom_val)+'px) !important;}}</style>');
			} else {
				jQuery('body #whitelab-search-height').html('@media (min-width: 992px) {body .db-main-search-listings{height: calc(100vh - '+(header+search+showmore+custom_val)+'px) !important;}}');
			}
		}
	}

	whitelab_calculate_side_height();

	jQuery(document).on('click', '.db-autolocate-me', function() {
		var geolocate_button = jQuery(this);
		var geolocation_field = jQuery(this).prev();

		if ( navigator.geolocation ) {
			navigator.geolocation.getCurrentPosition(function( position ) {
				jQuery.get('https://maps.googleapis.com/maps/api/geocode/json?address='+encodeURIComponent(position.coords.latitude+','+position.coords.longitude)+'&language=en', function( data ) {
					if ( data.status == 'OK' ) {
						geolocation_field.val( data.results['0'].formatted_address );

						if ( jQuery('.db-set-address').length ) {
							jQuery('.db-set-address').click();
						}
					} else {
						if ( data.status == 'OVER_QUERY_LIMIT' ) {
							alert('You\'re over your API query limit!');
						} else if ( data.status == 'REQUEST_DENIED' ) {
							alert('Seems like your address request was denied by Google!');
						} else {
							alert('Something went wrong while contacting Google!');
						}
					}
				});
			}, function( error ) {
				console.log('Failed to geolocate your location');
			}, { timeout: 30000, enableHighAccuracy: true });
		} else {
			alert('Your browser doesn\'t support geolocation');
		}
	});

	jQuery(document).on('change', '.db-pricing-main-wrapper.default [name="listing_package"]', function() {
		var current_package = jQuery(this).val();

		jQuery.ajax({
			type: 'POST',
			url: db_main.ajaxurl,
			data: { 
				'action': 'db_get_current_package',
				'package_id': current_package
			},
			success: function( data ) {
				var parsed_resp = jQuery.parseJSON(data);
				if ( parsed_resp.status == 'success' ) {
					if ( parsed_resp.fee_amount != '0' ) {
						jQuery('[name="custom"]').val(jQuery('[name="db-listing-id"]').val()+':'+parsed_resp.author+':author');
						jQuery('[name="db-package-fee"], [name="a3"], [name="amount"]').val(parsed_resp.fee_amount);
						jQuery('[name="item_name"]').val(parsed_resp.fee_label);

						if ( parsed_resp.payment_type == 'onetime' ) {
							jQuery('[name="cmd"]').val('_xclick');
						} else {
							jQuery('[name="cmd"]').val('_xclick-subscriptions');
							jQuery('[name="p3"]').val(parsed_resp.payment_interval);
							jQuery('[name="t3"]').val(parsed_resp.payment_cycle.charAt(0).toUpperCase());
						}

						jQuery('.db-main-checkout-wrapper').addClass('db-animate-dialog');
						setTimeout(function() {
							jQuery('.db-main-checkout-wrapper').next().addClass('overlay-shown');
						}, 150);
					} else {
						jQuery.ajax({
							type: 'POST',
							url: db_main.ajaxurl,
							data: { 
								'action': 'db_save_claim',
								'listing_id': jQuery('[name="db-listing-id"]').val(),
								'package_id': current_package,
							},
							success: function(data) {
								var parsed_resp = jQuery.parseJSON(data);
								if ( jQuery.isNumeric(parsed_resp.save_response) ) {
									window.location = window.location.href.replace('?db-claim', '');
								} else {
									alert('There was an issue while saving the claimed data!');
								}
							}
						});
					}
				}
			}
		});
	});

	jQuery(document).on('click', '.db-checkout-item', function() {
		jQuery('.db-checkout-select .db-checkout-item').removeClass('active');
		jQuery(this).addClass('active');

		jQuery('.db-checkout-option').hide();

		if ( jQuery(this).attr('data-type') == 'credit-card' ) {
			jQuery('.db-checkout-option.credit-card > form').attr('id', 'authorize_form');
		} else if ( jQuery(this).attr('data-type') == 'stripe' ) {
			jQuery('.db-checkout-option.stripe > form').attr('id', 'stripe_form');
		}
		jQuery('.db-checkout-option.'+jQuery(this).attr('data-type')).show();
	});

	jQuery(document).on('submit', '#authorize_form', function(e) {
		e.preventDefault();

		var all_fields = {};
		jQuery('#authorize_form .db-checkout-left [name]').each(function() {
			all_fields[jQuery(this).attr('name')] = jQuery(this).val();
		});

		var card_fields = {};
		jQuery('#authorize_form .db-checkout-right [name]').each(function() {
			card_fields[jQuery(this).attr('name')] = jQuery(this).val();
		});

		jQuery('#authorize_form .db-checkout-proceed').addClass('loading-effect');

		jQuery.ajax({
			type: 'POST',
			url: db_main.ajaxurl,
			data: { 
				'action': 'db_save_billing',
				'field_data': JSON.stringify(all_fields),
				'card_data': JSON.stringify(card_fields),
				'listing_id': jQuery('[name="db-listing-id"]').val(),
				'gateway': 'authorizenet'
			},
			success: function(data) {
				var parsed_resp = jQuery.parseJSON(data);
				if ( jQuery.isNumeric(parsed_resp.save_response) ) {
					window.location.replace(jQuery('.db-main-checkout').attr('data-return'));
				} else {
					if ( jQuery('#authorize_form .db-checkout-proceed .db-checkout-error').length ) {
						jQuery('#authorize_form .db-checkout-proceed .db-checkout-error').html(parsed_resp.message);
					} else {
						jQuery('#authorize_form .db-checkout-proceed').prepend('<span class="db-checkout-error">'+parsed_resp.message+'</span>')
					}
					jQuery('#authorize_form .db-checkout-proceed').removeClass('loading-effect');
				}
			}
		});
	});

	jQuery(document).on('submit', '#stripe_form', function(e) {
		e.preventDefault();

		var all_fields = {};
		jQuery('#stripe_form .db-checkout-left [name]').each(function() {
			all_fields[jQuery(this).attr('name')] = jQuery(this).val();
		});

		var card_fields = {};
		jQuery('#stripe_form .db-checkout-right [name]').each(function() {
			card_fields[jQuery(this).attr('name')] = jQuery(this).val();
		});

		jQuery('#stripe_form .db-checkout-proceed').addClass('loading-effect');

		jQuery.ajax({
			type: 'POST',
			url: db_main.ajaxurl,
			data: { 
				'action': 'db_save_billing',
				'field_data': JSON.stringify(all_fields),
				'card_data': JSON.stringify(card_fields),
				'listing_id': jQuery('[name="db-listing-id"]').val(),
				'gateway': 'stripe'
			},
			success: function(data) {
				var parsed_resp = jQuery.parseJSON(data);
				if ( jQuery.isNumeric(parsed_resp.save_response) ) {
					window.location.replace(jQuery('.db-main-checkout').attr('data-return'));
				} else {
					if ( jQuery('#stripe_form .db-checkout-proceed .db-checkout-error').length ) {
						jQuery('#stripe_form .db-checkout-proceed .db-checkout-error').html(parsed_resp.message);
					} else {
						jQuery('#stripe_form .db-checkout-proceed').prepend('<span class="db-checkout-error">'+parsed_resp.message+'</span>')
					}
					jQuery('#stripe_form .db-checkout-proceed').removeClass('loading-effect');
				}
			}
		});
	});

	jQuery(document).on('click', '.db-pricing-main-wrapper.default .db-checkout-close', function() {
		jQuery('.db-main-checkout-wrapper').removeClass('db-animate-dialog');
		jQuery('.db-main-checkout-wrapper').next().removeClass('overlay-shown');
	});

	jQuery(document).on('input', 'input[type="date"]', function() {
		var current_value = jQuery(this).val();
		var parsed_values = jQuery(this).val().split('-');

		if ( parsed_values['0'].length > 4 ) {
			var new_date = parsed_values['0'].slice(0,4) + '-' + parsed_values['1'] + '-' + parsed_values['2'];
			jQuery(this).val(new_date);
		}
	});

	jQuery(document).on('click', '.db-switch-inner', function() {
		jQuery(this).toggleClass('active');

		if ( jQuery('.db-field-time-row .db-switch-inner').hasClass('active') ) { // 24h
			jQuery('input[name="hop_format"][value="24h"]').prop('checked', true);
			jQuery('input[name="hop_format"][value="12h"]').prop('checked', false);

			whitelab_recheck_timeformat( '24h' );
		} else { // 12h
			jQuery('input[name="hop_format"][value="12h"]').prop('checked', true);
			jQuery('input[name="hop_format"][value="24h"]').prop('checked', false);

			whitelab_recheck_timeformat( '12h' );
		}

		set_hop_masks();
		whitelab_check_active_hop();
	});

	jQuery(document).on('change', '#listing_time_zone', function() {
		whitelab_check_active_hop();
	});

	function whitelab_recheck_timeformat( time_format ) {
		jQuery('.db-hop-day-row .db-hop-day-times').each(function() {
			var starting_time_obj = new Date(jQuery(this).attr('data-open')*1000);
			var starting_time = (starting_time_obj.getUTCHours()<10?'0':'')+starting_time_obj.getUTCHours()+':'+(starting_time_obj.getUTCMinutes()<10?'0':'')+starting_time_obj.getUTCMinutes();
			var ending_time_obj = new Date(jQuery(this).attr('data-close')*1000);
			var ending_time = (ending_time_obj.getUTCHours()<10?'0':'')+ending_time_obj.getUTCHours()+':'+(ending_time_obj.getUTCMinutes()<10?'0':'')+ending_time_obj.getUTCMinutes();
			if ( time_format == '12h' ) {
				var starting_time = whitelab_time_to_12h( starting_time );
				var ending_time = whitelab_time_to_12h( ending_time );
			}
			jQuery(this).text(starting_time+' - '+ending_time);
		});
	}

	function whitelab_time_to_12h(time) {
		time = time.toString ().match (/^([01]\d|2[0-3])(:)([0-5]\d)(:[0-5]\d)?$/) || [time];

		if (time.length > 1) {
			time = time.slice (1);
			time[5] = +time[0] < 12 ? ' AM' : ' PM';
			time[0] = +time[0] % 12 || 12;
		}
		return time.join ('');
	}

	jQuery(document).on('click', '.db-simple-switch span', function() {
		if ( jQuery(this).attr('data-type') == '24h' ) {
			jQuery('input[name="hop_format"][value="24h"]').prop('checked', true);
			jQuery('input[name="hop_format"][value="12h"]').prop('checked', false);
			jQuery(this).parent().find('.db-switch-inner').addClass('active');

			whitelab_recheck_timeformat( '24h' );
		} else {
			jQuery('input[name="hop_format"][value="12h"]').prop('checked', true);
			jQuery('input[name="hop_format"][value="24h"]').prop('checked', false);
			jQuery(this).parent().find('.db-switch-inner').removeClass('active');

			whitelab_recheck_timeformat( '12h' );
		}

		set_hop_masks();
		whitelab_check_active_hop();
	});

	function db_get_current_timestamp() {
		var current_date = new Date();
		var curr_time = current_date.getHours()+':'+current_date.getMinutes();

		var current_offset = parseInt(-current_date.getTimezoneOffset() / 60);
		if ( current_offset >= 0 ) {
			var current_utc = 'UTC+'+current_offset;
		} else {
			var current_utc = 'UTC'+current_offset;
		}

		var weekday = new Array();
			weekday[1] = '05';
			weekday[2] = '06';
			weekday[3] = '07';
			weekday[4] = '08';
			weekday[5] = '09';
			weekday[6] = '10';
			weekday[0] = '11';

		var curr_day = weekday[current_date.getUTCDay()];
		return (new Date('1970-01-'+curr_day+' '+curr_time+' UTC').getTime()/1000) + db_convert_utc( current_utc );
	}

	jQuery(document).on('click', '.dt-only-opened', function() {
		var all_search_fields = {};
		jQuery('[class^="db-search-"]').each(function() {
			var setting_name = jQuery(this).attr('class').replace('db-search-', '').replace('-', '_');
			if ( setting_name == 'sort' || jQuery(this).hasClass('db-search-sort') ) {
				return true;
			}
			if ( jQuery(this).attr('type') != 'checkbox' ) {
				if ( jQuery(this).val() != '' ) {
					all_search_fields[setting_name] = jQuery(this).val();
				}
			} else {
				all_search_fields[setting_name] = jQuery(this).prop('checked');
			}
		});
		jQuery('[id^="db-search-"]').each(function() {
			var setting_name = jQuery(this).attr('id').replace('db-search-', '').replace('-', '_');
			if ( setting_name == 'sort' ) {
				return true;
			}
			if ( jQuery(this).attr('type') != 'checkbox' ) {
				if ( jQuery(this).val() != '' ) {
					all_search_fields[setting_name] = jQuery(this).val();
				}
			} else {
				all_search_fields[setting_name] = jQuery(this).prop('checked');
			}
		});

		delete all_search_fields['listing_search_radius'];
		
		if ( Object.keys(all_search_fields).length > 1 ) {
			jQuery(this).toggleClass('active');
			if ( jQuery(this).next().val() != '' ) {
				jQuery(this).next().val('');
			} else {
				var utc_time = db_get_current_timestamp();
				jQuery(this).next().val(utc_time);
			}
			jQuery('.db-find-listings').click();
		}
	});

	function db_convert_utc( utc ) {
		var utc_offset = utc.substr(4);
		var utc_delimiter = utc.substr(3, 1);
		var offset = 3600 * parseFloat(utc_offset);

		if ( utc_delimiter == '+' ) {
			offset = 0 - offset;
		}

		return offset;
	}

	if ( jQuery('.db-single-opening-hours.realtime-ready').length ) {
		var weekday = new Array();
			weekday[1] = 'mon';
			weekday[2] = 'tue';
			weekday[3] = 'wed';
			weekday[4] = 'thu';
			weekday[5] = 'fri';
			weekday[6] = 'sat';
			weekday[0] = 'sun';
		var current_date = new Date();
		var curr_day = weekday[current_date.getUTCDay()];

		var user_time = db_get_current_timestamp() - db_convert_utc(jQuery('.db-single-opening-hours.'+curr_day).attr('data-utc'));
		var opening = parseInt(jQuery('.db-single-opening-hours.'+curr_day).attr('data-open'));
		var closing = parseInt(jQuery('.db-single-opening-hours.'+curr_day).attr('data-close'));

		if ( opening <= user_time && closing > user_time ) {
			jQuery('.db-single-opening-hours.'+curr_day).addClass('opened');
		} else {
			jQuery('.db-single-opening-hours.'+curr_day).addClass('closed');
		}
	}

	jQuery(document).on('click', '.db-review-yes, .db-review-no', function() {
		var comment_id = jQuery(this).parent().parent().attr('data-id');
		var helpful = jQuery(this).attr('class').replace('db-review-', '');
		var note = jQuery(this).parent().parent().find('.db-review-note');
		var wasit = jQuery(this).parent().parent().find('.db-review-was-it');
		var help_action = jQuery(this).parent().parent().find('.db-review-action');
		var helpful_parent = jQuery(this).parent().parent();

		if ( !helpful_parent.hasClass('processing') ) {
			helpful_parent.addClass('processing');

			jQuery.ajax({
				type: 'POST',
				url: db_main.ajaxurl,
				data: { 
					'action': 'db_review_helpful',
					'comment_id': comment_id,
					'helpful':helpful
				},
				success: function( data ) {
					var parsed_resp = jQuery.parseJSON(data);
					if ( parsed_resp.status === true ) {
						note.text(parsed_resp.response);
						help_action.remove();
						wasit.remove();
					}
					helpful_parent.removeClass('processing');
				}
			});		
		}
	});

	jQuery(document).on('click', '.advanced-images', function() {
		jQuery('.db-dialog-overlay').addClass('overlay-shown');
		jQuery(this).next().addClass('active');
	});

	jQuery(document).on('click', '*', function(e) {
		if ( jQuery('.db-review-photos').hasClass('active') ) {
			if ( !jQuery(e.target).hasClass('db-review-photos') && !jQuery(e.target).hasClass('dz-hidden-input') && !jQuery(e.target).hasClass('advanced-images') && !jQuery(e.target).closest('.db-review-photos').length ) {
				jQuery('.db-dialog-overlay').removeClass('overlay-shown');
				jQuery('.db-review-photos').removeClass('active');
			}
		}
	});

	if ( jQuery('.dropzone-review-images').length ) {
		jQuery('div.dropzone-review-images').dropzone({
			url: db_main.ajaxurl,
			maxFiles: 5,
			acceptedFiles: '.jpg,.jpeg,.gif,.png',
			addRemoveLinks: true,
			dictRemoveFile: 'Remove image',
			thumbnailWidth: 150,
			thumbnailHeight: 150,
			init: function() {
				this.on('sending', function(file, xhr, formData) {
					formData.append('action', 'db_upload_images');
					formData.append('valid', 'false');
				});
			},
			success: function(file, response) {
				var parsed_response = jQuery.parseJSON(response);
				var image_count = jQuery('[name="review_images"]').val().split('|').length-1;
				var current_image = jQuery(jQuery(this)['0'].files[image_count].previewElement);

				if ( parsed_response.save_status == 'true' ) {
					current_image.addClass('dz-success').removeClass('dz-error');
					jQuery('[name="review_images"]').val(jQuery('[name="review_images"]').val()+parsed_response.attachment_id+'|');
					current_image.attr('data-id', parsed_response.attachment_id);
				} else if ( parsed_response.save_status == 'false' ) {
					current_image.removeClass('dz-success').addClass('dz-error');
					current_image.find('.dz-error-message span').html(parsed_response.save_msg);
					current_image.attr('data-id', '0');
				}
			},
			removedfile: function(removed) {
				var removed_image = jQuery(removed.previewElement);
				var current_images = jQuery('[name="review_images"]').val();
				if ( current_images.indexOf( removed_image.attr('data-id') + '|' ) >= 0 ) {
					jQuery('[name="review_images"]').val( current_images.replace( removed_image.attr('data-id') + '|', '' ) );
				}
				jQuery(removed.previewElement).remove();
			}
		});
	}

	if ( jQuery('.db-review-image-gallery').length ) {
		jQuery('.db-review-image-gallery').prettyPhoto({ social_tools: false });
	}

	jQuery(document).on('click', '.hop-remove-old', function() {
		if ( confirm('Are you sure you want to delete the old format?') === true ) {
			jQuery('.db-hop-notice').remove();
			jQuery('input[name="hop"]').val('');
		}
	});

	var $idle_timer3;
	jQuery(document).on('input', '.dt-header-search-inner .dt-search-listing_keyword', function() {
		clearTimeout($idle_timer3);
		var keyword_value = jQuery(this).val();
		var keyword_row = jQuery(this).parent();

		if ( jQuery(this).val().length >= 2 ) {
			keyword_row.addClass('loading');
			$idle_timer3 = setTimeout(function() {
				$.ajax({
					type: 'POST',
					url: db_main.keyword_ajaxurl,
					data: { 
						'action': 'db_keyword_autocomplete',
						'keyword_value': keyword_value
					},
					dataType: 'json',
					success: function( data ) {
						jQuery('.dt-search-row.listing-keyword').find('span.db-autocomplete-item').each(function() {
							var category_name = jQuery(this).text().toLowerCase();
							if ( category_name.indexOf(keyword_value.toLowerCase()) >= 0 ) {
								jQuery(this).addClass('visible');
								jQuery(this).show();
							} else {
								jQuery(this).removeClass('visible');
								jQuery(this).hide();
							}
						});

						keyword_row.find('.db-row-autocomplete a.db-autocomplete-item').remove();

						if ( data !== false ) {
							jQuery.each(data, function( index, value ) {
								var image_field = '<span class="db-keyword-image" style="background: url('+value.img+') no-repeat"></span>';
								keyword_row.find('.db-row-autocomplete .db-autocomplete-items').append('<a href="'+db_main.homeurl+'?p='+value.id+'" class="db-autocomplete-item'+(index==0?' first':'')+'">'+image_field+'<span class="db-keyword-data"><span>'+value.title+'</span><span>'+value.address+'</span></span></a>');
							});
						} else {
							if ( !jQuery('.dt-search-row.listing-keyword').find('span.db-autocomplete-item.visible').length ) {
								keyword_row.find('.db-row-autocomplete .db-autocomplete-items .db-autocomplete-item.not-active').remove();
								keyword_row.find('.db-row-autocomplete .db-autocomplete-items').append('<span class="db-autocomplete-item not-active">Nothing found!</span>');
							}
						}
						keyword_row.find('.db-row-autocomplete').addClass('active');

						keyword_row.removeClass('loading');

						db_keyword_scroll();
					}
				});
			}, 250);
		} else {
			jQuery('.dt-search-row.listing-keyword').find('.db-row-autocomplete .db-autocomplete-items .db-autocomplete-item.not-active').remove();
			jQuery('.dt-search-row.listing-keyword').find('span.db-autocomplete-item').show();
			jQuery('.dt-search-row.listing-keyword').find('span.db-autocomplete-item').addClass('visible');
			jQuery('.dt-search-row.listing-keyword').find('.db-row-autocomplete a.db-autocomplete-item').remove();

			db_keyword_scroll();
		}
	});

	jQuery(document).on('click', '.dt-search-listing_keyword', function() {
		if ( jQuery(this).val() == '' ) {
			jQuery(this).parent().find('.db-row-autocomplete span.db-autocomplete-item').show();
		}
		jQuery(this).parent().find('.db-row-autocomplete').addClass('active');

		db_keyword_scroll();
	});

	function db_keyword_scroll() {
		var keyword_row = jQuery('.dt-search-row.listing-keyword');
		if ( keyword_row.find('.db-autocomplete-items')[0].scrollHeight < 220 ) {
			keyword_row.find('.db-autocomplete-scrollbar').hide();
		} else {
			keyword_row.find('.db-autocomplete-scrollbar').show();
		}

		keyword_row.find('.db-autocomplete-items').bind('scroll', function() {
			var scrolled_percentage = jQuery(this).scrollTop()/(jQuery(this)[0].scrollHeight-jQuery(this).innerHeight())*100;
			var extra_scroll = jQuery(this).parent().parent().find('.db-autocomplete-scrollbar').height()*(scrolled_percentage/100);
			var scroll_height = 'calc('+scrolled_percentage+'% - '+extra_scroll+'px)';
			jQuery(this).parent().parent().find('.db-autocomplete-scrollbar').css('top', scroll_height);
		});

		keyword_row.find('.db-autocomplete-scrollbar').css('height', keyword_row.find('.db-autocomplete-items')[0].offsetHeight*(keyword_row.find('.db-autocomplete-items')[0].offsetHeight/keyword_row.find('.db-autocomplete-items')[0].scrollHeight));
	}

	jQuery(document).on('click', '.db-book-now', function() {
		var time_wrapper = jQuery(this).parent().find('.db-booking-time');
		var curr_year = time_wrapper.attr('data-y');
		var curr_month = time_wrapper.attr('data-m');
		db_fill_booking_calendar( time_wrapper, curr_year, curr_month );

		if ( jQuery('.db-booking-wrapper').hasClass('initial') ) {
			db_check_clock( 'initial' );
		} else {
			jQuery('.db-booking-time').addClass('active');
		}
	});

	jQuery(document).on('click', '.db-booking-time-item:not(.active):not(.closed)', function() {
		jQuery('.db-booking-time-item').removeClass('active');
		jQuery('.db-booking-time').attr('data-selected', jQuery(this).text());
		jQuery(this).addClass('active');

		db_slide_calendar();
	});

	jQuery(document).on('click', '.db-booking-month-prev', function() {
		var time_wrapper = jQuery(this).parent().parent();
		var curr_year = parseInt(time_wrapper.attr('data-y'));
		var curr_month = parseInt(time_wrapper.attr('data-m'))-1;

		if ( curr_month == 0 ) {
			curr_month = 12;
			curr_year--;
		}

		db_fill_booking_calendar( time_wrapper, curr_year, curr_month );
		time_wrapper.attr('data-m', curr_month);
		time_wrapper.attr('data-y', curr_year);

		var current_time = new Date();
		if ( curr_month == current_time.getMonth()+1 ) {
			jQuery('.db-booking-month-prev').addClass('hidden');
		}
	});

	jQuery(document).on('click', '.db-booking-month-next', function() {
		var time_wrapper = jQuery(this).parent().parent();
		var curr_year = parseInt(time_wrapper.attr('data-y'));
		var curr_month = parseInt(time_wrapper.attr('data-m'))+1;

		if ( curr_month == 13 ) {
			curr_month = 1;
			curr_year++;
		}

		db_fill_booking_calendar( time_wrapper, curr_year, curr_month );
		time_wrapper.attr('data-m', curr_month);
		time_wrapper.attr('data-y', curr_year);

		jQuery('.db-booking-month-prev').removeClass('hidden');
	});

	function db_fill_booking_calendar( time_wrapper, curr_year, curr_month ) {
		var selected_date = time_wrapper.attr('data-selected');
		var actual_days = new Date(curr_year, curr_month, '0');
		var month = db_main.booking_months;
		var weekday = db_main.booking_weeks;
		time_wrapper.find('.db-booking-month').html(month[actual_days.getMonth()]);
		time_wrapper.find('.db-booking-times').html('');
		var closed_days = jQuery('.db-booking-time').attr('data-closed').split(',');
		var current_day = new Date();
		for (var day_num = 1; day_num <= actual_days.getDate(); day_num++) {
			var selected_day = new Date(curr_year, curr_month-1, day_num);
			var is_closed = false;
			if ( jQuery.inArray(weekday[selected_day.getDay()], closed_days) >= 0 ) {
				is_closed = true;
			}
			if ( day_num < current_day.getDate() && selected_day.getMonth() == current_day.getMonth() ) {
				is_closed = true;
			}
			var is_active = false;
			if ( selected_date == day_num ) {
				is_active = true;
			}

			time_wrapper.find('.db-booking-times').append('<span class="db-booking-time-item'+(is_active?' active':'')+(is_closed?' closed':'')+'" data-name="'+weekday[selected_day.getDay()]+'" data-day="'+day_num+'">'+day_num+'</span>');
		}

		if ( jQuery('.db-booking-times .db-booking-time-item.active.closed').length ) {
			if ( !jQuery('.db-booking-times .db-booking-time-item.active.closed').next().hasClass('closed') ) {
				jQuery('.db-booking-times .db-booking-time-item.active.closed').next().click();
			} else {
				jQuery('.db-booking-times .db-booking-time-item:not(.closed)').first().click();
			}	
		}

		if ( !jQuery('.db-booking-times .db-booking-time-item.active').length ) {
			jQuery('.db-booking-times .db-booking-time-item:not(.closed)').first().click();
		}

		db_slide_calendar();
	}

	function db_slide_calendar() {
		if ( jQuery('.db-booking-time-item.active').index() >= 2 ) {
			var offset = (jQuery('.db-booking-time-item.active').index()-2)*70;
		} else {
			var offset = 0;
		}
		
		jQuery('.db-booking-times').css('left', '-'+offset+'px');
	}

	jQuery(document).on('click', '.db-booking-time-next', function() {
		jQuery('.db-booking-time').removeClass('active');
		jQuery('.db-booking-info').addClass('active');
	});

	jQuery(document).on('click', '.db-booking-info-send', function() {
		jQuery('.db-booking-info form input[type="submit"]').click();
	});

	jQuery(document).on('submit', '.db-booking-info form', function(e) {
		e.preventDefault();
		var info_wrapper = jQuery(this).parent();

		if ( !info_wrapper.hasClass('processing') ) {
			info_wrapper.addClass('processing');

			var all_booking_data = {};
			all_booking_data['listing_id'] = jQuery('.db-booking-wrapper').attr('data-id');
			all_booking_data['date'] = jQuery('.db-booking-time').attr('data-y')+'-'+jQuery('.db-booking-time').attr('data-m')+'-'+jQuery('.db-booking-time').attr('data-selected');
			all_booking_data['time'] = jQuery('.db-booking-clock').attr('data-h')+':'+jQuery('.db-booking-clock').attr('data-m')+(jQuery('.db-booking-time-format').length?' '+jQuery('.db-booking-time-format').text():'');
			all_booking_data['name'] = jQuery('.db-booking-name').val();
			all_booking_data['email'] = jQuery('.db-booking-email').val();
			all_booking_data['comments'] = jQuery('.db-booking-comments').val();

			jQuery.ajax({
				type: 'POST',
				url: db_main.ajaxurl,
				data: { 
					'action': 'db_book_listing',
					'db-settings': JSON.stringify(all_booking_data)
				},
				dataType: 'json',
				success: function(data) {
					if ( data.status ) {
						var booking_date = new Date(parseInt(data.booking)*1000);

						var month = new Array();
							month[0] = "January";
							month[1] = "February";
							month[2] = "March";
							month[3] = "April";
							month[4] = "May";
							month[5] = "June";
							month[6] = "July";
							month[7] = "August";
							month[8] = "September";
							month[9] = "October";
							month[10] = "November";
							month[11] = "December";

						var weekday = new Array(7);
							weekday[0] =  "Sunday";
							weekday[1] = "Monday";
							weekday[2] = "Tuesday";
							weekday[3] = "Wednesday";
							weekday[4] = "Thursday";
							weekday[5] = "Friday";
							weekday[6] = "Saturday";

						jQuery('.db-booking-appointment').attr('data-for', month[booking_date.getMonth()]+', '+weekday[booking_date.getDay()]+' '+db_ordinal_suffix_of(booking_date.getUTCDate()));

						jQuery('.db-booking-app-time').attr('data-h', booking_date.getUTCHours());
						jQuery('.db-booking-app-time').attr('data-m', booking_date.getUTCMinutes());

						if ( !jQuery('.db-booking-time-format').length ) {
							jQuery('.db-booking-app-time').attr('data-h', booking_date.getUTCHours());
							jQuery('.db-booking-app-time').attr('data-m', (booking_date.getUTCMinutes()<10?'0'+booking_date.getUTCMinutes():booking_date.getUTCMinutes()));
						} else {
							var hours = booking_date.getUTCHours();
							var minutes = booking_date.getUTCMinutes();
							var ampm = hours >= 12 ? 'pm' : 'am';
							hours = hours % 12;
							hours = hours ? hours : 12;
							minutes = minutes < 10 ? '0'+minutes : minutes;

							jQuery('.db-booking-app-time').attr('data-h', hours);
							jQuery('.db-booking-app-time').attr('data-m', minutes);
							if ( !jQuery('.db-booking-completed .db-booking-app-format').length ) {
								jQuery('.db-booking-completed .db-booking-app-time').after('<span class="db-booking-app-format">'+ampm+'</span>');
							} else {
								jQuery('.db-booking-completed .db-booking-app-format').text(ampm);
							}
						}

						jQuery('.db-booking-info').removeClass('active');
						jQuery('.db-booking-completed').addClass('active');
					} else {
						info_wrapper.removeClass('processing');
					}
				}
			});
		}
	});

	function db_ordinal_suffix_of(i) {
		var j = i % 10,
			k = i % 100;
		if (j == 1 && k != 11) {
			return i + "st";
		}
		if (j == 2 && k != 12) {
			return i + "nd";
		}
		if (j == 3 && k != 13) {
			return i + "rd";
		}
		return i + "th";
	}

	jQuery(document).on('click', '.db-booking-clock-next', function() {
		db_check_clock( 'plus' );
	});

	jQuery(document).on('click', '.db-booking-clock-prev', function() {
		db_check_clock( 'minus' );
	});

	function db_check_clock( method ) {
		jQuery.ajax({
			type: 'POST',
			url: db_main.booking_ajaxurl,
			data: { 
				'action': 'db_booking_clock',
				'db_id': jQuery('.db-booking-wrapper').attr('data-id'),
				'db_date': jQuery('.db-booking-time').attr('data-y')+'-'+jQuery('.db-booking-time').attr('data-m')+'-'+jQuery('.db-booking-time').attr('data-selected')+' '+jQuery('.db-booking-clock').attr('data-h')+':'+jQuery('.db-booking-clock').attr('data-m')+(jQuery('.db-booking-time-format').length?' '+jQuery('.db-booking-time-format').text():''),
				'db_method': method
			},
			dataType: 'json',
			success: function(data) {
				var new_date = new Date(parseInt(data.next_date)*1000);

				var select_dates = false;
				if ( new_date.getUTCDate() != jQuery('.db-booking-time').attr('data-selected') ) {
					select_dates = true;
				}

				jQuery('.db-booking-time').attr('data-y', new_date.getUTCFullYear());
				jQuery('.db-booking-time').attr('data-m', new_date.getUTCMonth()+1);
				jQuery('.db-booking-time').attr('data-selected', new_date.getUTCDate());

				if ( !jQuery('.db-booking-time-format').length ) {
					jQuery('.db-booking-clock').attr('data-h', new_date.getUTCHours());
					jQuery('.db-booking-clock').attr('data-m', (new_date.getUTCMinutes()<10?'0'+new_date.getUTCMinutes():new_date.getUTCMinutes()));
				} else {
					var hours = new_date.getUTCHours();
					var minutes = new_date.getUTCMinutes();
					var ampm = hours >= 12 ? 'pm' : 'am';
					hours = hours % 12;
					hours = hours ? hours : 12;
					minutes = minutes < 10 ? '0'+minutes : minutes;

					jQuery('.db-booking-clock').attr('data-h', hours);
					jQuery('.db-booking-clock').attr('data-m', minutes);
					jQuery('.db-booking-time-format').text(ampm);
				}

				if ( select_dates === true ) {
					jQuery('.db-booking-time-item').removeClass('active');
					jQuery('.db-booking-time-item[data-day="'+new_date.getUTCDate()+'"]').addClass('active');
					db_slide_calendar();
				}

				if ( method == 'initial' ) {
					jQuery('.db-booking-time').addClass('active');
					jQuery('.db-booking-wrapper').removeClass('initial');
				}
			}
		});
	}

	jQuery(document).on('change', '#allow_bookings', function() {
		if ( jQuery(this).prop('checked') ) {
			jQuery('.db-field-row.db-booking-row').show();
		} else {
			jQuery('.db-field-row.db-booking-row').hide();
		}
	});

	jQuery(document).on('click', '.db-booking-add-to-calendar', function() {
		var myCalendar = createCalendar({
				options: {
					id: 'db-add-to-calendar-wrapper'
				},
				data: {
					title: jQuery('.db-booking-calendar-options').attr('data-title'),
					start: new Date(jQuery('.db-booking-time').attr('data-y')+'-'+jQuery('.db-booking-time').attr('data-m')+'-'+jQuery('.db-booking-time').attr('data-selected')+' '+jQuery('.db-booking-clock').attr('data-h')+':'+jQuery('.db-booking-clock').attr('data-m')+(jQuery('.db-booking-time-format').length?' '+jQuery('.db-booking-time-format').text():'')),
					duration: jQuery('.db-booking-calendar-options').attr('data-offset'),     
					address: jQuery('.db-booking-calendar-options').attr('data-address'),
					description: jQuery('.db-booking-comments').val()
				}
		});

		document.querySelector('.db-booking-calendar-options').appendChild(myCalendar);
	});

	jQuery(document).on('click', '.db-booking-not-now', function() {
		jQuery('.db-booking-completed').removeClass('active');
	});

	jQuery(document).on('click', '.db-cancel-booking', function() {
		var button = jQuery(this);

		if ( !button.hasClass('processing') && confirm('Are you sure you want to cancel this booking? User will be notified by email!') ) {
			button.addClass('processing');

			jQuery.ajax({
				type: 'POST',
				url: db_main.ajaxurl,
				data: { 
					'action': 'db_cancel_booking',
					'booking_id': button.attr('data-id')
				},
				dataType: 'json',
				success: function(data) {
					if ( data.status ) {
						button.parent().parent().parent().addClass('cancelled');
						button.after('<span class="db-curr-booking-data-item cancelled">'+button.parent().attr('data-cancelled')+'</span>');
						button.remove();
					} else {
						button.removeClass('processing');
					}
				}
			});
		}
	});

	jQuery(document).on('click', '*', function(e) {
		if ( jQuery('.db-booking-time.active, .db-booking-info.active, .db-booking-completed.active').length && !jQuery(e.target).closest('.db-booking-wrapper').length ) {
			jQuery('.db-booking-time, .db-booking-info, .db-booking-completed').removeClass('active');
		}
	});

	jQuery(document).on('click', '.db-fmenu-new-cat', function() {
		jQuery(this).before( jQuery('.db-fmenu-hidden').html() );
	});

	jQuery(document).on('click', '.db-fmenu-new-item', function() {
		jQuery(this).before( '<div class="db-fmenu-cat-item">'+jQuery('.db-fmenu-hidden .db-fmenu-cat-item').html()+'</div>' );
	});

	function db_recheck_fmenu() {
		if ( jQuery('.db-fmenu-wrapper > .db-fmenu-full-cat').length ) {
			var all_fmenu_fields = {};
			jQuery('.db-fmenu-wrapper > .db-fmenu-full-cat').each(function() {
				var current_fmenu_cat = {};
				current_fmenu_cat['name'] = jQuery(this).find('.db-fmenu-cat-name').val();

				var current_fmenu_items = {};
				jQuery(this).find('.db-fmenu-cat-item').each(function() {
					var current_fmenu_item = {};
					current_fmenu_item['name'] = jQuery(this).find('.db-fmenu-item-name').val();
					current_fmenu_item['desc'] = jQuery(this).find('.db-fmenu-item-desc').val();
					current_fmenu_item['price'] = jQuery(this).find('.db-fmenu-item-price').val();
					current_fmenu_items[jQuery(this).index()] = current_fmenu_item;
				});

				current_fmenu_cat['items'] = current_fmenu_items;
				all_fmenu_fields[jQuery(this).index()] = current_fmenu_cat;
			});

			jQuery('#listing_fmenu').val( JSON.stringify(all_fmenu_fields) );
		}
	}

	jQuery(document).on('mouseleave', '.db-fmenu-row', function() {
		db_recheck_fmenu();
	});

	jQuery(document).on('click', '.db-fmenu-open', function() {
		if ( jQuery('.db-fmenu-full').find('.db-fmenu-full-inner')[0].scrollHeight <= 580 ) {
			jQuery('.db-fmenu-full').find('.db-autocomplete-scrollbar').hide();
			jQuery('.db-fmenu-full').removeClass('has-scrollbar');
		} else {
			jQuery('.db-fmenu-full').find('.db-autocomplete-scrollbar').show();
			jQuery('.db-fmenu-full').addClass('has-scrollbar');
		}

		jQuery('.db-fmenu-full').find('.db-fmenu-full-inner').bind('scroll', function() {
			var scrolled_percentage = jQuery(this).scrollTop()/(jQuery(this)[0].scrollHeight-jQuery(this).innerHeight())*100;
			var extra_scroll = jQuery(this).parent().parent().find('.db-autocomplete-scrollbar').height()*(scrolled_percentage/100);
			var scroll_height = 'calc('+scrolled_percentage+'% - '+extra_scroll+'px)';
			jQuery(this).parent().parent().find('.db-autocomplete-scrollbar').css('top', scroll_height);
		});

		jQuery('.db-fmenu-full').find('.db-autocomplete-scrollbar').css('height', jQuery('.db-fmenu-full').find('.db-fmenu-full-inner')[0].offsetHeight*(jQuery('.db-fmenu-full').find('.db-fmenu-full-inner')[0].offsetHeight/jQuery('.db-fmenu-full').find('.db-fmenu-full-inner')[0].scrollHeight));
		jQuery('.db-fmenu-full').addClass('active');
		jQuery('html').addClass('noscroll');
	});

	jQuery(document).on('click', '*', function(e) {
		if ( !jQuery(e.target).hasClass('db-fmenu-open') && jQuery('.db-fmenu-full').hasClass('active') && !jQuery(e.target).closest('.db-fmenu-full').length ) {
			jQuery('.db-fmenu-full').removeClass('active');
			jQuery('html').removeClass('noscroll');
		}
	});

	jQuery(document).on('click', '.db-fmenu-cat-delete', function() {
		if ( confirm('Are you sure you want to remove the whole category?') ) {
			jQuery(this).parent().remove();
			db_recheck_fmenu();
		}
	});

	jQuery(document).on('click', '.db-fmenu-cat-item-delete', function() {
		jQuery(this).parent().remove();
		db_recheck_fmenu();
	});
});

jQuery(window).load(function() {
	var $geocoder;
	var $map;
	var $first_marker;
	function db_start_geolocation() {
		$geocoder = new google.maps.Geocoder()
		$geocoder.geocode( { "address": db_main.default_location}, function(results, status) {
			if (status == google.maps.GeocoderStatus.OK) {
				db_initialize(results[0].geometry.location);
			} 
		});
	}
	
	function db_initialize(location) {
		var mapCanvas = document.getElementById("db-listing-map");
		var myLatlng = location;
		var mapOptions = {
			center: location,
			zoom: 13,
			mapTypeId: google.maps.MapTypeId.ROADMAP,
			scrollwheel: false,
			navigationControl: false,
			mapTypeControl: false,
			scaleControl: false,
			disableDefaultUI: false
		}
		if ( jQuery('body').hasClass('directory-theme') ) {
			mapOptions['styles'] = jQuery.parseJSON(my_ajax.map_style);
		}
		$map = new google.maps.Map(mapCanvas, mapOptions);

		$first_marker = new google.maps.Marker({
			position: myLatlng,
			map: $map,
			draggable: true
		});
		db_add_dragend_event( $first_marker );
	}

	function db_add_dragend_event( marker_obj ) {
		google.maps.event.addListener(marker_obj, "dragend", function (event) {
			jQuery("#listing_address_lat").val(this.getPosition().lat());
			jQuery("#listing_address_lng").val(this.getPosition().lng());
			jQuery('.db-set-address').addClass('dragged').click();
		});
	}
	if ( jQuery('#db-listing-map').length ) {
		db_start_geolocation();
	}
	jQuery(document).on("click", ".db-set-address", function() {
		var google_json_address;
		if ( !jQuery(this).hasClass('dragged') ) {
			google_json_address = encodeURIComponent( jQuery('#listing_address').val() );
		} else {
			google_json_address = encodeURIComponent( jQuery('#listing_address_lat').val()+','+jQuery('#listing_address_lng').val() );
		}
		jQuery.get('https://maps.googleapis.com/maps/api/geocode/json?address='+google_json_address+'&language=en', function( data ) {
			if ( data.status == 'OK' ) {
				$first_marker.setMap(null);
				var marker = new google.maps.Marker({ position: data.results['0'].geometry.location, map: $map, draggable: true });
				$first_marker = marker;
				db_add_dragend_event( $first_marker );

				jQuery('#listing_city, #listing_zip, #listing_neighborhood, #listing_state').val('');
				jQuery.each(data.results['0'].address_components, function( index, address_comp ) {
					if( ( address_comp.types[0] == "locality" && address_comp.types[1] == "political" ) || address_comp.types[0] == "postal_town" ) {
						jQuery('#listing_city').val( address_comp.long_name );
					}

					if( address_comp.types[0] == "country" && address_comp.types[1] == "political" ) {
						jQuery('[name="listing_country"]').val( address_comp.long_name );
						jQuery('[name="listing_country"]').parent().find('.dt-custom-select').val( address_comp.long_name );

						if ( !jQuery('[name="listing_country"]').parent().find('.dt-custom-select-item[data-value="'+address_comp.long_name+'"]').length ) {
							jQuery('[name="listing_country"]').parent().find('.dt-custom-select-items').append('<div class="dt-custom-select-item" data-value="'+address_comp.long_name+'">'+address_comp.long_name+'</div>');
						}

						jQuery('[name="listing_country"]').parent().find('.dt-custom-select-item[data-value="'+address_comp.long_name+'"]').addClass('active');
					}

					if( address_comp.types[0] == "postal_code" ) {
						jQuery('#listing_zip').val( address_comp.long_name );
					}

					if ( ( address_comp.types[0] == "administrative_area_level_1" && address_comp.types[1] == "political" ) || address_comp.types[0] == "neighborhood" && address_comp.types[1] == "political" ) {
						jQuery('#listing_neighborhood').val( address_comp.long_name );
					}

					if ( address_comp.types[0] == "administrative_area_level_2" && address_comp.types[1] == "political" ) {
						jQuery('#listing_state').val( address_comp.long_name );
					}
				});

				jQuery('#listing_address').val( data.results['0'].formatted_address );

				jQuery('#listing_address_lat').val(data.results['0'].geometry.location.lat);
				jQuery('#listing_address_lng').val(data.results['0'].geometry.location.lng);

				$map.setCenter(data.results['0'].geometry.location);
				jQuery('.db-set-address').removeClass('dragged');
			} else {
				if ( data.status == 'OVER_QUERY_LIMIT' ) {
					alert('You\'re over your API query limit!');
				} else if ( data.status == 'REQUEST_DENIED' ) {
					alert('Seems like your address request was denied by Google!');
				} else {
					alert('Your address couldn\'t be found');
				}
			}
		});
	});

	if ( jQuery('.db-find-listings').length ) {
		jQuery(document).keydown(function(e) {
			if ( e.keyCode == 13 && jQuery(e.target).closest('.db-main-search').length ) {
				jQuery('.db-find-listings').attr('data-page', '1');
				jQuery('.db-find-listings').click();
			}
		});
	}

	// Search listing map
	if ( jQuery('#db-main-search-map').length && !jQuery('#dt-main-listing-search').length ) {
		if ( jQuery('body').hasClass('page-template-template-listing_search') ) {
			jQuery('#db-main-search-map').height(jQuery('#dt-main-listing-search').outerHeight());
		}
		var mapCanvas = document.getElementById("db-main-search-map");
		var location = new google.maps.LatLng(db_main.default_location_lat, db_main.default_location_lng);
		var mapOptions = {
			center: location,
			zoom: 13,
			mapTypeId: google.maps.MapTypeId.ROADMAP,
			scrollwheel: false,
			navigationControl: false,
			mapTypeControl: false,
			scaleControl: false,
			disableDefaultUI: false
		}
		$search_map = new google.maps.Map(mapCanvas, mapOptions);
	}

	jQuery(document).on('click', '.db-delete-listing', function() {
		if ( confirm('Are you sure you want to delete this listing?') ) {
			var listing_row = jQuery(this).parent().parent();
			jQuery.ajax({
				type: 'POST',
				url: db_main.ajaxurl,
				data: { 
					'action': 'db_account_delete_listing',
					'listing_id': jQuery(this).attr('data-id')
				},
				success: function(data) {
					if ( jQuery.isNumeric(jQuery.parseJSON(data).save_response) ) {
						listing_row.remove();
					}
				}
			});
		}
	});

	if ( jQuery('.db-find-listings').length ) {
		if ( jQuery('.db-find-listings').hasClass('onload') ) {
			jQuery('.db-find-listings').click();
		} else if ( jQuery('.db-search-categories a').hasClass('onload') ) {
			jQuery('.db-search-categories a.onload').click();
		}
	}

	jQuery(document).on('submit', '#db-add-listing-form', function(e) {
		var form_validated = true;

		if ( jQuery('[name="login_user_email"]').length && !jQuery('[name="register_user_email"]').length && ( !jQuery('[name="login_user_email"]').val() || !jQuery('[name="login_user_password"]').val() ) ) {
			// Only login field present
			form_validated = false;
		} else if ( jQuery('[name="login_user_email"]').length && jQuery('[name="register_user_email"]').length ) {
			// Login and register field present
			if ( ( !jQuery('[name="login_user_email"]').val() || !jQuery('[name="login_user_password"]').val() ) && ( !jQuery('[name="register_user_email"]').val() || !jQuery('[name="register_user_password"]').val() ) ) {
				form_validated = false;
			}
		}

		if ( !form_validated ) {
			e.preventDefault();
			jQuery("html, body").animate({ scrollTop: 0 }, "slow");
			return false;
		}
	});

	if ( jQuery('#db-register-form').length ) {
		var password = jQuery('[name="register_user_password"]');
		var confirm_password = jQuery('[name="register_user_password_confirm"]');

		function db_validate_password() {
			if ( password.val() != confirm_password.val() ) {
				confirm_password.get(0).setCustomValidity("Passwords Doesn't Match");
			} else {
				confirm_password.get(0).setCustomValidity('');
			}
		}

		jQuery(document).on('change', '[name="register_user_password"]', db_validate_password);
		jQuery(document).on('input', '[name="register_user_password_confirm"]', db_validate_password);
	}



	var $idle_timer;
	jQuery(document).on('input', '[name="listing_city"]', function() {
		clearTimeout($idle_timer);
		var city_name = jQuery(this).val();
		var city_row = jQuery(this).parent();

		if ( jQuery(this).val().length >= 1 ) {
			$idle_timer = setTimeout(function() {
				jQuery.ajax({
					type: 'POST',
					url: db_main.ajaxurl,
					data: { 
						'action': 'db_city_autocomplete',
						'city_value': city_name
					},
					success: function( data ) {
						if ( !city_row.find('.db-row-autocomplete').length ) {
							city_row.append('<div class="db-row-autocomplete" data-active="listing_city"><div class="db-autocomplete-inner"><div class="db-autocomplete-items"></div><div class="db-autocomplete-scrollbar-wrapper"><span class="db-autocomplete-scrollbar"></span></div></div></div>');
						}

						city_row.find('.db-row-autocomplete .db-autocomplete-items').html('');

						if ( data != 'failed' ) {
							var parsed_data = jQuery.parseJSON( data );
							jQuery.each(parsed_data, function( index, value ) {
								city_row.find('.db-row-autocomplete .db-autocomplete-items').append('<span class="db-autocomplete-item">'+value+'</span>');
							});
						} else {
							city_row.find('.db-row-autocomplete .db-autocomplete-items').append('<span class="db-autocomplete-item not-active">Nothing found!</span>');
						}
						city_row.find('.db-row-autocomplete').addClass('active');

						if ( city_row.find('.db-autocomplete-items')[0].scrollHeight < 139 ) {
							city_row.find('.db-autocomplete-scrollbar').hide();
						} else {
							city_row.find('.db-autocomplete-scrollbar').show();
						}

						city_row.find('.db-autocomplete-items').bind('scroll', function() {
							var scrolled_percentage = jQuery(this).scrollTop()/(jQuery(this)[0].scrollHeight-jQuery(this).innerHeight())*100;
							var extra_scroll = jQuery(this).parent().parent().find('.db-autocomplete-scrollbar').height()*(scrolled_percentage/100);
							var scroll_height = 'calc('+scrolled_percentage+'% - '+extra_scroll+'px)';
							jQuery(this).parent().parent().find('.db-autocomplete-scrollbar').css('top', scroll_height);
						});

						city_row.find('.db-autocomplete-scrollbar').css('height', city_row.find('.db-autocomplete-items')[0].offsetHeight*(city_row.find('.db-autocomplete-items')[0].offsetHeight/city_row.find('.db-autocomplete-items')[0].scrollHeight));
					}
				});
			}, 500);
		} else {
			city_row.find('.db-row-autocomplete').removeClass('active');
		}
	});

	var $idle_timer2;
	jQuery(document).on('input', '.dt-header-search-inner .dt-search-listing_address, #db-add-listing-form #listing_address, .db-search-listing_address', function() {
		clearTimeout($idle_timer2);
		var address_value = jQuery(this).val();
		var address_row = jQuery(this).parent();

		if ( jQuery(this).val().length >= 1 ) {
			$idle_timer2 = setTimeout(function() {
				jQuery.ajax({
					type: 'POST',
					url: db_main.ajaxurl,
					data: { 
						'action': 'db_address_autocomplete',
						'address_value': address_value
					},
					success: function( data ) {
						if ( !address_row.find('.db-row-autocomplete').length ) {
							address_row.append('<div class="db-row-autocomplete" data-active="listing_address"><div class="db-autocomplete-inner"><div class="db-autocomplete-items"></div><div class="db-autocomplete-scrollbar-wrapper"><span class="db-autocomplete-scrollbar"></span></div></div></div>');
						}

						address_row.find('.db-row-autocomplete .db-autocomplete-items').html('');

						if ( data != 'failed' ) {
							var parsed_data = jQuery.parseJSON( data );
							jQuery.each(parsed_data, function( index, value ) {
								address_row.find('.db-row-autocomplete .db-autocomplete-items').append('<span class="db-autocomplete-item">'+value+'</span>');
							});
						} else {
							address_row.find('.db-row-autocomplete .db-autocomplete-items').append('<span class="db-autocomplete-item not-active">Nothing found!</span>');
						}
						address_row.find('.db-row-autocomplete').addClass('active');

						if ( address_row.find('.db-autocomplete-items')[0].scrollHeight < 139 ) {
							address_row.find('.db-autocomplete-scrollbar').hide();
						} else {
							address_row.find('.db-autocomplete-scrollbar').show();
						}

						address_row.find('.db-autocomplete-items').bind('scroll', function() {
							var scrolled_percentage = jQuery(this).scrollTop()/(jQuery(this)[0].scrollHeight-jQuery(this).innerHeight())*100;
							var extra_scroll = jQuery(this).parent().parent().find('.db-autocomplete-scrollbar').height()*(scrolled_percentage/100);
							var scroll_height = 'calc('+scrolled_percentage+'% - '+extra_scroll+'px)';
							jQuery(this).parent().parent().find('.db-autocomplete-scrollbar').css('top', scroll_height);
						});

						address_row.find('.db-autocomplete-scrollbar').css('height', address_row.find('.db-autocomplete-items')[0].offsetHeight*(address_row.find('.db-autocomplete-items')[0].offsetHeight/address_row.find('.db-autocomplete-items')[0].scrollHeight));
					}
				});
			}, 500);
		} else {
			address_row.find('.db-row-autocomplete').removeClass('active');
		}
	});

	jQuery(document).on('click', 'span.db-autocomplete-item', function() {
		if ( !jQuery('.dt-header-search-inner').length ) {
			jQuery('[name="'+jQuery(this).parent().parent().parent().attr('data-active')+'"]').val( jQuery(this).text() );
		} else {
			jQuery(this).closest('.dt-search-row').find('input[type="text"]').val( jQuery(this).text() );
			// jQuery('.dt-search-listing_address').val( jQuery(this).text() );
		}
		jQuery(this).parent().parent().parent().removeClass('active');
	});

	jQuery(document).on('click', '*', function(e) {
		if ( jQuery(e.target).is('input') && jQuery(e.target).parent().find('.db-row-autocomplete').length ) {
			return;
		}

		if ( jQuery('.db-row-autocomplete.active').length && !jQuery(e.target).hasClass('db-autocomplete-item') ) {
			jQuery('.db-row-autocomplete').removeClass('active');
		}
	});

	jQuery(document).on('click', '.db-show-checkout-terms', function() {
		jQuery(this).next().toggleClass('hidden');
	});
});