<?php

require('stripe/init.php');

$main_settings = get_option( 'db_main_settings');
if ( isset($main_settings['stripe_key']) && $main_settings['stripe_key'] != '' ) {
	$card_data = json_decode( stripslashes( $_POST['card_data'] ), true );
	\Stripe\Stripe::setApiKey($main_settings['stripe_key']);
	global $stripe_currency;
	$stripe_currency = (isset($main_settings['stripe_currency'])?$main_settings['stripe_currency']:'usd');

	$get_order_meta = get_post_meta( $card_data['db-listing-id'], 'db_order_info', true );
	global $wpdb;
	if ( !isset($get_order_meta['listing_package']) ) {
		$package_data = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_packages LIMIT 1');
	} else {
		$package_data = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_packages WHERE ID="'.$get_order_meta['listing_package'].'"');
	}

	if ( !empty($package_data) ) {
		$package_settings = json_decode( $package_data['0']->package_settings, true );

		$no_payment_needed = false;
		$payment_type = (isset($package_settings['payment_type'])?$package_settings['payment_type']:'onetime');
		if ( $payment_type == 'onetime' ) {
			$single_payment = db_process_single_payment( $card_data );
		} else {
			$no_payment_needed = true;
		}
	}

	if ( $no_payment_needed || ( $single_payment['paid'] === true && $single_payment['status'] == 'succeeded' ) ) {
		if ( $payment_type == 'onetime' ) {
			$all_stripe_charges = get_post_meta( $card_data['db-listing-id'], 'stripe_charges', true );
			if ( !is_array($all_stripe_charges) ) {
				$all_stripe_charges = array();
			}
			$all_stripe_charges[] = array( 'time' => $single_payment['created'], 'charge' => $single_payment['id'], 'amount' => $single_payment['amount'], 'currency' => $single_payment['currency'] );
			update_post_meta( $card_data['db-listing-id'], 'stripe_charges', $all_stripe_charges );
			$payment_status = true;
		} else {
			$payment_status = false;

			$subscription_payment = db_process_stripe_subscription( $main_settings, $card_data, $package_settings );
			if ( $subscription_payment['status'] == 'active' ) {
				$payment_status = true;

				db_update_ipn_notes( $card_data['db-listing-id'], esc_html__('Signup for subscription completed!', 'directory-builder') );

				$sub_data = array(
					'status' => 'active',
					'payment_cycle' => $package_settings['payment_cycle'],
					'payment_interval' => $package_settings['payment_interval'],
					'starting' => time(),
					'next_payment' => strtotime('+ ' . $package_settings['payment_interval'] . ' ' . $package_settings['payment_cycle']),
					'geteway' => 'Stripe'
				);
				update_post_meta( $card_data['db-listing-id'], 'db_subscription', $sub_data );
			} else {
				echo '{"save_response": "failed", "message": "'.$subscription_payment.'"}';
				die(0);
			}
		}

		if ( $payment_status ) { // Payment succeeded
			$listing_billing = get_post_meta( $card_data['db-listing-id'], 'db_billing_info', true );

			if ( $payment_type == 'onetime' ) {
				$listing_billing['balance-transaction'] = $single_payment['balance_transaction'];
			} else {
				$listing_billing['sub-id'] = $subscription_payment['id'];
			}

			$listing_billing['card'] = $card_data['x_card_num'];
			$listing_billing['card_expiration'] = $card_data['x_year']."-".$card_data['x_month'];
			update_post_meta( $card_data['db-listing-id'], 'db_billing_info', $listing_billing );

			$payment_status = 'Completed';
			$payment_amount = $card_data['db-package-fee'];
			$listing_id = $card_data['db-listing-id'];

			$order_info = get_post_meta( $listing_id, 'db_order_info', true);

			$db_listing = array(
				'ID'           => $listing_id,
				'post_status'  => 'publish'
			);

			$order_info['payment_status'] = $payment_status;
			if ( $payment_status == 'Completed' ) {
				$order_info['completed_on'] = $single_payment['created'];

				if ( !empty($package_data) ) {
					$package_data = json_decode($package_data['0']->package_settings, true);

					if ( $payment_type != 'onetime' ) {
						if ( $package_data['payment_cycle'] == 'days' ) {
							$day_value = 1;
						} else if ( $package_data['payment_cycle'] == 'weeks' ) {
							$day_value = 7;
						} else if ( $package_data['payment_cycle'] == 'months' ) {
							$day_value = 30;
						} else if ( $package_data['payment_cycle'] == 'years' ) {
							$day_value = 365;
						}

						$package_data['listing_run_days'] = $day_value*intval($package_data['payment_interval']);
					}

					if ( isset($order_info['listing_expires']) && is_numeric($order_info['listing_expires']) ) {
						if ( $package_data['listing_run_type'] == 'days' ) {
							$new_expire_date = strtotime('+ '.$package_data['listing_run_days'].' days', $order_info['listing_expires']);
							$order_info['listing_expires'] = $new_expire_date;
						}
					} else if ( isset($order_info['listing_expires']) && !is_numeric($order_info['listing_expires']) ) {
						if ( $package_data['listing_run_type'] == 'days' ) {
							$new_expire_date = strtotime('+ '.$package_data['listing_run_days'].' days', time());
							$order_info['listing_expires'] = $new_expire_date;
						}
					}
				}

				$claim_value = get_current_user_id() . ':' . time();
				if ( isset($card_data['db-listing-claim']) ) {
					if ( $main_settings['claims_processing'] == 'manual' ) {
						$claim_value = get_current_user_id() . ':waiting';
					} else {
						$db_listing['post_author'] = get_current_user_id();
						$claim_value = get_current_user_id() . ':' . time();

						if ( function_exists( 'db_send_notification_email' ) ) {
							$current_user = get_userdata( get_current_user_id() );
							db_send_notification_email( get_current_user_id(), 'new_claim', array( 'username' => $current_user->data->user_login, 'url_dashboard' => get_permalink( $main_settings['account_page_id'] ), 'listing_title' => get_the_title($listing_id), 'listing' => get_permalink($listing_id) ) );
						}

						db_insert_activity( $listing_id, 'claimapproved', array(), get_current_user_id() );
					}
				} else {
					$claim_value = get_current_user_id() . ':author';
				}

				update_post_meta( $listing_id, 'db_claim_info', $claim_value );
			}

			update_post_meta( $listing_id, 'db_order_info', $order_info );
			
			wp_update_post( $db_listing );

			echo '{"save_response": "'.$card_data['db-listing-id'].'", "redirect": "true"}';
		} else {
			echo '{"save_response": "failed", "message": "'.__('Charge Credit Card ERROR: Invalid response', 'directory-builder').'"}';
		}
	} else {
		echo '{"save_response": "failed", "message": "'.$single_payment.'"}';
	}
} else {
	echo '{"save_response": "failed", "message": "'.__('Stripe is not configured!', 'directory-builder').'"}';
}

function db_process_single_payment( $card_data ) {
	try {
		global $stripe_currency;
		return \Stripe\Charge::create(array(
			"amount" => intval($card_data['db-package-fee'])*100,
			"currency" => $stripe_currency,
			"source" => array(
				"number" => $card_data['x_card_num'],
				"cvc" => $card_data['x_cvv'],
				"exp_month" => $card_data['x_month'],
				"exp_year" => $card_data['x_year']
			),
			"metadata" => array("listing_id" => $card_data['db-listing-id'])
		));
	} catch (Exception $e) {
		return $e->getMessage();
	}
}

function db_process_stripe_subscription( $main_settings, $card_data, $package_settings ) {
	try {
		$customer = \Stripe\Customer::create(array(
			"source" => array(
				"object" => 'card',
				"number" => $card_data['x_card_num'],
				"cvc" => $card_data['x_cvv'],
				"exp_month" => $card_data['x_month'],
				"exp_year" => $card_data['x_year']
			),
			"metadata" => array("listing_id" => $card_data['db-listing-id'])
		));
	} catch (Exception $e) {
		return $e->getMessage();
	}

	if ( isset($customer['id']) ) {
		try {
			$all_stripe_plans = \Stripe\Plan::all(array("limit" => 100));
		} catch (Exception $e) {
			return $e->getMessage();
		}
		$plan_exists = false;
		$existing_plan_id = '';
		if ( !empty($all_stripe_plans['data']) ) {
			foreach ($all_stripe_plans['data'] as $plan_values) {
				if ( $plan_values['id'] == str_replace(' ', '-', $card_data['item_name']) ) { // plan exists
					$existing_plan_id = $plan_values['id'];
					$plan_exists = true;
				}
			}
		}

		if ( $plan_exists === false ) {
			try {
				global $stripe_currency;
				$stripe_plan_settings = array(
					"amount" => intval($card_data['amount'])*100,
					"interval" => rtrim($package_settings['payment_cycle'], 's'),
					"interval_count" => $package_settings['payment_interval'],
					"name" => $card_data['item_name'],
					"currency" => $stripe_currency,
					"id" => str_replace(' ', '-', $card_data['item_name'])
				);
				if ( isset($package_settings['trial_period']) && $package_settings['trial_period'] === true ) {
					if ( $package_settings['trial_cycle'] == 'days' ) {
						$trial_days = intval($package_settings['trial_interval']);
					} else if ( $package_settings['trial_cycle'] == 'weeks' ) {
						$trial_days = intval($package_settings['trial_interval'])*7;
					} else if ( $package_settings['trial_cycle'] == 'months' ) {
						$trial_days = intval($package_settings['trial_interval'])*30;
					} else if ( $package_settings['trial_cycle'] == 'years' ) {
						$trial_days = intval($package_settings['trial_interval'])*365;
					}

					if ( $trial_daysisset($trial_days) ) {
						$stripe_plan_settings['trial_period_days'] = $trial_days;
					}
				}
				$listing_plan = \Stripe\Plan::create($stripe_plan_settings);
			} catch (Exception $e) {
				return $e->getMessage();
			}

			$existing_plan_id = $listing_plan['id'];
		}

		if ( $existing_plan_id != '' ) {
			try {
				return \Stripe\Subscription::create(array(
					"customer" => $customer['id'],
					"plan" => $existing_plan_id,
					"metadata" => array("listing_id" => $card_data['db-listing-id'])
				));
			} catch (Exception $e) {
				return $e->getMessage();
			}
		}
	}
}