<?php

require('stripe/init.php');

$main_settings = get_option( 'db_main_settings');
if ( isset($main_settings['stripe_key']) && $main_settings['stripe_key'] != '' ) {
	\Stripe\Stripe::setApiKey($main_settings['stripe_key']);
	$post_id = ( isset($_POST['listing_id']) ? intval( $_POST['listing_id'] ) : '' );
	$ref_amount = ( isset($_POST['ref_amount']) ? intval( $_POST['ref_amount'] ) : '' );
	$ref_reason = ( isset($_POST['ref_reason']) ? esc_attr( $_POST['ref_reason'] ) : '' );
	$ref_charge = ( isset($_POST['ref_charge']) ? esc_attr( $_POST['ref_charge'] ) : '' );

	$listing_billing = get_post_meta( $post_id, 'db_billing_info', true );

	try {
		$stripe_refund = \Stripe\Refund::create(array( "charge" => $ref_charge, "amount" => $ref_amount*100, "metadata" => array("listing_id" => $post_id )));
		if ( isset($stripe_refund['status']) && $stripe_refund['status'] == 'succeeded' ) {
			echo json_encode( array( 'save_response' => true, 'message' => esc_html__('Money refunded!', 'directory-builder') ) );

			$refunds = get_post_meta( $post_id, 'db_refunds', true );
			$refunds[time()] = array( 'amount' => $ref_amount, 'reason' => $ref_reason );
			update_post_meta( $post_id, 'db_refunds', $refunds );

			db_update_ipn_notes( $post_id, sprintf( __('Refund of %s initiated! %s', 'directory-builder'), ($stripe_refund['amount']/100).' '.strtoupper($stripe_refund['currency']), ($ref_reason!=''?esc_html__('Reason', 'directory-builder').': '.$ref_reason:'') ) );
		} else {
			echo json_encode( array( 'save_response' => false, 'message' => esc_html__('There was an issue, while refunding', 'directory-builder') ) );
		}
	} catch (Exception $e) {
		echo json_encode( array( 'save_response' => false, 'message' => $e->getMessage() ) );
	}
} else {
	echo json_encode( array( 'save_response' => false, 'message' => esc_html__('Stripe not configured!', 'directory-builder') ) );
}