<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://cohhe.com/
 * @since             1.0
 * @package           db_func
 *
 * @wordbress-plugin
 * Plugin Name:       Directory builder
 * Plugin URI:        https://cohhe.com/
 * Description:       Directory builder provides listing functionality for your theme.
 * Version:           1.5.5
 * Author:            Cohhe
 * Author URI:        https://cohhe.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       directory-builder
 * Domain Path:       /languages
 */

define( 'DB_CURRENT_VERSION', '1.5.5');

if ( ! defined( 'ABSPATH' ) ) exit; // If this file is called directly, abort.

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-db-functionality-activator.php
 */
function db_activate_db_func() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-db-functionality-activator.php';
	db_func_Activator::db_activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-db-functionality-deactivator.php
 */
function db_deactivate_db_func() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-db-functionality-deactivator.php';
	db_func_Deactivator::db_deactivate();
}

register_activation_hook( __FILE__, 'db_activate_db_func' );
register_deactivation_hook( __FILE__, 'db_deactivate_db_func' );

function db_is_current_version() {
	$curr_version = get_option( 'db_plugin_version' );
	return version_compare($curr_version, DB_CURRENT_VERSION, '=') ? true : false;
}

function db_check_actual_version() {
	if ( is_user_logged_in() && current_user_can('manage_options') && !db_is_current_version() ) db_activate_db_func();
}
add_action( 'admin_init', 'db_check_actual_version' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
define('DB_PLUGIN', plugin_dir_path( __FILE__ ));
define('DB_PLUGIN_URI', plugin_dir_url( __FILE__ ));
define('DB_PLUGIN_DASH_PAGE', 'directory-builder-dashboard');
define('DB_PLUGIN_FIELD_PAGE', 'directory-builder-fields');
define('DB_PLUGIN_SETTING_PAGE', 'directory-builder-settings');
define('DB_PLUGIN_PACKAGE_PAGE', 'directory-builder-packages');
define('DB_PLUGIN_THEME_PAGE', 'directory-builder-themes');
define('DB_PLUGIN_CLAIMS_PAGE', 'directory-builder-claims');
define('DB_PLUGIN_IMPROVEMENTS_PAGE', 'directory-builder-improvements');
define('DB_PLUGIN_SUB_PAGE', 'directory-builder-subscriptions');
define('DB_PLUGIN_SUPPORT_PAGE', 'directory-builder-support');
define('DB_PLUGIN_AD_PAGE', 'directory-builder-ads');
define('DB_PLUGIN_REG_PAGE', 'directory-builder-registration');
define('DB_PLUGIN_EMAIL_PAGE', 'directory-builder-templates');
define('DB_PLUGIN_IMPORT_PAGE', 'directory-builder-import');

define('DB_PLUGIN_DASH_PAGE_URL', get_admin_url() . 'admin.php?page=' . DB_PLUGIN_DASH_PAGE);
define('DB_PLUGIN_FIELD_PAGE_URL', get_admin_url() . 'admin.php?page=' . DB_PLUGIN_FIELD_PAGE);
define('DB_PLUGIN_SETTING_PAGE_URL', get_admin_url() . 'admin.php?page=' . DB_PLUGIN_SETTING_PAGE);
define('DB_PLUGIN_PACKAGE_PAGE_URL', get_admin_url() . 'admin.php?page=' . DB_PLUGIN_PACKAGE_PAGE);
define('DB_PLUGIN_THEME_PAGE_URL', get_admin_url() . 'admin.php?page=' . DB_PLUGIN_THEME_PAGE);
define('DB_PLUGIN_CLAIMS_PAGE_URL', get_admin_url() . 'admin.php?page=' . DB_PLUGIN_CLAIMS_PAGE);
define('DB_PLUGIN_IMPROVEMENTS_PAGE_URL', get_admin_url() . 'admin.php?page=' . DB_PLUGIN_IMPROVEMENTS_PAGE);
define('DB_PLUGIN_SUB_PAGE_URL', get_admin_url() . 'admin.php?page=' . DB_PLUGIN_SUB_PAGE);
define('DB_PLUGIN_SUPPORT_PAGE_URL', get_admin_url() . 'admin.php?page=' . DB_PLUGIN_SUPPORT_PAGE);
define('DB_PLUGIN_AD_PAGE_URL', get_admin_url() . 'admin.php?page=' . DB_PLUGIN_AD_PAGE);
define('DB_PLUGIN_REG_PAGE_URL', get_admin_url() . 'admin.php?page=' . DB_PLUGIN_REG_PAGE);
define('DB_PLUGIN_EMAIL_PAGE_URL', get_admin_url() . 'admin.php?page=' . DB_PLUGIN_EMAIL_PAGE);
define('DB_PLUGIN_IMPORT_PAGE_URL', get_admin_url() . 'admin.php?page=' . DB_PLUGIN_IMPORT_PAGE);

require plugin_dir_path( __FILE__ ) . 'includes/class-db-functionality.php';


/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_db_func() {

	$plugin = new db_func();
	$plugin->db_run();

}
run_db_func();

function db_register_manager_menu_page() {
	add_menu_page(
		__( 'Directory', 'directory-builder' ),
		__( 'Directory', 'directory-builder' ),
		'manage_options',
		DB_PLUGIN_DASH_PAGE,
		'',
		'dashicons-location',
		26
	);

	add_submenu_page(
		DB_PLUGIN_DASH_PAGE,
		__('Dashboard', 'directory-builder'),
		__('Dashboard', 'directory-builder'),
		'manage_options',
		DB_PLUGIN_DASH_PAGE,
		'db_main_html'
	);

	add_submenu_page(
		DB_PLUGIN_DASH_PAGE,
		__('Custom fields', 'directory-builder'),
		__('Custom fields', 'directory-builder'),
		'manage_options',
		DB_PLUGIN_FIELD_PAGE,
		'db_field_html'
	);

	add_submenu_page(
		DB_PLUGIN_DASH_PAGE,
		__('Packages', 'directory-builder'),
		__('Packages', 'directory-builder'),
		'manage_options',
		DB_PLUGIN_PACKAGE_PAGE,
		'db_package_html'
	);

	add_submenu_page(
		DB_PLUGIN_DASH_PAGE,
		__('Listing claims', 'directory-builder'),
		__('Listing claims', 'directory-builder'),
		'manage_options',
		DB_PLUGIN_CLAIMS_PAGE,
		'db_claims_html'
	);

	add_submenu_page(
		DB_PLUGIN_DASH_PAGE,
		__('Listing improvements', 'directory-builder'),
		__('Listing improvements', 'directory-builder'),
		'manage_options',
		DB_PLUGIN_IMPROVEMENTS_PAGE,
		'db_improvements_html'
	);

	add_submenu_page(
		DB_PLUGIN_DASH_PAGE,
		__('Subscriptions', 'directory-builder'),
		__('Subscriptions', 'directory-builder'),
		'manage_options',
		DB_PLUGIN_SUB_PAGE,
		'db_subscriptions_html'
	);

	add_submenu_page(
		DB_PLUGIN_DASH_PAGE,
		__('Support tickets', 'directory-builder'),
		__('Support tickets', 'directory-builder'),
		'manage_options',
		DB_PLUGIN_SUPPORT_PAGE,
		'db_support_html'
	);

	add_submenu_page(
		DB_PLUGIN_DASH_PAGE,
		__('Advertisements', 'directory-builder'),
		__('Advertisements', 'directory-builder'),
		'manage_options',
		DB_PLUGIN_AD_PAGE,
		'db_ads_html'
	);

	add_submenu_page(
		DB_PLUGIN_DASH_PAGE,
		__('Registration', 'directory-builder'),
		__('Registration', 'directory-builder'),
		'manage_options',
		DB_PLUGIN_REG_PAGE,
		'db_reg_html'
	);

	add_submenu_page(
		DB_PLUGIN_DASH_PAGE,
		__('Email templates', 'directory-builder'),
		__('Email templates', 'directory-builder'),
		'manage_options',
		DB_PLUGIN_EMAIL_PAGE,
		'db_email_html'
	);

	add_submenu_page(
		DB_PLUGIN_DASH_PAGE,
		__('Import', 'directory-builder'),
		__('Import', 'directory-builder'),
		'manage_options',
		DB_PLUGIN_IMPORT_PAGE,
		'db_import_html'
	);

	add_submenu_page(
		DB_PLUGIN_DASH_PAGE,
		__('Themes', 'directory-builder'),
		__('Themes', 'directory-builder'),
		'manage_options',
		DB_PLUGIN_THEME_PAGE,
		'db_theme_html'
	);

	add_submenu_page(
		DB_PLUGIN_DASH_PAGE,
		__('Settings', 'directory-builder'),
		__('Settings', 'directory-builder'),
		'manage_options',
		DB_PLUGIN_SETTING_PAGE,
		'db_settings_html'
	);
}
add_action( 'admin_menu', 'db_register_manager_menu_page' );

add_action( 'init', 'vh_create_post_type' );
function vh_create_post_type() {
	$main_settings = get_option( 'db_main_settings', array());

	register_post_type( 'listings',
		array(
		'labels' => array(
			'name' => __( 'Listings', "directory-builder" ),
			'singular_name' => __( 'Listing', "directory-builder" ),
			'add_new' => 'Add New Listing',
			'add_new_item' => 'Add New Listing',
			'edit_item' => 'Edit Listing',
			'new_item' => 'New Listing',
			'view_item' => 'View listing',
		),
		'taxonomies' => array('listing_category'),
		'rewrite' => array('slug'=>$main_settings['directory_slug'],'with_front'=>false),
		'public' => true,
		'has_archive' => true,
		'supports' => array(
			'title',
			'editor',
			'revisions',
			'thumbnail',
			'comments',
			'excerpt'
			),
		'menu_icon' => 'dashicons-location',
		'menu_position' => '25'
		)
	);

	register_taxonomy( 'listing_category',
		array (
			0 => 'listings',
		),
		array( 
			'hierarchical' => true, 
			'label' => 'Listing categories',
			'show_ui' => true,
			'query_var' => true,
			'rewrite' => array('slug' => $main_settings['category_slug'], 'with_front'=>false),
			'singular_label' => 'Listing category'
		) 
	);

	add_image_size( 'db_single_listing', 550 );
}

function db_available_icons() {
	$available_icons = array();

	if ( file_exists( dirname( __FILE__ ) . '/font/config.json' ) ) {
		$font_configuration = json_decode( file_get_contents( dirname( __FILE__ ) . '/font/config.json' ), true );

		if ( !empty( $font_configuration['glyphs'] ) ) {
			foreach ( $font_configuration['glyphs'] as $font_data ) {
				$available_icons[] = $font_configuration['css_prefix_text'] . $font_data['css'];
			}
		}
	}

	$available_icons[] = 'wl-health';
	$available_icons[] = 'wl-catering';
	$available_icons[] = 'wl-beauty';
	$available_icons[] = 'wl-finances';
	$available_icons[] = 'wl-plants';

	return $available_icons;
}


add_action ( 'listing_category_add_form_fields', 'db_add_category_fields');
function db_add_category_fields( $tag ) {
	$cat_meta = array();
	?>
	<div class="form-field term-default-image-wrap">
		<label for="tag-default-image">Default listing image</label>
		<div class="db-image-container">
			<?php echo (isset($cat_meta['tag-default-image'])&&$cat_meta['tag-default-image']!=''?'<img src="'.$cat_meta['tag-default-image'].'" alt="">':''); ?>
		</div>
		<input type="hidden" class="upload-field-value" name="tag-default-image" value="<?php echo (isset($cat_meta['tag-default-image'])&&$cat_meta['tag-default-image']!=''?$cat_meta['tag-default-image']:''); ?>">
		<input type="button" id="tag-default-image" class="db-image-upload" value="Upload image">
		<input type="button" class="db-image-delete" value="Delete image" <?php echo (!isset($cat_meta['tag-default-image'])||$cat_meta['tag-default-image']==''?'style="display: none;"':''); ?>>
		<p>Choose a default "No image".</p>
	</div>
	<div class="form-field term-category-icon-wrap">
		<label for="tag-category-icon">Category icon</label>
		<?php echo __('Icon selected: ', 'directory-builder').'<i class="db-active-category-icon "></i>'; ?>
		<div class="clearfix"></div>
		<input type="hidden" name="tag-category-icon" value="<?php echo (isset($cat_meta['tag-category-icon'])&&$cat_meta['tag-category-icon']!=''?$cat_meta['tag-category-icon']:''); ?>">
		<input type="button" id="db-choose-category-icon" value="Choose icon">
		<div class="db-category-icon-dialog main-card">
			<div class="db-category-icon-dialog-inner">
				<span class="db-category-icon-dialog-close dbicon-cancel"></span>
				<?php
					$icons = db_available_icons();
					foreach ($icons as $icon_value) {
						echo '<i class="db-category-icon-select '.$icon_value.'" data-id="'.$icon_value.'"></i>';
					}
				?>
			</div>
		</div>
		<p>Choose category icon.</p>
	</div>
	<div class="form-field term-category-icon-wrap">
		<label for="tag-category-color">Category color</label>
		<input type="text" id="db-choose-category-color" name="tag-category-color" value="<?php echo (isset($cat_meta['tag-category-color'])&&$cat_meta['tag-category-color']!=''?$cat_meta['tag-category-color']:''); ?>">
	</div>
	<?php
}

add_action ( 'listing_category_edit_form_fields', 'db_edit_category_fields');
function db_edit_category_fields( $tag ) {
	$t_id = $tag->term_id;
	$cat_meta = get_option( "listing_category_$t_id");
	?>
	<tr class="form-field term-default-image-wrap">
		<th scope="row"><label for="description">Default listing image</label></th>
		<td>
			<div class="db-image-container">
				<?php echo (isset($cat_meta['tag-default-image'])&&$cat_meta['tag-default-image']!=''?'<img src="'.$cat_meta['tag-default-image'].'" alt="">':''); ?>
			</div>
			<input type="hidden" class="upload-field-value" name="tag-default-image" value="<?php echo (isset($cat_meta['tag-default-image'])&&$cat_meta['tag-default-image']!=''?$cat_meta['tag-default-image']:''); ?>">
			<input type="button" id="tag-default-image" class="db-image-upload" value="Upload image">
			<input type="button" class="db-image-delete" value="Delete image" <?php echo (!isset($cat_meta['tag-default-image'])||$cat_meta['tag-default-image']==''?'style="display: none;"':''); ?>>
			<p class="description">Choose a default "No image".</p>
		</td>
	</tr>
	<tr class="form-field term-category-icon-wrap">
		<th scope="row"><label for="description">Category icon</label></th>
		<td>
			<?php echo __('Icon selected: ', 'directory-builder').'<i class="db-active-category-icon '.(isset($cat_meta['tag-category-icon'])?$cat_meta['tag-category-icon']:'').'"></i>'; ?>
			<div class="clearfix"></div>
			<input type="hidden" name="tag-category-icon" value="<?php echo (isset($cat_meta['tag-category-icon'])&&$cat_meta['tag-category-icon']!=''?$cat_meta['tag-category-icon']:''); ?>">
			<input type="button" id="db-choose-category-icon" value="Choose icon">
			<div class="category-icon-modal-container">
				<div class="db-category-icon-dialog main-card">
					<div class="db-category-icon-dialog-inner">
						<span class="db-category-icon-dialog-close dbicon-cancel"></span>
						<?php
							$icons = db_available_icons();
							foreach ($icons as $icon_value) {
								echo '<i class="db-category-icon-select '.$icon_value.'" data-id="'.$icon_value.'"></i>';
							}
						?>
					</div>
				</div>
			</div>
			<p>Choose category icon.</p>
		</td>
	</tr>
	<tr class="form-field term-category-icon-wrap">
		<th scope="row"><label for="description">Category color</label></th>
		<td>
			<input type="text" id="db-choose-category-color" name="tag-category-color" value="<?php echo (isset($cat_meta['tag-category-color'])&&$cat_meta['tag-category-color']!=''?$cat_meta['tag-category-color']:''); ?>">
		</td>
	</tr>
	<?php
}

add_action ( 'edited_listing_category', 'db_save_category_fields');
add_action ( 'create_listing_category', 'db_save_category_fields');
function db_save_category_fields( $term_id ) {
	$saved_options = 0;
	$t_id = $term_id;
	$cat_meta = get_option( "listing_category_$t_id");
	if ( isset( $_POST['tag-default-image'] ) ) {
		$cat_meta['tag-default-image'] = esc_url($_POST['tag-default-image']);
		$saved_options++;
	}

	if ( isset( $_POST['tag-category-icon'] ) ) {
		$cat_meta['tag-category-icon'] = sanitize_key($_POST['tag-category-icon']);
		$saved_options++;
	}

	if ( isset( $_POST['tag-category-color'] ) ) {
		$cat_meta['tag-category-color'] = sanitize_text_field($_POST['tag-category-color']);
		$saved_options++;
	}
	
	if ( $saved_options > 0 ) {
		update_option( "listing_category_$t_id", $cat_meta );
	}
}

function db_main_html() {
	if ( !current_user_can('manage_options') )  {
		wp_die( __('You do not have sufficient permissions to access this page.', 'directory-builder') );
	}
	?>
	<div class="db-main-wrapper container-fluid" id="db-main-wrapper">
		<div class="db-main-content main-card">
			<div class="db-box-title">
				<h3 class="db-main-title">Custom templates</h3>
			</div>
			<p>There are 3 destinations for templates, the default one in the plugin, inside your theme and custom ones saved in your WordPress <b>wp-content/db-plugin-themes</b> directory. The default theme inside the plugin is always the newest one and gets updated along with the plugin updates. The theme inside a theme directory is updated eather by you or your theme author. The custom themes uploaded via a zip file is updated and maintained by the custom theme author.</p>
			<br>
			<p>A valid custom theme counts as a <b>.zip</b> file containing <b>theme_data.json</b>, if you want to create a custom theme we suggest you to copy the default theme that's located in the plugin folder(<b>directory-builder/template</b>) and rename it into an unique name. From there you can start editing the template files by adding or removing information. Next step would be to edit the themes <b>theme_data.json</b> file that contains information about your custom theme like version, author and description. The last and final step is to archive your new template folder into a <b>.zip</b> file.</p>
		</div>
		<div class="db-main-content main-card db-m-t-20">
			<div class="db-box-title">
				<h3 class="db-main-title">Available shortcodes</h3>
			</div>
			<div class="db-row">
				<div class="db-row-group clearfix">
					<span class="db-row-label col-sm-2"><b>[directory_listings]</b></span>
					<div class="col-sm-10">
						This shortcode is going to show listing search with a map, you can control search settings at the Dashboard > Directory > Settings
					</div>
				</div>
			</div>
			<div class="db-row">
				<div class="db-row-group clearfix">
					<span class="db-row-label col-sm-2"><b>[directory_add_listing]</b></span>
					<div class="col-sm-10">
						This shortcode is going to add the add listing form so your users can add their listings to your page!
					</div>
				</div>
			</div>
			<div class="db-row">
				<div class="db-row-group clearfix">
					<span class="db-row-label col-sm-2"><b>[directory_account]</b></span>
					<div class="col-sm-10">
						This shortcode is going to show all of the user listings with the ability to edit and/or delete them.
					</div>
				</div>
			</div>
			<div class="db-row">
				<div class="db-row-group clearfix">
					<span class="db-row-label col-sm-2"><b>[directory_login]</b></span>
					<div class="col-sm-10">
						This shortcode is going to show the login form so your users can login to your page.
					</div>
				</div>
			</div>
			<div class="db-row">
				<div class="db-row-group clearfix">
					<span class="db-row-label col-sm-2"><b>[directory_register]</b></span>
					<div class="col-sm-10">
						This shortcode is going to show the register form so your users can register and start adding their listings!
					</div>
				</div>
			</div>
		</div>
	</div>

	<?php
}

function db_field_html() {
	if ( !current_user_can('manage_options') )  {
		wp_die( __('You do not have sufficient permissions to access this page.', 'directory-builder') );
	}
	?>
	<div class="db-main-wrapper container-fluid" id="db-main-wrapper">
		<div class="db-main-content main-card">
			<?php if ( !isset($_GET['field_type']) && !isset($_GET['field_id']) ) { ?>
				<a href="javascript:void(0)" class="db-add-new-field db-button db-primary-button">Add new</a>
				<table class="table table-striped table-hover">
					<thead>
						<tr>
							<th style="width: 5%;">Order</th>
							<th style="width: 65%;">Name</th>
							<th style="width: 15%;">Type</th>
							<th style="width: 15%;">Action</th>
						</tr>
					</thead>
					<tbody>
						<?php
						global $wpdb;
						$field_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_fields ORDER BY field_order, ID ASC');
						if ( !empty($field_list) ) {
							foreach ($field_list as $field_value) {
								$field_settings = json_decode($field_value->field_settings, true);
								$is_child = (isset($field_settings['child'])&&$field_settings['child']=='true'?'db-child-field':'');
								$disabled_settings = (isset($field_settings['disabled'])?explode(',', $field_settings['disabled']):array());

								echo '
								<tr class="'.$is_child.'">
									<td class="db-field-order">'.($is_child==''?$field_settings['display_order']:'').'</td>
									<td class="db-field-name">'.$field_settings['admin_title'].'</td>
									<td class="db-custom-field-type">'.$field_settings['field_type'].'</td>
									<td class="db-field-actions">';
										if ( !in_array('edit', $disabled_settings) ) {
											echo '<a href="'.DB_PLUGIN_FIELD_PAGE_URL.'&field_id='.$field_value->ID.'" class="db-edit-field">Edit</a>';
										}
										echo ' ';
										if ( !in_array('delete', $disabled_settings) ) {
											echo '<a href="javascript:void(0)" class="db-delete-field" data-id="'.$field_value->ID.'">Delete</a>';
										}
									echo '
									</td>
								</tr>';
							}
						}
						?>
					</tbody>
				</table>
				<div class="db-custom-field-dialog main-card" style="display: none;">
					<div class="db-field-row clearfix">
						<label class="field-label">Field type</label>
						<select class="db-field-type">
							<option value="text">Text</option>
							<option value="number">Number</option>
							<option value="textarea">Textarea</option>
							<option value="checkbox">Checkbox</option>
							<option value="radio">Radio</option>
							<option value="select">Select</option>
							<option value="multi-select">Multi select</option>
							<option value="url">URL</option>
							<option value="file-upload">File upload</option>
							<option value="date">Date</option>
							<option value="time">Time</option>
							<option value="email">Email</option>
							<option value="html">HTML</option>
							<option value="hoursofoperation">Hours of operation</option>
						</select>
					</div>
					<a href="javascript:void(0)" class="db-proceed-field db-button db-primary-button">Proceed</a>
				</div>
				<div class="db-dialog-overlay" style="display: none;"></div>
			<?php } else if ( isset($_GET['field_type']) || isset($_GET['field_id']) ) {
				$field_settings = array();
				$disabled_settings = array();
				$is_child = false;
				if ( isset($_GET['field_id']) ) {
					global $wpdb;
					$field_data = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_fields WHERE ID="'.intval($_GET['field_id']).'"');
					$field_settings = json_decode($field_data['0']->field_settings, true);
					$disabled_settings = (isset($field_settings['disabled'])?explode(',', $field_settings['disabled']):array());
					$is_child = (isset($field_settings['child'])&&$field_settings['child']=='true'?true:false);
				}
				$field_type = (isset($_GET['field_type'])?sanitize_text_field($_GET['field_type']):$field_settings['field_type']);
				?>
				<div class="db-custom-field">
					<div class="db-box-title">
						<h3 class="db-main-title">Custom field</h3>
					</div>
					<?php if ( !in_array('delete', $disabled_settings) ) { ?>
						<div class="db-field-row <?php echo(isset($field_settings['field_name'])&&$field_settings['field_name']!=''?'active':''); ?> clearfix">
							<label class="field-label">Field name <span class="db-required">*</span></label>
							<div class="db-field-input">
								<input type="text" class="db-create-field-name" data-required="true" value="<?php echo(isset($field_settings['field_name'])?$field_settings['field_name']:''); ?>">
								<span class="field-description">Unique name only from letters a-z</span>
								<span class="db-field-required">This field is required</span>
							</div>
						</div>
					<?php } ?>
					<div class="db-field-row <?php echo(isset($field_settings['admin_title'])&&$field_settings['admin_title']!=''?'active':''); ?> clearfix">
						<label class="field-label">Admin title</label>
						<div class="db-field-input">
							<input type="text" class="db-create-admin-title" value="<?php echo(isset($field_settings['admin_title'])?$field_settings['admin_title']:''); ?>">
							<span class="field-description">This is the name how you'll see it at the back-end field list</span>
						</div>
					</div>
					<div class="db-field-row <?php echo(isset($field_settings['frontend_title'])&&$field_settings['frontend_title']!=''?'active':''); ?> clearfix">
						<label class="field-label">Frontend title <span class="db-required">*</span></label>
						<div class="db-field-input">
							<input type="text" class="db-create-frontend-title" data-required="true" value="<?php echo(isset($field_settings['frontend_title'])?$field_settings['frontend_title']:''); ?>">
							<span class="field-description">How this field is going to be shown to other users</span>
							<span class="db-field-required">This field is required</span>
						</div>
					</div>
					<div class="db-field-row <?php echo(isset($field_settings['frontend_description'])&&$field_settings['frontend_description']!=''?'active':''); ?> clearfix">
						<label class="field-label">Frontend description</label>
						<div class="db-field-input">
							<input type="text" class="db-create-frontend-description" value="<?php echo(isset($field_settings['frontend_description'])?$field_settings['frontend_description']:''); ?>">
							<span class="field-description">The description which is going to be shown to users</span>
						</div>
					</div>
					<?php if ( ( isset($_GET['field_type']) && sanitize_key($_GET['field_type']) != 'hoursofoperation' ) || ( !isset($_GET['field_type']) && sanitize_key($field_settings['field_type']) != 'hoursofoperation' ) ) { ?>
					<div class="db-field-row <?php echo(isset($field_settings['default_value'])&&$field_settings['default_value']!=''?'active':''); ?> clearfix">
						<label class="field-label">Default value</label>
						<div class="db-field-input">
							<input type="text" class="db-create-default-value" value="<?php echo(isset($field_settings['default_value'])?$field_settings['default_value']:''); ?>">
							<span class="field-description"><?php echo ($field_type!='url'?'If this field has a default value, enter it here':'Link text for frontend'); ?></span>
						</div>
					</div>
					<?php } ?>
					<div class="db-field-row <?php echo(isset($field_settings['display_order'])&&$field_settings['display_order']!=''?'active':''); ?> clearfix">
						<label class="field-label">Display order</label>
						<div class="db-field-input">
							<input type="number" class="db-create-display-order" value="<?php echo(isset($field_settings['display_order'])?$field_settings['display_order']:''); ?>" <?php echo(in_array('display_order', $disabled_settings)?'disabled':''); ?>>
							<span class="field-description">The order in which it's goint to be shown to users</span>
						</div>
					</div>
					<?php if ( !in_array('delete', $disabled_settings) ) { ?>
						<div class="db-field-row focused active clearfix">
							<label class="field-label">Active?</label>
							<div class="db-field-input">
								<select class="db-create-field-active" <?php echo(in_array('field_active', $disabled_settings)?'disabled':''); ?>>
									<option value="yes" <?php echo(isset($field_settings['field_active'])&&$field_settings['field_active']=='yes'?'selected':''); ?>>Yes</option>
									<option value="no" <?php echo(isset($field_settings['field_active'])&&$field_settings['field_active']=='no'?'selected':''); ?>>No</option>
								</select>
								<span class="field-description">Do you want to show this field to users?</span>
							</div>
						</div>
						<div class="db-field-row focused active clearfix">
							<label class="field-label">For admins?</label>
							<div class="db-field-input">
								<select class="db-create-for-admins">
									<option value="no" <?php echo(isset($field_settings['for_admins'])&&$field_settings['for_admins']=='no'?'selected':''); ?>>No</option>
									<option value="yes" <?php echo(isset($field_settings['for_admins'])&&$field_settings['for_admins']=='yes'?'selected':''); ?>>Yes</option>
								</select>
								<span class="field-description">Only admins will be able to edit it</span>
							</div>
						</div>
					<?php } else { ?>
						<input type="hidden" class="db-create-field-active" value="yes">
						<input type="hidden" class="db-create-for-admins" value="no">
					<?php } ?>
					<div class="db-field-row focused active clearfix">
						<label class="field-label">Required?</label>
						<div class="db-field-input">
							<select class="db-create-required">
								<option value="yes" <?php echo(isset($field_settings['required'])&&$field_settings['required']=='yes'?'selected':''); ?>>Yes</option>
								<option value="no" <?php echo(isset($field_settings['required'])&&$field_settings['required']=='no'?'selected':''); ?>>No</option>
							</select>
							<span class="field-description">Is it required to fill this field in?</span>
						</div>
					</div>
					<div class="db-field-row <?php echo(isset($field_settings['required_message'])&&$field_settings['required_message']!=''?'active':''); ?> clearfix">
						<label class="field-label">Required message</label>
						<div class="db-field-input">
							<input type="text" class="db-create-required-message" value="<?php echo(isset($field_settings['required_message'])?$field_settings['required_message']:''); ?>">
							<span class="field-description">Message to be shown to users if they do not fill this field in.</span>
						</div>
					</div>
					<div class="db-field-row focused active clearfix">
						<label class="field-label">Show on list pages?</label>
						<div class="db-field-input">
							<select class="db-create-on-listing">
								<option value="no" <?php echo(isset($field_settings['on_listing'])&&$field_settings['on_listing']=='no'?'selected':''); ?>>No</option>
								<option value="yes" <?php echo(isset($field_settings['on_listing'])&&$field_settings['on_listing']=='yes'?'selected':''); ?>>Yes</option>
							</select>
							<span class="field-description">Do you want to show this field on pages that display listings in lists (for example search)?</span>
						</div>
					</div>
					<div class="db-field-row focused active clearfix">
						<label class="field-label">Show on details page?</label>
						<div class="db-field-input">
							<select class="db-create-on-detail">
								<option value="no" <?php echo(isset($field_settings['on_detail'])&&$field_settings['on_detail']=='no'?'selected':''); ?>>No</option>
								<option value="yes" <?php echo(isset($field_settings['on_detail'])&&$field_settings['on_detail']=='yes'?'selected':''); ?>>Yes</option>
							</select>
							<span class="field-description">Do you want to show this field on single listing page?</span>
						</div>
					</div>
					<div class="db-field-row focused active clearfix">
						<label class="field-label">Show on contact section?</label>
						<div class="db-field-input">
							<select class="db-create-on-contact">
								<option value="no" <?php echo(isset($field_settings['on_contact'])&&$field_settings['on_contact']=='no'?'selected':''); ?>>No</option>
								<option value="yes" <?php echo(isset($field_settings['on_contact'])&&$field_settings['on_contact']=='yes'?'selected':''); ?>>Yes</option>
							</select>
							<span class="field-description">Do you want to show this field on the contact section at the single listing pages?</span>
						</div>
					</div>
					<?php
					$sorting_types = array( 'text', 'number', 'textarea', 'checkbox', 'radio', 'select', 'multi-select', 'url', 'date', 'time', 'email' );
					if ( in_array($field_type, $sorting_types) ) { ?>
						<div class="db-field-row focused active clearfix">
							<label class="field-label">Show in sorting options?</label>
							<div class="db-field-input">
								<select class="db-create-on-sorting">
									<option value="no" <?php echo(isset($field_settings['on_sorting'])&&$field_settings['on_sorting']=='no'?'selected':''); ?>>No</option>
									<option value="yes" <?php echo(isset($field_settings['on_sorting'])&&$field_settings['on_sorting']=='yes'?'selected':''); ?>>Yes</option>
								</select>
								<span class="field-description">Do you want to show this field in sorting options at the search page?</span>
							</div>
						</div>
					<?php } ?>
					<div class="db-field-row active clearfix">
						<label class="field-label">Apply to categories</label>
						<div class="db-field-input">
							<select class="db-create-apply_categories" multiple>
							<?php
							$categories = get_terms( array(
								'taxonomy' => 'listing_category',
								'hide_empty' => false
							));
							if ( !empty($categories) ) {
								$categoryHierarchy = array();
								db_sort_terms_hierarchicaly($categories, $categoryHierarchy);

								foreach ($categoryHierarchy as $category_value) {
									$is_checked = (in_array($category_value->term_id, $field_settings['apply_categories'])?'selected':'');
									echo '<option value="'.$category_value->term_id.'" '.$is_checked.'>'.$category_value->name.'</option>';

									if ( !empty($category_value->children) ) {
										echo db_display_backend_categories( $category_value, $field_settings['apply_categories'] );
									}
								}
							}
							?>
							</select>
							<span class="field-description shown">If this field is only available to certain categories, then select those categories. If none of the categories are selected, then this field will be shown for all categories.</span>
						</div>
					</div>
					<div class="db-field-row focused active clearfix">
						<label class="field-label">Custom field icon</label>
						<div class="db-field-input">
							<div class="db-field-input">
								<?php echo __('Icon selected: ', 'directory-builder').'<i class="db-active-category-icon '.(isset($field_settings['field_icon'])&&$field_settings['field_icon']!=''?$field_settings['field_icon']:'').'"></i>'; ?>
								<div class="clearfix"></div>
								<input type="hidden" class="db-create-field-icon" value="<?php echo (isset($field_settings['field_icon'])&&$field_settings['field_icon']!=''?$field_settings['field_icon']:''); ?>">
								<input type="button" id="db-choose-category-icon" value="<?php esc_html_e('Choose icon', 'directory-builder'); ?>">
								<input type="button" id="db-delete-field-icon" value="<?php esc_html_e('Delete icon', 'directory-builder'); ?>" class="<?php echo (isset($field_settings['field_icon'])&&$field_settings['field_icon']!=''?'db-button-visible':''); ?>">
								<div class="db-category-icon-dialog main-card">
									<div class="db-category-icon-dialog-inner">
										<span class="db-category-icon-dialog-close dbicon-cancel"></span>
										<?php
											$icons = db_available_icons();
											$icons[] = 'wl-location';
											$icons[] = 'wl-phone';
											$icons[] = 'wl-link';
											foreach ($icons as $icon_value) {
												echo '<i class="db-category-icon-select '.$icon_value.'" data-id="'.$icon_value.'"></i>';
											}
										?>
									</div>
								</div>
							</div>
						</div>
					</div>
					<?php if ( isset( $field_settings['disabled'] ) ) { ?>
						<input type="hidden" class="db-create-disabled" value="<?php echo $field_settings['disabled']; ?>">
					<?php } ?>
					<?php if ( in_array('delete', $disabled_settings) ) { ?>
						<input type="hidden" class="db-create-field-name" data-required="true" value="<?php echo(isset($field_settings['field_name'])?$field_settings['field_name']:''); ?>">
					<?php } ?>
					<?php if ( $field_type == 'text' ) { ?>
						<div class="db-field-row <?php echo(isset($field_settings['validation_pattern'])&&$field_settings['validation_pattern']!=''?'active':''); ?> clearfix">
							<label class="field-label">Validation pattern</label>
							<div class="db-field-input">
								<input type="text" class="db-create-validation-pattern" value="<?php echo(isset($field_settings['validation_pattern'])?$field_settings['validation_pattern']:''); ?>">
								<span class="field-description">Validation pattern for HTML5 validation</span>
								<span class="field-description">Example: <strong>[A-Za-z]{3}</strong> - Any 3 letters from a to z</span>
							</div>
						</div>
						<div class="db-field-row <?php echo(isset($field_settings['validation_pattern_message'])&&$field_settings['validation_pattern_message']!=''?'active':''); ?> clearfix">
							<label class="field-label">Validation pattern message</label>
							<div class="db-field-input">
								<input type="text" class="db-create-validation-pattern-message" value="<?php echo(isset($field_settings['validation_pattern_message'])?$field_settings['validation_pattern_message']:''); ?>">
								<span class="field-description">Validation pattern message for HTML5 validation</span>
							</div>
						</div>
					<?php } else if ( $field_type == 'radio' ) { ?>
						<div class="db-field-row <?php echo(isset($field_settings['radio_options'])&&$field_settings['radio_options']!=''?'active':''); ?> clearfix">
							<label class="field-label">Radio button values</label>
							<div class="db-field-input">
								<input type="text" class="db-create-radio-options" value="<?php echo(isset($field_settings['radio_options'])?$field_settings['radio_options']:''); ?>">
								<span class="field-description">Provide radio button values separated with comma:</span>
								<span class="field-description">No WiFi,WiFi included,Nagotiable</span>
							</div>
						</div>
					<?php } else if ( $field_type == 'select' ) { ?>
						<div class="db-field-row <?php echo(isset($field_settings['select_options'])&&$field_settings['select_options']!=''?'active':''); ?> clearfix">
							<label class="field-label">Select values</label>
							<div class="db-field-input">
								<textarea class="db-create-select-options"><?php echo(isset($field_settings['select_options'])?$field_settings['select_options']:''); ?></textarea>
								<span class="field-description">Provide select option values, field name:field value, each value in a new line like so:</span>
								<span class="field-description">no-wifi:No WiFi<br>wifi-included:WiFi included</span>
							</div>
						</div>
					<?php } else if ( $field_type == 'file-upload' ) {
						$all_selected_types = (isset($field_settings['allowed_types'])?$field_settings['allowed_types']:array()); ?>
						<div class="db-field-row active clearfix">
							<label class="field-label">Allowed file types</label>
							<div class="db-field-input">
								<select class="db-create-allowed-types" multiple>
									<option value="*" selected="selected">All types</option>
									<optgroup label="Image formats">
											<option value="jpg" <?php echo(in_array('jpg',$all_selected_types)?'selected':''); ?>>.jpg</option>
											<option value="jpe" <?php echo(in_array('jpe',$all_selected_types)?'selected':''); ?>>.jpe</option>
											<option value="jpeg" <?php echo(in_array('jpeg',$all_selected_types)?'selected':''); ?>>.jpeg</option>
											<option value="gif" <?php echo(in_array('gif',$all_selected_types)?'selected':''); ?>>.gif</option>
											<option value="png" <?php echo(in_array('png',$all_selected_types)?'selected':''); ?>>.png</option>
											<option value="bmp" <?php echo(in_array('bmp',$all_selected_types)?'selected':''); ?>>.bmp</option>
											<option value="ico" <?php echo(in_array('ico',$all_selected_types)?'selected':''); ?>>.ico</option>
										</optgroup>
									<optgroup label="Video formats">
											<option value="asf" <?php echo(in_array('asf',$all_selected_types)?'selected':''); ?>>.asf</option>
											<option value="avi" <?php echo(in_array('avi',$all_selected_types)?'selected':''); ?>>.avi</option>
											<option value="flv" <?php echo(in_array('flv',$all_selected_types)?'selected':''); ?>>.flv</option>
											<option value="mkv" <?php echo(in_array('mkv',$all_selected_types)?'selected':''); ?>>.mkv</option>
											<option value="mp4" <?php echo(in_array('mp4',$all_selected_types)?'selected':''); ?>>.mp4</option>
											<option value="mpeg" <?php echo(in_array('mpeg',$all_selected_types)?'selected':''); ?>>.mpeg</option>
											<option value="mpg" <?php echo(in_array('mpg',$all_selected_types)?'selected':''); ?>>.mpg</option>
											<option value="wmv" <?php echo(in_array('wmv',$all_selected_types)?'selected':''); ?>>.wmv</option>
											<option value="3gp" <?php echo(in_array('3gp',$all_selected_types)?'selected':''); ?>>.3gp</option>
										</optgroup>
									<optgroup label="Audio formats">
											<option value="ogg" <?php echo(in_array('ogg',$all_selected_types)?'selected':''); ?>>.ogg</option>
											<option value="mp3" <?php echo(in_array('mp3',$all_selected_types)?'selected':''); ?>>.mp3</option>
											<option value="wav" <?php echo(in_array('wav',$all_selected_types)?'selected':''); ?>>.wav</option>
											<option value="wma" <?php echo(in_array('wma',$all_selected_types)?'selected':''); ?>>.wma</option>
										</optgroup>
									<optgroup label="Text formats">
											<option value="css" <?php echo(in_array('css',$all_selected_types)?'selected':''); ?>>.css</option>
											<option value="csv" <?php echo(in_array('csv',$all_selected_types)?'selected':''); ?>>.csv</option>
											<option value="htm" <?php echo(in_array('htm',$all_selected_types)?'selected':''); ?>>.htm</option>
											<option value="html" <?php echo(in_array('html',$all_selected_types)?'selected':''); ?>>.html</option>
											<option value="txt" <?php echo(in_array('txt',$all_selected_types)?'selected':''); ?>>.txt</option>
											<option value="rtx" <?php echo(in_array('rtx',$all_selected_types)?'selected':''); ?>>.rtx</option>
											<option value="vtt" <?php echo(in_array('vtt',$all_selected_types)?'selected':''); ?>>.vtt</option>
										</optgroup>
									<optgroup label="Application formats">
											<option value="doc" <?php echo(in_array('doc',$all_selected_types)?'selected':''); ?>>.doc</option>
											<option value="docx" <?php echo(in_array('docx',$all_selected_types)?'selected':''); ?>>.docx</option>
											<option value="exe" <?php echo(in_array('exe',$all_selected_types)?'selected':''); ?>>.exe</option>
											<option value="js" <?php echo(in_array('js',$all_selected_types)?'selected':''); ?>>.js</option>
											<option value="odt" <?php echo(in_array('odt',$all_selected_types)?'selected':''); ?>>.odt</option>
											<option value="pdf" <?php echo(in_array('pdf',$all_selected_types)?'selected':''); ?>>.pdf</option>
											<option value="pot" <?php echo(in_array('pot',$all_selected_types)?'selected':''); ?>>.pot</option>
											<option value="ppt" <?php echo(in_array('ppt',$all_selected_types)?'selected':''); ?>>.ppt</option>
											<option value="pptx" <?php echo(in_array('pptx',$all_selected_types)?'selected':''); ?>>.pptx</option>
											<option value="psd" <?php echo(in_array('psd',$all_selected_types)?'selected':''); ?>>.psd</option>
											<option value="rar" <?php echo(in_array('rar',$all_selected_types)?'selected':''); ?>>.rar</option>
											<option value="rtf" <?php echo(in_array('rtf',$all_selected_types)?'selected':''); ?>>.rtf</option>
											<option value="swf" <?php echo(in_array('swf',$all_selected_types)?'selected':''); ?>>.swf</option>
											<option value="tar" <?php echo(in_array('tar',$all_selected_types)?'selected':''); ?>>.tar</option>
											<option value="xls" <?php echo(in_array('xls',$all_selected_types)?'selected':''); ?>>.xls</option>
											<option value="xlsx" <?php echo(in_array('xlsx',$all_selected_types)?'selected':''); ?>>.xlsx</option>
											<option value="zip" <?php echo(in_array('zip',$all_selected_types)?'selected':''); ?>>.zip</option>
										</optgroup>
								</select>
							</div>
						</div>
					<?php } else if ( $field_type == 'date' ) { ?>
						<div class="db-field-row <?php echo(isset($field_settings['date_format'])&&$field_settings['date_format']!=''?'active':'active'); ?> clearfix">
							<label class="field-label">Date format</label>
							<div class="db-field-input">
								<input type="text" class="db-create-date-format" value="<?php echo(isset($field_settings['date_format'])?$field_settings['date_format']:'mm/dd/yy'); ?>">
								<span class="field-description">Provide date format for the datepicker</span>
							</div>
						</div>
					<?php } else if ( $field_type == 'multi-select' ) { ?>
						<div class="db-field-row focused active clearfix">
							<label class="field-label">Multiselect type</label>
							<div class="db-field-input">
								<select class="db-create-multiselect-type">
									<option value="select" <?php echo(isset($field_settings['multiselect_type'])&&$field_settings['multiselect_type']=='select'?'selected':''); ?>>Select</option>
									<option value="checkbox" <?php echo(isset($field_settings['multiselect_type'])&&$field_settings['multiselect_type']=='checkbox'?'selected':''); ?>>Checkbox</option>
								</select>
								<span class="field-description">What type of multiselect field is this?</span>
							</div>
						</div>
						<div class="db-field-row <?php echo (isset($field_settings['select_options'])&&$field_settings['select_options']!=''?'active':'') . (isset($field_settings['field_name']) && $field_settings['field_name'] == 'amenities'?' amenities':''); ?> clearfix">
							<label class="field-label">Multiselect values</label>
							<div class="db-field-input">
								<textarea class="db-create-select-options"><?php echo(isset($field_settings['select_options'])?$field_settings['select_options']:''); ?></textarea>
								<?php if ( isset($field_settings['field_name']) && $field_settings['field_name'] == 'amenities' ) { ?>
									<span class="field-description">Provide amenities values, field name:field value:media image id, each value in a new line like so:</span>
									<span class="field-description">wheelchair:Wheelchair access<br />kids-corder:Kids corner:11</span><br />
									<span class="field-description">Read more about amenities <a href="http://documentation.cohhe.com/whitelab/knowledgebase/amenities-field/" target="_blank">here</a></span>
								<?php } else { ?>
									<span class="field-description">Provide select option values, field name:field value, each value in a new line like so:</span>
									<span class="field-description">no-wifi:No WiFi<br>wifi-included:WiFi included</span>
									<?php } ?>
							</div>
						</div>
					<?php } else if ( $field_type == 'checkbox' ) { ?>
						<div class="db-field-row <?php echo(isset($field_settings['checkbox_true'])&&$field_settings['checkbox_true']!=''?'active':''); ?> clearfix">
							<label class="field-label">Checked checkbox value</label>
							<div class="db-field-input">
								<input type="text" class="db-create-checkbox-true" value="<?php echo(isset($field_settings['checkbox_true'])?$field_settings['checkbox_true']:''); ?>">
								<span class="field-description">When checkbox is shown as checked, this value will be shown.</span>
							</div>
						</div>
						<div class="db-field-row <?php echo(isset($field_settings['checkbox_false'])&&$field_settings['checkbox_false']!=''?'active':''); ?> clearfix">
							<label class="field-label">Un-checked checkbox value</label>
							<div class="db-field-input">
								<input type="text" class="db-create-checkbox-false" value="<?php echo(isset($field_settings['checkbox_false'])?$field_settings['checkbox_false']:''); ?>">
								<span class="field-description">When checkbox is shown as un-checked, this value will be shown.</span>
							</div>
						</div>
					<?php } ?>
					<input type="hidden" class="db-create-field-type" value="<?php echo $field_type; ?>">
					<?php if ( !isset($_GET['field_id']) ) { ?>
						<a href="javascript:void(0)" class="db-save-field db-button db-primary-button" data-save="insert">Create field</a>
					<?php } else {
						if ( $is_child ) {
							?><input type="hidden" class="db-create-child" value="true"><?php
						} ?>
						<a href="javascript:void(0)" class="db-save-field db-button db-primary-button" data-save="update" data-id="<?php echo esc_attr($_GET['field_id']); ?>">Save field</a>
					<?php } ?>
				</div>
			<?php } ?>
		</div>
	</div>
	<?php
}

function db_reg_html() {
	if ( !current_user_can('manage_options') )  {
		wp_die( __('You do not have sufficient permissions to access this page.', 'directory-builder') );
	}
	?>
	<div class="db-main-wrapper container-fluid" id="db-main-wrapper">
		<div class="db-main-content main-card">
			<?php if ( !isset($_GET['field_type']) && !isset($_GET['field_id']) ) { ?>
				<a href="javascript:void(0)" class="db-add-new-field db-button db-primary-button">Add new</a>
				<table class="table table-striped table-hover">
					<thead>
						<tr>
							<th style="width: 5%;">Order</th>
							<th style="width: 65%;">Name</th>
							<th style="width: 15%;">Type</th>
							<th style="width: 15%;">Action</th>
						</tr>
					</thead>
					<tbody>
						<?php
						global $wpdb;
						$field_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_registration ORDER BY field_order, ID ASC');
						if ( !empty($field_list) ) {
							foreach ($field_list as $field_value) {
								$field_settings = json_decode($field_value->field_settings, true);
								$is_child = (isset($field_settings['child'])&&$field_settings['child']=='true'?'db-child-field':'');
								$disabled_settings = (isset($field_settings['disabled'])?explode(',', $field_settings['disabled']):array());

								echo '
								<tr>
									<td class="db-field-order">'.$field_settings['display_order'].'</td>
									<td class="db-field-name">'.$field_settings['frontend_title'].'</td>
									<td class="db-custom-field-type">'.$field_settings['field_type'].'</td>
									<td class="db-field-actions">';
										if ( !in_array('edit', $disabled_settings) ) {
											echo '<a href="'.DB_PLUGIN_REG_PAGE_URL.'&field_id='.$field_value->ID.'" class="db-edit-field">Edit</a>';
										}
										echo ' ';
										if ( !in_array('delete', $disabled_settings) ) {
											echo '<a href="javascript:void(0)" class="db-delete-reg-field" data-id="'.$field_value->ID.'">Delete</a>';
										}
									echo '
									</td>
								</tr>';
							}
						}
						?>
					</tbody>
				</table>
				<div class="db-custom-field-dialog main-card" style="display: none;">
					<div class="db-field-row clearfix">
						<label class="field-label">Field type</label>
						<select class="db-field-type">
							<option value="text">Text</option>
							<option value="textarea">Textarea</option>
							<option value="checkbox">Checkbox</option>
							<option value="radio">Radio</option>
							<option value="select">Select</option>
						</select>
					</div>
					<a href="javascript:void(0)" class="db-proceed-field db-button db-primary-button">Proceed</a>
				</div>
				<div class="db-dialog-overlay" style="display: none;"></div>
			<?php } else if ( isset($_GET['field_type']) || isset($_GET['field_id']) ) {
				$field_settings = array();
				$disabled_settings = array();
				$is_child = false;
				global $wpdb;

				if ( isset($_GET['field_id']) ) {
					$field_data = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_registration WHERE ID="'.intval($_GET['field_id']).'"');
					$field_settings = json_decode($field_data['0']->field_settings, true);
					$disabled_settings = (isset($field_settings['disabled'])?explode(',', $field_settings['disabled']):array());
					$is_child = (isset($field_settings['child'])&&$field_settings['child']=='true'?true:false);
				}
				$field_type = (isset($_GET['field_type'])?sanitize_text_field($_GET['field_type']):$field_settings['field_type']);

				if ( isset($_GET['field_type']) ) {
					$order_val = $wpdb->get_var('SELECT MAX(field_order) FROM '.$wpdb->prefix.'directory_registration');

					if ( $order_val !== null ) {
						$new_field_order = intval($order_val) + 1;
					} else {
						$new_field_order = '1';
					}
				}

				?>
				<div class="db-custom-field">
					<div class="db-box-title">
						<h3 class="db-main-title">Custom registration field</h3>
					</div>
					<?php if ( !in_array('delete', $disabled_settings) ) { ?>
						<div class="db-field-row <?php echo(isset($field_settings['field_name'])&&$field_settings['field_name']!=''?'active':''); ?> clearfix">
							<label class="field-label">Field name <span class="db-required">*</span></label>
							<div class="db-field-input">
								<input type="text" class="db-create-field-name" data-required="true" value="<?php echo(isset($field_settings['field_name'])?$field_settings['field_name']:''); ?>">
								<span class="field-description">Unique name only from letters a-z</span>
								<span class="db-field-required">This field is required</span>
							</div>
						</div>
					<?php } ?>
					<div class="db-field-row <?php echo(isset($field_settings['frontend_title'])&&$field_settings['frontend_title']!=''?'active':''); ?> clearfix">
						<label class="field-label">Frontend title <span class="db-required">*</span></label>
						<div class="db-field-input">
							<input type="text" class="db-create-frontend-title" data-required="true" value="<?php echo(isset($field_settings['frontend_title'])?$field_settings['frontend_title']:''); ?>">
							<span class="field-description">How this field is going to be shown to other users</span>
							<span class="db-field-required">This field is required</span>
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Display order</label>
						<div class="db-field-input">
							<input type="number" class="db-create-display-order" value="<?php echo(isset($field_settings['display_order'])?$field_settings['display_order']:$new_field_order); ?>" <?php echo(in_array('display_order', $disabled_settings)?'disabled':''); ?>>
							<span class="field-description">The order in which it's goint to be shown to users</span>
						</div>
					</div>
					<div class="db-field-row focused active clearfix">
						<label class="field-label">Active?</label>
						<div class="db-field-input">
							<select class="db-create-field-active" <?php echo(in_array('field_active', $disabled_settings)?'disabled':''); ?>>
								<option value="yes" <?php echo(isset($field_settings['field_active'])&&$field_settings['field_active']=='yes'?'selected':''); ?>>Yes</option>
								<option value="no" <?php echo(isset($field_settings['field_active'])&&$field_settings['field_active']=='no'?'selected':''); ?>>No</option>
							</select>
							<span class="field-description">Do you want to show this field to users?</span>
						</div>
					</div>
					<div class="db-field-row focused active clearfix">
						<label class="field-label">Where to show this field?</label>
						<div class="db-field-input">
							<?php
							if ( isset($field_settings['field_for']) && !is_array($field_settings['field_for']) ) {
								$field_settings['field_for'] = json_decode( $field_settings['field_for'], true );
							}
							?>
							<select class="db-create-field-for" multiple>
								<option value="shortcode" <?php echo (isset($field_settings['field_for'])&&!empty($field_settings['field_for'])&&in_array('shortcode', $field_settings['field_for'])?'selected':''); ?>>At registration shortcode</option>
								<option value="modal" <?php echo (isset($field_settings['field_for'])&&!empty($field_settings['field_for'])&&in_array('modal', $field_settings['field_for'])?'selected':''); ?>>At header modal dialog</option>
								<option value="add_listing" <?php echo (isset($field_settings['field_for'])&&!empty($field_settings['field_for'])&&in_array('add_listing', $field_settings['field_for'])?'selected':''); ?>>At add listing page</option>
							</select>
						</div>
					</div>
					<div class="db-field-row focused active clearfix">
						<label class="field-label">Required?</label>
						<div class="db-field-input">
							<select class="db-create-required">
								<option value="yes" <?php echo(isset($field_settings['required'])&&$field_settings['required']=='yes'?'selected':''); ?>>Yes</option>
								<option value="no" <?php echo(isset($field_settings['required'])&&$field_settings['required']=='no'?'selected':''); ?>>No</option>
							</select>
							<span class="field-description">Is it required to fill this field in?</span>
						</div>
					</div>
					<?php if ( isset( $field_settings['disabled'] ) ) { ?>
						<input type="hidden" class="db-create-disabled" value="<?php echo $field_settings['disabled']; ?>">
					<?php } ?>
					<?php if ( in_array('delete', $disabled_settings) ) { ?>
						<input type="hidden" class="db-create-field-name" data-required="true" value="<?php echo(isset($field_settings['field_name'])?$field_settings['field_name']:''); ?>">
					<?php } ?>
					<?php if ( $field_type == 'radio' ) { ?>
						<div class="db-field-row <?php echo(isset($field_settings['radio_options'])&&$field_settings['radio_options']!=''?'active':''); ?> clearfix">
							<label class="field-label">Radio button values</label>
							<div class="db-field-input">
								<input type="text" class="db-create-radio-options" value="<?php echo(isset($field_settings['radio_options'])?$field_settings['radio_options']:''); ?>">
								<span class="field-description">Provide radio button values separated with comma:</span>
								<span class="field-description">No WiFi,WiFi included,Nagotiable</span>
							</div>
						</div>
					<?php } else if ( $field_type == 'select' ) { ?>
						<div class="db-field-row <?php echo(isset($field_settings['select_options'])&&$field_settings['select_options']!=''?'active':''); ?> clearfix">
							<label class="field-label">Select values</label>
							<div class="db-field-input">
								<textarea class="db-create-select-options"><?php echo(isset($field_settings['select_options'])?$field_settings['select_options']:''); ?></textarea>
								<span class="field-description">Provide select option values, field name:field value, each value in a new line like so:</span>
								<span class="field-description">no-wifi:No WiFi<br>wifi-included:WiFi included</span>
							</div>
						</div>
					<?php } ?>
					<input type="hidden" class="db-create-field-type" value="<?php echo (isset($field_settings['field_type'])?$field_settings['field_type']:$field_type); ?>">
					<?php if ( !isset($_GET['field_id']) ) { ?>
						<a href="javascript:void(0)" class="db-save-reg-field db-button db-primary-button" data-save="insert">Create field</a>
					<?php } else {
						if ( $is_child ) {
							?><input type="hidden" class="db-create-child" value="true"><?php
						} ?>
						<a href="javascript:void(0)" class="db-save-reg-field db-button db-primary-button" data-save="update" data-id="<?php echo esc_attr($_GET['field_id']); ?>">Save field</a>
					<?php } ?>
				</div>
			<?php } ?>
		</div>
	</div>
	<?php
}

function db_send_notification_email( $user_id, $template, $attributes = array(), $to_whom = '', $to_admin = '' ) {
	$output = '';
	$main_temaplates = get_option( 'db_main_templates', array() );
	$user_message = $admin_message = '';
	$blog_name = get_bloginfo('name');

	if ( $to_whom == '' ) {
		$user_data = get_userdata( $user_id );
		$user_email_address = $user_data->data->user_email;
	} else {
		$user_email_address = $to_whom;
	}

	if ( $to_admin == '' ) {
		$admin_email_address = get_bloginfo('admin_email');
	} else {
		$admin_email_address = $to_admin;
	}

	if ( $template == 'new_user_confirm' ) {
		$subject = '['.$blog_name.'] - ' . esc_html__( 'User registration confirmation', 'directory-builder' );

		$user_message = nl2br( $main_temaplates['new_user_confirm'] );
		if ( !empty($attributes) ) {
			foreach ($attributes as $att_key => $att_value) {
				if ( strpos($att_key, 'url_') === 0 ) {
					$user_message = str_replace('{'.$att_key.'}', '<a href="'.$att_value.'">'.$att_value.'</a>', $user_message);
				} else {
					$user_message = str_replace('{'.$att_key.'}', $att_value, $user_message);
				}
			}
		}
	} else if ( $template == 'new_user' ) {
		$subject = '['.$blog_name.'] - ' . esc_html__( 'User registration', 'directory-builder' );

		$user_message = nl2br( $main_temaplates['new_user'] );
		if ( !empty($attributes) ) {
			foreach ($attributes as $att_key => $att_value) {
				if ( strpos($att_key, 'url_') === 0 ) {
					$user_message = str_replace('{'.$att_key.'}', '<a href="'.$att_value.'">'.$att_value.'</a>', $user_message);
				} else {
					$user_message = str_replace('{'.$att_key.'}', $att_value, $user_message);
				}
			}
		}

		$admin_message = sprintf( __( 'A new user, %s, just confirmed email address and completed registration process!', 'directory-builder' ), '<strong>' . $attributes['username'] . '</strong>' );
	} else if ( $template == 'new_claim' ) {
		$subject = '['.$blog_name.'] - ' . esc_html__( 'Listing claimed', 'directory-builder' );

		$user_message = nl2br( $main_temaplates['new_claim'] );
		if ( !empty($attributes) ) {
			foreach ($attributes as $att_key => $att_value) {
				if ( strpos($att_key, 'url_') === 0 ) {
					$user_message = str_replace('{'.$att_key.'}', '<a href="'.$att_value.'">'.$att_value.'</a>', $user_message);
				} else {
					$user_message = str_replace('{'.$att_key.'}', $att_value, $user_message);
				}
			}
		}

		$admin_message = sprintf( __( 'The user %s just claimed a listing %s<br>Listing can be found here: %s', 'directory-builder' ), '<strong>' . $attributes['username'] . '</strong>', $attributes['listing_title'], '<a href="'.$attributes['listing'].'">'.$attributes['listing'].'</a>' );
	} else if ( $template == 'new_payment' ) {
		$subject = '['.$blog_name.'] - ' . esc_html__( 'Payment received', 'directory-builder' );

		$user_message = nl2br( $main_temaplates['new_payment'] );
		if ( !empty($attributes) ) {
			foreach ($attributes as $att_key => $att_value) {
				if ( strpos($att_key, 'url_') === 0 ) {
					$user_message = str_replace('{'.$att_key.'}', '<a href="'.$att_value.'">'.$att_value.'</a>', $user_message);
				} else {
					$user_message = str_replace('{'.$att_key.'}', $att_value, $user_message);
				}
			}
		}

		$admin_message = sprintf( __( 'A payment of %s was just received for %s', 'directory-builder' ), $attributes['price'], '<a href="'.$attributes['url_listing'].'">'.$attributes['url_listing'].'</a>' );
	} else if ( $template == 'new_listing' ) {
		$subject = '['.$blog_name.'] - ' . esc_html__( 'Listing added', 'directory-builder' );

		$user_message = nl2br( $main_temaplates['new_listing'] );
		if ( !empty($attributes) ) {
			foreach ($attributes as $att_key => $att_value) {
				if ( strpos($att_key, 'url_') === 0 ) {
					$user_message = str_replace('{'.$att_key.'}', '<a href="'.$att_value.'">'.$att_value.'</a>', $user_message);
				} else {
					$user_message = str_replace('{'.$att_key.'}', $att_value, $user_message);
				}
			}
		}

		$admin_message = sprintf( __( 'A new listing was just added by %s<br>Listing can be viewed at: %s', 'directory-builder' ), '<strong>' . $attributes['username'] . '</strong>', '<a href="'.$attributes['url_listing'].'">'.$attributes['url_listing'].'</a>' );
	} else if ( $template == 'new_booking' ) {
		$subject = '['.$blog_name.'] - ' . esc_html__( 'New appointment', 'directory-builder' );

		$user_message = nl2br( $main_temaplates['new_booking'] );
		if ( !empty($attributes) ) {
			foreach ($attributes as $att_key => $att_value) {
				if ( strpos($att_key, 'url_') === 0 ) {
					$user_message = str_replace('{'.$att_key.'}', '<a href="'.$att_value.'">'.$att_value.'</a>', $user_message);
				} else {
					$user_message = str_replace('{'.$att_key.'}', $att_value, $user_message);
				}
			}
		}

		$admin_message = sprintf( __( 'There\'s a new appointment made for your listing %s<br /><br />Appointment date: %s<br />Name: %s<br />Email: %s<br />Comments: %s', 'directory-builder' ), $attributes['calendar_url'], $attributes['app_date'], $attributes['app_name'], $attributes['app_email'], $attributes['app_comment'] );

		if ( $to_admin == '' ) {
			$admin_message = '';
		}
	}

	if ( $user_message != '' ) {
		add_filter( 'wp_mail_content_type','db_set_content_type' );
		add_filter( 'wp_mail_from_name', 'db_custom_wp_mail_from_name' );
		add_filter( 'wp_mail_from', 'db_custom_wp_mail_from' );
		$notice_user_email = wp_mail( $user_email_address, $subject, $user_message );
		remove_filter( 'wp_mail_from', 'db_custom_wp_mail_from' );
		if ( $admin_message != '' ) {
			$notice_admin_email = wp_mail( $admin_email_address, $subject, $admin_message );
		}
		remove_filter( 'wp_mail_content_type','db_set_content_type' );
		remove_filter( 'wp_mail_from_name', 'db_custom_wp_mail_from_name' );

		// Possible to debug if emails were sent
		// $notification_list = get_option( 'db_notification_emails', array() );
		// $notification_list[] = 'USER - email to ' . $user_email_address . ', with template: ' . $template . ', status: ' . ($notice_user_email?'success':'failed') . ', message: ' . $user_message;
		// $notification_list[] = 'ADMIN - email to ' . $admin_email_address . ', with template: ' . $template . ', status: ' . ($notice_admin_email?'success':'failed') . ', message: ' . $admin_message;
		// update_option( 'db_notification_emails', $notification_list );
	}
}

function db_email_html() {
	if ( !current_user_can('manage_options') )  {
		wp_die( __('You do not have sufficient permissions to access this page.', 'directory-builder') );
	}

	$main_templates = get_option( 'db_main_templates', array() );
	?>
	<div class="db-main-wrapper container-fluid" id="db-main-wrapper">
		<div class="db-main-content">
			<div class="db-box-wrapper">
				<div class="db-box-left">
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">New user confirmation email template</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<div class="col-sm-12">
										<textarea class="db-template-new_user_confirm"><?php echo ( isset($main_templates['new_user_confirm']) ? $main_templates['new_user_confirm'] : '' ); ?></textarea>
										<span class="field-description">You can use the following code pieces:</span>
										<ul>
											<li><strong>{username}</strong> - Replaced with the username</li>
											<li><strong>{url_confirm}</strong> - Replaced with the user confirmation URL</li>
										</ul>
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">New listing template</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<div class="col-sm-12">
										<textarea class="db-template-new_listing"><?php echo ( isset($main_templates['new_listing']) ? $main_templates['new_listing'] : '' ); ?></textarea>
										<span class="field-description">If no text is provided, then the email is not sent to user and site admin</span>
										<span class="field-description"><strong>Note that if new listing status is set to pending approval, then <em>{url_listing}</em> will return a 404 page, so do not include it in the email template!</strong></span><br />
										<span class="field-description">You can use the following code pieces:</span>
										<ul>
											<li><strong>{username}</strong> - Replaced with the username</li>
											<li><strong>{url_dashboard}</strong> - Replaced with the user dashboard URL</li>
											<li><strong>{url_listing}</strong> - Replaced with the URL of listing</li>
										</ul>
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">Payment email template</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<div class="col-sm-12">
										<textarea class="db-template-new_payment"><?php echo ( isset($main_templates['new_payment']) ? $main_templates['new_payment'] : '' ); ?></textarea>
										<span class="field-description">If no text is provided, then the email is not sent to user and site admin</span>
										<span class="field-description">You can use the following code pieces:</span>
										<ul>
											<li><strong>{username}</strong> - Replaced with the username</li>
											<li><strong>{price}</strong> - Replaced with the payment price</li>
											<li><strong>{listing_title}</strong> - Replaced with the title of the listing</li>
										</ul>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
				<div class="db-box-right">
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">New user email template</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<div class="col-sm-12">
										<textarea class="db-template-new_user"><?php echo ( isset($main_templates['new_user']) ? $main_templates['new_user'] : '' ); ?></textarea>
										<span class="field-description">If no text is provided, then the email is not sent to user and site admin</span>
										<span class="field-description">You can use the following code pieces:</span>
										<ul>
											<li><strong>{username}</strong> - Replaced with the username</li>
											<li><strong>{url_dashboard}</strong> - Replaced with the user dashboard URL</li>
										</ul>
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">Listing claim template</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<div class="col-sm-12">
										<textarea class="db-template-new_claim"><?php echo ( isset($main_templates['new_claim']) ? $main_templates['new_claim'] : '' ); ?></textarea>
										<span class="field-description">If no text is provided, then the email is not sent to user and site admin</span>
										<span class="field-description">You can use the following code pieces:</span>
										<ul>
											<li><strong>{username}</strong> - Replaced with the username</li>
											<li><strong>{url_dashboard}</strong> - Replaced with the user dashboard URL</li>
											<li><strong>{listing_title}</strong> - Replaced with the title of the listing</li>
										</ul>
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">New booking template</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<div class="col-sm-12">
										<textarea class="db-template-new_booking"><?php echo ( isset($main_templates['new_booking']) ? $main_templates['new_booking'] : '' ); ?></textarea>
										<span class="field-description">If no text is provided, then the email is not sent to user and listing author</span>
										<span class="field-description">You can use the following code pieces:</span>
										<span class="booking-field-error db-error hidden">All booking details are required in the template!</span>
										<ul>
											<li><strong>{listing_url}</strong> - Replaced with the URL of listing</li>
											<li><strong>{app_date}</strong> - Replaced with the date of the appointment</li>
											<li><strong>{app_name}</strong> - Replaced with the provided name for the appointment</li>
											<li><strong>{app_email}</strong> - Replaced with the provided email for the appointment</li>
											<li><strong>{app_comment}</strong> - Replaced with the provided comments for the appointment</li>
										</ul>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
			<?php
			// Display debug email information
			// $notification_list = get_option( 'db_notification_emails', array() );
			// echo '<div class="clearfix"></div>';
			// echo '<pre>'; var_dump($notification_list); echo '</pre>';
			?>
			<div class="db-row-group col-md-12 clearfix">
				<a href="javascript:void(0)" class="db-save-templates db-button db-primary-button">Save changes</a>
			</div>

		</div>
	</div>
	<?php
}

function db_import_html() {
	if ( !current_user_can('manage_options') )  {
		wp_die( __('You do not have sufficient permissions to access this page.', 'directory-builder') );
	}

	$import_error = false;
	if ( isset($_FILES['db_import']) && $_FILES['db_import']['error'] == UPLOAD_ERR_OK && is_uploaded_file( $_FILES['db_import']['tmp_name'] ) ) {
		$file_extension = pathinfo($_FILES['db_import']['name'], PATHINFO_EXTENSION);
		
		if ( $file_extension != 'csv' ) {
			$import_error = esc_html__( 'Only .csv file extensions are available for importing process!', 'directory-builder' );
		} else if ( $_FILES['db_import']['size'] == 0 ) {
			$import_error = esc_html__( 'Uploaded file is empty!', 'directory-builder' );
		} else {
			$import_file = fopen( $_FILES['db_import']['tmp_name'], 'r' ) or die ( 'File opening failed' );
			$loop = 1;
			$import_log = array();
			
			while ( $import_data = fgetcsv( $import_file ) ) { // Loop through every csv line
				$required_fields = array( '0', '1', '2', '3' ); // Required fields to insert post
				$valid_line = true;
				$extra_listing_fields = $import_data;
				foreach ($required_fields as $req_value) { // Check if all required fields are present
					if ( !isset( $import_data[$req_value] ) || $import_data[$req_value] == '' ) {
						$valid_line = false;
					}
					unset($extra_listing_fields[$req_value]);
				}

				if ( $valid_line ) { // Add new listing 
					$new_listing_values = array(
						'post_title' => $import_data['0'],
						'post_excerpt' => $import_data['1'],
						'post_content' => $import_data['2'],
						'post_status' => $import_data['3'],
						'post_type' => 'listings'
					);
					
					$created_listing_id = wp_insert_post( $new_listing_values );
					if ( !is_wp_error( $created_listing_id ) ) {
						if ( !empty( $extra_listing_fields ) ) { // Check if there are any extra fields to add to the post meta
							$order_info = array();
							foreach ( $extra_listing_fields as $extra_value ) {
								$parsed_extra = explode('::', $extra_value);
								
								if ( isset($parsed_extra['0']) && isset($parsed_extra['1']) ) { // Check if both values are present for extra listing fields
									if ( strpos($parsed_extra['0'], 'order_') === 0 ) { // Order related information
										$order_info[str_replace('order_', '', $parsed_extra['0'])] = $parsed_extra['1'];
									} else if ( strpos($parsed_extra['0'], 'post_') === 0 ) { // Listing related information
										if ( $parsed_extra['0'] == 'post_cat' ) {
											$listing_categories = explode( '^', $parsed_extra['1'] );
											if ( !empty($listing_categories) ) {
												$new_cat_values = array();
												foreach ($listing_categories as $cat_value) {
													$new_cat_values[] = intval($cat_value);
												}
												wp_set_object_terms( $created_listing_id, $new_cat_values, 'listing_category' );
											}
										} else if ( $parsed_extra['0'] == 'post_image' ) {
											set_post_thumbnail( $created_listing_id, $parsed_extra['1'] );
										}
									} else { // Main listing data
										if ( strpos($parsed_extra['1'], '^') !== false ) {
											$parsed_extra['1'] = str_replace('^', ',', $parsed_extra['1']);
										}
										update_post_meta( $created_listing_id, $parsed_extra['0'], $parsed_extra['1'] );
									}
									
								}
							}

							if ( !empty( $order_info ) ) {
								update_post_meta( $created_listing_id, 'db_order_info', $order_info );
							}
						}

						$import_log[] = array(
							'status' => 'success',
							'id' => $created_listing_id
							);
					} else {
						$import_log[] = array(
							'status' => 'failed',
							'message' => sprintf( __( 'Failed to import line %s from import file, encountered an error: %s', 'directory-builder' ), $loop, $created_listing_id->get_error_message() )
							);
					}
				} else {
					$import_log[] = array(
							'status' => 'failed',
							'message' => sprintf( __( 'All requested fields were not set! Failed to import line %s from import file!', 'directory-builder' ), $loop )
							);
				}

				$loop++;
			}
			fclose($import_file);
		}
	}
	
	?>
	<div class="db-main-wrapper container-fluid" id="db-main-wrapper">
		<div class="db-main-content">
			<div class="db-box-wrapper">
				<div class="db-box-container col-md-12">
					<div class="db-box main-card">
						<div class="db-box-title">
							<h3 class="db-main-title">Import new listings</h3>
						</div>
						<div class="db-row">
							<div class="db-row-group db-import-main clearfix">
								<?php
								if ( $import_error !== false ) {
									echo '<p class="db-error">' . $import_error . '</p>';
								}
								?>
								<form method="POST" enctype="multipart/form-data">
									<input type="file" name="db_import" accept=".csv">
									<input type="submit" value="<?php esc_html_e('Upload and import', 'directory-builder'); ?>">
								</form>
								<p><?php esc_html_e('Import accepts .csv files, read more about the import process at our', 'directory-builder'); ?> <a href="http://documentation.cohhe.com/whitelab/knowledgebase/import-process/" target="_blank">import documentation</a>.</p>
								<?php if ( isset($import_log) && !empty( $import_log ) ) { ?>
								<table class="table table-striped table-hover db-imported-listings">
									<thead>
										<tr>
											<th style="width: 15%;">Listing name</th>
											<th style="width: 10%;">Status</th>
											<th style="width: 75%;">Message</th>
										</tr>
									</thead>
									<tbody>
									<?php
										foreach ( $import_log as $log_data ) {
											echo '
											<tr>
												<td>'.($log_data['status']=='success'?'<a href="'.get_permalink($log_data['id']).'" target="_blank">'.get_the_title($log_data['id']).'</a>':'-').'</td>
												<td>'.($log_data['status']=='success'?'<span class="db-success">'.$log_data['status'].'</span>':'<span class="db-error">'.$log_data['status'].'</span>').'</td>
												<td>'.(($log_data['status']=='success'?'<a href="'.get_admin_url().'post.php?post='.$log_data['id'].'&action=edit" target="_blank">'.__('Edit', 'directory-builder').'</a>':$log_data['message'])).'</td>
											</tr>';
										}
									?>
									</tbody>
								</table>
								<?php } ?>
							</div>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
	<?php
}

function db_save_field() {
	if ( !current_user_can('manage_options') ) die(0);

	global $wpdb;
	$field_settings = ( isset($_POST['field_settings']) ? sanitize_text_field($_POST['field_settings']) : '' );
	$save_type = ( isset($_POST['save_type']) ? sanitize_key($_POST['save_type']) : '' );
	$field_id = ( isset($_POST['field_id']) ? intval($_POST['field_id']) : '' );
	
	$field_decoded_settings = json_decode(stripslashes($field_settings), true);
	if ( isset($field_decoded_settings) ) {
		$field_order = $field_decoded_settings['display_order'];
		$field_active = $field_decoded_settings['field_active'];

		if ( $save_type == 'insert' ) {
			$save_query = $wpdb->query('INSERT INTO '.$wpdb->prefix.'directory_fields (`field_order`, `field_active`, `field_settings`) VALUES ("'.$field_order.'", "'.$field_active.'", "'.$field_settings.'")');
		} else {
			$save_query = $wpdb->query('UPDATE '.$wpdb->prefix.'directory_fields SET field_order="'.$field_order.'", field_active="'.$field_active.'", field_settings="'.$field_settings.'" WHERE ID="'.$field_id.'"');
			if ( $field_decoded_settings['field_name'] == 'listing_address' ) {
				$wpdb->query('UPDATE '.$wpdb->prefix.'directory_fields SET field_order="'.$field_order.'" WHERE field_settings LIKE "%\"field_name\":\"listing_city\"%"');
				$wpdb->query('UPDATE '.$wpdb->prefix.'directory_fields SET field_order="'.$field_order.'" WHERE field_settings LIKE "%\"field_name\":\"listing_neighborhood\"%"');
				$wpdb->query('UPDATE '.$wpdb->prefix.'directory_fields SET field_order="'.$field_order.'" WHERE field_settings LIKE "%\"field_name\":\"listing_zip\"%"');
				$wpdb->query('UPDATE '.$wpdb->prefix.'directory_fields SET field_order="'.$field_order.'" WHERE field_settings LIKE "%\"field_name\":\"listing_state\"%"');
				$wpdb->query('UPDATE '.$wpdb->prefix.'directory_fields SET field_order="'.$field_order.'" WHERE field_settings LIKE "%\"field_name\":\"listing_country\"%"');
				$wpdb->query('UPDATE '.$wpdb->prefix.'directory_fields SET field_order="'.$field_order.'" WHERE field_settings LIKE "%\"field_name\":\"listing_address_lat\"%"');
				$wpdb->query('UPDATE '.$wpdb->prefix.'directory_fields SET field_order="'.$field_order.'" WHERE field_settings LIKE "%\"field_name\":\"listing_address_lng\"%"');
			}
		}

		if ( $save_query === false ) {
			echo '{"save_response": "failed"}';
		} else {
			echo '{"save_response": "'.$wpdb->insert_id.'", "redirect": "'.DB_PLUGIN_FIELD_PAGE_URL.'"}';
		}
	}

	die(0);
}
add_action( 'wp_ajax_db_save_field', 'db_save_field' );

function db_save_reg_field() {
	if ( !current_user_can('manage_options') ) die(0);

	global $wpdb;
	$field_settings = ( isset($_POST['field_settings']) ? sanitize_text_field($_POST['field_settings']) : '' );
	$save_type = ( isset($_POST['save_type']) ? sanitize_key($_POST['save_type']) : '' );
	$field_id = ( isset($_POST['field_id']) ? intval($_POST['field_id']) : '' );
	
	$field_decoded_settings = json_decode(stripslashes($field_settings), true);
	if ( isset($field_decoded_settings) ) {
		$field_order = $field_decoded_settings['display_order'];
		$field_active = $field_decoded_settings['field_active'];

		if ( $field_order == '' ) {
			$order_val = $wpdb->get_var('SELECT MAX(field_order) FROM '.$wpdb->prefix.'directory_registration');

			if ( $order_val !== null ) {
				$field_order = intval($order_val) + 1;
			} else {
				$field_order = '1';
			}

			$field_decoded_settings['display_order'] = $field_order;
			$field_settings = addslashes( json_encode( $field_decoded_settings ) );
		}

		if ( $save_type == 'insert' ) {
			$save_query = $wpdb->query('INSERT INTO '.$wpdb->prefix.'directory_registration (`field_order`, `field_active`, `field_settings`) VALUES ("'.$field_order.'", "'.$field_active.'", "'.$field_settings.'")');
		} else {
			$save_query = $wpdb->query('UPDATE '.$wpdb->prefix.'directory_registration SET field_order="'.$field_order.'", field_active="'.$field_active.'", field_settings="'.$field_settings.'" WHERE ID="'.$field_id.'"');
		}

		if ( $save_query === false ) {
			echo '{"save_response": "failed"}';
		} else {
			echo '{"save_response": "'.$wpdb->insert_id.'", "redirect": "'.DB_PLUGIN_REG_PAGE_URL.'"}';
		}
	}

	die(0);
}
add_action( 'wp_ajax_db_save_reg_field', 'db_save_reg_field' );

function db_save_package() {
	if ( !current_user_can('manage_options') ) die(0);

	global $wpdb;
	$package_settings = ( isset($_POST['package_settings']) ? sanitize_text_field($_POST['package_settings']) : '' );
	$save_type = ( isset($_POST['save_type']) ? sanitize_key($_POST['save_type']) : '' );
	$package_id = ( isset($_POST['package_id']) ? intval($_POST['package_id']) : '' );
	
	$package_decoded_settings = json_decode(stripslashes($package_settings), true);
	if ( isset($package_decoded_settings) ) {
		if ( $save_type == 'insert' ) {
			$save_query = $wpdb->query('INSERT INTO '.$wpdb->prefix.'directory_packages (`package_name`, `package_settings`) VALUES ("'.$package_decoded_settings['fee_label'].'", "'.$package_settings.'")');
		} else {
			$save_query = $wpdb->query('UPDATE '.$wpdb->prefix.'directory_packages SET package_name="'.$package_decoded_settings['fee_label'].'", package_settings="'.$package_settings.'" WHERE ID="'.$package_id.'"');
		}

		if ( $save_query === false ) {
			echo '{"save_response": "failed"}';
		} else {
			echo '{"save_response": "'.$wpdb->insert_id.'", "redirect": "'.DB_PLUGIN_PACKAGE_PAGE_URL.'"}';
		}
	}

	die(0);
}
add_action( 'wp_ajax_db_save_package', 'db_save_package' );

function db_delete_field() {
	if ( !current_user_can('manage_options') ) die(0);

	global $wpdb;
	$field_id = ( isset($_POST['field_id']) ? intval($_POST['field_id']) : '' );

	if ( $wpdb->query('DELETE FROM '.$wpdb->prefix.'directory_fields WHERE ID="'.$field_id.'"') === false ) {
		echo '{"save_response": "failed"}';
	} else {
		echo '{"save_response": "'.$wpdb->insert_id.'"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_delete_field', 'db_delete_field' );

function db_delete_reg_field() {
	if ( !current_user_can('manage_options') ) die(0);

	global $wpdb;
	$field_id = ( isset($_POST['field_id']) ? intval($_POST['field_id']) : '' );

	if ( $wpdb->query('DELETE FROM '.$wpdb->prefix.'directory_registration WHERE ID="'.$field_id.'"') === false ) {
		echo '{"save_response": "failed"}';
	} else {
		echo '{"save_response": "'.$wpdb->insert_id.'"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_delete_reg_field', 'db_delete_reg_field' );

add_action( 'load-post.php', 'db_metabox_setup' );
add_action( 'load-post-new.php', 'db_metabox_setup' );
function db_metabox_setup() {

	/* Add meta boxes on the 'add_meta_boxes' hook. */
	add_action( 'add_meta_boxes', 'db_add_metabox' );

	/* Save post meta on the 'save_post' hook. */
	add_action( 'save_post', 'db_save_field_metabox', 10, 2 );
}

function db_save_field_metabox( $post_id, $post ) {
	/* Verify the nonce before proceeding. */
	if ( !isset( $_POST['db_listing_field_nonce'] ) || !wp_verify_nonce( $_POST['db_listing_field_nonce'], basename( __FILE__ ) ) || $post->post_type == 'revision' )
	return $post_id;

	/* Get the post type object. */
	$post_type = get_post_type_object( $post->post_type );

	/* Check if the current user has permission to edit the post. */
	if ( !current_user_can( $post_type->cap->edit_post, $post_id ) )
	return $post_id;

	$meta_values = array(
		'listing_gallery_img',
		'db_listing_custom_img',
		'allow_bookings',
		'booking_interval',
		'booking_interval_val',
		'listing_fmenu'
	);

	global $wpdb;
	$field_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_fields WHERE field_active="yes" ORDER BY field_order DESC');
	if ( !empty($field_list) ) {
		foreach ($field_list as $field_value) {
			$field_settings = json_decode($field_value->field_settings, true);
			$meta_values[] = $field_settings['field_name'];
		}
	}

	foreach ($meta_values as $a_meta_value) {
		/* Get the posted data and sanitize it for use as an HTML class. */
		$new_meta_value   = ( isset( $_POST[$a_meta_value] ) ? ( !is_array( $_POST[$a_meta_value] ) ? sanitize_text_field( $_POST[$a_meta_value] ) : db_sanitize_array( $_POST[$a_meta_value] ) ) : '' );
		
		/* Get the meta key. */
		$meta_key   = sanitize_key($a_meta_value);

		/* Get the meta value of the custom field key. */
		$meta_value   = get_post_meta( $post_id, $meta_key, true );

		/* If a new meta value was added and there was no previous value, add it. */
		if ( $new_meta_value && '' != $new_meta_value )
		update_post_meta( $post_id, $meta_key, $new_meta_value );

		/* If there is no new meta value but an old value exists, delete it. */
		elseif ( '' == $new_meta_value && $meta_value )
		delete_post_meta( $post_id, $meta_key, $meta_value );
	}

	// Update paid category
	$sanitized_categories = array();
	$unsanitized_categories = $_POST['tax_input']['listing_category'];
	if ( is_array($unsanitized_categories) && !empty($unsanitized_categories) ) {
		foreach ($unsanitized_categories as $cat_value) {
			$sanitized_categories[] = intval($cat_value);
		}
	}
	$order_options = get_post_meta( $post_id, 'db_order_info', true );
	$order_options['category'] = implode(',', $sanitized_categories);
	update_post_meta( $post_id, 'db_order_info', $order_options );
}

function db_sanitize_array( $data ) {
	if ( !empty($data) ) {
		foreach ($data as $field_key => $field_value) {
			$data[$field_key] = sanitize_text_field( $field_value );
		}
	}

	return $data;
}

function db_add_metabox() {

	add_meta_box(
		'directory_listing_fields',                                      // Unique ID
		esc_html__( 'Advanced listing fields', 'directory-builder' ),    // Title
		'db_field_metabox_function',                                     // Callback function
		'listings',                                                      // Admin page (or post type)
		'advanced',                                                      // Context
		'high'                                                           // Priority
	);

	add_meta_box(
		'directory_listing_orders',                                      // Unique ID
		esc_html__( 'Order details', 'directory-builder' ),       // Title
		'db_order_metabox_function',                                     // Callback function
		'listings',                                                      // Admin page (or post type)
		'side',                                                          // Context
		'high'                                                           // Priority
	);

	add_meta_box(
		'directory_listing_payments',                                    // Unique ID
		esc_html__( 'Payment history', 'directory-builder' ),              // Title
		'db_payment_metabox_function',                                   // Callback function
		'listings',                                                      // Admin page (or post type)
		'side',                                                          // Context
		'high'                                                           // Priority
	);

	add_meta_box(
		'directory_listing_notes',                                    // Unique ID
		esc_html__( 'Gateway notes', 'directory-builder' ),              // Title
		'db_notes_metabox_function',                                   // Callback function
		'listings',                                                      // Admin page (or post type)
		'side',                                                          // Context
		'high'                                                           // Priority
	);

	add_meta_box(
		'directory_listing_image',                                       // Unique ID
		esc_html__( 'Open listing image', 'directory-builder' ),         // Title
		'db_listing_img_metabox_function',                               // Callback function
		'listings',                                                      // Admin page (or post type)
		'side',                                                          // Context
		'low'                                                            // Priority
	);

}

function db_field_metabox_function( $object, $box ) { ?>

	<?php
		wp_nonce_field( basename( __FILE__ ), 'db_listing_field_nonce' );
		$listing_images = esc_attr( get_post_meta( $object->ID, 'listing_gallery_img', true ) );
		$main_settings = get_option( 'db_main_settings');

		$listing_address = (get_post_meta( $object->ID, 'listing_address', true )?get_post_meta( $object->ID, 'listing_address', true ):$main_settings['default_location']);
		$listing_address_lat = (get_post_meta( $object->ID, 'listing_address_lat', true )?get_post_meta( $object->ID, 'listing_address_lat', true ):$main_settings['default_location_lat']);
		$listing_address_lng = (get_post_meta( $object->ID, 'listing_address_lng', true )?get_post_meta( $object->ID, 'listing_address_lng', true ):$main_settings['default_location_lng']);
	?>

	<style type="text/css">
		.db-field-row-label, .db-field-row-description, .db-radio-label, .db-checkbox-label { display: block; }
		.db-field-row { margin-bottom: 1em; }
		.db-field-row input:not([type="radio"]):not([type="checkbox"]):not([type="button"]), .db-field-row select, .db-field-row textarea { display: block; width: 100%; }
	</style>

	<?php
	global $wpdb;
	$field_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_fields WHERE field_active="yes" ORDER BY field_order ASC');
	if ( !empty($field_list) ) {
		foreach ($field_list as $field_value) {
			$field_settings = json_decode($field_value->field_settings, true);

			$default_value = get_post_meta( $object->ID, $field_settings['field_name'], true );

			if ( $field_settings['field_name'] == 'listing_address' && $default_value == '' ) {
				$default_value = $listing_address;
			} else if ( $field_settings['field_name'] == 'listing_address_lat' && $default_value == '' ) {
				$default_value = $listing_address_lat;
			} else if ( $field_settings['field_name'] == 'listing_address_lng' && $default_value == '' ) {
				$default_value = $listing_address_lng;
			}

			echo db_get_custom_field( $field_settings, '', $default_value );

			if ( $field_settings['field_name'] == 'listing_address_lng' ) { ?>
				<a href="javascript:void(0)" class="db-set-address button button-primary button-large">Set address</a>
				<br /><br />
				<script async defer src="https://maps.googleapis.com/maps/api/js?key=<?php echo $main_settings['google_key']; ?>" type="text/javascript"></script>
				<script type="text/javascript">
					jQuery(window).load(function() {
						var $geocoder;
						var $map;
						var $first_marker;
						function db_start_geolocation() {
							$geocoder = new google.maps.Geocoder()
							var address = <?php echo (isset($listing_address)&&$listing_address!=''?'"'.$listing_address.'";':'"'.$default_location.'";'); ?>
							$geocoder.geocode( { "address": address}, function(results, status) {

								if (status == google.maps.GeocoderStatus.OK) {
									db_initialize(results[0].geometry.location);
									jQuery('#listing_address_lat').val(results[0].geometry.location.lat());
									jQuery('#listing_address_lng').val(results[0].geometry.location.lng());
								} 
							});
						}
						
						function db_initialize(location) {
							var mapCanvas = document.getElementById("db-listing-map");
							var myLatlng = location;
							var mapOptions = {
								center: location,
								zoom: 13,
								mapTypeId: google.maps.MapTypeId.ROADMAP,
								scrollwheel: false,
								navigationControl: false,
								mapTypeControl: false,
								scaleControl: false,
								disableDefaultUI: false
							}
							$map = new google.maps.Map(mapCanvas, mapOptions);

							$first_marker = new google.maps.Marker({
								position: myLatlng,
								map: $map,
								draggable: true
							});
							db_add_dragend_event( $first_marker );
						}

						function db_add_dragend_event( marker_obj ) {
							google.maps.event.addListener(marker_obj, 'dragend', function (event) {
								jQuery('#listing_address_lat').val(this.getPosition().lat());
								jQuery('#listing_address_lng').val(this.getPosition().lng());
								jQuery('.db-set-address').addClass('dragged').click();
							});
						}
						<?php if ( $listing_address_lat != '' && $listing_address_lng != '' ) { ?>
							db_initialize( new google.maps.LatLng(jQuery('#listing_address_lat').val(), jQuery('#listing_address_lng').val()) );
						<?php } else { ?>
							db_start_geolocation();
						<?php } ?>
						jQuery(document).on('click', '.db-set-address', function() {
							var google_json_address;
							if ( !jQuery(this).hasClass('dragged') ) {
								google_json_address = encodeURIComponent( jQuery('#listing_address').val() );
							} else {
								google_json_address = encodeURIComponent( jQuery('#listing_address_lat').val()+','+jQuery('#listing_address_lng').val() );
							}
							jQuery.get('https://maps.googleapis.com/maps/api/geocode/json?address='+google_json_address+'&key=<?php echo $main_settings['google_key']; ?>&language=en', function( data ) {
								if ( data.status == 'OK' ) {
									$first_marker.setMap(null);
									var marker = new google.maps.Marker({ position: data.results['0'].geometry.location, map: $map, draggable: true });
									$first_marker = marker;
									db_add_dragend_event( $first_marker );

									jQuery('#listing_city, #listing_zip, #listing_neighborhood, #listing_state').val('');
									jQuery.each(data.results['0'].address_components, function( index, address_comp ) {
										if( ( address_comp.types[0] == "locality" && address_comp.types[1] == "political" ) || address_comp.types[0] == "postal_town" ) {
											jQuery('#listing_city').val( address_comp.long_name );
										}

										if( address_comp.types[0] == "country" && address_comp.types[1] == "political" ) {
											if ( jQuery('[name="listing_country"] option[value="'+address_comp.long_name+'"]').length ) {
												jQuery('[name="listing_country"]').val( address_comp.long_name );
											} else {
												jQuery('[name="listing_country"]').append('<option value="'+address_comp.long_name+'">'+address_comp.long_name+'</option>').val( address_comp.long_name );
											}
										}

										if( address_comp.types[0] == "postal_code" ) {
											jQuery('#listing_zip').val( address_comp.long_name );
										}

										if ( ( address_comp.types[0] == "administrative_area_level_1" && address_comp.types[1] == "political" ) || address_comp.types[0] == "neighborhood" && address_comp.types[1] == "political" ) {
											jQuery('#listing_neighborhood').val( address_comp.long_name );
										}

										if ( address_comp.types[0] == "administrative_area_level_2" && address_comp.types[1] == "political" ) {
											jQuery('#listing_state').val( address_comp.long_name );
										}
									});

									jQuery('#listing_address').val( data.results['0'].formatted_address );

									jQuery('#listing_address_lat').val(data.results['0'].geometry.location.lat);
									jQuery('#listing_address_lng').val(data.results['0'].geometry.location.lng);

									$map.setCenter(data.results['0'].geometry.location);
									jQuery('.db-set-address').removeClass('dragged');
								} else {
									if ( data.status == 'OVER_QUERY_LIMIT' ) {
										alert('You\'re over your API query limit!');
									} else if ( data.status == 'REQUEST_DENIED' ) {
										alert('Seems like your address request was denied by Google!');
									} else {
										alert('Your address couldn\'t be found');
									}
								}
							});
						});
					});
				</script>
				<div id="db-listing-map" style="width: 100%; height: 300px;"></div>
				<br />
				<?php
			}
		}
	}

	if ( isset($main_settings['listing_menu']) && $main_settings['listing_menu'] === true ) {
		$listing_fmenu_json = get_post_meta( intval($_GET['post']), 'listing_fmenu', true );
		$listing_fmenu = (isset($listing_fmenu_json)&&$listing_fmenu_json!=''?json_decode($listing_fmenu_json, true):false);
		echo '
		<div class="db-field-row db-fmenu-row clearfix" data-for="'.(isset($main_settings['listing_menu_cat'])&&$main_settings['listing_menu_cat']!=''?implode(',',$main_settings['listing_menu_cat']):array()).'">
			<label>'.esc_html__('Full menu', 'directory-builder').'</label>
			<div class="clearfix"></div>
			<span class="db-field-row-desc">'.esc_html__('Menu consists of categories that are broken down into individual items. You can create unlimited amount of categories and items.', 'directory-builder').'</span>
			<div class="db-fmenu-wrapper">';
				if ( $listing_fmenu !== false && !empty($listing_fmenu) ) {
					foreach ($listing_fmenu as $fmenu_items) {
						echo '
						<div class="db-fmenu-full-cat">
							<input type="text" class="db-fmenu-cat-name" placeholder="'.esc_html__('Category', 'directory-builder').'" value="'.esc_attr($fmenu_items['name']).'">
							<a href="javascript:void(0)" class="db-fmenu-cat-delete"><svg width="9px" height="9px" viewBox="0 0 9 9" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" stroke-linecap="square"> <g id="Add-listing" transform="translate(-1261.000000, -2150.000000)" stroke="#9B9B9B" stroke-width="2"> <g id="Full-menu" transform="translate(145.000000, 2037.000000)"> <g id="cross" transform="translate(1117.000000, 114.000000)"> <path d="M0.5,0.5 C0.5,0.5 1.47029385,1.47029385 2.65893276,2.65893276 L6.62354462,6.62354462" id="Line" fill="#D8D8D8"></path> <path d="M6.5,0.5 C6.5,0.5 5.52970615,1.47029385 4.34106724,2.65893276 L0.376455383,6.62354462" id="Line-Copy-2"></path> </g> </g> </g> </g> </svg></a>
							<div class="db-fmenu-cat-items">';
								if ( !empty($fmenu_items['items']) ) {
									foreach ($fmenu_items['items'] as $fmenu_item) {
										echo '
										<div class="db-fmenu-cat-item">
											<input type="text" class="db-fmenu-item-name" placeholder="'.esc_html__('Item name','directory-builder').'" value="'.esc_attr($fmenu_item['name']).'">
											<input type="text" class="db-fmenu-item-desc" placeholder="'.esc_html__('Description','directory-builder').'" value="'.esc_attr($fmenu_item['desc']).'">
											<input type="text" class="db-fmenu-item-price" placeholder="'.esc_html__('Price','directory-builder').'" value="'.esc_attr($fmenu_item['price']).'">
											<a href="javascript:void(0)" class="db-fmenu-cat-item-delete"><svg width="9px" height="9px" viewBox="0 0 9 9" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" stroke-linecap="square"> <g id="Add-listing" transform="translate(-1261.000000, -2150.000000)" stroke="#9B9B9B" stroke-width="2"> <g id="Full-menu" transform="translate(145.000000, 2037.000000)"> <g id="cross" transform="translate(1117.000000, 114.000000)"> <path d="M0.5,0.5 C0.5,0.5 1.47029385,1.47029385 2.65893276,2.65893276 L6.62354462,6.62354462" id="Line" fill="#D8D8D8"></path> <path d="M6.5,0.5 C6.5,0.5 5.52970615,1.47029385 4.34106724,2.65893276 L0.376455383,6.62354462" id="Line-Copy-2"></path> </g> </g> </g> </g> </svg></a>
										</div>';
									}
								}
								echo '
								<a href="javascript:void(0)" class="db-fmenu-new-item button-primary button-large">'.esc_html__('Add item','directory-builder').'</a>
								<div class="clearfix"></div>
							</div>
						</div>';
					}
				}
				echo '
				<a href="javascript:void(0)" class="db-fmenu-new-cat button button-primary button-large">'.esc_html__('Add category','directory-builder').'</a>
				<input type="hidden" id="listing_fmenu" name="listing_fmenu" value="'.esc_attr($listing_fmenu_json).'">
				<div class="db-fmenu-hidden">
					<div class="db-fmenu-full-cat">
						<input type="text" class="db-fmenu-cat-name" placeholder="'.esc_html__('Category', 'directory-builder').'">
						<a href="javascript:void(0)" class="db-fmenu-cat-delete"><svg width="9px" height="9px" viewBox="0 0 9 9" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" stroke-linecap="square"> <g id="Add-listing" transform="translate(-1261.000000, -2150.000000)" stroke="#9B9B9B" stroke-width="2"> <g id="Full-menu" transform="translate(145.000000, 2037.000000)"> <g id="cross" transform="translate(1117.000000, 114.000000)"> <path d="M0.5,0.5 C0.5,0.5 1.47029385,1.47029385 2.65893276,2.65893276 L6.62354462,6.62354462" id="Line" fill="#D8D8D8"></path> <path d="M6.5,0.5 C6.5,0.5 5.52970615,1.47029385 4.34106724,2.65893276 L0.376455383,6.62354462" id="Line-Copy-2"></path> </g> </g> </g> </g> </svg></a>
						<div class="db-fmenu-cat-items">
							<div class="db-fmenu-cat-item">
								<input type="text" class="db-fmenu-item-name" placeholder="'.esc_html__('Item name','directory-builder').'">
								<input type="text" class="db-fmenu-item-desc" placeholder="'.esc_html__('Description','directory-builder').'">
								<input type="text" class="db-fmenu-item-price" placeholder="'.esc_html__('Price','directory-builder').'">
								<a href="javascript:void(0)" class="db-fmenu-cat-item-delete"><svg width="9px" height="9px" viewBox="0 0 9 9" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" stroke-linecap="square"> <g id="Add-listing" transform="translate(-1261.000000, -2150.000000)" stroke="#9B9B9B" stroke-width="2"> <g id="Full-menu" transform="translate(145.000000, 2037.000000)"> <g id="cross" transform="translate(1117.000000, 114.000000)"> <path d="M0.5,0.5 C0.5,0.5 1.47029385,1.47029385 2.65893276,2.65893276 L6.62354462,6.62354462" id="Line" fill="#D8D8D8"></path> <path d="M6.5,0.5 C6.5,0.5 5.52970615,1.47029385 4.34106724,2.65893276 L0.376455383,6.62354462" id="Line-Copy-2"></path> </g> </g> </g> </g> </svg></a>
							</div>
							<div class="db-fmenu-cat-item">
								<input type="text" class="db-fmenu-item-name" placeholder="'.esc_html__('Item name','directory-builder').'">
								<input type="text" class="db-fmenu-item-desc" placeholder="'.esc_html__('Description','directory-builder').'">
								<input type="text" class="db-fmenu-item-price" placeholder="'.esc_html__('Price','directory-builder').'">
								<a href="javascript:void(0)" class="db-fmenu-cat-item-delete"><svg width="9px" height="9px" viewBox="0 0 9 9" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" stroke-linecap="square"> <g id="Add-listing" transform="translate(-1261.000000, -2150.000000)" stroke="#9B9B9B" stroke-width="2"> <g id="Full-menu" transform="translate(145.000000, 2037.000000)"> <g id="cross" transform="translate(1117.000000, 114.000000)"> <path d="M0.5,0.5 C0.5,0.5 1.47029385,1.47029385 2.65893276,2.65893276 L6.62354462,6.62354462" id="Line" fill="#D8D8D8"></path> <path d="M6.5,0.5 C6.5,0.5 5.52970615,1.47029385 4.34106724,2.65893276 L0.376455383,6.62354462" id="Line-Copy-2"></path> </g> </g> </g> </g> </svg></a>
							</div>
							<div class="db-fmenu-cat-item">
								<input type="text" class="db-fmenu-item-name" placeholder="'.esc_html__('Item name','directory-builder').'">
								<input type="text" class="db-fmenu-item-desc" placeholder="'.esc_html__('Description','directory-builder').'">
								<input type="text" class="db-fmenu-item-price" placeholder="'.esc_html__('Price','directory-builder').'">
								<a href="javascript:void(0)" class="db-fmenu-cat-item-delete"><svg width="9px" height="9px" viewBox="0 0 9 9" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" stroke-linecap="square"> <g id="Add-listing" transform="translate(-1261.000000, -2150.000000)" stroke="#9B9B9B" stroke-width="2"> <g id="Full-menu" transform="translate(145.000000, 2037.000000)"> <g id="cross" transform="translate(1117.000000, 114.000000)"> <path d="M0.5,0.5 C0.5,0.5 1.47029385,1.47029385 2.65893276,2.65893276 L6.62354462,6.62354462" id="Line" fill="#D8D8D8"></path> <path d="M6.5,0.5 C6.5,0.5 5.52970615,1.47029385 4.34106724,2.65893276 L0.376455383,6.62354462" id="Line-Copy-2"></path> </g> </g> </g> </g> </svg></a>
							</div>
							<a href="javascript:void(0)" class="db-fmenu-new-item button-primary button-large">'.esc_html__('Add item','directory-builder').'</a>
							<div class="clearfix"></div>
						</div>
					</div>
				</div>
			</div>
		</div>';
		}

	?>

	<p>
		<label for="listing_address"><?php _e( "Listing images ", 'directory-builder' ); ?></label>
		<br />
		<div class="db-listing-uploaded-images clearfix">
			<div class="column clearfix ui-sortable db-gallery">
			<?php
				if ( $listing_images != '' ) {
					$listing_images_parsed = explode('|', $listing_images);
					foreach ($listing_images_parsed as $image_value) {
						if ( $image_value == '' ) {
							continue;
						}
						$gallery_image = wp_get_attachment_image_src($image_value);
						// echo '<div class="db-uploaded-img-row"><span class="db-uploaded-img-delete dbicon-cancel"></span><img src="'.$gallery_image['0'].'"></div>';
						echo '
						<div class="portlet ui-widget ui-widget-content ui-helper-clearfix ui-corner-all" data-id="'.$image_value.'">
							<div class="portlet-header ui-sortable-handle ui-widget-header ui-corner-all">
								<span class="db-uploaded-img-delete dbicon-cancel"></span>
								<img src="'.$gallery_image['0'].'">
							</div>
						</div>';
					}
				}
			?>
			</div>
		</div>
		<input type="hidden" name="listing_gallery_img" id="listing_gallery_img" value="<?php echo $listing_images; ?>" />
		<a href="javascript:void(0)" class="db-upload-listing-images button button-primary button-large">Upload images</a>
	</p>

	<?php
}

function db_order_metabox_function( $object, $box ) { ?>
	<?php
		$main_settings = get_option( 'db_main_settings', array());
		$order_data = get_post_meta( $object->ID, 'db_order_info', true );
		$listing_expiration_date = '';
		$category_names = array();
		if ( $order_data != '' ) {
			$all_categories = explode(',', $order_data['category']);
			foreach ($all_categories as $category_id) {
				if ( $category_id != 0 ) {
					$category = get_term($category_id, 'listing_category');
					if ( isset($category->name) ) {
						$category_names[] = $category->name;
					}
				}
			}
			
			$featured_listings = get_option('db_sticky_listings', array());
			$listing_sticky = (in_array($object->ID, $featured_listings)?'Yes':'No');

			global $wpdb;
			$package_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_packages ORDER BY ID ASC');
			if ( !empty($package_list) ) {
				$field_settings = json_decode($package_list['0']->package_settings, true);
			}

			if ( isset($order_data['listing_expires']) && !is_numeric($order_data['listing_expires']) && isset($order_data['completed_on']) && $field_settings['listing_run_type'] == 'days' ) {
				$order_data['listing_expires'] = date( get_option('date_format'), strtotime('+'.$field_settings['listing_run_days'].' days', $order_data['completed_on']));
			} else if ( !isset($order_data['listing_expires']) ) {
				$order_data['listing_expires'] = 'Unknown';
			}
		} else {
			$order_data = array(
					'listing_package' => __('No information', 'directory-builder'),
					'listing_package_name' => __('No information', 'directory-builder'),
					'paid_amount' => __('No information', 'directory-builder'),
					'payment_history' => array(),
					'payment_status' => __('No information', 'directory-builder'),
					'category' => __('No information', 'directory-builder'),
					'listing_expires' => __('No information', 'directory-builder'),
					'listing_sticky' => __('No information', 'directory-builder')
				);

			$category = array();
			$category['name'] = 'No information';
			$category = (object)$category;
			$package_list = array();
			$listing_sticky = __('No information', 'directory-builder');
			$category_names = array( __('No information', 'directory-builder') );
			$field_settings = array();
		}

		if ( isset($field_settings['listing_run_type']) && $field_settings['listing_run_type'] == 'forever' ) {
			$listing_expiration = '<a href="javascript:void(0)" class="db-expiration-select">'.__('Never', 'directory-builder').'</a>';
		} else if ( isset($field_settings['listing_run_type']) && $field_settings['listing_run_type'] == 'days' && $order_data['listing_expires'] != 'Unknown' ) {
			$listing_expiration = '<a href="javascript:void(0)" class="db-expiration-select">'.date( get_option('date_format'), (is_numeric($order_data['listing_expires'])?$order_data['listing_expires']:strtotime($order_data['listing_expires']))).'</a>';
			$listing_expiration_date = date( 'Y-m-d', (is_numeric($order_data['listing_expires'])?$order_data['listing_expires']:strtotime($order_data['listing_expires'])));
		} else {
			$listing_expiration = '<a href="javascript:void(0)" class="db-expiration-select">'.__('Unknown', 'directory-builder').'</a>';
		}

		$listing_billing = get_post_meta( $object->ID, 'db_billing_info', true );
	?>

	<div class="db-order-wrapper">
		<div class="db-order-row">
			<span class="db-order-label">Listing author:</span>
			<span class="db-order-value"><a href="<?php echo admin_url('user-edit.php?user_id='.$object->post_author); ?>"><?php echo get_the_author_meta('nicename', $object->post_author); ?></a></span>
		</div>
		<div class="db-order-row">
			<span class="db-order-label">Listing status:</span>
			<span class="db-order-value">
				<?php echo (isset($order_data['payment_status'])?'<a href="javascript:void(0)" class="db-status-select" data-id="">'.$order_data['payment_status'].'</a>':'<a href="javascript:void(0)" class="db-status-select" data-id="">'.__('Set status', 'directory-builder').'</a>'); ?>
				<div class="db-listing-status-container" style="display: none;">
					<select class="db-listing-status">
						<option value="Processing" <?php echo (isset($order_data['payment_status'])&&$order_data['payment_status']=='Processing'?'selected':'') ?>>Processing</option>
						<option value="Completed" <?php echo (isset($order_data['payment_status'])&&$order_data['payment_status']=='Completed'?'selected':'') ?>>Completed</option>
						<option value="Pending" <?php echo (isset($order_data['payment_status'])&&$order_data['payment_status']=='Pending'?'selected':'') ?>>Pending</option>
						<option value="Refunded" <?php echo (isset($order_data['payment_status'])&&$order_data['payment_status']=='Refunded'?'selected':'') ?>>Refunded</option>
					</select>
					<a href="javascript:void(0)" class="db-listing-status-save" data-id="<?php echo $object->ID; ?>"><?php _e('Change', 'directory-builder'); ?></a>
				</div>
			</span>
		</div>
		<div class="db-order-row">
			<span class="db-order-label">Listing package:</span>
			<span class="db-order-value"><?php echo (isset($order_data['listing_package_name'])?'<a href="javascript:void(0)" class="db-order-select" data-id="'.$order_data['listing_package'].'">'.$order_data['listing_package_name'].'</a>':'<a href="javascript:void(0)" class="db-order-select" data-id="0">'.__('Add package', 'directory-builder').'</a>'); ?>
				<div class="db-order-package-container" style="display: none;">
					<select class="db-order-package">
					<?php
						if ( !empty($package_list) ) {
							foreach ($package_list as $package_value) {
								echo '<option value="'.$package_value->ID.'"'.($order_data['listing_package_name']==$package_value->package_name?' selected':'').'>'.$package_value->package_name.'</option>';
							}
						}
					?>
					</select>
					<a href="javascript:void(0)" class="db-order-package-save" data-id="<?php echo $object->ID; ?>"><?php _e('Change', 'directory-builder'); ?></a>
				</div>
			</span>
		</div>
		<div class="db-order-row">
			<span class="db-order-label">Listing cost:</span>
			<span class="db-order-value"><?php echo (isset($order_data['paid_amount'])?$order_data['paid_amount']:''); ?></span>
		</div>
		<div class="db-order-row">
			<span class="db-order-label">Listing expiration:</span>
			<span class="db-order-value"><?php echo $listing_expiration; ?>
				<div class="db-expiration-dialog" style="display: none;">
					<input type="date" class="db-listing-expiration-date" value="<?php echo $listing_expiration_date; ?>">
					<a href="javascript:void(0)" class="db-expiration-save" data-id="<?php echo $object->ID; ?>"><?php _e('Change', 'directory-builder'); ?></a>
				</div>
			</span>

		</div>
		<div class="db-order-row">
			<span class="db-order-label">Listing featured:</span>
			<span class="db-order-value">
				<a href="javascript:void(0)" class="db-featured-listing"><?php echo $listing_sticky; ?></a>
				<div class="db-featured-dialog" style="display: none;">
					<select class="db-featured-status">
						<option value="Yes" <?php echo (in_array($object->ID, $featured_listings)?'selected':''); ?>>Yes</option>
						<option value="No" <?php echo (!in_array($object->ID, $featured_listings)?'selected':''); ?>>No</option>
					</select>
					<a href="javascript:void(0)" class="db-featured-save" data-id="<?php echo $object->ID; ?>"><?php _e('Change', 'directory-builder'); ?></a>
				</div>
			</span>
		</div>
		<div class="db-order-row">
			<span class="db-order-label">Paid category:</span>
			<span class="db-order-value"><?php echo implode(', ', $category_names); ?></span>
		</div>
	</div>
	
	<?php
}

function db_process_history_row( $payment_value, $main_settings, $listing_billing = array(), $order_data = array(), $loop_order = 0 ) {
	$payment_data = explode('===', $payment_value);

	$output = '
	<div class="clearfix"></div>
	<div class="db-order-history-row">
		<span class="db-order-value-left'.(in_array( $payment_data['2'], array( 'Completed', 'Refunded' ) )?' invoiced':'').'">
			' . date( get_option('date_format'), strtotime($payment_data['0']) );
			if ( in_array( $payment_data['2'], array( 'Completed', 'Refunded' ) ) ) {
				$output .= '<a href="' . add_query_arg( array( 'dbgetinvoice' => get_the_ID(), 'r' => $loop_order ), get_admin_url() ) . '" title="' . esc_html__( 'Payment invoice', 'directory-builder' ) . '" target="_blank">' . esc_html__( 'View invoice', 'directory-builder' ) . '</a>';
			}
		$output .= '
		</span>
		<div class="db-payment-dialog">
			<div class="db-payment-dialog-row">
				' . __('Payment:', 'directory-builder').' <strong>'.date( get_option('date_format').' '.get_option('time_format'), strtotime($payment_data['0']) ).'</strong>
			</div>
			<div class="db-payment-dialog-row">
				' . __('Status:', 'directory-builder').' <strong>'.$payment_data['2'].'</strong>
			</div>
			<div class="db-payment-dialog-row">
				' . __('Gateway:', 'directory-builder').' <strong>'.(isset($payment_data['3'])&&$payment_data['3']!=''?$payment_data['3']:'-').'</strong>
			</div>';
			if ( isset($payment_data['4']) ) {
				$output .= '
				<div class="db-payment-dialog-row">
					' . __('Refunded by:', 'directory-builder').' <strong>'.get_the_author_meta('nicename', $payment_data['4']).'</strong>
				</div>';
			}
			$output .= '
			<div class="db-payment-dialog-row">
				' . __('Item:', 'directory-builder').' <strong>'.$order_data['listing_package_name'].'</strong>
			</div>
			<div class="db-payment-dialog-row">
				' . __('Total:', 'directory-builder').' <strong>'.(is_numeric($payment_data['1'])?$main_settings['default_currency_symbol'].round($payment_data['1'], 2):$payment_data['1']).'</strong>
			</div>';
			if ( !empty($listing_billing) ) {
				$output .= '<h3>'.__('Billing information', 'directory-builder').'</h3>';
				foreach ($listing_billing as $billing_key => $billing_value) {
					switch ( $billing_key ) {
						case 'x_full_name': $billing_label = __('Full name', 'directory-builder'); break;
						case 'x_company': $billing_label = __('Company', 'directory-builder'); break;
						case 'x_phone': $billing_label = __('Phone', 'directory-builder'); break;
						case 'x_email': $billing_label = __('Email', 'directory-builder'); break;
						case 'x_country': $billing_label = __('Country', 'directory-builder'); break;
						case 'x_address': $billing_label = __('Address', 'directory-builder'); break;
						case 'x_city': $billing_label = __('City', 'directory-builder'); break;
						case 'x_state': $billing_label = __('State', 'directory-builder'); break;
						case 'x_zip': $billing_label = __('ZIP', 'directory-builder'); break;
						case 'auth-code': $billing_label = __('Card Auth Code', 'directory-builder'); break;
						case 'trans-id': $billing_label = __('Transaction ID', 'directory-builder'); break;
						case 'subscription': $billing_label = __('Subscription ID', 'directory-builder'); break;
						case 'sub-id': $billing_label = __('Subscription ID', 'directory-builder'); break;

						default: $billing_label = '';;
					}
					if ( $billing_label != '' ) {
						$output .= '
						<div class="db-payment-dialog-row">
							' . $billing_label.': <strong>'.($billing_value!=''?$billing_value:'-').'</strong>
						</div>';
					} 
				}
			}
		$output .= '
		</div>
		<span class="db-order-value-center">' . (is_numeric($payment_data['1'])?$main_settings['default_currency_symbol'].round($payment_data['1'], 2):$payment_data['1']) . '</span>
		<span class="db-order-value-right ' . strtolower($payment_data['2']) . '">' . $payment_data['2'] . '</span>
		<div class="clearfix"></div>
	</div>';

	return $output;
}

function db_manual_refund_func() {
	$listing_id = ( isset($_POST['listing_id']) ? intval( $_POST['listing_id'] ) : '' );
	$ref_amount = ( isset($_POST['ref_amount']) ? esc_attr( $_POST['ref_amount'] ) : '' );
	$ref_reason = ( isset($_POST['ref_reason']) ? esc_attr( $_POST['ref_reason'] ) : '' );
	$ref_gateway = ( isset($_POST['ref_gateway']) ? esc_attr( $_POST['ref_gateway'] ) : '' );
	$ref_symbol = ( isset($_POST['ref_symbol']) ? esc_attr( $_POST['ref_symbol'] ) : '' );

	$refunds = get_post_meta( $listing_id, 'db_refunds', true );
	$refunds[time()] = array( 'amount' => $ref_amount, 'reason' => $ref_reason );
	update_post_meta( $listing_id, 'db_refunds', $refunds );

	$order_info = get_post_meta( $listing_id, 'db_order_info', true);
	$old_history = $order_info['payment_history'];
	$new_history = date('D, d M Y H:i:s', time()).'==='.$ref_amount.'===Refunded===' . $ref_gateway.'==='.get_current_user_id();
	$old_history[] = $new_history;
	$order_info['payment_history'] = $old_history;
	update_post_meta( $listing_id, 'db_order_info', $order_info );

	$refund_ipn = sprintf( __('Payment of %s refunded! %s', 'directory-builder'), $ref_symbol.$ref_amount, ($ref_reason!=''?esc_html__('Reason', 'directory-builder').': '.$ref_reason:'') );

	db_update_ipn_notes( $listing_id, $refund_ipn );

	$main_settings = get_option( 'db_main_settings', array());
	$history_html = db_process_history_row( $new_history, $main_settings );

	echo json_encode( array( 'note' => '<div class="db-note-item" data-time="'.date( get_option( 'date_format' ) . ' ' . get_option( 'time_format' ), time() ).'">' . $refund_ipn . '</div>', 'history' => $history_html ) );

	die(0);
}
add_action( 'wp_ajax_db_manual_refund', 'db_manual_refund_func' );
add_action( 'wp_ajax_nopriv_db_manual_refund', 'db_manual_refund_func' );

function db_notes_metabox_function( $object ) {
	$listing_notes = get_post_meta( $object->ID, 'db_notes', true );
	?>
	<div class="db-payment-wrapper">
		<?php
		if ( empty($listing_notes) ) {
			echo '<div class="db-note-item empty">' . esc_html__('No notes yet!', 'directory-builder') . '</div>';
		} else {
			$listing_notes = array_reverse( $listing_notes, true );
			$date_format = get_option( 'date_format' ) . ' ' . get_option( 'time_format' );
			foreach ( $listing_notes as $timestamp => $note ) {
				echo '<div class="db-note-item" data-time="' . date( $date_format, $timestamp ) . '">' . $note . '</div>';
			}
		}
		?>
	</div>
	
	<?php
}

function db_payment_metabox_function( $object ) {
	$listing_order_info = get_post_meta( $object->ID, 'db_order_info', true );
	$main_settings = get_option( 'db_main_settings', array());

	?>
	<div class="db-payment-history-wrapper">
		<?php
		if ( isset($listing_order_info['payment_history']) && !empty($listing_order_info['payment_history']) ) {
			$listing_billing = get_post_meta( $object->ID, 'db_billing_info', true );

			$loop = 0;
			foreach ($listing_order_info['payment_history'] as $payment_value) {
				$payment_data = explode('===', $payment_value);

				if ( $payment_data['2'] == 'Completed' ) {
					$last_gateway = $payment_data['3'];
				}

				echo db_process_history_row( $payment_value, $main_settings, $listing_billing, $listing_order_info, $loop );

				$loop++;
			}
		} else {
			echo '<p>' . esc_html__('No payment history yet!', 'directory-builder') . '</p>';
		}
		?>
	</div>
	<?php if ( isset($last_gateway)  ) {
		$payment_gateway = explode('.', $last_gateway); ?>
		<div class="db-order-row">
			<span class="db-order-value">
				<a href="javascript:void(0)" class="button button-primary button-large db-show-refund"><?php esc_html_e('Refund', 'directory-builder'); ?></a>
				<div class="db-refund-wrapper hidden">
					<form action="post" class="db-manual-refund">
						<div class="db-refund-items">
							<div class="db-refund-item">
								<?php
									esc_html_e('Total refund', 'directory-builder');
									$refunds = get_post_meta( $object->ID, 'db_refunds', true );
									$total_refund = '0.00';
									if ( !empty( $refunds ) ) {
										$total_refund = '';
										foreach ( $refunds as $refund_data ) {
											$total_refund += $refund_data['amount'];
										}
									}
								?>: <span class="db-error">-<?php echo $main_settings['default_currency_symbol'].round($total_refund, 2); ?></span>
							</div>
							<?php
								// $datetime = new DateTime('2000-01-01 11:40:00', new DateTimeZone('Europe/Berlin'));
								// var_dump($datetime->format('Y-m-d H:i:sP'));
								// $datetime->setTimezone(new DateTimeZone('europe/Riga'));
								// var_dump($datetime->format('Y-m-d H:i:sP'));
								if ( strtolower($last_gateway) == 'stripe' ) {
									$stripe_auto_ref = false;
									$all_stripe_charges = get_post_meta( $object->ID, 'stripe_charges', true );
									if ( !empty($all_stripe_charges) ) {
										$stripe_auto_ref = true;
										echo '<div class="db-refund-item"><select class="stripe-refund-charges"><option value="-">'.esc_attr('Select charge to refund!', 'directory-builder').'</option>';
										$date_format = get_option( 'date_format' ) . ' ' . get_option( 'time_format' );
										foreach ($all_stripe_charges as $charge_data) {
											echo '<option value="'.esc_attr($charge_data['charge']).'">'.sprintf( '%s - %s%s', date( $date_format, $charge_data['time'] ), $charge_data['amount']/100, $charge_data['currency'] ).'</option>';
										}
										echo '</select></div>';
									}
								}
							?>
							<div class="db-refund-item">
								<?php esc_html_e('Refund amount', 'directory-builder'); ?>:<br />
								<input type="number" class="db-refund-amount">
							</div>
							<div class="db-refund-item">
								<?php esc_html_e('Refund reason (optional)', 'directory-builder'); ?>:<br />
								<input type="text" class="db-refund-reason">
							</div>
						</div>

						<a href="javascript:void(0)" class="db-refund-manually button button-primary button-large" data-id="<?php echo $object->ID; ?>" data-gateway="<?php echo $last_gateway; ?>" data-symbol="<?php echo $main_settings['default_currency_symbol']; ?>" data-tooltip="<?php esc_html_e('You will have to manually refund this amount through your payment gateway after using this button.', 'directory-builder'); ?>" data-normal="<?php printf( __('Refund %s%d manually', 'directory-builder'), $main_settings['default_currency_symbol'], '0' ); ?>" data-process="<?php esc_html_e('Processing', 'directory-builder'); ?>" data-refund="<?php esc_html_e('Refunded', 'directory-builder'); ?>" disabled="disabled"></a><br />
						<?php
						$refund_url = 'javascript:void(0)';
						if ( strtolower($last_gateway) == 'paypal' ) {
							$refund_url = 'https://developer.paypal.com/docs/classic/admin/refunds/#refunding-within-180-days-of-payment';
						}
						?>
						<a href="<?php echo $refund_url; ?>" class="db-refund-auto <?php echo strtolower($payment_gateway['0']); ?> button button-primary button-large <?php echo (strtolower($payment_gateway['0'])=='authorize'&&(!isset($listing_billing['card'])||$listing_billing['card_expiration'])?'hidden':''); ?> <?php echo (strtolower($payment_gateway['0'])=='manual'?'hidden':''); ?>" data-normal="<?php printf( __('Refund %s%d via %s', 'directory-builder'), $main_settings['default_currency_symbol'], '0', $last_gateway ); ?>" data-process="<?php esc_html_e('Processing', 'directory-builder'); ?>" data-symbol="<?php echo $main_settings['default_currency_symbol']; ?>" data-refund="<?php esc_html_e('Refunded', 'directory-builder'); ?>" data-id="<?php echo $object->ID; ?>" <?php echo (strtolower($last_gateway)=='paypal'||strtolower($last_gateway)=='stripe'?'target="_blank"':''); ?> disabled="disabled"></a>
						<span class="db-refund-error db-error"></span>
					</form>
				</div>
			</span>
		</div>
	<?php }
}

function db_listing_img_metabox_function( $object, $box ) {
	$listing_custom_image = esc_attr( get_post_meta( $object->ID, 'db_listing_custom_img', true ) );
	?>
	<div class="db-custom-img-wrapper">
		<div class="db-custom-img-item empty <?php echo ($listing_custom_image==''?'active':''); ?>">
			<a href="javascript:void(0)" class="db-set-custom-image">Set custom image</a>
			<p>If custom image is not set, then the featured image is going to be used!</p>
		</div>
		<div class="db-custom-img-item set <?php echo ($listing_custom_image!=''?'active':''); ?>">
			<img src="<?php echo wp_get_attachment_url($listing_custom_image); ?>" alt="" style="max-width: 100%;">
			<a href="javascript:void(0)" class="db-remove-custom-image">Remove custom image</a>
		</div>
		<input type="hidden" name="db_listing_custom_img" id="db_listing_custom_img" value="<?php echo $listing_custom_image; ?>" />
	</div>
	
	<?php
}

function db_get_custom_field( $field_settings, $custom_class = '', $def_value = '', $field_placement = '' ) {
	if ( empty($field_settings) ) {
		return;
	}
	$output = '';

	$field_name = $field_settings['field_name'];
	$field_title = $field_settings['frontend_title'];
	$field_description = $field_settings['frontend_description'];
	$field_default = (isset($field_settings['default_value'])?$field_settings['default_value']:'');

	if ( $def_value != '' ) { 
		$field_default = $def_value;
	}

	$field_required = ($field_settings['required']=='yes'?' required':'');
	$field_required_message = $field_settings['required_message'];

	$field_only_for = '';
	if ( isset($field_settings['apply_categories']) && !empty($field_settings['apply_categories']) ) {
		$field_only_for = 'data-for="'.implode(',', $field_settings['apply_categories']).'"';
		$field_required .= ' field-hidden db-cat-for';
	}

	if ( isset($field_settings['for_admins']) && $field_settings['for_admins'] == 'yes' && !current_user_can('manage_options') ) {
		return '';
	}

	switch ( $field_settings['field_type'] ) {
		case 'text':
			$field_validation_pattern = (isset($field_settings['validation_pattern'])&&$field_settings['validation_pattern']!=''?' pattern="'.$field_settings['validation_pattern'].'"':'');
			$field_validation_pattern_message = (isset($field_settings['validation_pattern_message'])&&$field_settings['validation_pattern_message']!=''?' title="'.$field_settings['validation_pattern_message'].'"':'');

			$output .= '
			<div class="db-field-row'.$field_required.'" '.$field_only_for.'>';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<input type="text" id="'.$field_name.'" name="'.$field_name.'" class="'.$custom_class.'" placeholder="'.$field_title.'" value="'.$field_default.'"'.$field_validation_pattern.$field_validation_pattern_message.' autocomplete="off">';
				if ( $field_name == 'listing_address' && !is_admin() ) {
					$output .= '<span class="db-autolocate-me"><svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="15px" height="15px" viewBox="0 0 15 15" version="1.1"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <g id="All-listings" transform="translate(-964.000000, -626.000000)" fill-rule="nonzero" fill="#9B9B9B"> <g id="Group-4-Copy" transform="translate(731.000000, 611.000000)"> <g id="target-with-circle" transform="translate(233.000000, 15.000000)"> <g id="Capa_1"> <path d="M7.48790875,4.76543726 C5.98346008,4.76543726 4.76543726,5.98346008 4.76543726,7.48790875 C4.76543726,8.99235741 5.98346008,10.2103802 7.48790875,10.2103802 C8.99235741,10.2103802 10.2103802,8.99235741 10.2103802,7.48790875 C10.2103802,5.98346008 8.99235741,4.76543726 7.48790875,4.76543726 Z M13.5730894,6.80652091 C13.2604848,3.96798479 11.0072338,1.71473384 8.16869772,1.40272814 L8.16869772,0 L6.80714829,0 L6.80714829,1.40272814 C3.96858365,1.71473384 1.71536122,3.96798479 1.40210076,6.80652091 L0,6.80652091 L0,8.1693251 L1.40272814,8.1693251 C1.71596008,11.0078612 3.96921103,13.2611122 6.80774715,13.5731179 L6.80774715,14.975846 L8.16929658,14.975846 L8.16929658,13.5731179 C11.0078327,13.2611122 13.2610837,11.0078897 13.5736882,8.1693251 L14.975789,8.1693251 L14.975789,6.80652091 C14.975846,6.80652091 13.5730894,6.80652091 13.5730894,6.80652091 Z M7.48790875,12.253346 C4.85341255,12.253346 2.72247148,10.1224049 2.72247148,7.48790875 C2.72247148,4.85341255 4.85341255,2.72247148 7.48790875,2.72247148 C10.1224049,2.72247148 12.253346,4.85341255 12.253346,7.48790875 C12.253346,10.1224049 10.1224049,12.253346 7.48790875,12.253346 Z" id="Shape"/> </g> </g> </g> </g> </g> </svg></span>';
				}
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'number':
			$output .= '
			<div class="db-field-row'.$field_required.'" '.$field_only_for.'>';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<input type="number" id="'.$field_name.'" name="'.$field_name.'" class="'.$custom_class.'" placeholder="'.$field_title.'" value="'.$field_default.'">';
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'textarea':
			$output .= '
			<div class="db-field-row'.$field_required.'" '.$field_only_for.'>';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<textarea id="'.$field_name.'" name="'.$field_name.'" class="'.$custom_class.'" placeholder="'.$field_title.'">'.$field_default.'</textarea>';
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'checkbox':
			$output .= '
			<div class="db-field-row'.$field_required.' checkbox-label" '.$field_only_for.'>';
			global $post;
				if ( has_shortcode( $post->post_content, 'directory_add_listing' ) ) {
					$is_checked = ($field_default==$field_settings['checkbox_true']||$field_default=='true'?true:false);
				} else {
					$is_checked = ($field_default=='true'?true:false);
				}
				$output .= '<input type="checkbox" id="'.$field_name.'" name="'.$field_name.'" class="'.$custom_class.'" value="true"'.($is_checked?' checked':'').'>';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label'.($is_checked?' active':'').'" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<div class="clearfix"></div>';
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'radio':
			$radio_options = $field_settings['radio_options'];
			$radio_values = explode(',', $radio_options);

			$output .= '
			<div class="db-field-row'.$field_required.' default-label radio" '.$field_only_for.'>';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label">'.$field_title.'</label>';
				}
				if ( !empty($radio_values) ) {
					$loops = 1;
					foreach ($radio_values as $radio_value) {
						$is_checked = (isset($field_default['0'])&&$field_default['0']==$radio_value?' checked':'');
						$output .= '<label class="db-radio-label" for="'.$field_name.'-'.$loops.'"><input type="radio" name="'.$field_name.'[]" id="'.$field_name.'-'.$loops.'" class="'.$custom_class.'" value="'.$radio_value.'"'.$is_checked.'>'.$radio_value.'</label>';
						$loops++;
					}
				}
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'select':
			$select_options = $field_settings['select_options'];
			$select_values = explode(',', $select_options);

				if ( !defined('WHITELAB_CUSTOM_SELECT') || is_admin() ) {
					$output .= '<div class="db-field-row'.$field_required.'" '.$field_only_for.'>';
					if ( $field_title != '' ) {
						$output .= '<label class="db-field-row-label">'.$field_title.'</label>';
					}
					if ( !empty($select_values) ) {
						$output .= '<select class="'.$custom_class.'" name="'.$field_name.'">';
						if ( !in_array($field_default, $select_values) ) {
							$select_values[] = $field_default;
						}
						foreach ($select_values as $select_value) {
							$select_data = explode(':', $select_value);
							$is_selected = ($select_data['0']==$field_default?' selected':'');
							$output .= '<option value="'.$select_data['0'].'"'.$is_selected.'>'.(isset($select_data['1'])?$select_data['1']:$select_data['0']).'</option>';
						}
						$output .= '</select>';
					}
					if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
						$output .= '<div class="db-field-meta">';
							if ( $field_description != '' ) {
								$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
							}
							if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
								$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
							}
						$output .= '</div>';
					}
				} else {
					$output .= '
					<div class="db-field-row'.$field_required.' custom-select" '.$field_only_for.'>';
					if ( $field_title != '' && $field_placement == 'homepage' ) {
						$output .= '<label class="db-field-row-label">'.$field_title.'</label>';
					}

					$active_values = (isset($_GET[$field_name])?explode(',', sanitize_text_field($_GET[$field_name])):array( $field_default ));
					$active_value_shown = $active_value_hidden = '';
					if ( !empty($active_values) ) {
						$active_value_shown = implode(', ', $active_values);
						$active_value_hidden = implode(',', $active_values);
					}

					$output .= '
					<input type="text" class="dt-custom-select" placeholder="'.$field_title.'" value="'.$active_value_shown.'" readonly>
					<input type="hidden" class="'.$custom_class.'" name="'.$field_name.'" id="dt-search-search_category" value="'.$active_value_hidden.'">
					<div class="dt-custom-select-container">';
						$output .= '
						<div class="dt-custom-select-inner">
							<div class="dt-custom-select-search"><input type="text" placeholder="'.__('Search', 'directory-builder').'"></div>
							<div class="dt-custom-select-items">';
								if ( !empty($select_values) ) {
									foreach ($select_values as $select_value) {
										$select_data = explode( ':', $select_value );
										$selected_values = explode( ',', $field_default );
										$is_selected = (in_array($select_data['0'], $selected_values)?' active':'');
										$output .= '<div class="dt-custom-select-item'.$is_selected.'" data-value="'.$select_data['0'].'">'.(isset($select_data['1'])?$select_data['1']:$select_data['0']).'</div>';
									}
								}
							$output .= '
							</div>
							<div class="dt-custom-select-scrollbar-wrapper">
								<span class="dt-custom-select-scrollbar"></span>
							</div>
						</div>';
					$output .= '
					</div>';
					if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
						$output .= '<div class="db-field-meta">';
							if ( $field_description != '' ) {
								$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
							}
							if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
								$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
							}
						$output .= '</div>';
					}
				}
			$output .= '
			</div>';
			break;

		case 'multi-select':
			$select_options = $field_settings['select_options'];
			$select_values = preg_split("/\\r\\n|\\r|\\n/", $select_options);

			if ( !defined('WHITELAB_CUSTOM_SELECT') || is_admin() ) {
				$output .= '<div class="db-field-row'.$field_required.'" '.$field_only_for.'>';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label">'.$field_title.'</label>';
				}
				if ( !empty($select_values) ) {
					$output .= '<select class="'.$custom_class.'" name="'.$field_name.'[]" multiple>';
					foreach ($select_values as $select_value) {
						$select_data = explode(':', $select_value);
						if ( is_array($field_default) ) {
							$selected_values = $field_default;
						} else {
							$selected_values = explode( ',', $field_default );
						}

						$is_selected = (in_array($select_data['0'], $selected_values)?' selected':'');
						$output .= '<option value="'.$select_data['0'].'"'.$is_selected.'>'.(isset($select_data['1'])?$select_data['1']:$select_data['0']).'</option>';
					}
					$output .= '</select>';
				}
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			} else {
				$output .= '
				<div class="db-field-row'.$field_required.' custom-select" '.$field_only_for.'>';
				$active_values = (isset($_GET[$field_name])?explode(',', sanitize_text_field($_GET[$field_name])):(is_array($field_default)?$field_default:explode(',', $field_default)));
				$active_value_shown = $active_value_hidden = '';
				if ( !empty($active_values) ) {
					// $active_value_shown = implode(', ', $active_values);
					$active_value_hidden = implode(',', $active_values);

					$all_select_data = explode( '||', str_replace("\n", '||', $field_settings['select_options']) );
					$all_select_options = array();
					foreach ($all_select_data as $select_value) {
						$select_value_exploded = explode(':', $select_value);
						$all_select_options[$select_value_exploded['0']] = $select_value_exploded['1'];
					}

					$active_shown_values = array();
					if ( $active_values['0'] != '' ) {
						foreach ($active_values as $active_value) {
							$active_shown_values[] = $all_select_options[$active_value];
						}
					}

					$active_value_shown = implode( ', ', $active_shown_values );
				}

				if ( $field_title != '' && $field_placement == 'homepage' ) {
					$output .= '<label class="db-field-row-label">'.$field_title.'</label>';
				}

				$output .= '
				<input type="text" class="dt-custom-select" placeholder="'.$field_title.'" value="'.$active_value_shown.'" readonly>
				<input type="hidden" class="'.$custom_class.'" name="'.$field_name.'" id="dt-search-search_category" value="'.$active_value_hidden.'">
				<div class="dt-custom-select-container">';
					$output .= '
					<div class="dt-custom-select-inner">
						<div class="dt-custom-select-search"><input type="text" placeholder="'.__('Search', 'directory-builder').'"></div>
						<div class="dt-custom-select-items">';
							if ( !empty($select_values) ) {
								foreach ($select_values as $select_value) {
									$select_data = explode( ':', $select_value );
									$selected_values = (is_array($field_default)?$field_default:explode( ',', $field_default ));
									$is_selected = (in_array($select_data['0'], $selected_values)?' active':'');
									$output .= '<div class="dt-custom-select-item'.$is_selected.'" data-value="'.$select_data['0'].'">'.(isset($select_data['1'])?$select_data['1']:$select_data['0']).'</div>';
								}
							}
						$output .= '
						</div>
						<div class="dt-custom-select-scrollbar-wrapper">
							<span class="dt-custom-select-scrollbar"></span>
						</div>
					</div>';
				$output .= '
				</div>';
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			}
			$output .= '
			</div>';
			break;

		case 'file-upload':
			$allowed_types = (!empty($field_settings['allowed_types'])&&$field_settings['allowed_types']['0']!='*'?' accept="'.implode(',', $field_settings['allowed_types']).'"':'');

			$output .= '
			<div class="db-field-row'.$field_required.'" '.$field_only_for.'>';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<input type="button" id="'.$field_name.'" class="db-upload-file" value="Upload file">
				<input type="hidden" name="'.$field_name.'" class="'.$custom_class.'" value="'.$field_default.'">'.$field_default;
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'date':
			$output .= '
			<div class="db-field-row'.$field_required.'" '.$field_only_for.'>';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<input type="date" id="'.$field_name.'" name="'.$field_name.'" class="'.$custom_class.'" placeholder="'.$field_title.'" value="'.$field_default.'">';
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'time':
			$output .= '
			<div class="db-field-row'.$field_required.'" '.$field_only_for.'>';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<input type="time" id="'.$field_name.'" name="'.$field_name.'" class="'.$custom_class.'" placeholder="'.$field_title.'" value="'.$field_default.'">';
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'email':
			$output .= '
			<div class="db-field-row'.$field_required.'" '.$field_only_for.'>';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<input type="email" id="'.$field_name.'" name="'.$field_name.'" class="'.$custom_class.'" placeholder="'.$field_title.'" value="'.$field_default.'">';
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'url':
			$output .= '
			<div class="db-field-row'.$field_required.'" '.$field_only_for.'>';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<input type="url" id="'.$field_name.'" name="'.$field_name.'" class="'.$custom_class.'" placeholder="'.$field_title.'" value="'.$field_default.'">';
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'html':
			$output .= '
			<div class="db-field-row'.$field_required.'" '.$field_only_for.'>';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label" for="'.$field_name.'">'.$field_title.'</label>';
				}
				$output .= '<textarea id="'.$field_name.'" name="'.$field_name.'" class="'.$custom_class.'">'.$field_default.'</textarea>';
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			break;

		case 'hoursofoperation':
			wp_enqueue_script( 'jquery.mask' );
			if ( $field_default == 'always|' ) {
				$field_default = 'always';
			}
			$parsed_date = json_decode( $field_default, true );
			$output .= '
			<div class="db-field-row db-hop-times-row'.$field_required.' clearfix" '.$field_only_for.'>';
				if ( $field_title != '' ) {
					$output .= '<label class="db-field-row-label" for="'.$field_name.'">'.$field_title.'</label>';
				}

				// Display an error if invalid data saved
				if ( $field_default != '' && $parsed_date === null && $field_default != 'always' ) {
					$output .= '
					<div class="db-hop-notice">
						' . esc_html__( 'The format for the "Hours of operation" is changed and the old format will no longer work.', 'directory-builder' ).'
						<a href="javascript:void(0)" class="hop-remove-old">'.esc_html__('Remove old format', 'directory-builder').'</a>
					</div>';
				}

				$output .= '<label class="db-radio-label'.($field_default=='always'?' active': '').'"><input type="radio" name="hop-type[]" class="'.$field_name.'_type" class="'.$custom_class.'" value="always"'.($field_default=='always'?' checked': '').'>'.__('Always open', 'directory-builder').'</label>';
				$output .= '<label class="db-radio-label'.(is_array($parsed_date)?' active': '').'"><input type="radio" name="hop-type[]" class="'.$field_name.'_type" class="'.$custom_class.'" value="custom"'.(is_array($parsed_date)?' checked': '').'>'.__('Open in specific hours', 'directory-builder').'</label>';
				if ( is_array($parsed_date) ) {
					$show_button = 'style="display: inline-none;"';
				} else {
					$show_button = 'style="display: none;"';
				}

				$utc_zones = array( 'UTC-12', 'UTC-11.5', 'UTC-11', 'UTC-10.5', 'UTC-10', 'UTC-9.5', 'UTC-9', 'UTC-8.5', 'UTC-8', 'UTC-7.5', 'UTC-7', 'UTC-6.5', 'UTC-6', 'UTC-5.5', 'UTC-5', 'UTC-4.5', 'UTC-4', 'UTC-3.5', 'UTC-3', 'UTC-2.5', 'UTC-2', 'UTC-1.5', 'UTC-1', 'UTC-0.5', 'UTC+0', 'UTC+0.5', 'UTC+1', 'UTC+1.5', 'UTC+2', 'UTC+2.5', 'UTC+3', 'UTC+3.5', 'UTC+4', 'UTC+4.5', 'UTC+5', 'UTC+5.5', 'UTC+5.75', 'UTC+6', 'UTC+6.5', 'UTC+7', 'UTC+7.5', 'UTC+8', 'UTC+8.5', 'UTC+8.75', 'UTC+9', 'UTC+9.5', 'UTC+10', 'UTC+10.5', 'UTC+11', 'UTC+11.5', 'UTC+12', 'UTC+12.75', 'UTC+13', 'UTC+13.75', 'UTC+14' );

				$output .= '
				<div class="db-field-time-row"'.(is_array($parsed_date)?' style="display: block"':'').'>';
					if ( !defined('WHITELAB_CUSTOM_SELECT') || is_admin() ) {
						$output .= '
						<select id="listing_time_zone" name="listing_time_zone">';
							foreach ($utc_zones as $utc_zone) {
								$output .= '<option value="'.$utc_zone.'"'.(isset($parsed_date['0'])&&$parsed_date['0']==$utc_zone?' selected':'').'>'.$utc_zone.'</option>';
							}
						$output .= '
						</select>';
					} else {
						$output .= '
						<div class="single-select hop-timezone">
							<input type="text" class="dt-custom-select" placeholder="Time zone" readonly=""'.(isset($parsed_date['0'])?' value="'.$parsed_date['0'].'""':'').'>
							<input type="hidden" class="dt-custom-select-value" id="listing_time_zone" name="listing_time_zone"'.(isset($parsed_date['0'])?' value="'.$parsed_date['0'].'""':'').'>
							<div class="dt-custom-select-container">
								<div class="dt-custom-select-inner">
									<div class="dt-custom-select-items">';
										foreach ($utc_zones as $utc_zone) {
											$output .= '<div class="dt-custom-select-item'.(isset($parsed_date['0'])&&$parsed_date['0']==$utc_zone?' active':'').'" data-value="'.$utc_zone.'">'.$utc_zone.'</div>';
										}
									$output .= '
									</div>
									<div class="dt-custom-select-scrollbar-wrapper">
										<span class="dt-custom-select-scrollbar"></span>
									</div>
								</div>
							</div>
						</div>';
					}
					$output .= '
					<div class="db-simple-switch">
						<label for=""><input type="radio" value="12h" name="hop_format"'.(isset($parsed_date['1'])&&$parsed_date['1']=='12h'?' checked':'').'>12h</label>
						<label for=""><input type="radio" value="24h" name="hop_format"'.(isset($parsed_date['1'])&&$parsed_date['1']=='24h'?' checked':(!isset($parsed_date['1'])?' checked':'')).'>24h</label>
						<span data-type="12h">12h</span>
						<div class="db-switch-inner'.(isset($parsed_date['1'])&&$parsed_date['1']=='24h'?' active':(!isset($parsed_date['1'])?' active':'')).'"></div>
						<span data-type="24h">24h</span>
					</div>
					<div class="clearfix"></div>
				</div>';

				$output .= '
				<div class="db-custom-hop-times">
					<div class="db-hop-time-container" '.(!is_array($parsed_date)?'style="display: none;"':'').'>
						<input type="hidden" name="'.$field_name.'" value="'.esc_attr($field_default).'">';
						if ( is_array($parsed_date) && !empty($parsed_date) ) {
							$timezone = $parsed_date['0'];
							$timeformat = $parsed_date['1'];
							unset($parsed_date['0']);
							unset($parsed_date['1']);
							foreach ($parsed_date as $hop_data) {
								foreach ($hop_data as $hop_day_data) {
									if ( $timeformat == '24h' ) {
										$time_value = date('H:i', $hop_day_data['0']).' - '.date('H:i', $hop_day_data['1']);
									} else {
										$time_value = date('h:i A', $hop_day_data['0']).' - '.date('h:i A', $hop_day_data['1']);
									}
									$output .= '
									<div class="db-hop-day-row finished">
										<span class="db-hop-day-names">'.strtolower(date('D', $hop_day_data['0'])).'</span>
										<span class="db-hop-day-times" data-open="'.$hop_day_data['0'].'" data-close="'.$hop_day_data['1'].'">'.$time_value.'</span>
										<span class="db-hop-remove dbicon-cancel"></span>
									</div>';
								}
							}
						}
					$output .= '	
					</div>
					<a href="javascript:void(0)" class="db-add-new-hop button button-primary button-large" '.$show_button.'>'.__('Add hours', 'directory-builder').'</a>
					<div class="db-hop-dialog main-card" style="display: none;">
						<div class="db-hop-dialog-inner">
							<div class="db-hop-left">
								<label class="db-checkbox-label active"><input type="checkbox" name="custom-hop-day[]" class="'.$custom_class.'" value="mon" checked>'.__('Mon', 'directory-builder').'</label>
								<label class="db-checkbox-label active"><input type="checkbox" name="custom-hop-day[]" class="'.$custom_class.'" value="tue" checked>'.__('Tue', 'directory-builder').'</label>
								<label class="db-checkbox-label active"><input type="checkbox" name="custom-hop-day[]" class="'.$custom_class.'" value="wed" checked>'.__('Wed', 'directory-builder').'</label>
								<label class="db-checkbox-label active"><input type="checkbox" name="custom-hop-day[]" class="'.$custom_class.'" value="thu" checked>'.__('Thu', 'directory-builder').'</label>
								<label class="db-checkbox-label active"><input type="checkbox" name="custom-hop-day[]" class="'.$custom_class.'" value="fri" checked>'.__('Fri', 'directory-builder').'</label>
								<label class="db-checkbox-label"><input type="checkbox" name="custom-hop-day[]" class="'.$custom_class.'" value="sat">'.__('Sat', 'directory-builder').'</label>
								<label class="db-checkbox-label"><input type="checkbox" name="custom-hop-day[]" class="'.$custom_class.'" value="sun">'.__('Sun', 'directory-builder').'</label>
							</div>
							<div class="db-hop-right">
								<div class="db-hop-row clearfix">
									'.__('From:', 'directory-builder').' <input type="text" class="db-hop-from">
								</div>
								<div class="db-hop-row clearfix">
									'.__('Till:', 'directory-builder').' <input type="text" class="db-hop-till">
								</div>
								<a href="javascript:void(0)" class="db-hop-add-time button button-primary button-large">'.__('Add', 'directory-builder').'</a>
							</div>
							<div class="clearfix"></div>
						</div>
					</div>
				</div>';
				if ( $field_description != '' || ( $field_settings['required'] == 'yes' && $field_required_message != '' ) ) {
					$output .= '<div class="db-field-meta">';
						if ( $field_description != '' ) {
							$output .= '<span class="db-field-row-description">'.$field_description.'</span>';
						}
						if ( $field_settings['required'] == 'yes' && $field_required_message != '' && !is_admin() ) {
							$output .= '<span class="db-field-row-required">'.$field_required_message.'</span>';
						}
					$output .= '</div>';
				}
			$output .= '
			</div>';
			$main_settings = get_option( 'db_main_settings', array() );
			if ( isset($main_settings['listing_booking']) && $main_settings['listing_booking'] === true ) {
				$show_booking_feature = false;
				if ( is_admin() && isset($_GET['post']) ) {
					$listing_id = intval($_GET['post']);
					$terms = wp_get_post_terms( $listing_id, 'listing_category' );
					if ( !empty($terms) && isset($terms['0'])  ) {
						$active_booking_cats = (isset($main_settings['listing_booking_cat'])&&$main_settings['listing_booking_cat']!=''?$main_settings['listing_booking_cat']:array());
						if ( in_array($terms['0']->term_id, $active_booking_cats) ) {
							$show_booking_feature = true;
						}
					}
				} else if ( isset($_GET['edit-listing']) ) {
					$listing_id = intval($_GET['edit-listing']);
					$show_booking_feature = true;
				}

				if ( isset($listing_id) ) {
					$booking_date = get_post_meta( $listing_id, 'allow_bookings', true );
					$booking_int = get_post_meta( $listing_id, 'booking_interval', true );
					$booking_int_val = get_post_meta( $listing_id, 'booking_interval_val', true );
				}

				$output .= '
				<div class="db-booking-wrapper '.($show_booking_feature===false?'hidden':'').'" data-for="'.(isset($main_settings['listing_booking_cat'])&&is_array($main_settings['listing_booking_cat'])?implode(',',$main_settings['listing_booking_cat']):'').'">
					<h3>'.esc_html('Bookings','directory-builder').'</h3>
					<div class="db-field-row checkbox-label">
						<label class="db-field-row-label'.(isset($booking_date)&&($booking_date=='true'||$booking_date=='on')?' active':'').'" for="allow_bookings">'.esc_html__('Allow bookings', 'directory-builder').'</label>
						<input type="checkbox" id="allow_bookings" name="allow_bookings"'.(isset($booking_date)&&($booking_date=='true'||$booking_date=='on')?' checked':'').'>
						<div class="clearfix"></div>
					</div>
					<div class="db-field-row db-booking-row"'.(!isset($booking_date)||$booking_date=='false'?' style="display: none;"':'').'>
						<input type="number" id="booking_interval" name="booking_interval" placeholder="'.esc_html__('Booking interval','directory-builder').'" min="0" value="'.(isset($booking_int)?intval($booking_int):'').'">
						<select id="booking_interval_val" name="booking_interval_val">
							<option value="60"'.(isset($booking_int_val)&&$booking_int_val=='60'?' selected':'').'>'.esc_html__('Minutes', 'directory-builder').'</option>
							<option value="3600"'.(isset($booking_int_val)&&$booking_int_val=='3600'?' selected':'').'>'.esc_html__('Hours', 'directory-builder').'</option>
							<option value="86400"'.(isset($booking_int_val)&&$booking_int_val=='86400'?' selected':'').'>'.esc_html__('Days', 'directory-builder').'</option>
						</select>
					</div>
				</div>';
			}
			break;
		
		default:
			$output = '';
			break;
	}

	return $output;
}

function db_search_shortcode() {
	$main_settings = get_option( 'db_main_settings');
	$search_position = $main_settings['search_position'];

	if ( isset($_GET['mapontop']) ) {
		$search_position = 'bottom';
	}
	$search_fields = $main_settings['search_fields'];
	$search_layout = $main_settings['search_layout'];
	$search_layout = json_decode($search_layout, true);

	wp_enqueue_script( 'jquery-ui-slider' );
	wp_enqueue_script( 'jquery.mo' );
	wp_enqueue_script( 'jquery.isotope' );
	wp_enqueue_script( 'db-google-maps' );
	wp_enqueue_script( 'richmarkers' );
	wp_enqueue_script( 'markerclusterer' );
	wp_enqueue_script( 'infobubble' );

	$output = '
	<div class="db-main-wrapper">';
		$output .= '<div class="db-search-side-one '.$search_position.'">';
			$output .= '<div><a href="javascript:void(0)" class="dt-only-opened dt-button dt-button-green'.(isset($_GET['listing_opening'])?' active':'').'">'.esc_html__('Open now', 'directory-builder').'</a><input type="hidden" class="db-search-listing_opening" value="'.(isset($_GET['listing_opening'])?$_GET['listing_opening']:'').'"></div>';
			$output .= '<div id="db-main-search-map" style="width: 100%;height: 500px;"></div>';
		$output .= '</div>';
		$output .= '
		<div class="db-search-side-two '.$search_position.'">';
		$output .= '
			<div class="db-search-controls">
				<div class="db-main-search">';
					if ( in_array('listing_name', $search_fields) && !isset($search_layout) ) {
						$output .= '<input type="text" class="db-search-listing_name" placeholder="'.__('Listing name', 'directory-builder').'" value="'.(isset($_GET['listing_name'])?sanitize_text_field($_GET['listing_name']):'').'">';
					}
					$output .= '
					<div class="clearfix"></div>';
					global $wpdb;
					$field_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_fields WHERE field_active="yes" ORDER BY field_order DESC');
					if ( !empty($field_list) ) {
						$output .= '<div class="db-search-custom-fields clearfix">';
						
						if ( !isset($search_layout) ) {
							foreach ($field_list as $field_value) {
								$field_settings = json_decode($field_value->field_settings, true);
								if ( in_array($field_settings['field_name'], $search_fields) ) {
									$field_value = (isset($_GET[$field_settings['field_name']])?sanitize_text_field($_GET[$field_settings['field_name']]):'');

									if ( $field_settings['field_name'] == 'listing_address' && $main_settings['search_radius_status'] == 'yes' ) {
										$output .= '<div class="db-address-row">';
									}

									$output .= db_get_custom_field( $field_settings, 'db-search-'.$field_settings['field_name'], $field_value );

									if ( $field_settings['field_name'] == 'listing_address' && $main_settings['search_radius_status'] == 'yes' ) {
										$output .= '
										<div class="db-field-row db-slider-field-wrapper">
											<label class="db-field-row-label" for="listing_search_radius">'.__('Search radius', 'directory-builder').' ('.($main_settings['search_radius_value']=='km'?__('Kilometers', 'directory-builder'):__('Miles', 'directory-builder')).')</label>
											<div class="db-slider-field" data-value=" '.($main_settings['search_radius_value']=='km'?__('km', 'directory-builder'):__('miles', 'directory-builder')).'">
												<span class="db-slider-left"></span>
												<input type="text" id="listing_search_radius" class="db-search-listing_search_radius" value="'.(isset($_GET['listing_search_radius'])?intval($_GET['listing_search_radius']):'100').'">
											</div>
										</div>';
										$output .= '</div>';
									}
								}
							}
						} else {
							$all_fields = array();
							foreach ($field_list as $field_value) {
								$field_settings = json_decode($field_value->field_settings, true);
								if ( in_array($field_settings['field_name'], $search_fields) ) {
									$all_fields[$field_settings['field_name']] = $field_settings;
								}
							}

							if ( !empty($search_layout) ) {
								foreach ($search_layout as $field_row) {
									$output .= '<div class="db-search-row clearfix">';
										foreach ($field_row as $field_name) {
											$field_value = (isset($_GET[$field_name])?sanitize_text_field($_GET[$field_name]):'');

											if ( $field_name == 'search_radius' && $main_settings['search_radius_status'] != 'yes' ) {
												continue;
											}

											$output .= db_get_search_field( $field_name, $field_value, $all_fields );
										}
									$output .= '</div>';
								}
							}
						}
						if ( isset($_GET['mapontop']) ) {
							$output .= '<input type="hidden" id="db-search-mapontop" value="true">';
						}
						$output .= '<input type="hidden" id="db-search-current_user_time" value="">';
						$output .= '</div>';
					}

					$onload_click = $clickable_category = '';
					$get_variables = $_GET;
					unset($get_variables['page_id']);

					if ( !isset($_GET['search_category']) && !empty($get_variables) ) {
						$onload_click = ' onload';
					} else if ( isset($_GET['search_category']) ) {
						$clickable_category = sanitize_text_field($_GET['search_category']);
					}

					$output .= '
					<div class="clearfix"></div>
					<a href="javascript:void(0)" class="db-find-listings onload" data-page="1" data-max="'.$main_settings['per_page'].'" data-total="">'.__('Search', 'directory-builder').'</a>
				</div>';
				$custom_sorting = db_get_listing_custom_fields( '', 'on_sorting' );
				if ( !defined('WHITELAB_CUSTOM_SELECT') ) {
					$output .= __('Sort by:', 'directory-builder').'
					<select class="db-search-sort">
						<option value="opened">'.esc_html__('Open now', 'directory-builder').'</option>
						<option value="name">'.esc_html__('Name', 'directory-builder').'</option>
						<option value="date">'.esc_html__('Date', 'directory-builder').'</option>
						<option value="rating">'.esc_html__('Rating', 'directory-builder').'</option>';
						foreach ($custom_sorting as $field_name => $field_data) {
							$output .= '<option value="'.$field_name.'">'.$field_data['title'].'</option>';
						}
					$output .= '
					</select>';
				} else {
					$output .= '
					<div class="db-search-sort-container">
						<span class="db-found-count" data-found="0" data-total-found="0"> '.__('results', 'directory-builder').'</span>
						<div class="dt-sort-row single-select">
							<input type="text" class="dt-custom-select"  placeholder="'.__('Sort', 'directory-builder').'" readonly>
							<input type="hidden" class="dt-custom-select-value" id="db-search-sort">
							<div class="dt-custom-select-container">
								<div class="dt-custom-select-inner">
									<div class="dt-custom-select-items">
										<div class="dt-custom-select-item" data-value="opened">'.esc_html__('Open now', 'directory-builder').'</div>
										<div class="dt-custom-select-item" data-value="name">'.esc_html__('Name', 'directory-builder').'</div>
										<div class="dt-custom-select-item" data-value="date">'.esc_html__('Date', 'directory-builder').'</div>
										<div class="dt-custom-select-item" data-value="rating">'.esc_html__('Rating', 'directory-builder').'</div>';
										foreach ($custom_sorting as $field_name => $field_data) {
											$output .= '<div class="dt-custom-select-item" data-value="'.$field_name.'">'.$field_data['title'].'</div>';
										}
									$output .= '
									</div>
									<div class="dt-custom-select-scrollbar-wrapper">
										<span class="dt-custom-select-scrollbar"></span>
									</div>
								</div>
							</div>
						</div>
						<div class="clearfix"></div>
					</div>';
				}
				$output .= '
				<div class="clearfix"></div>
			</div>
			<a href="javascript:void(0)" class="db-show-more-fields db-invisible">'.esc_html__('Show more', 'directory-builder').'</a>
			<div class="db-main-search-listings loading" data-scroll="0"></div>
		</div>';
	$output .= '
		<div class="clearfix"></div>
	</div>';

	return $output;
}
add_shortcode('directory_listings','db_search_shortcode');

function db_get_search_field( $field_name, $field_value, $all_fields, $add_names = false ) {
	$output = '';
	$main_settings = get_option( 'db_main_settings');

	if ( $field_name == 'listing_name' ) {
		$output .= '
		<div class="db-field-row">
			<label class="db-field-row-label" for="listing_address">'.__('Listing name', 'directory-builder').'</label>
			<input type="text" class="db-search-listing_name"'.($add_names?' name="listing_name"':'').' placeholder="'.__('Listing name', 'directory-builder').'" value="'.(isset($_GET['listing_name'])?sanitize_text_field($_GET['listing_name']):'').'">
		</div>';
	} else if ( $field_name == 'search_radius' && $main_settings['search_radius_status'] == 'yes' ) {
		$output .= '
		<div class="db-field-row db-slider-field-wrapper">
			<label class="db-field-row-label" for="listing_search_radius">'.__('Search radius', 'directory-builder').' ('.($main_settings['search_radius_value']=='km'?__('Kilometers', 'directory-builder'):__('Miles', 'directory-builder')).')</label>
			<div class="db-slider-field" data-value=" '.($main_settings['search_radius_value']=='km'?__('km', 'directory-builder'):__('miles', 'directory-builder')).'">
				<span class="db-slider-left"></span>
				<input type="text" id="listing_search_radius" class="db-search-listing_search_radius"'.($add_names?' name="listing_search_radius"':'').' data-default="'.$main_settings['search_radius_distance'].'" value="'.(isset($_GET['listing_search_radius'])?intval($_GET['listing_search_radius']):$main_settings['search_radius_distance']).'">
			</div>
		</div>';
	} else if ( $field_name == 'listing_categories' ) {
		$term_settings = array(
			'taxonomy' => 'listing_category',
			'hide_empty' => $main_settings['hide_empty_categories'],
			'order' => $main_settings['category_list_sort'],
			'orderby' => $main_settings['category_list_order']
		);
		$terms = get_terms( $term_settings );

		if ( !is_wp_error($terms) ) {
			if ( !defined('WHITELAB_CUSTOM_SELECT') ) {
				$output .= '<div class="db-search-categories"><ul>';
				foreach ($terms as $category_value) {
					if ( $category_value->parent == 0 ) {
						$category_count = ($main_settings['category_post_count']===true?'<span class="db-category-count">('.$category_value->count.')</span>':'');
						$onload = (isset($clickable_category)&&$clickable_category==$category_value->term_id?'onload':'');
						$output .= '<li>
								<a href="javascript:void(0)" class="'.$onload.'" data-term-id="'.$category_value->term_id.'">'.$category_value->name.'</a>'.$category_count;
								if ( $main_settings['only_parent_categories'] === false ) {
									$term_settings['child_of'] = $category_value->term_id;
									$child_terms = get_terms( $term_settings );
									if ( !empty($child_terms) ) {
										$output .= '<ul>';
										foreach ($child_terms as $child_value) {
											$onload = ($clickable_category&&$clickable_category==$child_value->term_id?'onload':'');
											$category_count = ($main_settings['category_post_count']===true?'<span class="db-category-count">('.$child_value->count.')</span>':'');
											$output .= '<li><a href="javascript:void(0)" class="'.$onload.'" data-term-id="'.$child_value->term_id.'">'.$child_value->name.'</a>'.$category_count.'</li>';
										}
										$output .= '</ul>';
									}
								}
							$output .= '    
							</li>';
					}
					
				}
				$output .= '</ul></div>';
			} else {
				$active_categories = (isset($_GET['search_category'])?explode(',', sanitize_text_field($_GET['search_category'])):array());
				$active_placeholder = '';
				if ( empty($active_categories) ) {
					$active_placeholder = '';
				} else {
					foreach ($terms as $cat_data) {
						if ( in_array($cat_data->term_id, $active_categories) ) {
							$active_placeholder .= $cat_data->name.', ';
						}
					}
					$active_placeholder = substr($active_placeholder, 0, -2);
				}
				$output .= '
				<div class="db-field-row db-search-categories custom-select">
					<input type="text" class="dt-custom-select" placeholder="'.esc_html__( 'Category', 'directory-builder' ).'" value="'.$active_placeholder.'" readonly>
					<input type="hidden" class="dt-custom-select-value" id="db-search-search_category"'.($add_names?' name="search_category"':'').' value="'.implode(',', $active_categories).'">
					<div class="dt-custom-select-container">';
						$output .= '
						<div class="dt-custom-select-inner">
							<div class="dt-custom-select-search"><input type="text" placeholder="Search"></div>
							<div class="dt-custom-select-items">';
								$categoryHierarchy = array();
								db_sort_terms_hierarchicaly($terms, $categoryHierarchy);
								foreach ($categoryHierarchy as $category_data) {
									$output .= '
									<div class="dt-custom-select-item '.(in_array($category_data->term_id, $active_categories)?'active':'').'" data-value="'.$category_data->term_id.'">'.$category_data->name.'</div>';
									if ( !empty($category_data->children) ) {
										$output .= db_display_categories( $category_data, $active_categories );
									}
								}
							$output .= '
							</div>
							<div class="dt-custom-select-scrollbar-wrapper">
								<span class="dt-custom-select-scrollbar"></span>
							</div>
						</div>';
					$output .= '
					</div>
				</div>';
			}
		}
	} else if ( $field_name == 'listing_keyword' ) {
		if ( isset($_GET['search_category']) && is_numeric($_GET['search_category']) ) {
			$category_term = get_term( intval($_GET['search_category']), 'listing_category' );
			if ( isset($category_term->name) ) {
				$keyword_field_cat = $category_term->name;
			}
		}
		$output .= '
		<div class="db-field-row">
			<label class="db-field-row-label" for="listing_keyword">'.__('Keyword', 'directory-builder').'</label>
			<input type="text" class="db-search-listing_keyword"'.($add_names?' name="listing_keyword"':'').' placeholder="'.__('Keyword', 'directory-builder').'" value="'.(isset($_GET['listing_keyword'])?sanitize_text_field($_GET['listing_keyword']):(isset($keyword_field_cat)?sanitize_text_field($keyword_field_cat):'')).'">
		</div>';
	} else {
		if ( $field_name != 'geotarget' ) {
			$output .= db_get_custom_field( $all_fields[$field_name], 'db-search-'.$field_name, $field_value );
		}
	}

	return $output;
}

function db_check_listing_status() {
	global $post;

	if ( isset($post) && get_post_type( $post->ID ) == 'listings' && get_post_status( $post->ID ) == 'publish' ) {
		$order_data = get_post_meta( $post->ID, 'db_order_info', true );

		if ( isset($order_data['listing_expires']) && is_numeric($order_data['listing_expires']) && time() > $order_data['listing_expires'] ) {
			global $wpdb;
			$package_data = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_packages WHERE ID="'.intval($order_data['listing_package']).'"');
			$new_status = 'draft';
			if ( !empty($package_data) ) {
				$package_settings = json_decode( $package_data['0']->package_settings, true );
				$new_status = $package_settings['listing_status'];
			}

			wp_update_post( array( 'ID' => $post->ID, 'post_status' => $new_status ) );

			global $wp_query;
			$wp_query->set_404();
			status_header(404);
		}
	}
}
add_action( 'wp', 'db_check_listing_status', 10 );

function db_search_for_listings() {
	$output = '';
	$search_terms = ( isset($_POST['search_terms']) ? json_decode(stripslashes(sanitize_text_field($_POST['search_terms'])), true) : '' );
	$db_full_url = ( isset($_POST['db_full_url']) ? esc_url($_POST['db_full_url']) : '' );
	$db_parsed_url = parse_url( $db_full_url );
	$db_url_base = $db_parsed_url['scheme'].'://'.$db_parsed_url['host'].$db_parsed_url['path'];
	$db_page = ( isset($_POST['db_page']) ? intval( $_POST['db_page'] ) : 1 );

	if ( !isset($search_terms['listing_address']) || ( isset($search_terms['listing_address']) && $search_terms['listing_address'] == '' ) ) {
		unset($search_terms['listing_search_radius']);
	}

	if ( !isset($search_terms['amenities']) && strpos($db_full_url, 'amenities=') !== false ) { // Add amenities to the search parameters
		$url_parts = parse_url( $_POST['db_full_url'] );
		parse_str($url_parts['query'], $url_query);
		$search_terms['amenities'] = $url_query['amenities'];
	}

	if ( isset($search_terms['current_user_time']) ) {
		$current_user_time = $search_terms['current_user_time'];
		unset($search_terms['current_user_time']);
	}

	if ( get_option('permalink_structure') ) {
		$db_new_url = $db_url_base.'?'.http_build_query($search_terms);
	} else {
		$url_params = explode('&', $db_parsed_url['query']);
		foreach ( $url_params as $url_value ) {
			$get_part = explode('=', $url_value);
			if ( $get_part['0'] == 'page_id' ) {
				$search_terms['page_id'] = $get_part['1'];
			}
		}

		$db_new_url = $db_url_base.'?'.http_build_query($search_terms);
		unset($search_terms['page_id']);
	}
	unset($search_terms['mapontop']);

	$all_listings = array();
	$all_markers = array();

	if ( !empty($search_terms) ) {
		global $wpdb;
		$main_settings = get_option( 'db_main_settings');
		
		$search_where = '';
		if ( isset($search_terms['listing_name']) && !isset($search_terms['search_category']) ) {
			$search_where .= ' && lower(post_title) LIKE "%'.$search_terms['listing_name'].'%"';
			unset($search_terms['listing_name']);
		}
		$search_listings = $wpdb->get_results('SELECT * FROM '.$wpdb->posts.' WHERE post_type="listings" && post_status="publish"'.$search_where);
		$search_distance = (isset($search_terms['listing_search_radius'])?$search_terms['listing_search_radius']:$main_settings['search_radius_distance']);
		unset($search_terms['listing_search_radius']);

		$map_new_center = false;
		if ( !empty($search_listings) ) {
			$field_list = db_get_active_fields();

			if ( isset($search_terms['listing_address']) && $search_terms['listing_address'] != '' ) {
				$search_address_data = db_get_coordinates( $search_terms['listing_address'] );

				$map_new_center = true;
			}

			$listings_matched = 0;
			$loops = 0;
			$end_of_loop = false;
			foreach ($search_listings as $listing_value) {
				if ( in_array($listing_value->ID, $current_listings) ) {
					continue;
				}

				$listing_order_info = get_post_meta($listing_value->ID, 'db_order_info', true);
				if ( isset($listing_order_info['listing_expires']) && is_numeric($listing_order_info['listing_expires']) && $listing_order_info['listing_expires'] < time() ) {
					wp_update_post( array( 'ID' => $listing_value->ID, 'post_status' => 'pending' ) );
					continue;
				}

				$custom_field_data = db_get_listing_custom_values($field_list, $listing_value->ID);
				$listing_value = array_merge((array)$listing_value, $custom_field_data);
				$show_listing = true;
				$listing_visible = false;

				if ( isset($search_terms['listing_address']) && $search_terms['listing_address'] != '' ) {
					if ( $search_address_data['status'] && $search_address_data['type'] == 'fields' ) {
						if ( $search_address_data['field_type'] == 'country' && strpos($listing_value['listing_country'], $search_address_data['value']) !== false ) {
							$listing_visible = true;
						} else if ( $search_address_data['field_type'] == 'locality' && strpos($listing_value['listing_city'], $search_address_data['value']) !== false ) {
							$listing_visible = true;
						} else {
							$listing_visible = false;
						}
					} else {
						$db_search_distance = db_calculateDistanceFromLatLong($listing_value['listing_address_lat'], $listing_value['listing_address_lng'], $search_address_data['lat'], $search_address_data['lng'], $main_settings['search_radius_value']);

						if ( $main_settings['search_radius_status'] != 'yes' ) {
							$search_distance = '200';
						}
						if ( intval($db_search_distance) > intval($search_distance) ) {
							$listing_visible = false;
						} else {
							$listing_visible = true;
						}
					}

					if ( $listing_visible ) {
						$dist_show_listing = true;
					} else {
						$dist_show_listing = false;
					}
				}

				if ( !empty($search_terms) ) {
					$matched_settings = 0;

					foreach ($search_terms as $search_key => $search_value) {

						if ( isset($search_terms['listing_address']) && $search_terms['listing_address'] != '' && $search_key == 'listing_address' && $dist_show_listing ) {
							$matched_settings++;
							continue;
						}

						if ( $search_key == 'search_category' ) {
							$searched_categories = explode(',', $search_terms['search_category']);
							$has_category = false;
							foreach ($searched_categories as $cat_id) {
								if ( has_term($cat_id, 'listing_category', $listing_value['ID']) ) {
									$has_category = true;
									$matched_settings++;
									break;
								} else {
									$cat_child = get_term_children($cat_id, 'listing_category');
									if ( !empty($cat_child) ) {
										foreach ($cat_child as $child_id) {
											if ( has_term($child_id, 'listing_category', $listing_value['ID']) ) {
												$has_category = true;
												$matched_settings++;
												break;
											}
										}
									}
								}
							}
							if ( !$has_category ) {
								$show_listing = false;
							}
						} else if ( $search_key == 'listing_name' ) {
							if ( strpos(strtolower($listing_value['post_title']), strtolower($search_value)) !== false ) {
								$show_listing = true;
								$matched_settings++;
							}
						} else if ( $search_key == 'listing_country' ) {
							$searched_countries = explode(',', $search_value);
							foreach ($searched_countries as $country_value) {
								if ( strtolower($country_value) == strtolower($listing_value[$search_key]) ) {
									$show_listing = true;
									$matched_settings++;
									break;
								} else {
									$show_listing = false;
								}
							}
						} else if ( $search_key == 'amenities' ) {
							$amenities_values = (is_array($listing_value[$search_key])?$listing_value[$search_key]:explode(',', $listing_value[$search_key]));
							$searched_amenities = explode( ',', $search_value );

							if ( !empty($searched_amenities) ) {
								foreach ($searched_amenities as $amenity_value) {
									if ( in_array($amenity_value, $amenities_values) ) {
										$show_listing = true;
										$matched_settings++;
										break;
									} else {
										$show_listing = false;
									}
								}
							}
						} else if ( $search_key == 'listing_keyword' ) {
							if ( strpos(strtolower( $listing_value['post_title'] ), strtolower($search_value)) !== false ) {
								$show_listing = true;
								$matched_settings++;
							} else if ( strpos(strtolower( $listing_value['post_excerpt'] ), strtolower($search_value)) !== false ) {
								$show_listing = true;
								$matched_settings++;
							} else {
								$category_found = false;
								$listing_categories = wp_get_object_terms($listing_value['ID'], 'listing_category');
								if ( !empty( $listing_categories ) ) {
									foreach ($listing_categories as $category_data) {
										if ( strpos( strtolower($category_data->name), strtolower($search_value) ) !== false ) {
											$show_listing = $category_found = true;
											$matched_settings++;
											break;
										}
										
									}
								}

								if ( !$category_found ) {
									$do_not_check = array(
										'listing_address',
										'listing_city',
										'listing_neighborhood',
										'listing_zip',
										'listing_state',
										'listing_country',
										'listing_address_lat',
										'listing_address_lng'
									);

									$searchable_keyword_fields = $custom_field_data;
									foreach ($do_not_check as $unset_value) { // Unset fields that are not searchable
										unset($searchable_keyword_fields[$unset_value]);
									}

									if ( !empty($searchable_keyword_fields) ) {
										foreach ($searchable_keyword_fields as $field_name => $field_value) { // Loop through searchable keyword fields
											if ( !is_array( $field_value ) ) {
												if ( strpos( strtolower($field_value), strtolower($search_value) ) !== false ) {
													$show_listing = true;
													$matched_settings++;
													break;
												}
											} else {
												$field_data = db_get_custom_field_data( $field_name );

												if ( isset( $field_data['select_options'] ) ) {
													$select_values = preg_split("/\\r\\n|\\r|\\n/", $field_data['select_options']);

													if ( !empty($field_value) && !empty($select_values) ) {
														foreach ($field_value as $listing_select_value) {
															foreach ($select_values as $select_value) {
																if ( strpos($select_value.':', $listing_select_value.':') === 0 && strpos( strtolower($select_value), strtolower($search_value) ) !== false ) {
																	$show_listing = true;
																	$matched_settings++;
																	break 3;
																} else {
																	$show_listing = false;
																}
															}
														}
													}
												}
											}
										}
									}
								}
							}
						} else if ( $search_key == 'listing_opening' ) {
							$parsed_hop = json_decode( $listing_value['hop'], true );
							if ( is_array($parsed_hop) ) {
								$listing_timezone = $parsed_hop['0'];
								$listing_format = $parsed_hop['1'];
								unset($parsed_hop['0']);
								unset($parsed_hop['1']);
								if ( !empty($parsed_hop) ) {
									$user_time = $search_value - db_convert_utc( $listing_timezone );
									foreach ($parsed_hop as $hop_data) {
										if ( !empty($hop_data) ) {
											foreach ($hop_data as $hop_day_data) {
												$opening_time = $hop_day_data['0'];
												$closing_time = $hop_day_data['1'];

												if ( $opening_time <= $user_time && $closing_time > $user_time ) {
													$show_listing = true;
													$matched_settings++;
													break 2;
												}
											}
										}
									}
								}
							} else if ( $listing_value['hop'] == 'always' ) {
								$show_listing = true;
								$matched_settings++;
							} else {
								$show_listing = false;
								break;
							}
						} else {
							if ( is_array($listing_value[$search_key]) ) {
								$multiselect_val = false;
								$searched_values = explode(',', $search_value);
								if ( !empty($searched_values) ) {
									foreach ($searched_values as $searched_value) {
										if ( in_array($searched_value, $listing_value[$search_key]) ) {
											$multiselect_val = true;
											break;
										}
									}

									if ( $multiselect_val ) {
										$matched_settings++;
									} else {
										$show_listing = false;
										break;
									}
								}
							} else {
								if ( strtolower($listing_value[$search_key]) != strtolower($search_value) ) {
									$show_listing = false;
									break;
								} else {
									$matched_settings++;
								}		
							}
						}
					}
				}

				if ( $show_listing && $matched_settings == count($search_terms) ) {
					$loops++;

					if ( $loops == count($search_listings) ) {
						$end_of_loop = true;
					}

					global $db_search_listing_data;
					$db_search_listing_data = $listing_value;

					if ( isset($current_user_time) ) {
						$db_search_listing_data['current_user_time'] = $current_user_time;
					}

					$listings_matched++;

					if ( $listings_matched > ( ( $db_page - 1 ) * $main_settings['per_page'] ) && $listings_matched < (($main_settings['per_page']*$db_page)+1) ) {
						$all_listings[$listing_value['ID']] = db_load_template( 'search-listing-item.php', true, false, $main_settings );
						if ( function_exists('whitelab_get_image_css') ) {
							$listing_category = get_the_terms($db_search_listing_data['ID'], 'listing_category');
							$img = wp_get_attachment_image_src( get_post_thumbnail_id( $db_search_listing_data['ID'] ), 'db_single_listing' );
							
							$extra_css = '<style type="text/css">';
								$listing_category = get_the_terms($db_search_listing_data['ID'], 'listing_category');
								if ( isset($listing_category['0']) ) {
									$cat_meta = get_option( "listing_category_".$listing_category['0']->term_id);
									$tag_color = (isset($cat_meta['tag-category-color'])?$cat_meta['tag-category-color']:'#555555');
									$extra_css .= '.dt-featured-listings-category.'.$listing_category['0']->slug.' { color: '.$tag_color.'; }';
									$extra_css .= '.dt-featured-listings-category.'.$listing_category['0']->slug.':before { border-color: '.$tag_color.'; }';
								}
								if ( !isset($img['0']) && isset($cat_meta['tag-default-image']) && $cat_meta['tag-default-image'] != '' ) {
									$img['0'] = $cat_meta['tag-default-image'];
								}
								if ( isset($img['0']) ) {
									$extra_css .= '.dt-featured-item-image.id-'.$listing_value['ID'].' { background: url('.preg_replace('#^https?://#', '//', $img['0']).') }';
								}
							$extra_css .= '</style>';
							$all_listings[$listing_value['ID']] .= $extra_css;
						}

						$categories = wp_get_object_terms($listing_value['ID'], 'listing_category');
						$cat_meta = get_option( "listing_category_".$categories['0']->term_id);

						$custom_icon = '';
						if ( isset($cat_meta['tag-category-icon']) ) {
							$custom_icon = $cat_meta['tag-category-icon'];
						}

						$all_markers[] = array($listing_value['listing_address_lat'], $listing_value['listing_address_lng'], $custom_icon, $listing_value['ID']);
					}
				}
			}
		}
	}

	$search_data = array('listing_html' => $all_listings, 'marker_data' => $all_markers, 'new_url' => $db_new_url, 'map_changed' => false, 'total' => $listings_matched );

	if ( isset( $search_address_data['status'] ) && !$search_address_data['status'] ) {
		$search_data['gmsg'] = $search_address_data['message'];
	}

	if ( empty( $all_markers ) && $map_new_center ) {
		$search_data['map_lat'] = $search_address_data['lat'];
		$search_data['map_lng'] = $search_address_data['lng'];
		$search_data['map_changed'] = true;
	}

	echo json_encode( $search_data );

	die(0);
}
add_action( 'wp_ajax_db_search_listings', 'db_search_for_listings' );
add_action( 'wp_ajax_nopriv_db_search_listings', 'db_search_for_listings' );

function db_convert_utc( $utc ) {
	$utc_offset = substr( $utc, 4 );
	$utc_delimiter = substr( $utc, 3, 1 );
	$offset = 3600 * floatval($utc_offset);

	if ( $utc_delimiter == '+' ) {
		$offset = 0 - $offset;
	}

	return $offset;
}

function db_parse_hop_days( $days, $time ) {
	$returned_days = array();
	if ( strpos($days, '-') !== false ) { // Multiple days
		$hoo_days = array( 'mon', 'tue', 'wed', 'thu', 'fri', 'sat', 'sun' );
		$start_end = explode(' - ', $days);
		$start = false;
		foreach ($hoo_days as $hoo_day) {
			if ( $hoo_day == $start_end['0'] || $start === true ) {
				$returned_days[$hoo_day] = $time;
				$start = true;
				if ( $hoo_day == $start_end['1'] ) {
					break;
				}
			}
		}
	} else {
		$returned_days[$days] = $time;
	}

	return $returned_days;
}

function db_get_custom_sorting() {
	$custom_sorting = db_get_listing_custom_fields( '', 'on_sorting' );
	$sort_ints = array( 'number', 'date', 'time', 'phone' );
	$sorting_arr = array( 'name' => '[data-name]', 'date' => '[data-date] parseInt', 'rating' => '[data-rating] parseInt', 'featured' => '[data-featured] parseInt', 'opened' => '[data-opened] parseInt' );

	if ( !empty($custom_sorting) ) {
		foreach ($custom_sorting as $sorting_key => $sorting_value) {
			$sorting_arr[$sorting_key] = '[data-'.$sorting_key.']'.(in_array($sorting_value['type'], $sort_ints)?' parseInt':'');
		}
	}

	return json_encode( $sorting_arr );
}

function db_get_custom_sorting_dir() {
	$custom_sorting = db_get_listing_custom_fields( '', 'on_sorting' );
	$sort_ints = array( 'number', 'date', 'time', 'phone' );
	$sorting_dir_arr = array( 'name' => true, 'date' => false, 'rating' => false, 'featured' => true, 'opened' => true );

	if ( !empty($custom_sorting) ) {
		foreach ($custom_sorting as $sorting_key => $sorting_value) {
			$sorting_dir_arr[$sorting_key] = (in_array($sorting_value['type'], $sort_ints)?false:true);
		}
	}

	return json_encode( $sorting_dir_arr );
}

function db_get_coordinates( $address ) {
	$address = str_replace(" ", "+", $address);
	$url = "http://maps.google.com/maps/api/geocode/json?sensor=false&address=$address";
	$response = wp_remote_get($url);
	$json = json_decode($response['body'],TRUE);

	if ( $json['status'] == 'OK' ) {
		if ( ( $json['results'][0]['types']['0'] == 'country' || $json['results'][0]['types']['0'] == 'locality' ) && $json['results'][0]['types']['1'] == 'political' ) {
			return array( 'status' => true, 'type' => 'fields', 'field_type' => $json['results'][0]['types']['0'], 'value' => $json['results'][0]['address_components']['0']['long_name'], 'lat' => $json['results'][0]['geometry']['location']['lat'], 'lng' => $json['results'][0]['geometry']['location']['lng'] );
		} else {
			return array( 'status' => true, 'type' => 'coordinates', 'lat' => $json['results'][0]['geometry']['location']['lat'], 'lng' => $json['results'][0]['geometry']['location']['lng'] );
		}
	} else {
		if ( $json['status'] == 'OVER_QUERY_LIMIT' ) {
			$message = esc_html__('You\'re over your API query limit!', 'directory-builder');
		} else if ( $json['status'] == 'REQUEST_DENIED' ) {
			$message = esc_html__('Seems like your address request was denied by Google!', 'directory-builder');
		} else {
			$message = esc_html__('Something went wrong while contacting Google!', 'directory-builder');
		}
		return array( 'status' => false, 'message' => $message );
	}
}

function db_calculate_distance($lat1, $lon1, $lat2, $lon2, $unit) {
	$theta = $lon1 - $lon2;
	$dist = sin(deg2rad($lat1)) * sin(deg2rad($lat2)) + cos(deg2rad($lat1)) * cos(deg2rad($lat2)) * cos(deg2rad($theta));
	$dist = acos($dist);
	$dist = rad2deg($dist);
	$miles = $dist * 60 * 1.1515;

	if ($unit == 'km') {
		return ($miles * 1.609344);
	} else if ($unit == 'N') {
		return ($miles * 0.8684);
	} else {
		return $miles;
	}
}

function db_getDistanceRadius( $uom = 'km' ) {
	//	Use Haversine formula to calculate the great circle distance between two points identified by longitude and latitude
	switch ( strtolower( $uom ) ):
		case 'km':
			$earthMeanRadius = 6371.009; // km
			break;
		case 'm':
		case 'meters':
			$earthMeanRadius = 6371.009 * 1000; // km
			break;
		case 'miles':
			$earthMeanRadius = 3958.761; // miles
			break;
		case 'yards':
		case 'yds':
			$earthMeanRadius = 3958.761 * 1760; // yards
			break;
		case 'feet':
		case 'ft':
			$earthMeanRadius = 3958.761 * 1760 * 3; // feet
			break;
		case 'nm':
			$earthMeanRadius = 3440.069; //  miles
			break;
		default:
			$earthMeanRadius = 3958.761; // miles
			break;
	endswitch;

	return $earthMeanRadius;
}

function db_calculateDistanceFromLatLong( $loc1_lat, $loc1_lng, $loc2_lat, $loc2_lng, $uom = 'km' ) {
	//	Use Haversine formula to calculate the great circle distance between two points identified by longitude and latitude

	$earthMeanRadius = db_getDistanceRadius( $uom );

	$deltaLatitude  = deg2rad( (float) $loc2_lat - (float) $loc1_lat );
	$deltaLongitude = deg2rad( (float) $loc2_lng - (float) $loc1_lng );
	$a              = sin( $deltaLatitude / 2 ) * sin( $deltaLatitude / 2 ) +
					  cos( deg2rad( (float) $loc1_lat ) ) * cos( deg2rad( (float) $loc2_lat ) ) *
					  sin( $deltaLongitude / 2 ) * sin( $deltaLongitude / 2 );
	$c              = 2 * atan2( sqrt( $a ), sqrt( 1 - $a ) );
	$distance       = $earthMeanRadius * $c;

	return $distance;

}

function db_get_active_fields() {
	$meta_values = array(
		'listing_address',
		'listing_address_lat',
		'listing_address_lng'
	);

	global $wpdb;
	$field_list = $wpdb->get_results('SELECT field_settings FROM '.$wpdb->prefix.'directory_fields WHERE field_active="yes" ORDER BY field_order DESC');
	if ( !empty($field_list) ) {
		foreach ($field_list as $field_value) {
			$field_settings = json_decode($field_value->field_settings, true);
			$meta_values[] = $field_settings['field_name'];
		}
	}

	return $meta_values;
}

function db_get_listing_custom_values( $field_list, $post_id ) {
	$field_data = array();
	if ( !empty($field_list) ) {
		foreach ($field_list as $field_name) {
			$custom_field_value = get_post_meta( $post_id, $field_name, true );
			$field_data[$field_name] = ( !is_array( $custom_field_value ) ? sanitize_text_field( $custom_field_value ) : db_sanitize_array( $custom_field_value ) );
			if ( $field_name == 'listing_address' && $field_data[$field_name] == '' ) {
				$field_data[$field_name] = 'London';
			}
			if ( $field_name == 'listing_address_lat' && $field_data[$field_name] == '' ) {
				$field_data[$field_name] = '51.5073509';
			}
			if ( $field_name == 'listing_address_lng' && $field_data[$field_name] == '' ) {
				$field_data[$field_name] = '-0.12775829999998223';
			}
		}
	}
	
	return $field_data;
}

function db_get_custom_field_data( $field_name ) {
	global $wpdb;

	$actual_field = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_fields WHERE field_active="yes" && field_settings LIKE "%\"field_name\":\"'.$field_name.'\"%"');
	if ( !empty($actual_field) ) {
		return json_decode( $actual_field['0']->field_settings, true );;
	} else {
		return false;
	}
}

function db_get_active_details_fields() {
	$meta_values = array();

	global $wpdb;
	$field_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_fields WHERE field_active="yes" ORDER BY field_order DESC');
	if ( !empty($field_list) ) {
		foreach ($field_list as $field_value) {
			$field_settings = json_decode($field_value->field_settings, true);

			if ( $field_settings['on_listing'] == 'yes' ) {
				$meta_values[$field_settings['field_name']] = $field_settings['frontend_title'];
			}
		}
	}

	return $meta_values;
}

function db_settings_html() {
	if ( !current_user_can('manage_options') )  {
		wp_die( __('You do not have sufficient permissions to access this page.', 'directory-builder') );
	}
	$main_settings = get_option( 'db_main_settings');
	?>

	<div class="db-main-wrapper container-fluid" id="db-main-wrapper">
		<div class="db-main-content">
			<div class="db-box-wrapper">
				<div class="db-box-left">
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">General settings</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Per page limit at search</span>
									<div class="col-sm-9">
										<input type="number" class="db-settings-per_page" placeholder="Per page limit at search" value="<?php echo $main_settings['per_page']; ?>">
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Include listing contact form on listing page?</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo ($main_settings['contact_form_status']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-contact_form_status" <?php echo ($main_settings['contact_form_status']=='true'?'checked':''); ?>>
										</div>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Contact form only for registered users?</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo ($main_settings['contact_form_registered']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-contact_form_registered" <?php echo ($main_settings['contact_form_registered']=='true'?'checked':''); ?>>
										</div>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Maximum contact form submissions per day</span>
									<div class="col-sm-9">
										<input type="number" class="db-settings-contact_form_max" placeholder="0" value="<?php echo $main_settings['contact_form_max']; ?>">
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Include ratings for listings?</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo ($main_settings['listing_ratings']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-listing_ratings" <?php echo ($main_settings['listing_ratings']=='true'?'checked':''); ?>>
										</div>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Enable listing booking feature?</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo (isset($main_settings['listing_booking'])&&$main_settings['listing_booking']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-listing_booking" <?php echo (isset($main_settings['listing_booking'])&&$main_settings['listing_booking']=='true'?'checked':''); ?>>
										</div>
										<span>You're able to read more about bookings at the <a href="http://documentation.cohhe.com/whitelab/knowledgebase/bookings/" target="_blank">bookings documentation</a> page.</span>
									</div>
								</div>
							</div>
							<div class="db-row db-listing-booking">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Enable booking for these categories</span>
									<div class="col-sm-9">
										<select class="db-settings-listing_booking_cat" multiple>
											<?php
											$categories = get_terms( array(
												'taxonomy' => 'listing_category',
												'hide_empty' => false
											));
											if ( !empty($categories) ) {
												foreach ($categories as $category_value) {
													echo '<option value="'.$category_value->term_id.'"'.(isset($main_settings['listing_booking_cat'])&&in_array($category_value->term_id, $main_settings['listing_booking_cat'])?' selected':'').'>'.$category_value->name.'</option>';
												}
											}
											?>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Enable listing menu feature?</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo (isset($main_settings['listing_menu'])&&$main_settings['listing_menu']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-listing_menu" <?php echo (isset($main_settings['listing_menu'])&&$main_settings['listing_menu']=='true'?'checked':''); ?>>
										</div>
									</div>
								</div>
							</div>
							<div class="db-row db-listing-booking">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Enable listing menu feature for these categories</span>
									<div class="col-sm-9">
										<select class="db-settings-listing_menu_cat" multiple>
											<?php
											$categories = get_terms( array(
												'taxonomy' => 'listing_category',
												'hide_empty' => false
											));
											if ( !empty($categories) ) {
												foreach ($categories as $category_value) {
													echo '<option value="'.$category_value->term_id.'"'.(isset($main_settings['listing_menu_cat'])&&in_array($category_value->term_id, $main_settings['listing_menu_cat'])?' selected':'').'>'.$category_value->name.'</option>';
												}
											}
											?>
										</select>
									</div>
								</div>
							</div>	
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">New listing status</span>
									<div class="col-sm-9">
										<select class="db-settings-new_post_status">
											<option value="pending" <?php echo ($main_settings['new_post_status']=='pending'?'selected':''); ?>>Listing is pending approval</option>
											<option value="publish" <?php echo ($main_settings['new_post_status']=='publish'?'selected':''); ?>>Listing is published</option>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Listing status after plugin uninstall</span>
									<div class="col-sm-9">
										<select class="db-settings-after_uninstall">
											<option value="nothing" <?php echo ($main_settings['after_uninstall']=='nothing'?'selected':''); ?>>Do not change</option>
											<option value="draft" <?php echo ($main_settings['after_uninstall']=='draft'?'selected':''); ?>>Draft</option>
											<option value="trash" <?php echo ($main_settings['after_uninstall']=='trash'?'selected':''); ?>>Trash</option>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Listing no image</span>
									<div class="col-sm-9">
										<input type="button" value="Upload image" class="db-image-upload">
										<input type="button" class="db-image-delete" value="Delete image" <?php echo ($main_settings['default_listing_image']==''?'style="display: none;"':''); ?>>
										<div class="db-image-container">
											<?php echo ($main_settings['default_listing_image']!=''?'<img src="'.$main_settings['default_listing_image'].'" alt="">':''); ?>
										</div>
										<input type="hidden" class="db-settings-default_listing_image" value="<?php echo $main_settings['default_listing_image']; ?>">
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Register on "Add listing" page</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo ($main_settings['add_listing_register']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-add_listing_register" <?php echo ($main_settings['add_listing_register']=='true'?'checked':''); ?>>
										</div>
									</div>
								</div>
							</div>
							<?php $all_pages = get_pages(); ?>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Login page</span>
									<div class="col-sm-9">
										<select class="db-settings-login_page_id">
										<?php
											foreach ($all_pages as $page_key => $page_value) {
												$is_selected = ($main_settings['login_page_id']==$page_value->ID?' selected':'');
												echo '<option value="'.$page_value->ID.'"'.$is_selected.'>'.$page_value->post_title.'</option>';
											}
										?>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Listing search page</span>
									<div class="col-sm-9">
										<select class="db-settings-search_page_id">
										<?php
											foreach ($all_pages as $page_key => $page_value) {
												$is_selected = ($main_settings['search_page_id']==$page_value->ID?' selected':'');
												echo '<option value="'.$page_value->ID.'"'.$is_selected.'>'.$page_value->post_title.'</option>';
											}
										?>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Add listing page</span>
									<div class="col-sm-9">
										<select class="db-settings-add_page_id">
										<?php
											foreach ($all_pages as $page_key => $page_value) {
												$is_selected = ($main_settings['add_page_id']==$page_value->ID?' selected':'');
												echo '<option value="'.$page_value->ID.'"'.$is_selected.'>'.$page_value->post_title.'</option>';
											}
										?>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Listing author account page</span>
									<div class="col-sm-9">
										<select class="db-settings-account_page_id">
										<?php
											foreach ($all_pages as $page_key => $page_value) {
												$is_selected = ($main_settings['account_page_id']==$page_value->ID?' selected':'');
												echo '<option value="'.$page_value->ID.'"'.$is_selected.'>'.$page_value->post_title.'</option>';
											}
										?>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Claim listing learn more page</span>
									<div class="col-sm-9">
										<select class="db-settings-claim_learn_more">
										<?php
											foreach ($all_pages as $page_key => $page_value) {
												$is_selected = ($main_settings['claim_learn_more']==$page_value->ID?' selected':'');
												echo '<option value="'.$page_value->ID.'"'.$is_selected.'>'.$page_value->post_title.'</option>';
											}
										?>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Default location</span>
									<div class="col-sm-9">
										<input type="text" class="db-settings-default_location" value="<?php echo $main_settings['default_location']; ?>">
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Google API key</span>
									<div class="col-sm-9">
										<input type="text" class="db-settings-google_key" value="<?php echo $main_settings['google_key']; ?>">
										<span>This key is needed for the google maps, without it google maps can't work.</p>
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">Permalink settings</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Directory listing slug</span>
									<div class="col-sm-9">
										<input type="text" class="db-settings-directory_slug" placeholder="Directory listing slug" value="<?php echo $main_settings['directory_slug']; ?>">
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Directory category slug</span>
									<div class="col-sm-9">
										<input type="text" class="db-settings-category_slug" placeholder="Directory category slug" value="<?php echo $main_settings['category_slug']; ?>">
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">Image settings</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Allow images?</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo ($main_settings['allow_images']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-allow_images" <?php echo ($main_settings['allow_images']=='true'?'checked':''); ?>>
										</div>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Min image file size (KB)</span>
									<div class="col-sm-9">
										<input type="number" class="db-settings-image_min_size" placeholder="0" value="<?php echo $main_settings['image_min_size']; ?>">
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Max image file size (KB)</span>
									<div class="col-sm-9">
										<input type="number" class="db-settings-image_max_size" placeholder="0" value="<?php echo $main_settings['image_max_size']; ?>">
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Min image width (px)</span>
									<div class="col-sm-9">
										<input type="number" class="db-settings-image_min_width" placeholder="0" value="<?php echo $main_settings['image_min_width']; ?>">
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Max image width (px)</span>
									<div class="col-sm-9">
										<input type="number" class="db-settings-image_max_width" placeholder="0" value="<?php echo $main_settings['image_max_width']; ?>">
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Min image height (px)</span>
									<div class="col-sm-9">
										<input type="number" class="db-settings-image_min_height" placeholder="0" value="<?php echo $main_settings['image_min_height']; ?>">
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Max image height (px)</span>
									<div class="col-sm-9">
										<input type="number" class="db-settings-image_max_height" placeholder="0" value="<?php echo $main_settings['image_max_height']; ?>">
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">User settings</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Users are allowed to</span>
									<div class="col-sm-9">
										<select class="db-settings-users_are_allowed" multiple>
											<option value="edit" <?php echo (in_array('edit', $main_settings['users_are_allowed'])?'selected':''); ?>>Edit listings</option>
											<option value="delete" <?php echo (in_array('delete', $main_settings['users_are_allowed'])?'selected':''); ?>>Delete listings</option>
										</select>
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">Claim settings</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Claim amount</span>
									<div class="col-sm-9">
										<input type="number" class="db-settings-claim_amount" placeholder="0" value="<?php echo $main_settings['claim_amount']; ?>">
										<span>Number of listing one user can claim</span>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Claims require purchase</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo ($main_settings['claims_require_purchase']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-claims_require_purchase" <?php echo ($main_settings['claims_require_purchase']=='true'?'checked':''); ?>>
										</div>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Claim processing</span>
									<div class="col-sm-9">
										<select class="db-settings-claims_processing">
											<option value="auto" <?php echo ($main_settings['claims_processing']=='auto'?'selected':''); ?>>Automatically accept claim requests</option>
											<option value="manual" <?php echo ($main_settings['claims_processing']=='manual'?'selected':''); ?>>Manually accept claim requests</option>
										</select>
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">Invoice PDF settings</h3>
							</div>
							<div class="db-row-group invoice-logo clearfix">
								<span class="db-row-label col-sm-3">Invoice logo</span>
								<div class="col-sm-9">
									<input type="button" value="Upload image" class="db-image-upload">
									<input type="button" class="db-image-delete" value="Delete image" <?php echo ($main_settings['invoice_logo']==''?'style="display: none;"':''); ?>>
									<div class="db-image-container">
										<?php echo ($main_settings['invoice_logo']!=''?'<img src="'.$main_settings['invoice_logo'].'" alt="">':''); ?>
									</div>
									<input type="hidden" class="db-settings-invoice_logo" value="<?php echo $main_settings['invoice_logo']; ?>">
								</div>
							</div>
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Invoice business details</span>
								<div class="col-sm-9">
									<textarea class="db-settings-invoice_business"><?php echo $main_settings['invoice_business']; ?></textarea>
								</div>
							</div>
						</div>
					</div>
				</div>
				<div class="db-box-right">
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">Terms and conditions</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Display terms and conditions</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo ($main_settings['terms_and_conditions_status']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-terms_and_conditions_status" <?php echo ($main_settings['terms_and_conditions_status']=='true'?'checked':''); ?>>
										</div>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Terms and conditions</span>
									<div class="col-sm-9">
										<textarea class="db-settings-terms_and_conditions"><?php echo $main_settings['terms_and_conditions']; ?></textarea>
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">Search settings</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Search form display</span>
									<div class="col-sm-9">
										<select class="db-settings-search_position">
											<option value="left" <?php echo ($main_settings['search_position']=='left'?'selected':''); ?>>Left side</option>
											<option value="right" <?php echo ($main_settings['search_position']=='right'?'selected':''); ?>>Right side</option>
											<option value="bottom" <?php echo ($main_settings['search_position']=='bottom'?'selected':''); ?>>Below map</option>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Include fields in search</span>
									<div class="col-sm-9">
										<select class="db-settings-search_fields" multiple>
											<option value="listing_name" <?php echo (in_array('listing_name', $main_settings['search_fields'])?'selected':''); ?>>Listing name</option>
											<option value="search_radius" <?php echo (in_array('search_radius', $main_settings['search_fields'])?'selected':''); ?>>Search radius</option>
											<option value="listing_categories" <?php echo (in_array('listing_categories', $main_settings['search_fields'])?'selected':''); ?>>Listing categories</option>
											<option value="listing_keyword" <?php echo (in_array('listing_keyword', $main_settings['search_fields'])?'selected':''); ?>>Keyword</option>
											<?php
												global $wpdb;
												$field_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_fields WHERE field_active="yes" ORDER BY field_order DESC');
												$field_data_list = array(
													'listing_name' => 'Listing name',
													'search_radius' => 'Search radius',
													'listing_categories' => 'Listing categories',
													'listing_keyword' => 'Keyword'
												);
												if ( !empty($field_list) ) {
													foreach ($field_list as $field_value) {
														$field_settings = json_decode($field_value->field_settings, true);
														if ( $field_settings['field_type'] != 'fileupload' && $field_settings['field_type'] != 'html' && $field_settings['field_type'] != 'checkbox' && $field_settings['field_type'] != 'radio' && $field_settings['field_type'] != 'hoursofoperation' ) {
															$is_selected = (in_array($field_settings['field_name'], $main_settings['search_fields'])?'selected':'');
															echo '<option value="'.$field_settings['field_name'].'" '.$is_selected.'>'.$field_settings['frontend_title'].'</option>';
															$field_data_list[$field_settings['field_name']] = $field_settings['frontend_title'];
														}
													}
												}
											?>
										</select>
										<a href="javascript:void(0)" class="db-change-layout db-button db-primary-button" data-source="searchpage">Change field layout</a>
									</div>
								</div>
								<div class="db-search-field-layout-dialog searchpage" style="display: none;">
									<a href="javascript:void(0);" class="db-add-new-column db-button db-primary-button">Add row</a>
									<a href="javascript:void(0);" class="db-confirm-layout db-button db-primary-button" data-source="searchpage">Confirm layout</a>
									<input type="hidden" class="db-settings-search_layout" value='<?php echo $main_settings['search_layout']; ?>'>
									<?php
									$search_layout = json_decode($main_settings['search_layout'], true);
									if ( isset($search_layout) && !empty($search_layout) ) {
										foreach ($search_layout as $row_value) {
											echo '<div class="column clearfix">';
											foreach ($row_value as $row_item) {
												echo '<div class="portlet" data-id="'.$row_item.'"><div class="portlet-header">'.$field_data_list[$row_item].'</div></div>';
											}
											echo '</div>';
										}
									} else { ?>
										<div class="column clearfix"></div>
									<?php } ?>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Limit search radius</span>
									<div class="col-sm-9">
										<select class="db-settings-search_radius_status">
											<option value="no" <?php echo ($main_settings['search_radius_status']=='no'?'selected':''); ?>>No</option>
											<option value="yes" <?php echo ($main_settings['search_radius_status']=='yes'?'selected':''); ?>>Yes</option>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row db-search-radius-options">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Search radius measurement</span>
									<div class="col-sm-9">
										<select class="db-settings-search_radius_value">
											<option value="km" <?php echo ($main_settings['search_radius_value']=='km'?'selected':''); ?>>Kilometers</option>
											<option value="mil" <?php echo ($main_settings['search_radius_value']=='mil'?'selected':''); ?>>Miles</option>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row db-search-radius-options">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Search radius distance</span>
									<div class="col-sm-9">
										<input type="number" class="db-settings-search_radius_distance" value="<?php echo $main_settings['search_radius_distance']; ?>">
										<span>If search has "Listing address" field added, then while searching by address only listing in a given radius around the search address will be returned.</span>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Homepage search fields</span>
									<div class="col-sm-9">
										<select class="db-settings-homepage_search_fields" multiple>
											<option value="listing_name" <?php echo (in_array('listing_name', $main_settings['homepage_search_fields'])?'selected':''); ?>>Listing name</option>
											<option value="listing_categories" <?php echo (in_array('listing_categories', $main_settings['homepage_search_fields'])?'selected':''); ?>>Listing categories</option>
											<option value="listing_keyword" <?php echo (in_array('listing_keyword', $main_settings['homepage_search_fields'])?'selected':''); ?>>Keyword</option>
											<?php
												if ( !empty($field_list) ) {
													foreach ($field_list as $field_value) {
														$field_settings = json_decode($field_value->field_settings, true);
														if ( $field_settings['field_type'] != 'fileupload' && $field_settings['field_type'] != 'html' && $field_settings['field_type'] != 'checkbox' && $field_settings['field_type'] != 'radio' && $field_settings['field_type'] != 'hoursofoperation' ) {
															$is_selected = (in_array($field_settings['field_name'], $main_settings['homepage_search_fields'])?'selected':'');
															echo '<option value="'.$field_settings['field_name'].'" '.$is_selected.'>'.$field_settings['frontend_title'].'</option>';
															$field_data_list[$field_settings['field_name']] = $field_settings['frontend_title'];
														}
													}
												}
											?>
										</select>
										<a href="javascript:void(0)" class="db-change-layout db-button db-primary-button" data-source="homepage">Change field layout</a>
									</div>
								</div>
								<div class="db-search-field-layout-dialog homepage" style="display: none;">
									<a href="javascript:void(0);" class="db-confirm-layout db-button db-primary-button" data-source="homepage">Confirm layout</a>
									<input type="hidden" class="db-settings-homepage_search_layout" value='<?php echo $main_settings['homepage_search_layout']; ?>'>
									<?php
									$homepage_search_layout = json_decode($main_settings['homepage_search_layout'], true);
									if ( isset($homepage_search_layout) && !empty($homepage_search_layout) ) {
										foreach ($homepage_search_layout as $row_value) {
											echo '<div class="column clearfix">';
											foreach ($row_value as $row_item) {
												echo '<div class="portlet" data-id="'.$row_item.'"><div class="portlet-header">'.$field_data_list[$row_item].'</div></div>';
											}
											echo '</div>';
										}
									} else { ?>
										<div class="column clearfix"></div>
									<?php } ?>
								</div>
							</div>
						</div>
					</div>
					<div class="db-box-container col-md-12">
						<div class="db-box main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">Listing/category settings</h3>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Order category list by</span>
									<div class="col-sm-9">
										<select class="db-settings-category_list_order">
											<option value="name" <?php echo ($main_settings['category_list_order']=='name'?'selected':''); ?>>Name</option>
											<option value="slug" <?php echo ($main_settings['category_list_order']=='slug'?'selected':''); ?>>Slug</option>
											<option value="count" <?php echo ($main_settings['category_list_order']=='count'?'selected':''); ?>>Count of listings</option>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Sort category list</span>
									<div class="col-sm-9">
										<select class="db-settings-category_list_sort">
											<option value="asc" <?php echo ($main_settings['category_list_sort']=='asc'?'selected':''); ?>>Ascending</option>
											<option value="desc" <?php echo ($main_settings['category_list_sort']=='desc'?'selected':''); ?>>Descending</option>
										</select>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Show category post count?</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo ($main_settings['category_post_count']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-category_post_count" <?php echo ($main_settings['category_post_count']=='true'?'checked':''); ?>>
										</div>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Hide empty categories</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo ($main_settings['hide_empty_categories']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-hide_empty_categories" <?php echo ($main_settings['hide_empty_categories']=='true'?'checked':''); ?>>
										</div>
									</div>
								</div>
							</div>
							<div class="db-row">
								<div class="db-row-group clearfix">
									<span class="db-row-label col-sm-3">Show only parent categories in category list?</span>
									<div class="col-sm-9">
										<div class="db-checkbox <?php echo ($main_settings['only_parent_categories']=='true'?'active':''); ?>">
											<input type="checkbox" class="db-settings-only_parent_categories" <?php echo ($main_settings['only_parent_categories']=='true'?'checked':''); ?>>
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="db-box-container col-md-12">
					<div class="db-box main-card">
						<div class="db-box-title">
							<h3 class="db-main-title">Listing packages</h3>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Paypal currency</span>
								<div class="col-sm-9">
									<select class="db-settings-default_currency">
										<?php
											$currencies = array(
												'AUD' => 'Australian Dollar',
												'BRL' => 'Brazilian Real',
												'CAD' => 'Canadian Dollar',
												'CZK' => 'Czech Koruna',
												'DKK' => 'Danish Krone',
												'EUR' => 'Euro',
												'HKD' => 'Hong Kong Dollar',
												'HUF' => 'Hungarian Forint',
												'ILS' => 'Israeli New Sheqel',
												'JPY' => 'Japanese Yen',
												'MYR' => 'Malaysian Ringgit',
												'MXN' => 'Mexican Peso',
												'NOK' => 'Norwegian Krone',
												'NZD' => 'New Zealand Dollar',
												'PHP' => 'Philippine Peso',
												'PLN' => 'Polish Zloty',
												'GBP' => 'Pound Sterling',
												'RUB' => 'Russian Ruble',
												'SGD' => 'Singapore Dollar',
												'SEK' => 'Swedish Krona',
												'CHF' => 'Swiss Franc',
												'TWD' => 'Taiwan New Dollar',
												'THB' => 'Thai Baht',
												'USD' => 'U.S. Dollar',
												);

											foreach ($currencies as $currency_key => $currency_value) {
												$is_selected = ($main_settings['default_currency']==$currency_key?' selected':'');
												echo '<option value="'.$currency_key.'"'.$is_selected.'>'.$currency_value.'</option>';
											}
										?>
									</select>
									<span class="db-field-required">This field is required</span>
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Stripe currency</span>
								<div class="col-sm-9">
									<select class="db-settings-stripe_currency">
										<?php
											$currencies = array('AFN' => 'Afghan Afghani', 'ALL' => 'Albanian Lek', 'DZD' => 'Algerian Dinar', 'AOA' => 'Angolan Kwanza', 'ARS' => 'Argentine Peso', 'AMD' => 'Armenian Dram', 'AWG' => 'Aruban Florin', 'AUD' => 'Australian Dollar', 'AZN' => 'Azerbaijani Manat', 'BSD' => 'Bahamian Dollar', 'BDT' => 'Bangladeshi Taka', 'BBD' => 'Barbadian Dollar', 'BZD' => 'Belize Dollar', 'BMD' => 'Bermudian Dollar', 'BOB' => 'Bolivian Boliviano', 'BAM' => 'Bosnia & Herzegovina Convertible Mark', 'BWP' => 'Botswana Pula', 'BRL' => 'Brazilian Real', 'GBP' => 'British Pound', 'BND' => 'Brunei Dollar', 'BGN' => 'Bulgarian Lev', 'BIF' => 'Burundian Franc', 'KHR' => 'Cambodian Riel', 'CAD' => 'Canadian Dollar', 'CVE' => 'Cape Verdean Escudo', 'KYD' => 'Cayman Islands Dollar', 'XAF' => 'Central African Cfa Franc', 'XPF' => 'Cfp Franc', 'CLP' => 'Chilean Peso', 'CNY' => 'Chinese Renminbi Yuan', 'COP' => 'Colombian Peso', 'KMF' => 'Comorian Franc', 'CDF' => 'Congolese Franc', 'CRC' => 'Costa Rican Colón', 'HRK' => 'Croatian Kuna', 'CZK' => 'Czech Koruna', 'DKK' => 'Danish Krone', 'DJF' => 'Djiboutian Franc', 'DOP' => 'Dominican Peso', 'XCD' => 'East Caribbean Dollar', 'EGP' => 'Egyptian Pound', 'ETB' => 'Ethiopian Birr', 'EUR' => 'Euro', 'FKP' => 'Falkland Islands Pound', 'FJD' => 'Fijian Dollar', 'GMD' => 'Gambian Dalasi', 'GEL' => 'Georgian Lari', 'GIP' => 'Gibraltar Pound', 'GTQ' => 'Guatemalan Quetzal', 'GNF' => 'Guinean Franc', 'GYD' => 'Guyanese Dollar', 'HTG' => 'Haitian Gourde', 'HNL' => 'Honduran Lempira', 'HKD' => 'Hong Kong Dollar', 'HUF' => 'Hungarian Forint', 'ISK' => 'Icelandic Króna', 'INR' => 'Indian Rupee', 'IDR' => 'Indonesian Rupiah', 'ILS' => 'Israeli New Sheqel', 'JMD' => 'Jamaican Dollar', 'JPY' => 'Japanese Yen', 'KZT' => 'Kazakhstani Tenge', 'KES' => 'Kenyan Shilling', 'KGS' => 'Kyrgyzstani Som', 'LAK' => 'Lao Kip', 'LBP' => 'Lebanese Pound', 'LSL' => 'Lesotho Loti', 'LRD' => 'Liberian Dollar', 'MOP' => 'Macanese Pataca', 'MKD' => 'Macedonian Denar', 'MGA' => 'Malagasy Ariary', 'MWK' => 'Malawian Kwacha', 'MYR' => 'Malaysian Ringgit', 'MVR' => 'Maldivian Rufiyaa', 'MRO' => 'Mauritanian Ouguiya', 'MUR' => 'Mauritian Rupee', 'MXN' => 'Mexican Peso', 'MDL' => 'Moldovan Leu', 'MNT' => 'Mongolian Tögrög', 'MAD' => 'Moroccan Dirham', 'MZN' => 'Mozambican Metical', 'MMK' => 'Myanmar Kyat', 'NAD' => 'Namibian Dollar', 'NPR' => 'Nepalese Rupee', 'ANG' => 'Netherlands Antillean Gulden', 'TWD' => 'New Taiwan Dollar', 'NZD' => 'New Zealand Dollar', 'NIO' => 'Nicaraguan Córdoba', 'NGN' => 'Nigerian Naira', 'NOK' => 'Norwegian Krone', 'PKR' => 'Pakistani Rupee', 'PAB' => 'Panamanian Balboa', 'PGK' => 'Papua New Guinean Kina', 'YGí' => 'Paraguayan Guaran,', 'PEN' => 'Peruvian Nuevo Sol', 'PHP' => 'Philippine Peso', 'PLN' => 'Polish Złoty', 'QAR' => 'Qatari Riyal', 'RON' => 'Romanian Leu', 'RUB' => 'Russian Ruble', 'RWF' => 'Rwandan Franc', 'STD' => 'São Tomé and Príncipe Dobra', 'SHP' => 'Saint Helenian Pound', 'SVC' => 'Salvadoran Colón', 'WST' => 'Samoan Tala', 'SAR' => 'Saudi Riyal', 'RSD' => 'Serbian Dinar', 'SCR' => 'Seychellois Rupee', 'SLL' => 'Sierra Leonean Leone', 'SGD' => 'Singapore Dollar', 'SBD' => 'Solomon Islands Dollar', 'SOS' => 'Somali Shilling', 'ZAR' => 'South African Rand', 'KRW' => 'South Korean Won', 'LKR' => 'Sri Lankan Rupee', 'SRD' => 'Surinamese Dollar', 'SZL' => 'Swazi Lilangeni', 'SEK' => 'Swedish Krona', 'CHF' => 'Swiss Franc', 'TJS' => 'Tajikistani Somoni', 'TZS' => 'Tanzanian Shilling', 'THB' => 'Thai Baht', 'TOP' => 'Tongan Paʻanga', 'TTD' => 'Trinidad and Tobago Dollar', 'TRY' => 'Turkish Lira', 'UGX' => 'Ugandan Shilling', 'UAH' => 'Ukrainian Hryvnia', 'AED' => 'United Arab Emirates Dirham', 'USD' => 'United States Dollar', 'UYU' => 'Uruguayan Peso', 'UZS' => 'Uzbekistani Som', 'VUV' => 'Vanuatu Vatu', 'VND' => 'Vietnamese Đồng', 'XOF' => 'West African Cfa Franc', 'YER' => 'Yemeni Rial', 'ZMW' => 'Zambian Kwacha');

											foreach ($currencies as $currency_key => $currency_value) {
												$is_selected = ($main_settings['stripe_currency']==strtolower($currency_key)?' selected':'');
												echo '<option value="'.strtolower($currency_key).'"'.$is_selected.'>'.$currency_value.'</option>';
											}
										?>
									</select>
									<span class="db-field-required">This field is required</span>
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Currency symbol <span class="db-required">*</span></span>
								<div class="col-sm-9">
									<input type="text" class="db-settings-default_currency_symbol" placeholder="Default currency symbol" data-required="true" value="<?php echo $main_settings['default_currency_symbol']; ?>">
									<span class="db-field-required">This field is required</span>
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Payment method</span>
								<div class="col-sm-9">
									<select class="db-settings-payment_method" multiple>
										<option value="paypal" <?php echo (in_array('paypal', $main_settings['payment_method'])?'selected':''); ?>>Paypal</option>
										<option value="authorize.net" <?php echo (in_array('authorize.net', $main_settings['payment_method'])?'selected':''); ?>>Authorize.Net</option>
										<option value="stripe" <?php echo (in_array('stripe', $main_settings['payment_method'])?'selected':''); ?>>Stripe</option>
									</select>
									<span class="auth-msg db-error hidden">Currency for Authorize.net payment gateway should be specified at account settings.</span>
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Active?</span>
								<div class="col-sm-9">
									<select class="db-settings-payment_active">
										<option value="yes" <?php echo ($main_settings['payment_active']=='yes'?'selected':''); ?>>Yes</option>
										<option value="no" <?php echo ($main_settings['payment_active']=='no'?'selected':''); ?>>No</option>
									</select>
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Mode</span>
								<div class="col-sm-9">
									<select class="db-settings-payment_mode">
										<option value="live" <?php echo ($main_settings['payment_mode']=='live'?'selected':''); ?>>Live</option>
										<option value="sandbox" <?php echo ($main_settings['payment_mode']=='sandbox'?'selected':''); ?>>Test mode (sandbox)</option>
									</select>
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Merchant ID <span class="db-required">*</span></span>
								<div class="col-sm-9">
									<input type="text" class="db-settings-paypal_merchant_id" placeholder="Merchant ID" data-required="true" value="<?php echo $main_settings['paypal_merchant_id']; ?>">
									<span>Your PayPal email where the money is sent to.</p>
									<span class="db-field-required">This field is required</span>
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Cancel URL</span>
								<div class="col-sm-9">
									<input type="text" class="db-settings-paypal_cancel_url" placeholder="Cancel URL" value="<?php echo $main_settings['paypal_cancel_url']; ?>">
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Return URL</span>
								<div class="col-sm-9">
									<input type="text" class="db-settings-paypal_return_url" placeholder="Return URL" value="<?php echo $main_settings['paypal_return_url']; ?>">
									<span>Also known as thank you page.</p>
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Order success page</span>
								<div class="col-sm-9">
									<select class="db-settings-order_success_url">
										<?php
											$all_pages = get_pages();
											if ( !empty($all_pages) ) {
												foreach ($all_pages as $page_data) {
													echo '<option value="' . $page_data->ID . '"'.(isset($main_settings['order_success_url'])&&$main_settings['order_success_url']==$page_data->ID?' selected':'').'>' . $page_data->post_title . '</option>';
												}
											}
										?>
									</select>
									<span>This page will be used for free listings, otherwise "Return URL" option will be used!</p>
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Authorize.net login ID</span>
								<div class="col-sm-9">
									<input type="text" class="db-settings-authorize_id" placeholder="Authorize.net login ID" value="<?php echo $main_settings['authorize_id']; ?>">
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Authorize.net key</span>
								<div class="col-sm-9">
									<input type="text" class="db-settings-authorize_key" placeholder="Authorize.net key" value="<?php echo $main_settings['authorize_key']; ?>">
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Stripe API key</span>
								<div class="col-sm-9">
									<input type="text" class="db-settings-stripe_key" placeholder="Stripe API key" value="<?php echo (isset($main_settings['stripe_key'])?$main_settings['stripe_key']:''); ?>">
								</div>
							</div>
						</div>
					</div>
				</div>
				<div class="db-box-container col-md-12">
					<div class="db-box main-card">
						<div class="db-box-title">
							<h3 class="db-main-title">Advanced reviews</h3>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Enable advanced reviews?</span>
								<div class="col-sm-9">
									<div class="db-checkbox <?php echo (isset($main_settings['advanced_reviews'])&&$main_settings['advanced_reviews']=='true'?'active':''); ?>">
										<input type="checkbox" class="db-settings-advanced_reviews" <?php echo (isset($main_settings['advanced_reviews'])&&$main_settings['advanced_reviews']=='true'?'checked':''); ?>>
									</div>
								</div>
							</div>
						</div>
						<div class="db-row">
							<div class="db-row-group clearfix">
								<span class="db-row-label col-sm-3">Review categories</span>
								<div class="col-sm-9">
									<div class="review-cat-container">
										<a href="javascript:void(0)" class="db-review-cat db-button db-primary-button">Add new category</a>
										<div class="review-cat-dialog main-card">
											<label>Review category name</label>
											<input type="text" class="review-cat-title" placeholder="Category name" value="">
											<label>Apply to these categories</label>
											<select class="review-cat-attach" multiple>
											<?php
											$categories = get_terms( array(
												'taxonomy' => 'listing_category',
												'hide_empty' => false
											));
											if ( !empty($categories) ) {
												foreach ($categories as $category_value) {
													echo '<option value="'.$category_value->term_id.'">'.$category_value->name.'</option>';
												}
											}
											?>
											</select>
											<button class="db-add-review-cat db-button db-primary-button" data-add="Add" data-save="Save"></button>
										</div>
										<input type="hidden" class="db-settings-advanced_review_cat" value="<?php echo (isset($main_settings['advanced_review_cat'])?esc_attr($main_settings['advanced_review_cat']):''); ?>">
									</div>
									<div class="review-added-cats">
										<?php
										if ( isset($main_settings['advanced_review_cat']) ) {
											$all_review_cats = json_decode($main_settings['advanced_review_cat'], true);
											if ( is_array($all_review_cats) && !empty($all_review_cats) ) {
												foreach ($all_review_cats as $review_cat_index => $review_cat_data) {
													echo '<div class="review-cat-item '.esc_attr($review_cat_index).'" data-categories="'.esc_attr($review_cat_data['1']).'">'.$review_cat_data['0'].'<span class="review-cat-remove"></span></div>';
												}
											}
										}
										?>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
				</div>
			</div>
			<div class="db-row-group col-md-12 clearfix">
				<input type="hidden" class="db-settings-db_theme_id" value="<?php echo $main_settings['db_theme_id']; ?>">
				<input type="hidden" class="db-settings-db_theme_path" value="<?php echo $main_settings['db_theme_path']; ?>">
				<input type="hidden" class="db-settings-db_theme_url" value="<?php echo $main_settings['db_theme_url']; ?>">
				<a href="javascript:void(0)" class="db-save-settings db-button db-primary-button">Save changes</a>
			</div>
		</div>
	</div>
	<?php
}

function db_load_template( $template_name, $load = false, $require_once = true, $theme_settings ) {
	if ( $template_name == '' ) {
		return;
	}

	if ( is_child_theme() && file_exists( get_stylesheet_directory().'/directory-template/'.$template_name ) ) {
		$located = get_stylesheet_directory().'/directory-template/'.$template_name;
	} else if ( isset($theme_settings['db_theme_path']) && file_exists( $theme_settings['db_theme_path'].$template_name ) ) {
		$located = $theme_settings['db_theme_path'].$template_name;
	} else if ( file_exists( plugin_dir_path( __FILE__ ).'/template/'.$template_name ) ) {
		$located = plugin_dir_path( __FILE__ ).'/template/'.$template_name;
	}

	if ( $load && '' != $located ) {
		ob_start();
		load_template( $located, $require_once );
		$located = ob_get_clean();
	}

	return $located;
}

function db_get_categories( $post_id, $separator = ', ' ) {
	$categories = wp_get_object_terms($post_id, 'listing_category');
	$all_categories = array();
	if ( !empty($categories) ) {
		foreach ($categories as $category_value) {
			$all_categories[] = '<span class="db-search-listing-category">'.$category_value->name.'</span>';
		}
	}

	echo implode($separator, $all_categories);
}

function db_get_listing_custom_field_data( $listing_array, $custom_class = '', $echo = true ) {
	$active_fields = db_get_listing_custom_fields( $listing_array['ID'], 'on_listing' );

	if ( !empty($active_fields) ) {
		foreach ($active_fields as $field_data) {
			if ( !empty($field_data['value']) ) {
				$field_value = (is_array($field_data['value'])?implode(', ', $field_data['value']):$field_data['value']);
			
				if ( $field_data['icon'] == '' ) {
					$field_title = '<span class="db-field-title">'.$field_data['title'].': </span>';
				} else {
					$field_title = '<span class="db-field-icon '.$field_data['icon'].'" title="'.$field_data['title'].'"></span>';
				}

				// Echo or return?
				if ( $echo === true ) {
					echo '<div class="'.$custom_class.'">'.$field_title.'<span class="db-field-value">'.$field_value.'</span></div>';
				} else if ( $echo === false ) {
					return '<div class="'.$custom_class.'">'.$field_title.'<span class="db-field-value">'.$field_value.'</span></div>';
				}
			}
		}
	}
}

function db_save_settings() {
	if ( !current_user_can('manage_options') ) die(0);

	global $wpdb;
	$db_settings = ( isset($_POST['db_settings']) ? sanitize_text_field($_POST['db_settings']) : '' );
	
	$db_settings_decoded = json_decode(stripslashes($db_settings), true);

	if ( isset($db_settings_decoded['default_location']) && $db_settings_decoded['default_location'] != '' ) {
		$response = wp_remote_get( "http://maps.google.com/maps/api/geocode/json?sensor=false&address=".str_replace(" ", "+", $db_settings_decoded['default_location']) );
		$json = json_decode( $response['body'], true );
		$db_settings_decoded['default_location_lat'] = $json['results'][0]['geometry']['location']['lat'];
		$db_settings_decoded['default_location_lng'] = $json['results'][0]['geometry']['location']['lng'];
	}
	
	if ( !empty($db_settings_decoded) ) {
		update_option( 'db_main_settings', $db_settings_decoded );
		echo '{"save_response": "0"}';
	} else {
		echo '{"save_response": "failed"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_save_settings', 'db_save_settings' );

function db_save_templates() {
	if ( !current_user_can('manage_options') ) die(0);

	$db_templates = ( isset($_POST['db_templates']) ? json_decode( stripslashes( sanitize_text_field($_POST['db_templates']) ), true ) : '' );
	
	if ( update_option( 'db_main_templates', $db_templates ) ) {
		echo '{"save_response": "0"}';
	} else {
		echo '{"save_response": "failed"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_save_templates', 'db_save_templates' );

function db_package_html() {
	if ( !current_user_can('manage_options') )  {
		wp_die( __('You do not have sufficient permissions to access this page.', 'directory-builder') );
	}
	?>
	<div class="db-main-wrapper container-fluid" id="db-main-wrapper">
		<div class="db-main-content main-card">
			<?php if ( !isset($_GET['package_type']) && !isset($_GET['package_id']) ) { ?>
				<a href="<?php echo DB_PLUGIN_PACKAGE_PAGE_URL; ?>&package_type=new" class="db-add-new-package db-button db-primary-button">Add new</a>
				<table class="table table-striped table-hover">
					<thead>
						<tr>
							<th>ID</th>
							<th>Name</th>
							<th>Action</th>
						</tr>
					</thead>
					<tbody>
						<?php
						global $wpdb;
						$field_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_packages ORDER BY ID ASC');
						if ( !empty($field_list) ) {
							foreach ($field_list as $field_value) {
								$field_settings = json_decode($field_value->package_settings, true);
								echo '
								<tr>
									<td style="width: 5%;">'.$field_value->ID.'</td>
									<td style="width: 80%;">'.$field_settings['fee_label'].'</td>
									<td style="width: 15%;">
										<a href="'.DB_PLUGIN_PACKAGE_PAGE_URL.'&package_id='.$field_value->ID.'" class="db-edit-package">Edit</a>
										<a href="javascript:void(0)" class="db-delete-package" data-id="'.$field_value->ID.'">Delete</a>
									</td>
								</tr>';
							}
						}
						?>
					</tbody>
				</table>
			<?php } else if ( isset($_GET['package_type']) || isset($_GET['package_id']) ) {
				$field_settings = array();
				if ( isset($_GET['package_id']) ) {
					global $wpdb;
					$field_data = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_packages WHERE ID="'.intval($_GET['package_id']).'"');
					$field_settings = json_decode($field_data['0']->package_settings, true);
				}
				?>
				<div class="db-custom-field">
					<div class="db-box-title">
						<h3 class="db-main-title">Custom package</h3>
					</div>
					<div class="db-field-row <?php echo(isset($field_settings['fee_label'])&&$field_settings['fee_label']!=''?'active':''); ?> clearfix">
						<label class="field-label">Fee label</label>
						<div class="db-field-input">
							<input type="text" class="db-create-fee_label" value="<?php echo(isset($field_settings['fee_label'])?$field_settings['fee_label']:''); ?>">
						</div>
					</div>
					<div class="db-field-row <?php echo(isset($field_settings['fee_amount'])&&$field_settings['fee_amount']!=''?'active':''); ?> clearfix">
						<label class="field-label">Fee amount</label>
						<div class="db-field-input">
							<input type="number" class="db-create-fee_amount" value="<?php echo(isset($field_settings['fee_amount'])?$field_settings['fee_amount']:''); ?>">
							<span>One time payment set to have a fee of <strong>0</strong> will be considered as free package.</span>
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Payment type</label>
						<div class="db-field-input">
							<select class="db-create-payment_type">
								<option value="onetime" <?php echo(isset($field_settings['payment_type'])&&$field_settings['payment_type']=='onetime'?'selected':''); ?>>One time payment</option>
								<option value="recurring" <?php echo(isset($field_settings['payment_type'])&&$field_settings['payment_type']=='recurring'?'selected':''); ?>>Recurring payment</option>
							</select>
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Run listing for</label>
						<div class="db-field-input">
							<select class="db-create-listing_run_type">
								<option value="days" <?php echo(isset($field_settings['listing_run_type'])&&$field_settings['listing_run_type']=='days'?'selected':''); ?>>Set amount of days</option>
								<option value="forever" <?php echo(isset($field_settings['listing_run_type'])&&$field_settings['listing_run_type']=='forever'?'selected':''); ?>>Forever</option>
							</select>
						</div>
					</div>
					<div class="db-field-row <?php echo(isset($field_settings['listing_run_days'])&&$field_settings['listing_run_days']!=''?'active':(!isset($field_settings['listing_run_days'])?'active':'')); ?> clearfix">
						<label class="field-label">Run listing for (days)</label>
						<div class="db-field-input">
							<input type="number" class="db-create-listing_run_days" value="<?php echo(isset($field_settings['listing_run_days'])?$field_settings['listing_run_days']:'20'); ?>">
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Enable trial period</label>
						<div class="db-field-input">
							<div class="db-checkbox <?php echo (isset($field_settings['trial_period'])&&$field_settings['trial_period']=='true'?'active':''); ?>">
								<input type="checkbox" class="db-create-trial_period" <?php echo (isset($field_settings['trial_period'])&&$field_settings['trial_period']=='true'?'checked':''); ?>>
							</div>
						</div>
					</div>
					<div class="db-field-row active db-trial-row clearfix">
						<label class="field-label">Trial period lasts for</label>
						<div class="db-field-input interval">
							<input type="number" class="db-create-trial_interval" value="<?php echo(isset($field_settings['trial_interval'])?$field_settings['trial_interval']:''); ?>">
						</div>
						<div class="db-field-input cycle">
							<select class="db-create-trial_cycle">
								<option value="days" <?php echo(isset($field_settings['trial_cycle'])&&$field_settings['trial_cycle']=='days'?'selected':''); ?>>Days</option>
								<option value="weeks" <?php echo(isset($field_settings['trial_cycle'])&&$field_settings['trial_cycle']=='weeks'?'selected':''); ?>>Weeks</option>
								<option value="months" <?php echo(isset($field_settings['trial_cycle'])&&$field_settings['trial_cycle']=='months'?'selected':''); ?>>Months</option>
								<option value="years" <?php echo(isset($field_settings['trial_cycle'])&&$field_settings['trial_cycle']=='years'?'selected':''); ?>>Years</option>
							</select>
						</div>
						<div class="clearfix"></div>
						<span class="db-trial-text">
							For Authorize.net the trial period is going to be the 1st payment cycle.<br>
							For example, if your payment is set to be once a month, then trial period is going to be the 1st month.
						</span>
					</div>
					<div class="db-field-row active db-sub-row clearfix">
						<label class="field-label">Subscription payment intervals</label>
						<div class="db-field-input interval">
							<input type="number" class="db-create-payment_interval" value="<?php echo(isset($field_settings['payment_interval'])?$field_settings['payment_interval']:''); ?>">
						</div>
						<div class="db-field-input cycle">
							<select class="db-create-payment_cycle">
								<option value="days" <?php echo(isset($field_settings['payment_cycle'])&&$field_settings['payment_cycle']=='days'?'selected':''); ?>>Days</option>
								<option value="weeks" <?php echo(isset($field_settings['payment_cycle'])&&$field_settings['payment_cycle']=='weeks'?'selected':''); ?>>Weeks</option>
								<option value="months" <?php echo(isset($field_settings['payment_cycle'])&&$field_settings['payment_cycle']=='months'?'selected':''); ?>>Months</option>
								<option value="years" <?php echo(isset($field_settings['payment_cycle'])&&$field_settings['payment_cycle']=='years'?'selected':''); ?>>Years</option>
							</select>
						</div>
						<div class="clearfix"></div>
						<span>For example, if set to 1 months, then a payment will be needed each month.</span>
					</div>
					<div class="db-field-row <?php echo(isset($field_settings['image_amount'])&&$field_settings['image_amount']!=''?'active':''); ?> clearfix">
						<label class="field-label">Images allowed</label>
						<div class="db-field-input">
							<input type="number" class="db-create-image_amount" value="<?php echo(isset($field_settings['image_amount'])?$field_settings['image_amount']:''); ?>">
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Package listings sticky (featured)?</label>
						<div class="db-field-input">
							<div class="db-checkbox <?php echo (isset($field_settings['listing_sticky'])&&$field_settings['listing_sticky']=='true'?'active':''); ?>">
								<input type="checkbox" class="db-create-listing_sticky" <?php echo (isset($field_settings['listing_sticky'])&&$field_settings['listing_sticky']=='true'?'checked':''); ?>>
							</div>
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Apply to categories</label>
						<div class="db-field-input">
							<select class="db-create-apply_categories" multiple>
							<?php
							$categories = get_terms( array(
								'taxonomy' => 'listing_category',
								'hide_empty' => false
							));
							if ( !empty($categories) ) {
								$categoryHierarchy = array();
								db_sort_terms_hierarchicaly($categories, $categoryHierarchy);

								foreach ($categoryHierarchy as $category_value) {
									$is_checked = (in_array($category_value->term_id, $field_settings['apply_categories'])?'selected':'');
									echo '<option value="'.$category_value->term_id.'" '.$is_checked.'>'.$category_value->name.'</option>';

									if ( !empty($category_value->children) ) {
										echo db_display_backend_categories( $category_value, $field_settings['apply_categories'] );
									}
								}
							}
							?>
							</select>
						</div>
					</div>
					<div class="db-field-row <?php echo(isset($field_settings['fee_description'])&&$field_settings['fee_description']!=''?'active':''); ?> clearfix">
						<label class="field-label">Fee description</label>
						<div class="db-field-input">
							<textarea class="db-create-fee_description"><?php echo(isset($field_settings['fee_description'])?$field_settings['fee_description']:''); ?></textarea>
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Listing status after it expires</label>
						<div class="db-field-input">
							<select class="db-create-listing_status">
								<option value="draft" <?php echo(isset($field_settings['listing_status'])&&$field_settings['listing_status']=='draft'?'selected':''); ?>>Draft</option>
								<option value="trash" <?php echo(isset($field_settings['listing_status'])&&$field_settings['listing_status']=='trash'?'selected':''); ?>>Trash</option>
							</select>
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Popular package?</label>
						<div class="db-field-input">
							<div class="db-checkbox <?php echo (isset($field_settings['listing_popular'])&&$field_settings['listing_popular']=='true'?'active':''); ?>">
								<input type="checkbox" class="db-create-listing_popular" <?php echo (isset($field_settings['listing_popular'])&&$field_settings['listing_popular']=='true'?'checked':''); ?>>
							</div>
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Package image</label>
						<div class="db-field-input">
							<input type="button" value="Upload image" class="db-image-upload">
							<input type="button" class="db-image-delete" value="Delete image" <?php echo (!isset($field_settings['package_img'])||$field_settings['package_img']==''?'style="display: none;"':''); ?>s>
							<div class="db-image-container">
								<?php echo (isset($field_settings['package_img'])&&$field_settings['package_img']!=''?'<img src="'.$field_settings['package_img'].'" alt="">':''); ?>
							</div>
							<input type="hidden" class="db-create-package_img" value="<?php echo (isset($field_settings['package_img'])&&$field_settings['package_img']!=''?$field_settings['package_img']:''); ?>">
						</div>
					</div>

					<?php if ( !isset($_GET['package_id']) ) { ?>
						<a href="javascript:void(0)" class="db-save-package db-button db-primary-button" data-save="insert">Create package</a>
					<?php } else { ?>
						<a href="javascript:void(0)" class="db-save-package db-button db-primary-button" data-save="update" data-id="<?php echo esc_attr($_GET['package_id']); ?>">Save package</a>
					<?php } ?>
				</div>
			<?php } ?>
		</div>
	</div>
	<?php
}

function db_display_backend_categories( $cat_data, $active_categories = array() ) {
	$output = '';
	foreach ($cat_data->children as $child_value) {
		$parents = get_category_parents($child_value->term_id);
		$parents_exploded = explode('/', $parents);
		$depth = count($parents_exploded)-2;
		$depth_str = '';
		for ($i=0; $i < $depth; $i++) { 
			$depth_str .= '-';
		}

		$is_checked = (in_array($child_value->term_id, $active_categories)?'selected':'');
		$output .= '<option value="'.$child_value->term_id.'" '.$is_checked.'>'.$child_value->name.'</option>';
		
		if ( !empty( $child_value->children ) ) {
			$output .= db_display_backend_categories( $child_value );
		}
	}

	return $output;
}

function db_claims_html() {
	if ( !current_user_can('manage_options') )  {
		wp_die( __('You do not have sufficient permissions to access this page.', 'directory-builder') );
	}
	?>
	<div class="db-main-wrapper container-fluid" id="db-main-wrapper">
		<div class="db-main-content main-card">
			<div class="db-box-title">
				<h3 class="db-main-title"><?php esc_html_e('Listing claims', 'directory-builder'); ?></h3>
			</div>
			<table class="table table-striped table-hover">
				<thead>
					<tr>
						<th>ID</th>
						<th>Name</th>
						<th>Claimed by</th>
						<th>Date</th>
						<th>Action</th>
					</tr>
				</thead>
				<tbody>
					<?php
					global $wpdb;
					$claims_list = $wpdb->get_results('SELECT post_id, meta_value FROM '.$wpdb->prefix.'postmeta WHERE meta_key="db_claim_info" ORDER BY post_id ASC');
					if ( !empty($claims_list) ) {
						$date_format = get_option( 'date_format' );
						foreach ($claims_list as $claims_value) {
							$author = explode(':', $claims_value->meta_value);
							if ( get_post_type( $claims_value->post_id ) == 'listings' && $author['0'] != '0' && strpos($claims_value->meta_value, 'author') === false ) {
								$meta_parsed = explode(':', $claims_value->meta_value);
								echo '
								<tr>
									<td style="width: 5%;">'.$claims_value->post_id.'</td>
									<td style="width: 30%;"><a href="'.get_permalink($claims_value->post_id).'" target="_blank">'.get_the_title($claims_value->post_id).'</a></td>
									<td style="width: 35%;"><a href="'.admin_url('user-edit.php?user_id='.$author['0']).'">'.get_the_author_meta('nicename', $author['0']).'</a></td>
									<td style="width: 15%;">' . ( is_numeric( $meta_parsed['1'] ) ? date( $date_format, $meta_parsed['1'] ) : esc_html__('Not approved', 'directory-builder') ) . '</td>
									<td style="width: 15%;">';
										if ( strpos($claims_value->meta_value, 'waiting') === false ) {
											esc_html_e('Claimed', 'directory-builder');
											echo ' <a href="javascript:void(0)" class="db-cancel-claim" data-id="'.$claims_value->post_id.'">'.esc_html__('Remove', 'directory-builder').'</a>';
										} else {
											echo '
											<a href="javascript:void(0)" class="db-approve-claim" data-id="'.$claims_value->post_id.'">'.esc_html__('Approve', 'directory-builder').'</a>
											<a href="javascript:void(0)" class="db-cancel-claim" data-id="'.$claims_value->post_id.'">'.esc_html__('Cancel', 'directory-builder').'</a>';
										}
									echo '
									</td>
								</tr>';
							}
						}
					} else {
						echo '
						<tr>
							<td colspan="4" class="center">'.esc_html__('None of the listings is claimed!', 'directory-builder').'</td>
						</tr>';
					}
					?>
				</tbody>
			</table>
		</div>
	</div>
	<?php
}

function db_improvements_html() {
	if ( !current_user_can('manage_options') )  {
		wp_die( __('You do not have sufficient permissions to access this page.', 'directory-builder') );
	}
	?>
	<div class="db-main-wrapper container-fluid" id="db-main-wrapper">
		<div class="db-main-content main-card">
			<?php if ( !isset($_GET['improvement']) ) { ?>
				<div class="db-box-title">
					<h3 class="db-main-title"><?php esc_html_e('Listing improvements', 'directory-builder'); ?></h3>
				</div>
				<table class="table table-striped table-hover">
					<thead>
						<tr>
							<th>ID</th>
							<th>Name</th>
							<th>Sent by</th>
							<th>Date</th>
							<th>Status</th>
							<th>Action</th>
						</tr>
					</thead>
					<tbody>
						<?php
						global $wpdb;
						$improvements = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_improvements ORDER BY sent_at DESC');
						if ( !empty($improvements) ) {
							$date_format = get_option( 'date_format' );
							$time_format = get_option( 'time_format' );
							foreach ($improvements as $improvement_data) {
								if ( intval($improvement_data->author) > 0 ) {
									$author_url = '<a href="'.admin_url('user-edit.php?user_id='.$improvement_data->author).'">'.get_the_author_meta('nicename', $improvement_data->author).'</a>';
								} else {
									$author_url = esc_html__('Someone', 'directory-builder');
								}
								echo '
								<tr>
									<td style="width: 5%;">'.$improvement_data->ID.'</td>
									<td style="width: 30%;"><a href="'.get_permalink($improvement_data->listing_id).'" target="_blank">'.get_the_title($improvement_data->listing_id).'</a></td>
									<td style="width: 10%;">'.$author_url.'</td>
									<td style="width: 10%;">' . date( $date_format . ' ' . $time_format, $improvement_data->sent_at ) . '</td>
									<td style="width: 15%;">'.$improvement_data->status.'</td>
									<td style="width: 15%;">';
										if ( $improvement_data->status == 'pending' ) {
											echo '<a href="'.esc_url(add_query_arg( 'improvement', $improvement_data->ID, DB_PLUGIN_IMPROVEMENTS_PAGE_URL )).'">'.esc_html__('Review', 'directory-builder').'</a>';
										}
									echo '
									</td>
								</tr>';
							}
						} else {
							echo '
							<tr>
								<td colspan="6" class="center">'.esc_html__('There are no improvements sent!', 'directory-builder').'</td>
							</tr>';
						}
						?>
					</tbody>
				</table>
			<?php } else {
				global $wpdb;
				$improvements = $wpdb->get_results('SELECT ID, listing_id, improvements, author FROM '.$wpdb->prefix.'directory_improvements WHERE ID="'.intval($_GET['improvement']).'"');
				$sent_improvements = json_decode($improvements['0']->improvements, true);
				?>
				<div class="db-box-title">
					<h3 class="db-main-title"><?php printf( esc_html__('%s improvements, sent by %s', 'directory-builder'), get_the_title($improvements['0']->listing_id), get_the_author_meta('nicename', $improvements['0']->author) ); ?></h3>
				</div>
				<?php
				if ( !empty($sent_improvements) ) {
					echo '
					<ul class="imp-explanation">
						<li class="added">Information added to an empty field</li>
						<li class="removed">Information completely removed from filled field</li>
						<li class="changed">Information changed for the field</li>
					</ul>';
					echo '<table class="table table-striped table-hover">
							<tr>
								<th style="width: 45%;">Current value</th>
								<th style="width: 45%;">Improved value</th>
								<th style="width: 10%;">Action</th>
							</tr>';

					$valid_keys = array( 'post_title', 'post_excerpt', 'post_content', 'listing_featured_img' );
					$changes_found = 0;
					foreach ($sent_improvements as $field_key => $field_value) {
						if ( in_array($field_key, $valid_keys) ) {
							if ( $field_key == 'post_title' ) {
								$saved_value = get_the_title( $improvements['0']->listing_id );
							} else if ( $field_key == 'post_content' ) {
								$saved_value = preg_replace('/\s+/', '', get_post_field('post_content', $improvements['0']->listing_id));
								$field_value = preg_replace('/\s+/', '', str_replace('type=&quot;tiled&quot;', 'type=&quot;tiled&quot;', htmlspecialchars_decode($field_value)));
							} else if ( $field_key == 'post_excerpt' ) {
								$saved_value = get_the_excerpt( $improvements['0']->listing_id );
							} else if ( $field_key == 'listing_featured_img' ) {
								$saved_value = get_post_thumbnail_id( $improvements['0']->listing_id );
							}
						} else {
							$saved_value = get_post_meta($improvements['0']->listing_id, $field_key, true);
						}

						if ( is_array($field_value) ) { // Convert the new data
							$field_value = implode(',', $field_value);
						}

						if ( is_array($saved_value) ) { // Convert saved data
							$saved_value = implode(',', $saved_value);
						}

						$field_value = stripslashes($field_value);

						if ( $field_key == 'listing_gallery_img' ) {
							$saved_value = rtrim($saved_value, '|');
							$field_value = rtrim($field_value, '|');
						}

						if ( $saved_value != $field_value ) { // Check if values are different
							$field_data = $wpdb->get_results('SELECT field_settings FROM '.$wpdb->prefix.'directory_fields WHERE field_active="yes" && field_settings LIKE "%\"field_name\":\"'.$field_key.'\"%"');
							if ( !empty($field_data) ) {
								$field_settings = json_decode($field_data['0']->field_settings, true);
								if ( ( $saved_value == '' || $saved_value === false ) && $field_value != '' ) {
									$imp_class = 'imp-added';
								} else if ( $saved_value != '' && $field_value == '' ) {
									$imp_class = 'imp-removed';
								} else {
									$imp_class = 'imp-changed';
								}
								echo '
								<tr>
									<td>'.db_get_custom_field( $field_settings, '',  $saved_value, true ).'</td>
									<td class="'.esc_attr($imp_class).'">'.db_get_custom_field( $field_settings, '',  $field_value, true ).'</td>
									<td class="imp-actions"><a href="javascript:void(0)" class="imp-change-accept" data-key="'.esc_attr($field_key).'" data-id="'.intval($improvements['0']->ID).'" data-author="'.$improvements['0']->author.'">'.esc_html__('Accept', 'directory-builder').'</a> / <a href="javascript:void(0)" class="imp-change-discard" data-key="'.esc_attr($field_key).'" data-id="'.intval($improvements['0']->ID).'">'.esc_html__('Discard', 'directory-builder').'</a></td>
								</tr>';

								$changes_found++;
							} else {
								if ( in_array($field_key, $valid_keys) ) {
									if ( $field_key == 'post_title' ) {
										$field_current_value = get_the_title( $improvements['0']->listing_id );
										$field_current_html = esc_html__('Listing title', 'directory-builder').'<br /><input type="text" value="'.esc_attr($field_current_value).'">';
										$field_new_html = esc_html__('Listing title', 'directory-builder').'<br /><input type="text" value="'.esc_attr($field_value).'">';
									} else if ( $field_key == 'post_content' ) {
										$field_current_value = get_post_field('post_content', $improvements['0']->listing_id);
										$field_current_html = esc_html__('Listing long description', 'directory-builder').'<br /><textarea>'.esc_attr($field_current_value).'</textarea>';
										$field_new_html = esc_html__('Listing long description', 'directory-builder').'<br /><textarea>'.esc_attr($field_value).'</textarea>';
									} else if ( $field_key == 'post_excerpt' ) {
										$field_current_value = get_the_excerpt( $improvements['0']->listing_id );
										$field_current_html = esc_html__('Listing short description', 'directory-builder').'<br /><textarea>'.esc_attr($field_current_value).'</textarea>';
										$field_new_html = esc_html__('Listing short description', 'directory-builder').'<br /><textarea>'.esc_attr($field_value).'</textarea>';
									} else if ( $field_key == 'listing_featured_img' ) {
										$field_current_value = get_the_post_thumbnail( $improvements['0']->listing_id );
										$field_current_html = esc_html__('Listing featured image', 'directory-builder').'<br />'.$field_current_value;
										$field_new_html = esc_html__('Listing featured image', 'directory-builder').'<br />'.wp_get_attachment_image( $field_value, 'full' );
									}

									if ( $field_current_value == '' && $field_value != '' ) {
										$imp_class = 'imp-added';
									} else if ( $field_current_value != '' && $field_value == '' ) {
										$imp_class = 'imp-removed';
									} else {
										$imp_class = 'imp-changed';
									}

									echo '
									<tr>
										<td>'.$field_current_html.'</td>
										<td class="'.esc_attr($imp_class).'">'.$field_new_html.'</td>
										<td class="imp-actions"><a href="javascript:void(0)" class="imp-change-accept" data-key="'.esc_attr($field_key).'" data-id="'.intval($improvements['0']->ID).'">'.esc_html__('Accept', 'directory-builder').'</a> / <a href="javascript:void(0)" class="imp-change-discard" data-key="'.esc_attr($field_key).'" data-id="'.intval($improvements['0']->ID).'">'.esc_html__('Discard', 'directory-builder').'</a></td>
									</tr>';

									$changes_found++;
								}
							}
						}
					}

					if ( $changes_found === 0 ) {
						echo '
						<tr>
							<td colspan="3">'.esc_html__('No valid changes were found!', 'directory-builder').'</td>
						</tr>';
					}

					echo '</table>';
				}
				?>
			<?php } ?>
		</div>
	</div>
	<?php
}

function db_subscriptions_html() {
	if ( !current_user_can('manage_options') )  {
		wp_die( __('You do not have sufficient permissions to access this page.', 'directory-builder') );
	}
	?>
	<div class="db-main-wrapper container-fluid" id="db-main-wrapper">
		<div class="db-main-content main-card">
			<div class="db-box-title">
				<h3 class="db-main-title"><?php esc_html_e('Package subscriptions', 'directory-builder'); ?></h3>
			</div>
			<table class="table table-striped table-hover">
				<thead>
					<tr>
						<th width="10%">Status</th>
						<th width="20%">Listing</th>
						<th width="15%">Cycle</th>
						<th width="15%">Starting date</th>
						<th width="15%">Next payment</th>
						<th width="15%">Payment gateway</th>
						<th width="10%">Actions</th>
					</tr>
				</thead>
				<tbody>
					<?php
					global $wpdb;
					$sub_list = $wpdb->get_results('SELECT post_id, meta_value FROM '.$wpdb->prefix.'postmeta WHERE meta_key LIKE "db_subscription" ORDER BY meta_id ASC');
					if ( !empty($sub_list) ) {
						$date_format = get_option( 'date_format' );
						foreach ($sub_list as $sub_data) {
							$listing_id = $sub_data->post_id;
							$subscription_data = unserialize( $sub_data->meta_value );

							if ( $subscription_data['payment_interval'] == 1 ) {
								$payment_cycle = sprintf( __( 'Once a %s', 'directory-builder' ), rtrim( $subscription_data['payment_cycle'], 's' ) );
							} else {
								$payment_cycle = sprintf( __( 'Every %d %s', 'directory-builder' ), $subscription_data['payment_interval'], $subscription_data['payment_cycle'] );
							}

							$gateway = strtolower( $subscription_data['geteway'] );

							echo '
							<tr>
								<td>' . ucfirst( $subscription_data['status'] ) . '</td>
								<td><a href="' . get_permalink( $listing_id ) . '" target="_blank">' . get_the_title( $listing_id ) . '</a></td>
								<td>' . $payment_cycle . '</td>
								<td>' . date( $date_format, $subscription_data['starting'] ) . '</td>
								<td>' . ($subscription_data['status'] == 'active' ? date( $date_format, $subscription_data['next_payment'] ) : '-' ) . '</td>
								<td>' . $subscription_data['geteway'] . '</td>
								<td>';
									if ( $subscription_data['status'] == 'active' ) {
										echo '
										<a href="'.get_admin_url().'post.php?post='.$listing_id.'&action=edit">' . esc_html__('Edit', 'directory-builder') . '</a>
										<a href="javascript:void(0)" class="db-cancel-subscription" data-gateway="'.$gateway.'" data-id="'.$listing_id.'">' . esc_html__('Cancel', 'directory-builder') . '</a>
										'.($gateway=='paypal'?'<span class="db-cancel-paypal hidden">'.esc_html__('You can cancel this subscription via your PayPal account.', 'directory-builder').'</span>':'');
									}
								echo '
								</td>
							</tr>';
						}
					} else {
						echo '
						<tr>
							<td colspan="7" class="center">'.esc_html__('There\'s no subscriptions!', 'directory-builder').'</td>
						</tr>';
					}
					?>
				</tbody>
			</table>
		</div>
	</div>
	<?php
}

function db_support_html() {
	if ( !current_user_can('manage_options') )  {
		wp_die( __('You do not have sufficient permissions to access this page.', 'directory-builder') );
	}
	?>
	<div class="db-main-wrapper container-fluid" id="db-main-wrapper">
		<div class="db-main-content main-card">
			<?php if ( !isset($_GET['tid']) ) { ?>
				<div class="db-box-title">
					<h3 class="db-main-title"><?php esc_html_e('Support tickets', 'directory-builder'); ?></h3>
				</div>
				<table class="table table-striped table-hover">
					<thead>
						<tr>
							<th width="40%">Subject</th>
							<th width="15%">Status</th>
							<th width="15%">Created</th>
							<th width="15%">Last reply</th>
							<th width="15%">Author</th>
						</tr>
					</thead>
					<tbody>
						<?php
						global $wpdb;
						$support_table = $wpdb->prefix.'directory_support';
						$support_tickets = $wpdb->get_results( "SELECT * FROM $support_table WHERE parent='0' ORDER BY `date` DESC" );

						if ( !empty($support_tickets) ) {
							$date_format = get_option( 'date_format' );
							foreach ($support_tickets as $ticket_data) {
								$last_reply = $wpdb->get_results( $wpdb->prepare( "SELECT `date` FROM $support_table WHERE parent='%d' ORDER BY `date` DESC LIMIT 1", $ticket_data->ID ) );
								if ( empty($last_reply) ) {
									$last_reply_time = $ticket_data->date;
								} else {
									$last_reply_time = $last_reply['0']->date;
								}
								echo '
									<tr>
										<td><a href="'.esc_url(add_query_arg('tid', $ticket_data->ID, DB_PLUGIN_SUPPORT_PAGE_URL)).'">'.$ticket_data->subject.'</a></td>
										<td>'.ucwords($ticket_data->status).'</td>
										<td>'.date($date_format, $ticket_data->date).'</td>
										<td>'.human_time_diff($last_reply_time,time()).'</td>
										<td><a href="'.admin_url('user-edit.php?user_id='.$ticket_data->author).'">'.get_the_author_meta('nicename', $ticket_data->author).'</a></td>
									</tr>';
							}
						} else {
							echo '
							<tr>
								<td colspan="6" class="center">'.esc_html__('There\'s no support tickets!', 'directory-builder').'</td>
							</tr>';
						}
						?>
					</tbody>
				</table>
			<?php } else {
				global $wpdb;
				$support_table = $wpdb->prefix.'directory_support';

				if ( isset($_POST['db-support-content']) && $_POST['db-support-content'] != '' ) {
					$add_reply_status = $wpdb->query( $wpdb->prepare( "INSERT INTO $support_table (`author`,`content`,`date`,`parent`) VALUES ('%d','%s','%d','%d')", get_current_user_id(), $_POST['db-support-content'], time(), $_GET['tid'] ) );

					if ( $add_reply_status ) {
						$ticket_author = $wpdb->query( $wpdb->prepare( "SELECT author FROM $support_table WHERE ID='%d'", $_GET['tid'] ) );
						$wpdb->query( $wpdb->prepare( "UPDATE $support_table SET status='answered' WHERE ID='%d'", $_GET['tid'] ) );
						db_insert_activity( '0', 'supportnew', array( 'support-parent' => $_GET['tid'] ), $ticket_author );
						$query_status = true;
						$query_result = 'Your reply was added!';
					} else {
						$query_status = false;
						$query_result = 'There was an issue while adding your reply!';
					}
				}

				if ( isset($_POST['db-support-status']) && $_POST['db-support-status'] != '' ) {
					$add_status_query = $wpdb->query( $wpdb->prepare( "UPDATE $support_table SET status='%s' WHERE ID='%d'", $_POST['db-support-status'], $_GET['tid'] ) );

					if ( $add_status_query ) { // Change the tickets status
						$query_status = true;
						$query_result = 'Status was updated to ' . $_POST['db-support-status'];
					} else {
						$query_status = false;
						$query_result = 'There was an issue while updating ticket status!';
					}
				}

				$support_tickets = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM $support_table WHERE ID='%d' || parent='%d' ORDER BY `date` ASC", intval($_GET['tid']), intval($_GET['tid']) ) );

				?>
				<div class="db-box-title">
					<h3 class="db-main-title"><?php echo $support_tickets['0']->subject; ?></h3>
				</div>
				<?php
				if ( isset($query_result) ) {
					?>
					<span class="db-ad-notice <?php echo ($query_status?'success':'failed'); ?>"><?php echo $query_result; ?></span>
					<?php
				}
				?>
				<form method="post" class="db-support-status">
					<label class="field-label">Change status</label>
					<select name="db-support-status">
						<option value="waiting"<?php echo ($support_tickets['0']->status=='waiting'?' selected':''); ?>>Waiting</option>
						<option value="answered"<?php echo ($support_tickets['0']->status=='answered'?' selected':''); ?>>Answered</option>
						<option value="closed"<?php echo ($support_tickets['0']->status=='closed'?' selected':''); ?>>Closed</option>
					</select>
				</form>
				<table class="table table-striped table-hover db-support-table">
					<tbody>
						<?php
						if ( !empty($support_tickets) ) {
							$date_format = get_option( 'date_format' );
							foreach ($support_tickets as $ticket_data) {
								echo '
								<tr>
									<td style="width: 10%;">'.get_avatar($ticket_data->author, 50).'<span class="db-support-author">'.get_the_author_meta('nicename', $ticket_data->author).'</span></td>
									<td style="width: 90%;">'.stripslashes($ticket_data->content).'</td>
								</tr>';
							}
						}
						?>
					</tbody>
				</table>
				<form method="post" class="db-support-reply">
					<div class="db-field-row active clearfix">
						<label class="field-label">Leave a reply</label>
						<div class="db-field-input">
							<textarea name="db-support-content" required></textarea>
						</div>
					</div>
					<input type="submit" class="db-button db-primary-button" value="<?php esc_html_e('Submit', 'directory-builder'); ?>">
				</form>
			<?php } ?>
		</div>
	</div>
	<?php
}

function db_ads_html() {
	if ( !current_user_can('manage_options') )  {
		wp_die( __('You do not have sufficient permissions to access this page.', 'directory-builder') );
	}

	$active_packages = array();
	if ( isset($_POST['ad_packages']) ) {
		$active_packages = $_POST['ad_packages'];
	}

	$active_categories = array();
	if ( isset($_POST['ad_categories']) ) {
		$active_categories = $_POST['ad_categories'];
	}

	if ( isset($_GET['action']) && $_GET['action'] == 'new' && isset($_POST['ad_label']) ) { // Add new ad
		global $wpdb;
		$insert_result = $wpdb->query( 'INSERT INTO ' . $wpdb->prefix . 'directory_ads ( title, content, placement, packages, categories, status ) VALUES ( "'.esc_attr($_POST['ad_label']).'", "'.urlencode($_POST['ad_html']).'", "'.esc_attr($_POST['ad_place']).'", "'.addslashes( json_encode($active_packages) ).'", "'.addslashes( json_encode($active_categories) ).'", "'.(!isset($_POST['ad_status'])?'false':'true').'" )' );

		if ( $insert_result ) {
			$query_status = true;
			$query_result = 'Your new advertisement was added successfully!';
			$new_url = add_query_arg('id', $wpdb->insert_id, DB_PLUGIN_AD_PAGE_URL);
			$extra_func = '<script type=\'text/javascript\'>var new_url = \''.$new_url.'\'; history.pushState({page: new_url}, \'\', new_url);</script>';
			$new_id = $wpdb->insert_id;
		} else {
			$query_status = false;
			$query_result = 'Something went wrong while adding your advertisement!';;
		}
	} else if ( isset($_GET['id']) && isset($_POST['ad_label']) ) { // Edit existing ad
		global $wpdb;
		$update_result = $wpdb->query( 'UPDATE ' . $wpdb->prefix . 'directory_ads SET title="'.esc_attr($_POST['ad_label']).'", content="'.urlencode($_POST['ad_html']).'", placement="'.esc_attr($_POST['ad_place']).'", packages="'.addslashes( json_encode($active_packages) ).'", categories="'.addslashes( json_encode($active_categories) ).'", status="'.(!isset($_POST['ad_status'])?'false':'true').'" WHERE ID="'.intval($_GET['id']).'"' );

		if ( $update_result ) {
			$query_status = true;
			$query_result = 'Your advertisement was saved successfully!';
		} else {
			$query_status = false;
			$query_result = 'Something went wrong while saving your advertisement!';;
		}
	} else if ( isset($_GET['action']) && $_GET['action'] == 'delete' ) { // Delete ad
		global $wpdb;
		$delete_result = $wpdb->query( 'DELETE FROM ' . $wpdb->prefix . 'directory_ads WHERE ID="'.intval($_GET['id']).'"' );

		if ( $delete_result ) {
			$query_status = true;
			$query_result = 'Your advertisement was deleted successfully!';
		} else {
			$query_status = false;
			$query_result = 'Something went wrong while deleting your advertisement!';;
		}
	}

	?>
	<div class="db-main-wrapper container-fluid" id="db-main-wrapper">
		<div class="db-main-content main-card">
			<div class="db-box-title">
				<h3 class="db-main-title"><?php esc_html_e('Listing advertisements', 'directory-builder'); ?></h3>
			</div>
			<?php
			if ( isset($query_result) ) {
				?>
				<span class="db-ad-notice <?php echo ($query_status?'success':'failed'); ?>"><?php echo $query_result; ?></span>
				<?php
			}
			if ( isset($extra_func) ) {
				echo $extra_func;
			}
			if ( ( isset($_GET['action']) && $_GET['action'] == 'delete' ) || !isset($_GET['action']) && !isset($_GET['id']) ) { ?>
				<a href="<?php echo add_query_arg('action', 'new', DB_PLUGIN_AD_PAGE_URL); ?>" class="db-add-new-ad db-button db-primary-button">Add new</a>
				<table class="table table-striped table-hover">
					<thead>
						<tr>
							<th width="70%">Title</th>
							<th width="10%">Views</th>
							<th width="10%">Status</th>
							<th width="10%">Actions</th>
						</tr>
					</thead>
					<tbody>
						<?php
						global $wpdb;
						$all_ads = $wpdb->get_results( 'SELECT * FROM ' . $wpdb->prefix . 'directory_ads' );

						if ( !empty( $all_ads ) ) {
							foreach ( $all_ads as $ad_data ) {
								?>
								<tr>
									<td><?php echo $ad_data->title; ?></td>
									<td><?php echo $ad_data->views; ?></td>
									<td><?php echo ($ad_data->status=='true'?'Active':'Inactive'); ?></td>
									<td>
										<a href="<?php echo add_query_arg('id', $ad_data->ID, DB_PLUGIN_AD_PAGE_URL); ?>">Edit</a>
										<a href="<?php echo add_query_arg(array( 'action' => 'delete', 'id' => $ad_data->ID ), DB_PLUGIN_AD_PAGE_URL); ?>">Delete</a>
									</td>
								</tr>
								<?php
							}
						} else { ?>
							<tr>
								<td colspan="4" class="aligncenter">There's no advertisements added!</td>
							</tr>
						<?php
						}
						?>
						
					</tbody>
				</table>
			<?php } else {
				if ( isset($_GET['id']) || isset($new_id) ) {
					global $wpdb;
					if ( !isset($_GET['id']) ) {
						$_GET['id'] = $new_id;
					}
					$current_ad = $wpdb->get_results( 'SELECT * FROM ' . $wpdb->prefix . 'directory_ads WHERE ID="'.intval($_GET['id']).'"' );
				}?>
				<form method="post">
					<div class="db-field-row clearfix">
						<label class="field-label">Advertisement title</label>
						<div class="db-field-input">
							<input type="text" name="ad_label" value="<?php echo (!empty($current_ad)?$current_ad['0']->title:''); ?>" required>
						</div>
					</div>
					<div class="db-field-row clearfix">
						<div class="db-field-input">
							<?php wp_editor( (!empty($current_ad)?stripslashes( urldecode($current_ad['0']->content) ):''), 'ad_html', array( 'textarea_name' => 'ad_html', 'editor_height' => '300', 'wpautop' => false ) ); ?>
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Advertisement placement</label>
						<div class="db-field-input">
							<select name="ad_place">
								<option value="content" <?php echo(!empty($current_ad)&&$current_ad['0']->placement=='content'?'selected':''); ?>>Below content</option>
								<option value="sidebar" <?php echo(!empty($current_ad)&&$current_ad['0']->placement=='sidebar'?'selected':''); ?>>At sidebar</option>
							</select>
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Advertisement packages</label>
						<div class="db-field-input">
							<?php
							global $wpdb;
							$all_packages = $wpdb->get_results( 'SELECT ID, package_name FROM ' . $wpdb->prefix . 'directory_packages' );
							if ( !empty($all_packages) ) {
								$active_packages = ( !empty($current_ad) ? json_decode( $current_ad['0']->packages ) : array() );
								echo '<select name="ad_packages[]" multiple>';
								foreach ($all_packages as $package_data) {
									echo '<option value="'.$package_data->ID.'" '.(in_array($package_data->ID, $active_packages)?'selected':'').'>'.$package_data->package_name.'</option>';
								}
								echo '</select>';
								echo '<span>Show this ad only for the selected packages</span>';
							}
							?>
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Apply to these categories</label>
						<div class="db-field-input">
							<?php
							$categories = get_terms( array(
								'taxonomy' => 'listing_category',
								'hide_empty' => false
							));
							if ( !empty($categories) ) {
								$categoryHierarchy = array();
								db_sort_terms_hierarchicaly($categories, $categoryHierarchy);
								$selected_categories = (isset($current_ad['0']->categories)?json_decode($current_ad['0']->categories, true):array());
								echo '<select name="ad_categories[]" multiple>';
									foreach ($categoryHierarchy as $category_value) {
										$is_checked = (in_array($category_value->term_id, $selected_categories)?'selected':'');
										echo '<option value="'.$category_value->term_id.'" '.$is_checked.'>'.$category_value->name.'</option>';

										if ( !empty($category_value->children) ) {
											echo db_display_backend_categories( $category_value, $selected_categories );
										}
									}
								echo '</select>';
								echo '<span>Show this ad only for the selected categories</span>';
							}
							?>
						</div>
					</div>
					<div class="db-field-row active clearfix">
						<label class="field-label">Is this ad active?</label>
						<div class="db-field-input">
							<div class="db-checkbox <?php echo (!empty($current_ad)&&$current_ad['0']->status=='true'?'active':''); ?>">
								<input type="checkbox" name="ad_status" <?php echo (!empty($current_ad)&&$current_ad['0']->status=='true'?'checked':''); ?>>
							</div>
						</div>
					</div>
					<input type="submit" class="db-button db-primary-button" value="Save">
				</form>
			<?php } ?>
		</div>
	</div>
	<?php
}

function db_get_active_ads( $listing_id ) {
	global $wpdb;
	
	$listing_data = get_post_meta( $listing_id, 'db_order_info', true );
	$listing_terms = wp_get_post_terms( $listing_id, 'listing_category' );
	$listing_category = (isset($listing_terms['0']->term_id)?$listing_terms['0']->term_id:'-1');

	if ( isset($listing_data['listing_package']) ) {
		$all_ads = $wpdb->get_results( 'SELECT * FROM ' . $wpdb->prefix . 'directory_ads WHERE status="true" && packages LIKE "%\"'.intval($listing_data['listing_package']).'\"%" && categories LIKE "%\"'.$listing_category.'\"%"' );
	} else {
		$all_ads = array();
	}

	return $all_ads;
}

function db_cancel_claim_func() {
	if ( !current_user_can('manage_options') ) die(0);

	$claim_post = ( isset($_POST['claim_post']) ? intval($_POST['claim_post']) : '' );

	if ( delete_post_meta( $claim_post, 'db_claim_info' ) ) {
		wp_update_post( array( 'ID' => $claim_post, 'post_author' => get_current_user_id() ) );

		echo '{"save_response": "'.$claim_post.'"}';
	} else {
		echo '{"save_response": "failed"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_cancel_claim', 'db_cancel_claim_func' );

function db_approve_claim_func() {
	if ( !current_user_can('manage_options') ) die(0);

	$claim_post = ( isset($_POST['claim_post']) ? intval($_POST['claim_post']) : '' );
	$claim_info = get_post_meta( $claim_post, 'db_claim_info', true );
	$author = explode(':', $claim_info);

	if ( wp_update_post( array( 'ID' => $claim_post, 'post_author' => $author['0'] ) ) ) {
		update_post_meta( $claim_post, 'db_claim_info', $author['0'] . ':' . time() );

		db_insert_activity( $claim_post, 'claimapproved', array(), $author['0'] );

		if ( function_exists( 'db_send_notification_email' ) ) {
			$main_settings = get_option( 'db_main_settings', array());
			$current_user = get_userdata( $author['0'] );
			db_send_notification_email( $author['0'], 'new_claim', array( 'username' => $current_user->data->user_login, 'url_dashboard' => get_permalink( $main_settings['account_page_id'] ), 'listing_title' => get_the_title($claim_post), 'listing' => get_permalink($claim_post) ) );
		}

		echo '{"save_response": "'.$claim_post.'", "message": "'.esc_html__('Claimed', 'directory-builder').'"}';
	} else {
		echo '{"save_response": "failed"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_approve_claim', 'db_approve_claim_func' );

function db_delete_package() {
	if ( !current_user_can('manage_options') ) die(0);

	global $wpdb;
	$package_id = ( isset($_POST['package_id']) ? intval($_POST['package_id']) : '' );

	if ( $wpdb->query('DELETE FROM '.$wpdb->prefix.'directory_packages WHERE ID="'.$package_id.'"') === false ) {
		echo '{"save_response": "failed"}';
	} else {
		echo '{"save_response": "'.$wpdb->insert_id.'"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_delete_package', 'db_delete_package' );

function db_single_listing_template( $template ) {
	global $post;

	if ( $post->post_type == "listings" ) {
		$main_settings = get_option( 'db_main_settings');

		return db_load_template( 'single-listings.php', false, false, $main_settings );
	}

	return $template;
}
add_filter('single_template', 'db_single_listing_template');

function db_listing_rating_template( $comment_template ) {
	 global $post;
	 if ( !( is_singular() && ( have_comments() || 'open' == $post->comment_status ) ) ) {
		return;
	 }
	 if ( $post->post_type == 'listings' ) {
		$main_settings = get_option( 'db_main_settings');

		return db_load_template( 'single-listing-ratings.php', false, false, $main_settings );
	 }
}
add_filter( "comments_template", "db_listing_rating_template" );

function db_insert_review( $comment_id, $comment_object ) {
	if ( !isset($_POST['review-title']) ) {
		return;
	}

	$saved_ratings = array();
	if ( !empty($_POST) ) {
		$main_settings = get_option( 'db_main_settings', array() );
		$active_rev_cats = json_decode($main_settings['advanced_review_cat'], true);
		foreach ($_POST as $post_key => $post_value) {
			if ( strpos($post_key, 'listing_rating') !== false && isset($active_rev_cats[str_replace('listing_rating_', '', $post_key)]) ) {
				$saved_ratings[esc_attr($post_key)] = array( 'title' => $active_rev_cats[str_replace('listing_rating_', '', $post_key)]['0'], 'overall' => intval($post_value) );
			}
		}
	}

	$rating_value = (!empty($saved_ratings)?$saved_ratings:(isset($_POST['listing_rating'])?intval($_POST['listing_rating']):1));
	$rating_title = (isset($_POST['review-title'])?sanitize_text_field($_POST['review-title']):'');
	$review_images = (isset($_POST['review_images'])?sanitize_text_field($_POST['review_images']):'');

	add_comment_meta( $comment_id, 'listing_review_rating', $rating_value);
	add_comment_meta( $comment_id, 'listing_review_title', $rating_title);
	if ( $review_images != '' ) {
		add_comment_meta( $comment_id, 'listing_review_images', $review_images);
	}
	$post_id = $comment_object->comment_post_ID;

	$user_id = 'anon-'.rand(100000,999999);

	if ( is_array($rating_value) ) {
		$count = $total = 0;
		foreach ($rating_value as $rating_value) {
			$total += $rating_value['overall'];
			$count++;
		}

		$rating_value = floor($total/$count);
	}

	$listing_ratings = get_post_meta( $post_id, 'listing_ratings', true);
	if ( $listing_ratings == '' ) {
		update_post_meta( $post_id, 'listing_ratings', array( $user_id => $rating_value ) );
	} else {
		$listing_ratings[$user_id] = $rating_value;
		update_post_meta( $post_id, 'listing_ratings', $listing_ratings );
	}

	db_insert_activity( $post_id, 'addreview', array( 'comment-id' => $comment_id, 'rating-value' => $rating_value ) );
}
add_action( 'wp_insert_comment', 'db_insert_review', 10, 2 );

function db_delete_review( $comment_id ) {
	$comment_data = get_comment( $comment_id );
	$listing_ratings = get_post_meta( $comment_data->comment_post_ID, 'listing_ratings', true );
	if ( is_array($listing_ratings) && !empty($listing_ratings) ) {
		$review_rating = get_comment_meta( $comment_id, 'listing_review_rating', true );
		if ( is_array($review_rating) ) {
			$count = $total = 0;
			foreach ($review_rating as $rating_value) {
				$total += $rating_value['overall'];
				$count++;
			}

			$rating_value = floor($total/$count);
		} else {
			$rating_value = $review_rating;
		}

		if ( isset($listing_ratings[$comment_data->user_id]) ) {
			$key_to_remove = $comment_data->user_id;
		} else {
			$key_to_remove = array_search($rating_value, $listing_ratings);
		}
		unset($listing_ratings[$key_to_remove]);
		update_post_meta( $comment_data->comment_post_ID, 'listing_ratings', $listing_ratings );
	}

	exit;
}
add_action( 'delete_comment', 'db_delete_review', 10, 1 );

function db_disable_comment_url($fields) { 
	unset($fields['url']);
	return $fields;
}
add_filter('comment_form_default_fields','db_disable_comment_url');

function db_review( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	$rating_value = get_comment_meta( $comment->comment_ID, 'listing_review_rating', true );
	
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'directory-builder' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( 'Edit', 'directory-builder' ), '<span class="edit-link button blue">', '</span>' ); ?></p>
	<?php
			break;
		default :
	?>
	
	<li <?php comment_class(); ?> id="li-review-<?php comment_ID(); ?>">
		<div id="review-<?php comment_ID(); ?>" class="review">
			<div class="review-meta">
				<div class="review-author vcard shadows">
					<?php
						$avatar_size = 70;
						echo get_avatar( $comment, $avatar_size );                          
					?>
				</div><!-- .review-author .vcard -->
			</div>

			<div class="review-content">
				<?php echo '<h4>' . get_comment_author_link() . '</h4>' ?>
				<?php if ( $comment->comment_approved == '0' ) { ?>
					<em class="review-awaiting-moderation"><?php _e( 'Your review is awaiting moderation.', 'directory-builder' ); ?></em>
				<?php } ?>
				<?php echo '<span class="db-listing-rating">'.__('Rating:', 'directory-builder').' '.$rating_value.db_get_rating_stars( $rating_value ).'</span>'; ?>
				<?php edit_comment_link( __( 'Edit', 'directory-builder' ), '<span class="edit-link button blue">', '</span>' ); ?>
				<?php comment_text(); ?>
				<div class="reply-edit-container">
					
				</div>
				<div class="clearfix"></div>
			</div>
			<div class="clearfix"></div>
		</div><!-- end of review -->

	<?php
			break;
	endswitch;
}

function db_get_rating_stars( $rating ) {
	$output = '';

	if ( is_array($rating) && !empty($rating) ) {
		$rating_total = $rating_count = 0;
		foreach ($rating as $rating_value) {
			$rating_total += $rating_value['overall'];
			$rating_count++;
		}
		$rating = floor($rating_total/$rating_count);
	} else {
		$rating = intval($rating);
	}

	if ( !defined('WHITELAB_CUSTOM_STARS') ) {
		for ( $i=1; $i <= $rating; $i++ ) { 
			$output .= '<i class="dbicon-star"></i>';
		}
		
		if ( $rating != 5 ) {
			for ( $i=1; $i <= 5-$rating; $i++ ) { 
				$output .= '<i class="dbicon-star-empty"></i>';
			}
		}
	} else {
		$rating_star = '
		<svg width="16px" height="15px" viewBox="0 0 16 15" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
			<g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">
				<g id="Single-listing" transform="translate(-380.000000, -2797.000000)" stroke="#909FA5" fill="#FFFFFF">
					<g id="Listing" transform="translate(-1.000000, 172.000000)">
						<g id="Coments" transform="translate(151.000000, 2089.000000)">
							<g id="Comment-form" transform="translate(30.000000, 474.000000)">
								<g id="stars" transform="translate(120.000000, 63.000000)">
									<g id="star" transform="translate(81.000000, 0.000000)">
										<g  >
											<path d="M0.321780893,6.17123188 L2.50574108,8.42145652 L2.1280167,11.6264746 L2.12589942,11.6556304 C2.11037263,12.0718188 2.22649417,12.421029 2.46132506,12.6649674 C2.79557443,13.0122935 3.34150567,13.0825688 3.88292002,12.8381594 L6.78224162,11.2581413 L9.65700266,12.8257246 L9.68137501,12.8381594 C9.89954989,12.9364601 10.1142901,12.9864348 10.3202788,12.9864348 C10.6253566,12.9864348 10.903239,12.8720725 11.1027347,12.6649674 C11.3375656,12.421029 11.4537342,12.0718188 11.4382074,11.6556304 L11.0580834,8.42145652 L13.2126839,6.20533333 L13.2420436,6.17123188 C13.5430751,5.77477899 13.6379767,5.31996739 13.5024702,4.9238913 C13.3667755,4.52781522 13.0133764,4.22678986 12.5327047,4.09848551 L9.29649891,3.57613043 L7.88544334,0.734076087 L7.86417635,0.696771739 C7.58582341,0.27040942 7.17751597,0.0257173913 6.74384811,0.0257173913 C6.32693036,0.0257173913 5.93866659,0.243985507 5.65005656,0.639684783 L3.98116223,3.57537681 L1.0584093,4.06692754 L1.01827491,4.07601812 C0.541132045,4.21237681 0.191355884,4.51980797 0.0585312811,4.91969928 C-0.0743403731,5.31940217 0.0214551963,5.77576812 0.321780893,6.17123188 L0.321780893,6.17123188 Z M0.754978244,5.15186232 C0.809698405,4.98780797 0.967836376,4.85898551 1.2017733,4.78819203 L4.44682468,4.24228623 L6.25522483,1.05686232 C6.55028083,0.665684783 6.96362272,0.675481884 7.23863505,1.08187319 L8.80740512,4.24157971 L12.3604515,4.81296739 C12.5950471,4.87933333 12.7537027,5.00278623 12.8084228,5.16217754 C12.8626254,5.32053261 12.8134102,5.51449638 12.6705167,5.70992029 L10.2882371,8.15985507 L10.7051078,11.6968442 C10.7103775,11.8992391 10.6640324,12.0613623 10.5742123,12.1546703 C10.456444,12.2771341 10.2406687,12.2814203 9.99506316,12.1733225 L6.78200636,10.4211014 L3.56871431,12.1733225 C3.32263827,12.2812319 3.10691003,12.276663 2.98980042,12.1551413 C2.89974506,12.0614094 2.85339995,11.8992391 2.8586226,11.6968913 L3.27554035,8.15990217 L0.893731257,5.7102029 C0.749708547,5.51313043 0.700493338,5.31577536 0.754978244,5.15186232 L0.754978244,5.15186232 Z"  ></path>
										</g>
									</g>
								</g>
							</g>
						</g>
					</g>
				</g>
			</g>
		</svg>';

		$rating_star_filled = '
		<svg width="16px" height="15px" viewBox="0 0 16 15" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
			<g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd">
				<g id="Single-listing" transform="translate(-380.000000, -2797.000000)" stroke="#247ba0" fill="#FFFFFF">
					<g id="Listing" transform="translate(-1.000000, 172.000000)">
						<g id="Coments" transform="translate(151.000000, 2089.000000)">
							<g id="Comment-form" transform="translate(30.000000, 474.000000)">
								<g id="stars" transform="translate(120.000000, 63.000000)">
									<g id="star" transform="translate(81.000000, 0.000000)">
										<g  >
											<path d="M0.321780893,6.17123188 L2.50574108,8.42145652 L2.1280167,11.6264746 L2.12589942,11.6556304 C2.11037263,12.0718188 2.22649417,12.421029 2.46132506,12.6649674 C2.79557443,13.0122935 3.34150567,13.0825688 3.88292002,12.8381594 L6.78224162,11.2581413 L9.65700266,12.8257246 L9.68137501,12.8381594 C9.89954989,12.9364601 10.1142901,12.9864348 10.3202788,12.9864348 C10.6253566,12.9864348 10.903239,12.8720725 11.1027347,12.6649674 C11.3375656,12.421029 11.4537342,12.0718188 11.4382074,11.6556304 L11.0580834,8.42145652 L13.2126839,6.20533333 L13.2420436,6.17123188 C13.5430751,5.77477899 13.6379767,5.31996739 13.5024702,4.9238913 C13.3667755,4.52781522 13.0133764,4.22678986 12.5327047,4.09848551 L9.29649891,3.57613043 L7.88544334,0.734076087 L7.86417635,0.696771739 C7.58582341,0.27040942 7.17751597,0.0257173913 6.74384811,0.0257173913 C6.32693036,0.0257173913 5.93866659,0.243985507 5.65005656,0.639684783 L3.98116223,3.57537681 L1.0584093,4.06692754 L1.01827491,4.07601812 C0.541132045,4.21237681 0.191355884,4.51980797 0.0585312811,4.91969928 C-0.0743403731,5.31940217 0.0214551963,5.77576812 0.321780893,6.17123188 L0.321780893,6.17123188 Z M0.754978244,5.15186232 C0.809698405,4.98780797 0.967836376,4.85898551 1.2017733,4.78819203 L4.44682468,4.24228623 L6.25522483,1.05686232 C6.55028083,0.665684783 6.96362272,0.675481884 7.23863505,1.08187319 L8.80740512,4.24157971 L12.3604515,4.81296739 C12.5950471,4.87933333 12.7537027,5.00278623 12.8084228,5.16217754 C12.8626254,5.32053261 12.8134102,5.51449638 12.6705167,5.70992029 L10.2882371,8.15985507 L10.7051078,11.6968442 C10.7103775,11.8992391 10.6640324,12.0613623 10.5742123,12.1546703 C10.456444,12.2771341 10.2406687,12.2814203 9.99506316,12.1733225 L6.78200636,10.4211014 L3.56871431,12.1733225 C3.32263827,12.2812319 3.10691003,12.276663 2.98980042,12.1551413 C2.89974506,12.0614094 2.85339995,11.8992391 2.8586226,11.6968913 L3.27554035,8.15990217 L0.893731257,5.7102029 C0.749708547,5.51313043 0.700493338,5.31577536 0.754978244,5.15186232 L0.754978244,5.15186232 Z"  ></path>
										</g>
									</g>
								</g>
							</g>
						</g>
					</g>
				</g>
			</g>
		</svg>';

		for ( $i=1; $i <= $rating; $i++ ) { 
			$output .= $rating_star_filled;
		}
		
		if ( $rating != 5 ) {
			for ( $i=1; $i <= 5-$rating; $i++ ) { 
				$output .= $rating_star;
			}
		}
	}
	
	return $output;
}

function db_set_content_type() {
	return "text/html";
}

function db_insert_activity( $listing_id, $type, $settings = array(), $user_id = 0 ) {
	global $wpdb;
	if ( $user_id == 0 ) {
		$post_data = get_post($listing_id);
		$author_id = $post_data->post_author;
	} else {
		$author_id = $user_id;
	}
	
	$activity_table = $wpdb->prefix.'directory_activities';
	return $wpdb->query( $wpdb->prepare( "INSERT INTO $activity_table (`listing_id`, `user_id`, `timestamp`, `type`, `settings`) VALUES ('%d', '%d', '%d', '%s', '%s')", $listing_id, $author_id, time(), $type, json_encode( $settings )  ) );
}

function db_get_activity( $type, $listing_id, $settings = array() ) {
	$settings = json_decode( $settings, true );
	switch ( $type ) {
		case 'helpful': return esc_html__('Someone found your review helpful.', 'directory-builder'); break; // comment-id
		case 'unhelpful': return esc_html__('Someone found your review unhelpful.', 'directory-builder'); break; // comment-id
		case 'addreview':
			$comment_data = get_comment( $settings['comment-id'] );
			return sprintf( esc_html__('%s left a %d star rating and review on %s.', 'directory-builder'), (isset($comment_data->user_id)&&$comment_data->user_id!='0'?'<a href="'.esc_url(add_query_arg('#comment-'.$settings['comment-id'], '', get_permalink($comment_data->comment_post_ID))).'">'.$comment_data->comment_author.'</a>':$comment_data->comment_author), $settings['rating-value'], '<a href="'.esc_url(get_permalink($listing_id)).'">'.get_the_title( $listing_id ).'</a>' );
		break; // comment-id, rating-value
		case 'payment':
			$main_settings = get_option( 'db_main_settings', array() );
			$invoice_data = explode('-', $settings['invoice-id']);
			if ( isset($main_settings['account_page_id']) && $main_settings['account_page_id'] != '' ) {
				$invoice_url = '<a href="'.esc_url(add_query_arg(array( 'invoices' => '', 'lid' => $listing_id, 'prow' => $invoice_data['2'] ), get_permalink($main_settings['account_page_id']))).'">#'.$settings['invoice-id'].'</a>';
			} else {
				$invoice_url = '#'.$settings['invoice-id'];
			}
			return sprintf( esc_html__('You made a payment for order %s.', 'directory-builder'), $invoice_url );
		break; // invoice-id
		case 'newbooking': return esc_html__('Hooray! You have a new booking.', 'directory-builder'); break;
		case 'newmessage': return esc_html__('Someone sent you a message, please check your email.', 'directory-builder'); break;
		case 'newfavorite':
			$user_data = get_userdata($settings['author-id']);
			return sprintf( esc_html__('%s favorited %s listing.', 'directory-builder'), $user_data->data->display_name, '<a href="'.esc_url(get_permalink($listing_id)).'">'.get_the_title( $listing_id ).'</a>' );
		break; // author-id
		case 'improvement': return sprintf( esc_html__('Your suggested improvement for %s listing has been approved.', 'directory-builder'), '<a href="'.esc_url(get_permalink($listing_id)).'">'.get_the_title( $listing_id ).'</a>' ); break; 
		case 'claimapproved': return sprintf( esc_html__('Your claim for %s listing has been approved.', 'directory-builder'), '<a href="'.esc_url(get_permalink($listing_id)).'">'.get_the_title( $listing_id ).'</a>' ); break;
		case 'supportnew': return esc_html__( 'Your support ticket is successfully created.', 'directory-builder' ); break; // support-parent
		case 'supportreply': return esc_html__( 'Someone just replied to your ticket.', 'directory-builder' ); break; // support-parent
		default: break;
	}
}

function db_send_contact_email() {
	$db_author_email = ( isset($_POST['db_author']) ? sanitize_text_field($_POST['db_author']) : '' );
	$db_message = ( isset($_POST['db_message']) ? sanitize_text_field($_POST['db_message']) : '' );
	$db_name = ( isset($_POST['db_name']) ? sanitize_text_field($_POST['db_name']) : '' );
	$db_email = ( isset($_POST['db_email']) ? sanitize_text_field($_POST['db_email']) : '' );
	$db_listing = ( isset($_POST['db_listing']) ? intval($_POST['db_listing']) : '0' );

	$db_author_email = get_post_meta( $db_listing, 'listingcontact', true );

	$subject = esc_html__( 'Contacting regarding your listing', 'directory-builder' );
	$message = esc_html__( 'Name:', 'directory-builder' ) . ' ' . $db_name . '<br />';
	$message .= esc_html__( 'Email:', 'directory-builder' ) . ' ' . $db_email . '<br />';
	$message .= esc_html__( 'Message:', 'directory-builder' ) . '<br />' . $db_message;

	add_filter( 'wp_mail_content_type','db_set_content_type' );
	add_filter( 'wp_mail_from_name', 'db_custom_wp_mail_from_name' );
	add_filter( 'wp_mail_from', 'db_custom_wp_mail_from' );
	$maintenance_email = wp_mail( $db_author_email, $subject, $message );
	remove_filter( 'wp_mail_content_type','db_set_content_type' );
	remove_filter( 'wp_mail_from_name', 'db_custom_wp_mail_from_name' );
	remove_filter( 'wp_mail_from', 'db_custom_wp_mail_from' );
	
	if ( $maintenance_email ) {
		db_insert_activity( $db_listing, 'newmessage' );
		echo esc_html__('Your email was sent successfully!', 'directory-builder');
	} else {
		echo esc_html__('Something went wrong!', 'directory-builder');
	}

	die(0);
}
add_action( 'wp_ajax_db_send_contact_email', 'db_send_contact_email' );
add_action( 'wp_ajax_nopriv_db_send_contact_email', 'db_send_contact_email' );

add_action('init', 'db_check_form_actions');
function db_check_form_actions() {
	session_start();

	if( isset($_POST['login_user_email']) && $_POST['login_user_email'] != '' && isset($_POST['login_user_password']) && $_POST['login_user_password'] != '' ) {
		$db_user_login = esc_attr($_POST['login_user_email']);
		$user_password = esc_attr($_POST['login_user_password']);

		$user_creds = array(
			'user_login'    => $db_user_login,
			'user_password' => $user_password,
			'remember'      => true
		);

		global $db_user_login;
		$db_user_login = wp_signon( $user_creds );

		if ( !is_wp_error( $db_user_login ) ) {
			$user_validation = get_user_meta( $db_user_login->data->ID, 'db_validation', true );

			if ( $user_validation !== false && $user_validation != '' ) {
				if ( $user_validation !== 'validated' ) {
					wp_logout();
					$db_user_login = new WP_Error( 'pending_validation', __( "Your account is pending validation!", "directory-builder" ) );
				}
			}
		}

		if ( !is_wp_error( $db_user_login ) ) {
			if ( !isset($_GET['db-claim']) ) {
				$main_settings = get_option( 'db_main_settings', array() );
				wp_redirect( get_permalink( $main_settings['account_page_id'] ) );
			} else {
				header("Refresh:0");
			}
			exit;
		}
	}

	if ( isset($_POST['db-register-action']) ) {
		global $db_user_register;

		$user_name = esc_attr($_POST['db_registerusername']);
		$user_email = sanitize_email($_POST['db_registeremail']);
		$user_password = esc_attr($_POST['db_registerpassword']);
		$user_password_confirm = esc_attr($_POST['db_registerpasswordconfirm']);

		$valid_request = true;
		if ( isset( $_POST['g-recaptcha-response'] ) ) {
			$gcaptcha_options = get_option( 'gglcptch_options', array() );

			$gcaptcha_response = wp_remote_get( add_query_arg( array( 'secret' => $gcaptcha_options['private_key'], 'response' => $_POST['g-recaptcha-response'], 'remoteip' => filter_var( $_SERVER['REMOTE_ADDR'], FILTER_VALIDATE_IP ) ), 'https://www.google.com/recaptcha/api/siteverify' ) );
			$gcaptcha_body = json_decode( $gcaptcha_response['body'], true );

			if ( !$gcaptcha_body['success'] ) {
				$db_user_register = new WP_Error( 'invalid', esc_html__('You failed the captcha test!', 'directory-builder') );
				$valid_request = false;
			}
		}
		
		if ( $valid_request ) {
			$db_user_register = wp_create_user( $user_name, $user_password, $user_email );
			if ( !is_wp_error( $db_user_register ) ) {
				wp_update_user( array( 'ID' => $db_user_register, 'role' => 'db_listing_author' ) );

				$replicated_fields = $_POST;
				unset($replicated_fields['db_registerusername']);
				unset($replicated_fields['db_registeremail']);
				unset($replicated_fields['db_registerpassword']);
				unset($replicated_fields['db_registerpasswordconfirm']);
				unset($replicated_fields['db-register']);
				if ( !empty($replicated_fields) ) {
					foreach ( $replicated_fields as $field_key => $field_value ) {
						update_user_meta( $db_user_register, $field_key, $field_value );
					}
				}

				$user_validation_code = wp_generate_password( 12, false );
				update_user_meta( $db_user_register, 'db_validation', $user_validation_code );

				$main_settings = get_option( 'db_main_settings', array() );
				if ( function_exists( 'db_send_notification_email' ) ) {
					db_send_notification_email( $db_user_register, 'new_user_confirm', array( 'username' => $user_name, 'url_confirm' => add_query_arg( array( 'user' => $db_user_register, 'validation' => $user_validation_code ), get_permalink( $main_settings['account_page_id'] ) ), 'source' => __('registration shortcode','directory-builder') ) );
				}

				// wp_signon( array( 'user_login' => $user_name, 'user_password' => $user_password, 'remember' => false ), false ); // Log the new user in

				if ( isset($_GET['db-claim']) ) {
					header("Refresh:0");
					exit;
				}
			}
		}
	}

	if ( isset($_POST['db-account-pass']) && isset($_POST['db-account-pass2']) && isset($_GET['key']) && isset($_GET['login']) ) {
		$key = esc_attr( $_GET['key'] );
		$login = esc_attr( $_GET['login'] );
		$pass1 = esc_attr( $_POST['db-account-pass'] );
		$pass2 = esc_attr( $_POST['db-account-pass2'] );
		global $db_lost_password;

		$key_check = check_password_reset_key( $key, $login );
			
		if ( is_wp_error( $key_check ) ) {
			$db_lost_password = '<p>' . esc_html__( 'We\'re sorry but there has been an error', 'directory-builder' ) . ': <strong>' . $key_check->get_error_message() . '</strong></p>';
		} else {
			if ( $pass1 != $pass2 ) {
				$db_lost_password = '<p>' . esc_html__( 'Your passwords didn\'t match!', 'directory-builder' ) . '</p>';
			} else {
				wp_update_user( array( 'ID' => $key_check->data->ID, 'user_pass' => $pass1 ) ); // Change user password
				wp_signon( array( 'user_login' => $key_check->data->user_login, 'user_password' => $pass1, 'remember' => false ), false ); // Log the new user in

				global $wpdb;
				$wpdb->update( $wpdb->users, array( 'user_activation_key' => '' ), array( 'ID' => $key_check->data->ID ) );

				$main_settings = get_option( 'db_main_settings', array() );
				wp_redirect( get_permalink( $main_settings['account_page_id'] ) );
				exit;
			}
		}
	}
}

function db_check_timezone() {
	if ( !isset($_SESSION['db_tz']) ) {
		?>
		<script type="text/javascript">
			jQuery(document).ready(function($) {
				var current_date = new Date();
				var current_offset = parseInt(-current_date.getTimezoneOffset() / 60);

				if ( current_offset >= 0 ) {
					var current_utc = 'UTC+'+current_offset;
				} else {
					var current_utc = 'UTC'+current_offset;
				}

				jQuery.ajax({
					type: 'POST',
					url: db_main.ajaxurl,
					data: { 
						'action': 'db_save_tz',
						'tz_offset': current_utc
					},
					dataType: 'json'
				});
			});
		</script>
		<?php
	}
}
add_action('wp_footer', 'db_check_timezone');

function db_save_tz_func() {
	if ( isset($_POST['tz_offset']) ) {
		$_SESSION['db_tz'] = $_POST['tz_offset'];
	}

	die(0);
}
add_action( 'wp_ajax_db_save_tz', 'db_save_tz_func' );
add_action( 'wp_ajax_nopriv_db_save_tz', 'db_save_tz_func' );

function db_check_authorize_card( $card_data ) {
	require 'vendor/autoload.php';
	require 'auth_autoload.php';
}

function db_check_stripe_card( $card_data ) {
	require 'stripe_auth.php';
}

function db_checkout_html( $package_data = array(), $claim_listing = false ) {
	$main_settings = get_option( 'db_main_settings');

	if ( is_string( $main_settings['payment_method'] ) ) {
		$main_settings['payment_method'] = str_split( $main_settings['payment_method'] );
	}

	$output = '
	<div class="db-main-checkout-wrapper db-dialog-animation"><div class="db-main-checkout" data-return="'.$main_settings['paypal_return_url'].'" data-success="'.get_permalink($main_settings['order_success_url']).'">
		<h1 class="db-checkout-title">'.__('Checkout', 'directory-builder').'<span class="db-checkout-close"><img src="'.DB_PLUGIN_URI.'/public/images/x.png" alt=""></span></h1>
		<p class="db-checkout-desc">'.__('Choose a payment option bellow and fill out the information', 'directory-builder').'</p>
		<div class="db-checkout-select">';
			if ( in_array('authorize.net', $main_settings['payment_method']) ) {
				$output .= '
				<div class="db-checkout-item active" data-type="credit-card">
					<img src="'.DB_PLUGIN_URI.'/public/images/credit-card.png" alt="">
					<span>'.__('Credit card', 'directory-builder').'</span>
				</div>';
			}
			if ( in_array('paypal', $main_settings['payment_method']) ) {
				$output .= '
				<div class="db-checkout-item '.(count($main_settings['payment_method'])==1?'active':'').'" data-type="paypal">
					<img src="'.DB_PLUGIN_URI.'/public/images/paypal.png" alt="">
					<span>'.__('PayPal', 'directory-builder').'</span>
				</div>';
			}
			if ( in_array('stripe', $main_settings['payment_method']) ) {
				$output .= '
				<div class="db-checkout-item '.(count($main_settings['payment_method'])==1?'active':'').'" data-type="stripe">
					<img src="'.DB_PLUGIN_URI.'/public/images/stripe.png" alt="">
					<span>'.__('Stripe', 'directory-builder').'</span>
				</div>';
			}
		$output .= '</div>';

		$billing_fields = '
		<div class="db-checkout-left">
			<h3>'.__('1. Billing information', 'directory-builder').'</h3>
			<div class="db-checkout-row">
				<span class="db-checkout-label">'.__('Full name *', 'directory-builder').'</span>
				<input type="text" class="db-checkout-field" name="x_full_name" placeholder="'.__('Full name *', 'directory-builder').'" required>
			</div>
			<div class="db-checkout-split two">
				<div class="db-checkout-row">
					<span class="db-checkout-label">'.__('Company name', 'directory-builder').'</span>
					<input type="text" class="db-checkout-field" name="x_company" placeholder="'.__('Company name', 'directory-builder').'">
				</div>
				<div class="db-checkout-row">
					<span class="db-checkout-label">'.__('Phone *', 'directory-builder').'</span>
					<input type="phone" class="db-checkout-field" name="x_phone" placeholder="'.__('Phone *', 'directory-builder').'" required>
				</div>
				<div class="db-checkout-row">
					<span class="db-checkout-label">'.__('Email *', 'directory-builder').'</span>
					<input type="email" class="db-checkout-field" name="x_email" placeholder="'.__('Email *', 'directory-builder').'" required>
				</div>
				<div class="db-checkout-row">
					<span class="db-checkout-label">'.__('Country *', 'directory-builder').'</span>
					<input type="text" class="db-checkout-field" name="x_country" placeholder="'.__('Country *', 'directory-builder').'" required>
				</div>
				<div class="clearfix"></div>
			</div>
			<div class="db-checkout-row">
				<span class="db-checkout-label">'.__('Address 1 *', 'directory-builder').'</span>
				<input type="text" class="db-checkout-field" name="x_address" placeholder="'.__('Address 1 *', 'directory-builder').'" required>
			</div>
			<div class="db-checkout-split two">
				<div class="db-checkout-row">
					<span class="db-checkout-label">'.__('City *', 'directory-builder').'</span>
					<input type="text" class="db-checkout-field" name="x_city" placeholder="'.__('City *', 'directory-builder').'" required>
				</div>
				<div class="db-checkout-row">
					<span class="db-checkout-label">'.__('State / County *', 'directory-builder').'</span>
					<input type="text" class="db-checkout-field" name="x_state" placeholder="'.__('State / County *', 'directory-builder').'" required>
				</div>
				<div class="clearfix"></div>
			</div>
			<div class="db-checkout-row">
				<span class="db-checkout-label">'.__('Postcode / ZIP *', 'directory-builder').'</span>
				<input type="text" class="db-checkout-field" name="x_zip" placeholder="'.__('Postcode / ZIP *', 'directory-builder').'" required>
			</div>';
			if ( $claim_listing ) {
				$billing_fields .= '<input type="hidden" name="db-claim-listing" value="true">';
			}
		$billing_fields .= '
		</div>';

		if ( in_array('authorize.net', $main_settings['payment_method']) || in_array('stripe', $main_settings['payment_method']) ) {
			$output .= '
			<div class="db-checkout-option credit-card stripe">
				<form id="authorize_form" method="post">
					'.$billing_fields.'
					<div class="db-checkout-right">
						<h3>'.__('2. Credit card info', 'directory-builder').'</h3>
						<div class="db-checkout-row">
							<span class="db-checkout-label">'.__('Name on card *', 'directory-builder').'</span>
							<input type="text" class="db-checkout-field" name="name_on_card" placeholder="'.__('Name on card *', 'directory-builder').'" required>
						</div>
						<div class="db-checkout-row">
							<span class="db-checkout-label">'.__('Card number *', 'directory-builder').'</span>
							<input type="text" class="db-checkout-field" name="x_card_num" placeholder="'.__('Card number *', 'directory-builder').'" required>
						</div>
						<div class="db-checkout-split three">
							<div class="db-checkout-row">
								<span class="db-checkout-label">'.__('CVV code *', 'directory-builder').'</span>
								<input type="text" class="db-checkout-field" name="x_cvv" placeholder="'.__('CVV code *', 'directory-builder').'" required>
							</div>
							<div class="db-checkout-row">
								<span class="db-checkout-label">'.__('Month *', 'directory-builder').'</span>
								<input type="text" class="db-checkout-field" name="x_month" placeholder="'.__('Month *', 'directory-builder').'" required>
							</div>
							<div class="db-checkout-row">
								<span class="db-checkout-label">'.__('Year *', 'directory-builder').'</span>
								<input type="text" class="db-checkout-field" name="x_year" placeholder="'.__('Year *', 'directory-builder').'" required>
							</div>
							<div class="clearfix"></div>
						</div>
						<div class="db-checkout-proceed">
							<input type="hidden" name="db-checkout" value="true">
							<input type="hidden" name="db-listing-id" value="'.get_the_ID().'">
							<input type="hidden" name="db-package-fee" value="">
							<input type="hidden" name="item_name" value="'.(isset($package_data['fee_label'])?$package_data['fee_label']:'').'">
							<input type="hidden" name="amount" value="'.(isset($package_data['fee_amount'])?$package_data['fee_amount']:'').'">';
							if ( $main_settings['terms_and_conditions_status'] ) {
								$output .= '
								<div class="dt-form-row">
									<label for="db-agree-to-terms" class="dt-checkbox">
										<input type="checkbox" id="db-agree-to-terms" name="db-agree-to-terms" required="">'.esc_html__('I agree to all statements in', 'directory-builder').' <a href="javascript:void(0)" class="db-show-checkout-terms">'.esc_html__('terms and conditions', 'directory-builder').'</a>
										<div class="db-checkout-terms hidden">'.nl2br($main_settings['terms_and_conditions']).'</div>
									</label>
								</div>';
							}
							$output .= '
							<input type="submit" class="btn btn-primary" type="button" value="' . __('Pay with credit card', 'directory-builder') . '">
						</div>
					</div>
					<div class="clearfix"></div>
				</form>
			</div>';
		}
		if ( in_array('paypal', $main_settings['payment_method']) ) {
			$output .= '
			<div class="db-checkout-option paypal" '.(count($main_settings['payment_method'])>1?'style="display: none;"':'').'>';
				if ( $main_settings['payment_mode'] == 'sandbox' ) {
					$paypal_url = 'https://www.sandbox.paypal.com/cgi-bin/webscr';
				} else {
					$paypal_url = 'https://www.paypal.com/cgi-bin/webscr';
				}
				$new_listing_id = 0;
				$output .=
				'<form id="paypal-gateway" action="' . $paypal_url . '" method="post">
					'.$billing_fields.'
					<div class="db-checkout-right">
						<h3>'.__('2. PayPal', 'directory-builder').'</h3>
						<div class="db-checkout-proceed">
							<input type="hidden" name="db-checkout" value="true">
							<input type="hidden" name="db-listing-id" value="'.get_the_ID().'">
							<input type="hidden" name="cmd" value="_xclick">
							<input type="hidden" name="business" value="' . $main_settings['paypal_merchant_id'] . '">
							<input type="hidden" name="item_name" value="'.(isset($package_data['fee_label'])?$package_data['fee_label']:'').'">
							<input type="hidden" name="amount" value="'.(isset($package_data['fee_amount'])?$package_data['fee_amount']:'').'">
							<input type="hidden" name="no_shipping" value="1">
							<input type="hidden" name="no_note" value="1">
							<input type="hidden" name="currency_code" value="' . $main_settings['default_currency'] . '">
							<input type="hidden" name="return" value="' . $main_settings['paypal_return_url'] . '">
							<input type="hidden" name="notify_url" value="' . get_permalink( $main_settings['add_page_id'] ) . '">
							<input type="hidden" name="custom" value="' . $new_listing_id . '">
							<input type="hidden" name="src" value="1">
							<input type="hidden" name="a3" value="'.(isset($package_data['fee_amount'])?$package_data['fee_amount']:'').'">
							<input type="hidden" name="p3" value="1">
							<input type="hidden" name="t3" value="M">';

							if ( $main_settings['terms_and_conditions_status'] ) {
								$output .= '
								<div class="dt-form-row">
									<label for="db-agree-to-terms" class="dt-checkbox">
										<input type="checkbox" id="db-agree-to-terms" name="db-agree-to-terms" required="">'.esc_html__('I agree to all statements in', 'directory-builder').' <a href="javascript:void(0)" class="db-show-checkout-terms">'.esc_html__('terms and conditions', 'directory-builder').'</a>
										<div class="db-checkout-terms hidden">'.nl2br($main_settings['terms_and_conditions']).'</div>
									</label>
								</div>';
							}
							$output .= '
							<input type="submit" class="btn btn-primary" type="button" value="' . __('Proceed to PayPal', 'directory-builder') . '">
						</div>
					</div>
					<div class="clearfix"></div>
				</form>
			</div>';
		}
	$output .= '</div></div><div class="db-dialog-overlay"></div>';

	return $output;
}

function db_add_listing_shortcode( $db_edit_listing = false ) {
	$main_settings = get_option( 'db_main_settings');
	$listing_categories = wp_dropdown_categories( array(
				'taxonomy'      => 'listing_category',
				'hide_empty'    => 0,
				'orderby'       => 'name',
				'order'         => 'ASC',
				'name'          => 'listing_category',
				'echo'          => '0'
			) );
	global $wpdb;
	$register_message = $output = '';

	if ( isset($_GET['edit-listing']) ) {
		$can_user_access = false;
		if ( is_user_logged_in() ) {
			$pre_listing_info = get_post( intval($_GET['edit-listing']) );

			if ( isset($pre_listing_info->post_author) && intval($pre_listing_info->post_author) === get_current_user_id() ) {
				$db_edit_listing = true;
				$can_user_access = true;
			}
		}

		if ( isset($_GET['improve']) ) {
			$imp_table = $wpdb->prefix.'directory_improvements';
			$improvements = $wpdb->get_results( "SELECT ID FROM $imp_table WHERE listing_id='".intval($_GET['edit-listing'])."' && status='pending'" );

			if ( get_post_meta( intval($_GET['edit-listing']), 'db_claim_info', true ) == '' && empty($improvements) ) {
				$db_edit_listing = true;
				$can_user_access = true;
			}
		}
	}

	if ( !$db_edit_listing ) {
		// Paypal IPN payment verification
		$post_input       = @file_get_contents('php://input');
		$post_input_array = explode('&', $post_input);

		if ( $main_settings['payment_active'] == 'yes' && !empty($post_input) && $post_input_array[0] != 'wp_customize=on' && strpos($post_input_array['0'], 'listing_title') === false && strpos($post_input_array['0'], 'login_user_email') === false ) {
			include('paypal_ipn.php');
		}

		if ( $main_settings['payment_active'] == 'yes' && in_array('authorize.net', $main_settings['payment_method']) && !empty($_REQUEST['x_response_code']) ) {
			require_once('authorize_relay.php');
		}

		if ( $main_settings['payment_active'] == 'yes' && in_array('stripe', $main_settings['payment_method']) ) {
			$received_data = json_decode($post_input, true);
			if ( isset($received_data['object']) && $received_data['object'] == 'event' ) {
				require_once('stripe_hooks.php');
			}
		}
	}

	$package_data = array();
	if ( isset($_POST['listing_title']) && !$db_edit_listing ) {
		global $db_user_login;
		$ready_to_post = false;

		if ( is_user_logged_in() ) {
			$logged_in_user = get_current_user_id();
			$ready_to_post = true;
		} else if ( $db_user_login ) {
			if ( is_wp_error( $db_user_login ) ) {
				$register_message = '<p>'.$db_user_login->get_error_message().'</p>';
			} else {
				$logged_in_user = $db_user_login->data->ID;
				$ready_to_post = true;
			}
		} else if ( isset($_POST['register_user_email']) && sanitize_email($_POST['register_user_email']) != '' ) {
			$user_email = sanitize_email($_POST['register_user_email']);
			$db_user_login = explode('@', $user_email);

			$register_errors = register_new_user($db_user_login['0'], $user_email);

			if ( !is_wp_error($register_errors) ) {
				$logged_in_user = $register_errors;
				$ready_to_post = true;
			} else {
				$register_message = '<p>'.$register_errors->get_error_message().'</p>';
			}
		}

		$listing_values = array(
			'post_author' => $logged_in_user,
			'post_content' => sanitize_text_field($_POST['listing_content']),
			'post_title' => sanitize_text_field($_POST['listing_title']),
			'post_excerpt' => sanitize_text_field($_POST['listing_excerpt']),
			'post_status' => $main_settings['new_post_status'],
			'post_type' => 'listings',
			'comment_status' => 'open',
			'post_parent' => 0,
			'menu_order' => 0,
		);

		if ( $ready_to_post ) {
			$new_listing_id = wp_insert_post($listing_values);

			if ( $new_listing_id ) {
				$all_listing_values = $_POST;
				unset($all_listing_values['listing_title']);
				unset($all_listing_values['listing_content']);
				unset($all_listing_values['listing_excerpt']);
				unset($all_listing_values['listing_category']);
				unset($all_listing_values['listing_featured_img']);

				if ( isset($all_listing_values['listing_featured_img']) && esc_url($all_listing_values['listing_featured_img']) != '' ) {
					// DB_Generate_Featured_Image( content_url().'/directory-uploads/'.$all_listing_values['listing_featured_img'], $new_listing_id );
				}  

				// Add all custom data to the post
				foreach ($all_listing_values as $listing_value_key => $listing_key_value) {
					add_post_meta( $new_listing_id, sanitize_text_field($listing_value_key), ( !is_array( $listing_key_value ) ? sanitize_text_field( $listing_key_value ) : db_sanitize_array( $listing_key_value ) ), true );
				}

				// Add category to the listing
				wp_set_object_terms( $new_listing_id, intval($_POST['listing_category']), 'listing_category' );

				// Package payment
				$package_data = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_packages WHERE ID="'.intval($_POST['listing_package']).'"');
				if ( !empty($package_data) ) {
					$package_data = json_decode($package_data['0']->package_settings, true);
					if ( isset($package_data['listing_sticky']) && $package_data['listing_sticky'] === true ) {
						$sticky_listings = get_option('db_sticky_listings');
						if ( !isset($sticky_listings) || $sticky_listings == '' ) {
							$sticky_listings = array();
						}
						$sticky_listings[] = $new_listing_id;
						update_option('db_sticky_listings', $sticky_listings);
					}

					if ( $package_data['listing_run_type'] == 'forever' ) {
						$run_listing = __('Forever','directory-builder');
					} else {
						$run_listing = $package_data['listing_run_days'].' '.__('days','directory-builder');
					}

					// Add order info
					$order_data = array(
						'listing_package' => intval($_POST['listing_package']),
						'listing_package_name' => sanitize_text_field($package_data['fee_label']),
						'paid_amount' => $main_settings['default_currency_symbol'].$package_data['fee_amount'],
						'payment_history' => array(),
						'payment_status' => 'Processing',
						'category' => sanitize_text_field($_POST['listing_category']),
						'listing_run_type' => $package_data['listing_run_type'],
						'listing_run_days' => $package_data['listing_run_days'],
						'listing_sticky' => $package_data['listing_sticky'],
						'listing_expires' => 'Unknown'
					);
					add_post_meta( $new_listing_id, 'db_order_info', $order_data, true );
				} else {
					$output = '
					<div class="db-main-wrapper">
						<p>'.__('Your listing was successfully added, but your package couldn\'t be found!', 'directory-builder').'</p>
					</div>';
				}

				if ( $main_settings['db_theme_id'] == 'default' ) {
					$output .= db_checkout_html( $package_data );
				}

				// $payment_url = add_query_arg('db-payment', 'true', );
				$output .= '
				<script type="text/javascript">
				jQuery(document).ready(function($) {
					history.pushState({page: "'.get_permalink().'"}, "", "'.get_permalink().'");
				});
				</script>';

				return $output;
			} else {
				return '<div class="db-main-wrapper"><p>'.__('There was an issue while adding your listing!', 'directory-builder').'</p></div>';
			}
		}
	} else if ( isset($_POST['listing_title']) && $db_edit_listing ) {
		if ( !isset($_GET['improve']) ) {
			$db_listing = array(
				'ID'           => intval($_GET['edit-listing']),
				'post_title'   => esc_attr($_POST['listing_title']),
				'post_content' => esc_attr($_POST['listing_content']),
				'post_excerpt' => esc_attr($_POST['listing_excerpt'])
			);
			wp_update_post( $db_listing );

			$fields_to_save = $_POST;

			if ( isset($fields_to_save['listing_featured_img']) && $fields_to_save['listing_featured_img'] != '' ) {
				set_post_thumbnail( esc_attr($_GET['edit-listing']), $fields_to_save['listing_featured_img'] );
			}

			unset($fields_to_save['listing_title']);
			unset($fields_to_save['listing_content']);
			unset($fields_to_save['listing_excerpt']);
			unset($fields_to_save['listing_featured_img']);

			foreach ($fields_to_save as $field_key => $field_value) {
				update_post_meta( esc_attr($_GET['edit-listing']), sanitize_key($field_key), (!is_array($field_value)?sanitize_text_field($field_value):$field_value));
			}

			$success_message = __('Listing updated successfully!', 'directory-builder');
		} else {
			global $wpdb;
			$imp_table = $wpdb->prefix.'directory_improvements';
			$improvements = $wpdb->get_results( "SELECT ID FROM $imp_table WHERE listing_id='".intval($_GET['edit-listing'])."' && status='pending'" );

			if ( empty($improvements) ) {
				$improved_data = array(
					'post_title'   => esc_attr($_POST['listing_title']),
					'post_content' => esc_attr($_POST['listing_content']),
					'post_excerpt' => esc_attr($_POST['listing_excerpt'])
				);

				$fields_to_save = $_POST;

				if ( isset($fields_to_save['listing_featured_img']) && $fields_to_save['listing_featured_img'] != '' ) {
					$improved_data['listing_featured_img'] = $fields_to_save['listing_featured_img'];
				}

				unset($fields_to_save['listing_title']);
				unset($fields_to_save['listing_content']);
				unset($fields_to_save['listing_excerpt']);
				unset($fields_to_save['listing_featured_img']);

				foreach ($fields_to_save as $field_key => $field_value) {
					$improved_data[sanitize_key($field_key)] = (!is_array($field_value)?sanitize_text_field($field_value):$field_value);
				}

				if ( is_user_logged_in() ) {
					$imp_author = get_current_user_id();
				} else {
					$imp_author = '0';
				}
				
				$improvements_table = $wpdb->prefix . 'directory_improvements';
				$wpdb->query( $wpdb->prepare( "INSERT INTO $improvements_table (author,listing_id,sent_at,improvements,status) VALUES('%d','%d','%d','%s','pending')", $imp_author, intval($_GET['edit-listing']), time(),json_encode($improved_data) ) );

				$success_message = __('Improved data successfully sent, someone will shortly review your changes!', 'directory-builder');
				$listing_improved = true;
			}
		}
	}

	if ( $db_edit_listing ) {
		$listing_information = get_post( intval($_GET['edit-listing']) );
		$listing_address = get_post_meta( intval($_GET['edit-listing']) , 'listing_address', true);
		$listing_address_lat = get_post_meta( intval($_GET['edit-listing']) , 'listing_address_lat', true);
		$listing_address_lng = get_post_meta( intval($_GET['edit-listing']) , 'listing_address_lng', true);
	}

	if ( isset($can_user_access) && $can_user_access === false ) {
		return esc_html__('You can\'t access this page!', 'directory-builder');
	}

	$output = '<div class="db-main-wrapper">';
		if ( isset($success_message) ) {
			$output .= '<div class="db-info-message success"><p>'.$success_message.'</p></div>';

			if ( isset($listing_improved) && $listing_improved === true ) {
				$output .= '</div>';
				return $output;
			}
		}

		if ( !$db_edit_listing && $main_settings['db_theme_id'] != 'default' ) {
			$output .= db_checkout_html( $package_data );
		}

		$output .= '
		<form method="post" id="db-add-listing-form">';
			$output .= '
			<div class="db-field-row required">
				<label for="listing_title">'.__('Listing title', 'directory-builder').'</label>
				<input type="text" name="listing_title" id="listing_title" placeholder="'.__('Listing title', 'directory-builder').'" value="'.(isset($listing_information->post_title)?$listing_information->post_title:(isset($_POST['listing_title'])?sanitize_text_field($_POST['listing_title']):'')).'">
				<div class="db-field-meta">
					<span class="db-field-row-required">'.__('This field is required!', 'directory-builder').'</span>
				</div>
			</div>
			<div class="db-field-row listing_excerpt">
				<label for="listing_excerpt">'.__('Listing short description', 'directory-builder').'</label>
				<textarea name="listing_excerpt" placeholder="'.__('Listing short description', 'directory-builder').'" id="listing_excerpt">'.(isset($listing_information->post_excerpt)?$listing_information->post_excerpt:(isset($_POST['listing_excerpt'])?sanitize_text_field($_POST['listing_excerpt']):'')).'</textarea>
			</div>
			<div class="db-field-row listing_content">
				<label for="listing_content">'.__('Listing long description', 'directory-builder').'</label>
				<textarea name="listing_content" placeholder="'.__('Listing long description', 'directory-builder').'" id="listing_content">'.(isset($listing_information->post_content)?$listing_information->post_content:(isset($_POST['listing_content'])?sanitize_text_field($_POST['listing_content']):'')).'</textarea>';
				if ( $main_settings['allow_images'] ) {
					$output .= '<div class="db-field-meta"><span class="db-field-row-description">'.sprintf( __('To display gallery images in your listing, please put %s into the content, at the place where you want your gallery shown.', 'directory-builder'), '<strong>[directory_gallery]</strong>' ).'</span></div>';
				}
			$output .= '
			</div>';

			if ( !$db_edit_listing ) {
				if ( !defined('WHITELAB_CUSTOM_SELECT') ) {
					$output .= '
					<div class="db-field-row required">
						<label for="listing_address_lng">'.__('Listing category', 'directory-builder').'</label>
						'.$listing_categories.'
					</div>';
				} else {
					$term_settings = array(
						'taxonomy' => 'listing_category',
						'hide_empty' => false,
						'order' => 'asc',
						'orderby' => 'name'
					);

					$terms = get_terms( $term_settings );
					$categoryHierarchy = array();
					db_sort_terms_hierarchicaly($terms, $categoryHierarchy);

					$output .= '
					<div class="db-field-row required listing_category single-select">
						<input type="text" class="dt-custom-select"  placeholder="'.__('Category', 'directory-builder').'" readonly>
						<input type="hidden" class="dt-custom-select-value" id="listing_category" name="listing_category">
						<div class="dt-custom-select-container">
							<div class="dt-custom-select-inner">
								<div class="dt-custom-select-items">';
									if ( !empty($categoryHierarchy) ) {
										foreach ($categoryHierarchy as $cat_data) {
											$output .= '<div class="dt-custom-select-item" data-value="'.$cat_data->term_id.'">'.$cat_data->name.'</div>';
											if ( !empty($cat_data->children) ) {
												$output .= db_display_categories( $cat_data );
											}
										}
									}
								$output .= '
								</div>
								<div class="dt-custom-select-scrollbar-wrapper">
									<span class="dt-custom-select-scrollbar"></span>
								</div>
							</div>
						</div>
						<div class="db-field-meta">
							<span class="db-field-row-required">'.esc_html__('This field is required!', 'directory-builder').'</span>
						</div>
					</div>';
				}
			} else {
				$listing_featured_image = get_post_thumbnail_id(intval($_GET['edit-listing']));
				$listing_gallery_images = get_post_meta( intval($_GET['edit-listing']), 'listing_gallery_img', true );
			}
			
			$field_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_fields WHERE field_active="yes" ORDER BY field_order ASC');
			if ( !empty($field_list) ) {
				$default_location = $main_settings['default_location'];
				$default_location_lat = $main_settings['default_location_lat'];
				$default_location_lng = $main_settings['default_location_lng'];

				foreach ($field_list as $field_value) {
					$field_settings = json_decode($field_value->field_settings, true);

					$listing_field_default = '';
					if ( $db_edit_listing ) {
						$listing_field_default = get_post_meta( intval($_GET['edit-listing']), sanitize_text_field($field_settings['field_name']), true );
					}

					if ( !$db_edit_listing ) {
						if ( $field_settings['field_name'] == 'listing_address' ) {
							$listing_field_default = $default_location;
						} else if ( $field_settings['field_name'] == 'listing_address_lat' ) {
							$listing_field_default = $default_location_lat;
						} else if ( $field_settings['field_name'] == 'listing_address_lng' ) {
							$listing_field_default = $default_location_lng;
						}
					}

					if ( isset($_POST[$field_settings['field_name']]) ) {
						$listing_field_default = sanitize_text_field($_POST[$field_settings['field_name']]);
					}

					if ( $field_settings['field_name'] == 'listing_address' ) {
						$output .= '<div class="db-field-custom-row clearfix">';
					}

					if ( $field_settings['field_name'] == 'listing_address_lat' ) {
						$output .= '<div id="db-listing-map" style="width: calc(66.66% - 10px); height: 300px;"></div>';
						$output .= '<div class="db-map-row">';
					}

					$output .= db_get_custom_field( $field_settings, '', $listing_field_default, true );

					if ( $field_settings['field_name'] == 'listing_country' ) {
						$output .= '</div>';
					}

					if ( $field_settings['field_name'] == 'listing_address_lng' ) {
						$output .= '<a href="javascript:void(0)" class="db-set-address dt-button dt-button-invert">'.__('Set address on map', 'directory-builder').'</a>';
						$output .= '</div>';

						wp_enqueue_script( 'jquery.dropzone' );

						$output .= '<div class="db-field-upload-row-wrapper clearfix">';

						$output .= "
							<script type='text/javascript'>
							jQuery(document).ready(function($) {
								if ( jQuery('.dropzone-featured').length ) {
									jQuery('div.dropzone-featured').dropzone({
										url: db_main.ajaxurl,
										maxFiles: 1,
										acceptedFiles: '.jpg,.jpeg,.gif,.png',
										addRemoveLinks: true,
										dictRemoveFile: 'Remove image',
										thumbnailWidth: 150,
										thumbnailHeight: 150,
										init: function() {
											this.on('sending', function(file, xhr, formData) {
												formData.append('action', 'db_upload_images');
											});";

											if ( $db_edit_listing && isset($listing_featured_image) && $listing_featured_image != '' ) {
												$featured_image_url = wp_get_attachment_url($listing_featured_image);
												$featured_image_size = filesize(get_attached_file($listing_featured_image));

												$output .= "
												var mockFile = { 
													name: '".basename($featured_image_url)."', 
													size: '".$featured_image_size."', 
													type: 'image/jpeg', 
													status: Dropzone.ADDED, 
													url: '".$featured_image_url."' 
												};
												this.emit('addedfile', mockFile);
												this.emit('thumbnail', mockFile, '".$featured_image_url."');
												this.files.push(mockFile);";
											}
										$output .= "
										},
										success: function(file, response) {
											var parsed_response = jQuery.parseJSON(response);
											var current_image = jQuery(jQuery(this)['0'].files['0'].previewElement);
											if ( parsed_response.save_status == 'true' ) {
												current_image.addClass('dz-success').removeClass('dz-error');
												jQuery('[name=\"listing_featured_img\"]').val(parsed_response.attachment_id);
												current_image.attr('data-id', parsed_response.attachment_id);
											} else if ( parsed_response.save_status == 'false' ) {
												current_image.removeClass('dz-success').addClass('dz-error');
												current_image.find('.dz-error-message span').html(parsed_response.save_msg);
												current_image.attr('data-id', '0');
											}

										},
										removedfile: function(removed) {
											jQuery('[name=\"listing_featured_img\"]').val('');
											jQuery(removed.previewElement).remove();
										}
									});
								}

								if ( jQuery('.dropzone-gallery').length ) {
									jQuery('div.dropzone-gallery').dropzone({
										url: db_main.ajaxurl,
										acceptedFiles: '.jpg,.jpeg,.gif,.png',
										addRemoveLinks: true,
										dictRemoveFile: 'Remove image',
										thumbnailWidth: 150,
										thumbnailHeight: 150,
										init: function() {
											this.on('sending', function(file, xhr, formData) {
												formData.append('action', 'db_upload_images');
											});";

											if ( $db_edit_listing && isset($listing_gallery_images) && $listing_gallery_images != '' ) {
												$featured_gallery_images = explode( '|', $listing_gallery_images );
												if ( !empty($featured_gallery_images) ) {
													$gallery_loops = 1;
													foreach ($featured_gallery_images as $gallery_image_id) {
														if ( $gallery_image_id == '' ) {
															continue;
														}

														$featured_gallery_image_url = wp_get_attachment_url($gallery_image_id);
														$featured_image_size = filesize(get_attached_file($gallery_image_id));

														$output .= "
														var mockFile".$gallery_loops." = { 
															name: '".basename($featured_gallery_image_url)."', 
															size: '".$featured_image_size."', 
															type: 'image/jpeg', 
															status: Dropzone.ADDED, 
															url: '".$featured_gallery_image_url."' 
														};
														this.emit('addedfile', mockFile".$gallery_loops.");
														this.emit('thumbnail', mockFile".$gallery_loops.", '".$featured_gallery_image_url."');
														this.emit('complete', mockFile".$gallery_loops.");
														this.files.push(mockFile".$gallery_loops.");";

														$gallery_loops++;
													}

													$output .= "
													var gallery_images = jQuery('[name=\"listing_gallery_img\"]').val().split('|');
													jQuery.each(gallery_images, function(gindex, gval) {
														var current_preview = jQuery(jQuery('[name=\"listing_gallery_img\"]').parent().find('.dz-preview').get(gindex));
														current_preview.attr('data-id', gval);
														current_preview.addClass('dz-success');
													});";
												}
											}
										$output .= "
										},
										success: function(file, response) {
											var parsed_response = jQuery.parseJSON(response);
											var image_count = jQuery('[name=\"listing_gallery_img\"]').val().split('|').length-1;
											console.log(image_count);
											var current_image = jQuery(jQuery(this)['0'].files[image_count].previewElement);

											if ( parsed_response.save_status == 'true' ) {
												current_image.addClass('dz-success').removeClass('dz-error');
												jQuery('[name=\"listing_gallery_img\"]').val(jQuery('[name=\"listing_gallery_img\"]').val()+parsed_response.attachment_id+'|');
												current_image.attr('data-id', parsed_response.attachment_id);
											} else if ( parsed_response.save_status == 'false' ) {
												current_image.removeClass('dz-success').addClass('dz-error');
												current_image.find('.dz-error-message span').html(parsed_response.save_msg);
												current_image.attr('data-id', '0');
											}
										},
										removedfile: function(removed) {
											var removed_image = jQuery(removed.previewElement);
											var current_images = jQuery('[name=\"listing_gallery_img\"]').val();
											if ( current_images.indexOf( removed_image.attr('data-id') + '|' ) >= 0 ) {
												jQuery('[name=\"listing_gallery_img\"]').val( current_images.replace( removed_image.attr('data-id') + '|', '' ) );
											}
											jQuery(removed.previewElement).remove();
										}
									});
								}
							});
							</script>";
							$output .= '<div class="db-field-upload-row">';
								$output .= '<h3>'.__('Featured image', 'directory-builder').'</h3>';
								$output .= '
								<div class="db-field-upload-container dropzone-upload dropzone-featured">
									<span class="db-upload-placeholder">'.__('Drag an image here or <a>browse</a> for the image to upload.', 'directory-builder').'</span>
									<div class="clearfix"></div>
									<input type="hidden" name="listing_featured_img" value="'.(isset($listing_featured_image)?$listing_featured_image:'').'">
								</div>
								<span class="db-file-upload-hint">'.__('JPG, GIF or PNG. Featured images are 1000x1000 pixels.', 'directory-builder').'</span>';
							$output .= '</div>';
							if ( $main_settings['allow_images'] ) {
								$output .= '<div class="db-field-upload-row">';
									$output .= '<h3>'.__('Gallery images', 'directory-builder').'</h3>';
									$output .= '
									<div class="db-field-upload-container dropzone-upload dropzone-gallery">
										<span class="db-upload-placeholder">'.__('Drag an image here or <a>browse</a> for the image to upload.', 'directory-builder').'</span>
										<div class="clearfix"></div>
										<input type="hidden" name="listing_gallery_img" value="'.(isset($listing_gallery_images)&&$listing_gallery_images!=''?(substr($listing_gallery_images, -1)!='|'?$listing_gallery_images.'|':$listing_gallery_images):'').'">
									</div>
									<span class="db-file-upload-hint">'.__('JPG, GIF or PNG. Featured images are 1000x1000 pixels.', 'directory-builder').'</span>
									<span class="db-file-upload-limit" data-limit="0">'.__('You have uploaded too many images, the limit is ', 'directory-builder').'</span>';
								$output .= '</div>';
							}
							$output .= '<div class="clearfix"></div>';
						$output .= '</div>';
					}
				}
			}

			if ( isset($main_settings['listing_menu']) && $main_settings['listing_menu'] === true ) {
				if ( $db_edit_listing ) {
					$listing_fmenu_json = get_post_meta( intval($_GET['edit-listing']), 'listing_fmenu', true );
					$listing_fmenu = (isset($listing_fmenu_json)&&$listing_fmenu_json!=''?json_decode($listing_fmenu_json, true):false);
				}

				$output .= '
				<div class="db-field-row db-fmenu-row clearfix" data-for="'.(isset($main_settings['listing_menu_cat'])&&$main_settings['listing_menu_cat']!=''?implode(',',$main_settings['listing_menu_cat']):array()).'">
					<h3>'.esc_html__('Full menu', 'directory-builder').'</h3>
					<span class="db-field-row-desc">'.esc_html__('Menu consists of categories that are broken down into individual items. You can create unlimited amount of categories and items.', 'directory-builder').'</span>
					<div class="db-fmenu-wrapper">';
						if ( $db_edit_listing && $listing_fmenu !== false && !empty($listing_fmenu) ) {
							foreach ($listing_fmenu as $fmenu_items) {
								$output .= '
								<div class="db-fmenu-full-cat">
									<input type="text" class="db-fmenu-cat-name" placeholder="'.esc_html__('Category', 'directory-builder').'" value="'.esc_attr($fmenu_items['name']).'">
									<a href="javascript:void(0)" class="db-fmenu-cat-delete"><svg width="9px" height="9px" viewBox="0 0 9 9" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" stroke-linecap="square"> <g id="Add-listing" transform="translate(-1261.000000, -2150.000000)" stroke="#9B9B9B" stroke-width="2"> <g id="Full-menu" transform="translate(145.000000, 2037.000000)"> <g id="cross" transform="translate(1117.000000, 114.000000)"> <path d="M0.5,0.5 C0.5,0.5 1.47029385,1.47029385 2.65893276,2.65893276 L6.62354462,6.62354462" id="Line" fill="#D8D8D8"></path> <path d="M6.5,0.5 C6.5,0.5 5.52970615,1.47029385 4.34106724,2.65893276 L0.376455383,6.62354462" id="Line-Copy-2"></path> </g> </g> </g> </g> </svg></a>
									<div class="db-fmenu-cat-items">';
										if ( !empty($fmenu_items['items']) ) {
											foreach ($fmenu_items['items'] as $fmenu_item) {
												$output .= '
												<div class="db-fmenu-cat-item">
													<input type="text" class="db-fmenu-item-name" placeholder="'.esc_html__('Item name','directory-builder').'" value="'.esc_attr($fmenu_item['name']).'">
													<input type="text" class="db-fmenu-item-desc" placeholder="'.esc_html__('Description','directory-builder').'" value="'.esc_attr($fmenu_item['desc']).'">
													<input type="text" class="db-fmenu-item-price" placeholder="'.esc_html__('Price','directory-builder').'" value="'.esc_attr($fmenu_item['price']).'">
													<a href="javascript:void(0)" class="db-fmenu-cat-item-delete"><svg width="9px" height="9px" viewBox="0 0 9 9" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" stroke-linecap="square"> <g id="Add-listing" transform="translate(-1261.000000, -2150.000000)" stroke="#9B9B9B" stroke-width="2"> <g id="Full-menu" transform="translate(145.000000, 2037.000000)"> <g id="cross" transform="translate(1117.000000, 114.000000)"> <path d="M0.5,0.5 C0.5,0.5 1.47029385,1.47029385 2.65893276,2.65893276 L6.62354462,6.62354462" id="Line" fill="#D8D8D8"></path> <path d="M6.5,0.5 C6.5,0.5 5.52970615,1.47029385 4.34106724,2.65893276 L0.376455383,6.62354462" id="Line-Copy-2"></path> </g> </g> </g> </g> </svg></a>
												</div>';
											}
										}
										$output .= '
										<a href="javascript:void(0)" class="db-fmenu-new-item button-primary button-large">'.esc_html__('Add item','directory-builder').'</a>
										<div class="clearfix"></div>
									</div>
								</div>';
							}
						}
						$output .= '
						<a href="javascript:void(0)" class="db-fmenu-new-cat dt-button dt-button-invert">'.esc_html__('Add category','directory-builder').'</a>
						<input type="hidden" id="listing_fmenu" name="listing_fmenu" value="'.(isset($listing_fmenu_json)?esc_attr($listing_fmenu_json):'').'">
						<div class="db-fmenu-hidden">
							<div class="db-fmenu-full-cat">
								<input type="text" class="db-fmenu-cat-name" placeholder="'.esc_html__('Category', 'directory-builder').'">
								<a href="javascript:void(0)" class="db-fmenu-cat-delete"><svg width="9px" height="9px" viewBox="0 0 9 9" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" stroke-linecap="square"> <g id="Add-listing" transform="translate(-1261.000000, -2150.000000)" stroke="#9B9B9B" stroke-width="2"> <g id="Full-menu" transform="translate(145.000000, 2037.000000)"> <g id="cross" transform="translate(1117.000000, 114.000000)"> <path d="M0.5,0.5 C0.5,0.5 1.47029385,1.47029385 2.65893276,2.65893276 L6.62354462,6.62354462" id="Line" fill="#D8D8D8"></path> <path d="M6.5,0.5 C6.5,0.5 5.52970615,1.47029385 4.34106724,2.65893276 L0.376455383,6.62354462" id="Line-Copy-2"></path> </g> </g> </g> </g> </svg></a>
								<div class="db-fmenu-cat-items">
									<div class="db-fmenu-cat-item">
										<input type="text" class="db-fmenu-item-name" placeholder="'.esc_html__('Item name','directory-builder').'">
										<input type="text" class="db-fmenu-item-desc" placeholder="'.esc_html__('Description','directory-builder').'">
										<input type="text" class="db-fmenu-item-price" placeholder="'.esc_html__('Price','directory-builder').'">
										<a href="javascript:void(0)" class="db-fmenu-cat-item-delete"><svg width="9px" height="9px" viewBox="0 0 9 9" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" stroke-linecap="square"> <g id="Add-listing" transform="translate(-1261.000000, -2150.000000)" stroke="#9B9B9B" stroke-width="2"> <g id="Full-menu" transform="translate(145.000000, 2037.000000)"> <g id="cross" transform="translate(1117.000000, 114.000000)"> <path d="M0.5,0.5 C0.5,0.5 1.47029385,1.47029385 2.65893276,2.65893276 L6.62354462,6.62354462" id="Line" fill="#D8D8D8"></path> <path d="M6.5,0.5 C6.5,0.5 5.52970615,1.47029385 4.34106724,2.65893276 L0.376455383,6.62354462" id="Line-Copy-2"></path> </g> </g> </g> </g> </svg></a>
									</div>
									<div class="db-fmenu-cat-item">
										<input type="text" class="db-fmenu-item-name" placeholder="'.esc_html__('Item name','directory-builder').'">
										<input type="text" class="db-fmenu-item-desc" placeholder="'.esc_html__('Description','directory-builder').'">
										<input type="text" class="db-fmenu-item-price" placeholder="'.esc_html__('Price','directory-builder').'">
										<a href="javascript:void(0)" class="db-fmenu-cat-item-delete"><svg width="9px" height="9px" viewBox="0 0 9 9" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" stroke-linecap="square"> <g id="Add-listing" transform="translate(-1261.000000, -2150.000000)" stroke="#9B9B9B" stroke-width="2"> <g id="Full-menu" transform="translate(145.000000, 2037.000000)"> <g id="cross" transform="translate(1117.000000, 114.000000)"> <path d="M0.5,0.5 C0.5,0.5 1.47029385,1.47029385 2.65893276,2.65893276 L6.62354462,6.62354462" id="Line" fill="#D8D8D8"></path> <path d="M6.5,0.5 C6.5,0.5 5.52970615,1.47029385 4.34106724,2.65893276 L0.376455383,6.62354462" id="Line-Copy-2"></path> </g> </g> </g> </g> </svg></a>
									</div>
									<div class="db-fmenu-cat-item">
										<input type="text" class="db-fmenu-item-name" placeholder="'.esc_html__('Item name','directory-builder').'">
										<input type="text" class="db-fmenu-item-desc" placeholder="'.esc_html__('Description','directory-builder').'">
										<input type="text" class="db-fmenu-item-price" placeholder="'.esc_html__('Price','directory-builder').'">
										<a href="javascript:void(0)" class="db-fmenu-cat-item-delete"><svg width="9px" height="9px" viewBox="0 0 9 9" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" stroke-linecap="square"> <g id="Add-listing" transform="translate(-1261.000000, -2150.000000)" stroke="#9B9B9B" stroke-width="2"> <g id="Full-menu" transform="translate(145.000000, 2037.000000)"> <g id="cross" transform="translate(1117.000000, 114.000000)"> <path d="M0.5,0.5 C0.5,0.5 1.47029385,1.47029385 2.65893276,2.65893276 L6.62354462,6.62354462" id="Line" fill="#D8D8D8"></path> <path d="M6.5,0.5 C6.5,0.5 5.52970615,1.47029385 4.34106724,2.65893276 L0.376455383,6.62354462" id="Line-Copy-2"></path> </g> </g> </g> </g> </svg></a>
									</div>
									<a href="javascript:void(0)" class="db-fmenu-new-item">'.esc_html__('Add item','directory-builder').'</a>
									<div class="clearfix"></div>
								</div>
							</div>
						</div>
					</div>
				</div>';
			}

			if ( !$db_edit_listing && !is_user_logged_in() ) {
				$register_setting = $main_settings['add_listing_register'];

				$login_required = (!$register_setting?' required':'');

				global $db_user_login;
				if ( !$register_setting && $db_user_login ) {
					if ( is_wp_error( $db_user_login ) ) {
						$register_message = '<p>'.$db_user_login->get_error_message().'</p>';
					}
				}

				$output .= '
				<div class="db-register-wrapper">'
					.$register_message.'
					<div class="db-register-login">';
						if ( !$register_setting ) {
							$output .= '
							<div class="db-field-row db-login-username">'
								. __('Already have an account? Go ahead and sign in now!', 'directory-builder').'
								<label class="db-field-row-label" for="register_user_email">'.__('Your username', 'directory-builder').'</label>
								<input type="text" name="login_user_email" placeholder="'.__('Your username', 'directory-builder').'"'.$login_required.'>
							</div>
							<div class="db-field-row">
								<label class="db-field-row-label" for="login_user_password">'.__('Your password', 'directory-builder').'</label>
								<input type="password" name="login_user_password" placeholder="'.__('Your password', 'directory-builder').'"'.$login_required.'>
								<input type="submit" name="db-sign-in" value="'.__('Sign in', 'directory-builder').'">
							</div>';
						}
					if ( $register_setting ) {
						$login_url = get_permalink($main_settings['login_page_id']);

						$reg_fields = array();
						if ( function_exists('db_get_registration_fields') ) {
							$reg_fields = db_get_registration_fields( 'add_listing' );
						}
						
						$output .= '
						<div class="db-field-row db-register-email">'.
							__('Already have an account? Go ahead and', 'directory-builder').' <a href="'.$login_url.'">'.__('sign in', 'directory-builder').'</a> '.__('now!', 'directory-builder').' '.
							__('Or you can simply register with your details below!', 'directory-builder');
							if ( !empty( $reg_fields ) ) {
								foreach ($reg_fields as $field_id => $field_settings) {
									$output .= '<div class="db-field-row'.($field_settings['field_type']=='select'?' single-select':'').'"><label class="db-field-row-label" for="'.$field_settings['field_name'].'">'.$field_settings['frontend_title'].'</label>';
									$output .= $field_settings['field_html'];
									$output .= '</div>';
								}
							}
						$output .= '
						</div>';
					}
				$output .= '
					</div>
				</div>';
			}

			$gcaptcha_options = get_option( 'gglcptch_options', array() );
			if ( function_exists( 'gglcptch_init' ) && isset( $gcaptcha_options['public_key'] ) && $gcaptcha_options['public_key'] != '' && isset( $gcaptcha_options['private_key'] ) && $gcaptcha_options['private_key'] != '' ) {
				$output .= '<div class="db-field-row"><h3>'.__('Are you human?', 'directory-builder').'</h3>' . do_shortcode( '[bws_google_captcha]' ) . '</div>';
			}

			if ( $main_settings['payment_active'] == 'yes' && !$db_edit_listing ) {
				$package_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_packages ORDER BY ID ASC');
				if ( !empty($package_list) ) {
					$output .= '<div class="db-field-row"><h3>'.__('Listing package', 'directory-builder').'</h3>';
					$output .= '<ul class="db-payment-packages">';

					$output .= '<li data-for="" style="display: none;width: 100%;">
							<p>'.__('Please select a category to see the available plans for it!', 'directory-builder').'</p>
						</li>';

					foreach ($package_list as $package_value) {
						$package_settings = json_decode($package_value->package_settings, true);
						$output .= '
						<li data-for="'.implode(',', isset($package_settings['apply_categories'])?$package_settings['apply_categories']:array()).'" class="'.($package_settings['listing_popular']?'popular':'').'" style="display: none;">
							<div class="db-package-inner">
								<label for="db-package-'.$package_value->ID.'"><input type="radio" id="db-package-'.$package_value->ID.'" name="listing_package" value="'.$package_value->ID.'"> '.$package_value->package_name.'</label>';
								if ( $package_settings['fee_description'] != '' ) {
									if ( $package_settings['listing_run_type'] == 'forever' ) {
										$run_listing = __('forever','directory-builder');
									} else {
										$run_listing = $package_settings['listing_run_days'].' '.__('days','directory-builder');
									}
									$active_ad_packages = db_get_ad_packages();
									if ( !defined('WHITELAB_CUSTOM_ADD_LISTING') ) {
										$output .= '<div class="db-fee-description">
											<span class="db-fee-status-description">'.$package_settings['fee_description'].'</span>
											<span class="db-fee-status-name">'.__('Package price','directory-builder').': '.$main_settings['default_currency_symbol'].$package_settings['fee_amount'].'</span>
											<span class="db-fee-status-name">'.__('Run listing for','directory-builder').': '.$run_listing.'</span>
											<span class="db-fee-status-name">'.__('Images allowed','directory-builder').': '.$package_settings['image_amount'].'</span>
											<span class="db-fee-status-name">'.__('Listing featured?','directory-builder').': '.$package_settings['listing_sticky'].'</span>';
											if ( in_array($package_value->ID, $active_ad_packages) ) {
												$output .= '<span class="db-fee-status-name">'.__('Includes advertisements','directory-builder').'</span>';
											}
										$output .= '
										</div>';
									} else {
										$output .= '
										<div class="db-fee-description">';
											if ( isset($package_settings['package_img']) && $package_settings['package_img'] != '' ) {
												$output .= '<img src="'.preg_replace('#^https?://#', '//', $package_settings['package_img']).'" class="db-fee-image">';
											}
											$output .= '
											<span class="db-fee-value">'.($package_settings['fee_amount']!='0'?$main_settings['default_currency_symbol'].$package_settings['fee_amount']:__('Free', 'directory-builder')).'</span>
											<span class="db-fee-description">'.$package_settings['fee_description'].'</span>';
											$output .= '<div class="db-package-desc">';
											if ( !isset($package_settings['payment_type']) || $package_settings['payment_type'] == 'onetime' ) {
												$output .= '<span class="db-fee-pay">'.__('One Time Payment','directory-builder').'</span>';
												$output .= '<span class="db-fee-run-for">'.__('Run listing for','directory-builder').' '.$run_listing.'</span>';
											} else if ( isset($package_settings['payment_type']) || $package_settings['payment_type'] == 'recurring' ) {
												if ( $package_settings['payment_interval'] == 1 ) {
													$payment_cycle = sprintf( __( 'Recurring payment once a %s', 'directory-builder' ), rtrim( $package_settings['payment_cycle'], 's' ) );
												} else {
													$payment_cycle = sprintf( __( 'Recurring payment every %d %s', 'directory-builder' ), $package_settings['payment_interval'], $package_settings['payment_cycle'] );
												}

												$output .= '<span class="db-fee-pay">'.$payment_cycle.'</span>';
											}
											$output .= '
											<span class="db-fee-images">'.$package_settings['image_amount'].' '.__('Images allowed','directory-builder').'</span>';
											if ( $package_settings['listing_sticky'] === true ) {
												$output .= '<span class="db-fee-sticky">'.__('Featured listing','directory-builder').'</span>';
											}
											if ( in_array($package_value->ID, $active_ad_packages) ) {
												$output .= '<span class="db-package-extra">'.__('Includes advertisements','directory-builder').'</span>';
											}
											$output .= '</div>';
										$output .= '
											<a href="javascript:void(0)" class="db-choose-package" data-id="'.$package_value->ID.'" data-images="'.intval($package_settings['image_amount']).'">'.__('Choose', 'directory-builder').'</a>
										</div>';
									}
								}
						$output .= '
							</div>   
						</li>';
					}
					$output .= '</ul><input type="hidden" name="db-active-package" value=""><div class="clearfix"></div></div>';
				} else {
					$output .= '<ul class="db-payment-packages">';

					$output .= '<li data-for="" style="width: 100%;">
							<p><strong>Please add some packages in the directory builder settings.</strong></p>
						</li>
						</ul>';
				}
			} elseif (($main_settings['payment_active'] == 'no' && !$db_edit_listing) || ($main_settings['payment_active'] == NULL && !$db_edit_listing)) {
				$output .= '<ul class="db-payment-packages">';

					$output .= '<li data-for="" style="width: 100%;">
							<p><strong>Payments are turned off in the settings, can\'t add listing. Please turn on payments in the directory builder settings.</strong></p>
						</li>
						</ul>';
			}

			if ( $main_settings['terms_and_conditions_status'] && !$db_edit_listing && $main_settings['db_theme_id'] != 'db_theme' ) {
				$output .= '<div class="db-field-row terms-and-conditions required">
					<label>'.__('Terms and conditions', 'directory-builder').'</label>
					<div class="db-terms-and-conditions">'.$main_settings['terms_and_conditions'].'</div>
					<label for="listing_terms_and_conditions"><input type="checkbox" id="listing_terms_and_conditions">'.__('I accept terms and conditions!', 'directory-builder').'</label>
				</div>';
			}

		$output .= '
			<input type="submit" value="'.(!$db_edit_listing?__('Add listing', 'directory-builder'):__('Save listing', 'directory-builder')).'" '.($db_edit_listing?'style="display: block;" class="db-edit-listing"':'').'>
		</form>';

	$output .= '</div>';

	return $output;
}
add_shortcode('directory_add_listing','db_add_listing_shortcode');

function db_get_ad_packages() {
	global $wpdb;
	$all_packages = $wpdb->get_results( 'SELECT packages FROM ' . $wpdb->prefix . 'directory_ads WHERE status="true"' );
	if ( !empty($all_packages) ) {
		$ad_packages = array();
		foreach ($all_packages as $package_value) {
			$current_ad_packages = json_decode( $package_value->packages, true );

			if ( !empty($current_ad_packages) ) {
				foreach ($current_ad_packages as $package_id) {
					$ad_packages[] = $package_id;
				}
			}
		}

		$all_packages = array_unique($ad_packages);
	}

	return $all_packages;
}

function db_sort_terms_hierarchicaly(Array &$cats, Array &$into, $parentId = 0) {
	foreach ($cats as $i => $cat) {
		if ($cat->parent == $parentId) {
			$into[$cat->term_id] = $cat;
			unset($cats[$i]);
		}
	}

	foreach ($into as $topCat) {
		$topCat->children = array();
		db_sort_terms_hierarchicaly($cats, $topCat->children, $topCat->term_id);
	}
}

function db_display_categories( $cat_data, $active_categories = array() ) {
	$output = '';
	foreach ($cat_data->children as $child_value) {
		$parents = get_category_parents($child_value->term_id);
		$parents_exploded = explode('/', $parents);
		$depth = count($parents_exploded)-2;
		$depth_str = '';
		for ($i=0; $i < $depth; $i++) { 
			$depth_str .= '-';
		}

		$output .= '<div class="dt-custom-select-item child '.(in_array($child_value->term_id, $active_categories)?'active':'').'" data-value="'.$child_value->term_id.'" data-depth="'.$depth_str.' ">'.$child_value->name.'</div>';

		if ( !empty( $child_value->children ) ) {
			$output .= db_display_categories( $child_value );
		}
	}

	return $output;
}

function db_inspect_scripts() {
	global $wp_scripts;

	if ( !empty($wp_scripts->registered) ) {
		foreach ($wp_scripts->registered as $script_key => $script_value) {
			if ( strpos($script_value->src, 'maps.googleapis.com/maps') !== false && $script_key != 'db-google-maps' ) {
				wp_dequeue_script( $script_key );
			}
			
		}
	}
}
add_action( 'wp_print_scripts', 'db_inspect_scripts' );

function db_add_listing_columns( $columns_ ) {
	$columns = array();

	foreach ( $columns_ as $k => $v ) {
		$columns[ $k ] = $v;
		if ( $k == 'cb' ) {
			$columns['payment_status'] = __( 'Status', 'directory-builder' );
		} else if ( $k == 'title' ) {
			$columns['listing_address'] = __( 'Address', 'directory-builder' );
			$columns['listing_author'] = __( 'Author', 'directory-builder' );
		}
	}

	return $columns;
}
add_action( 'manage_listings_posts_columns', 'db_add_listing_columns' );

function db_add_listing_payment_column( $column_name, $listing_id ) {
	if ( $column_name == 'payment_status' ) {
		$listing_data = get_post_meta( $listing_id, 'db_order_info', true );
		$status_class = 'dbicon-info';
		$payment_status = (isset($listing_data['payment_status'])?$listing_data['payment_status']:'');
		
		if ( $payment_status == 'Pending' ) {
			$status_class = 'dbicon-cancel-circled2';
		} else if ( $payment_status == 'Completed' ) {
			$status_class = 'dbicon-ok-circled2';
		} else if ( $payment_status == 'Refunded' ) {
			$status_class = 'dbicon-cancel-circled2';
		}
		
		echo '<span class="db-listing-status '.$status_class.' '.strtolower($payment_status).'"></span><div class="row-actions"><span class="db-listing-payment-status">'.($payment_status?$payment_status:__('Processing', 'directory-builder')).'</span></div>';
	} else if ( $column_name == 'listing_author' ) {
		$post_data = get_post($listing_id);
		echo '<a href="'.admin_url('user-edit.php?user_id='.$post_data->post_author).'">'.get_the_author_meta('nicename', $post_data->post_author).'</a>';
	} else if ( $column_name == 'listing_address' ) {
		echo get_post_meta( $listing_id, 'listing_address', true );
	}
}
add_action( 'manage_listings_posts_custom_column', 'db_add_listing_payment_column', 10, 2 );

function db_change_package_func() {
	if ( !current_user_can('manage_options') ) die(0);

	$listing_id = ( isset($_POST['listing_id']) ? intval($_POST['listing_id']) : '' );
	$package_id = ( isset($_POST['package_id']) ? intval($_POST['package_id']) : '' );
	$package_name = ( isset($_POST['package_name']) ? sanitize_text_field($_POST['package_name']) : '' );

	if ( isset($package_id) && $package_id != '' ) {
		global $wpdb;
		$selected_package = $wpdb->get_results( 'SELECT * FROM ' . $wpdb->prefix . 'directory_packages WHERE ID="'.$package_id.'"' );

		if ( !empty($selected_package) ) {
			$package_settings = json_decode( $selected_package['0']->package_settings, true );
			$listing_info = get_post_meta( $listing_id, 'db_order_info', true );
			$main_settings = get_option( 'db_main_settings');

			$listing_info['listing_package'] = $package_id;
			$listing_info['listing_package_name'] = $package_name;
			$listing_info['paid_amount'] = $main_settings['default_currency_symbol'].$package_settings['fee_amount'];

			if ( update_post_meta( $listing_id, 'db_order_info', $listing_info ) ) {
				echo '{"save_response": "0", "package_name": "'.$package_name.'", "paid": "'.$main_settings['default_currency_symbol'].$package_settings['fee_amount'].'"}';
			} else {
				echo '{"save_response": "failed"}';
			}
		} else {
			echo '{"save_response": "failed"}';
		}
	}

	die(0);
}
add_action( 'wp_ajax_db_change_package', 'db_change_package_func' );

function db_change_expiration_func() {
	if ( !current_user_can('manage_options') ) die(0);

	$listing_id = ( isset($_POST['listing_id']) ? intval($_POST['listing_id']) : '' );
	$new_date = ( isset($_POST['new_date']) ? sanitize_text_field($_POST['new_date']) : '' );

	$listing_info = get_post_meta( $listing_id, 'db_order_info', true );
	global $wpdb;
	$save_expiration = false;

	$listing_info['listing_expires'] = strtotime($new_date);
	$save_expiration = update_post_meta( $listing_id, 'db_order_info', $listing_info );

	if ( $save_expiration ) {
		echo '{"save_response": "0", "package_name": "'.date( get_option('date_format'), $listing_info['listing_expires']).'"}';
	} else {
		echo '{"save_response": "failed"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_change_expiration', 'db_change_expiration_func' );

function db_check_my_profile_form() {
	global $update_message;

	if ( isset($_POST['action']) && sanitize_key($_POST['action']) == 'edit-profile' ) {
		$user_new_data = array(
			'ID' => get_current_user_id(),
			'display_name' => sanitize_text_field($_POST['display_name']),
			'user_email' => sanitize_email($_POST['user_email'])
			);

		$proceed_with_update = true;
		if ( isset($_POST['user_password']) && $_POST['user_password'] != '' ) {
			if ( isset($_POST['user_conf_password']) && $_POST['user_password'] == $_POST['user_conf_password'] ) {
				$user_new_data['user_pass'] = $_POST['user_password'];
			} else {
				$update_message = '<span class="db-update-message error">'.__('Passwords did not match!', 'directory-builder').'</span>';
				$proceed_with_update = false;
			}
		}

		if ( $proceed_with_update ) {
			$user_update = wp_update_user( $user_new_data );

			if ( is_wp_error( $user_update ) ) {
				$update_message = '<span class="db-update-message error">'.$user_update->get_error_message().'</span>';
			} else {
				$update_message = '<span class="db-update-message success">'.__('Your profile was successfully updated!', 'directory-builder').'</span>';
			}
		}
	}
}
add_action('init', 'db_check_my_profile_form');

function db_account_shortcode( $atts, $content = null ) {
	$main_settings = get_option( 'db_main_settings');

	$output = '<div class="db-main-wrapper">
		<link href="https://fonts.googleapis.com/css?family=Open+Sans:300,400,600" rel="stylesheet">';
	if ( !is_user_logged_in() ) {
		if ( isset($_GET['key']) ) {
			$key_check = check_password_reset_key($_GET['key'], $_GET['login']);
			
			if ( is_wp_error($key_check) ) {
				return '<p class="aligncenter">' . esc_html__( 'We\'re sorry but there has been an error', 'directory-builder' ) . ': <strong>' . $key_check->get_error_message() . '</strong></p>';
			} else {
				global $db_lost_password;
				$output .= '
				<p class="aligncenter">' . esc_html__( 'Please enter your new password!', 'directory-builder' ) . '</p>
				<form method="post" class="db-account-lost-pass">
					'.$db_lost_password.'
					<input type="password" name="db-account-pass" placeholder="'.esc_html__('Password', 'directory-builder').'" required>
					<input type="password" name="db-account-pass2" placeholder="'.esc_html__('Confirm password', 'directory-builder').'" required>
					<input type="submit" value="'.esc_html__('Change', 'directory-builder').'">
				</form>';
			}
		} else if ( isset($_GET['validation']) ) {
			$actual_validation_code = get_user_meta( intval($_GET['user']), 'db_validation', true );
			if ( $actual_validation_code === esc_attr($_GET['validation']) ) {
				update_user_meta( intval($_GET['user']), 'db_validation', 'validated' );

				$main_settings = get_option( 'db_main_settings', array() );
				if ( function_exists( 'db_send_notification_email' ) ) {
					db_send_notification_email( intval($_GET['user']), 'new_user', array( 'username' => get_user_meta( intval($_GET['user']), 'nickname', true ), 'url_dashboard' => get_permalink( $main_settings['account_page_id'] ) ) );
				}

				echo '<p class="aligncenter">' . esc_html__( 'You successfully validated your email and can now login to your account!', 'directory-builder' ) . '</p>';
			} else {
				echo '<p class="aligncenter">' . esc_html__( 'The validation code for your account seems to be invalid!!', 'directory-builder' ) . '</p>';
			}
		} else {
			$output .= '<p>'.__('Only logged in users can access this page!', 'directory-builder').'</p>';
		}
	} else {
		$main_dashboard = false;
		if ( get_option('permalink_structure') ) {
			if ( empty($_GET) ) {
				$main_dashboard = true;
			}
		} else {
			if ( count($_GET) === 1 ) {
				$main_dashboard = true;
			}
		}

		global $wpdb;
		if ( !isset($_GET['edit-listing']) ) {
			$listing_limit = '6';
			if ( isset($_GET['my-listings']) || ( isset($_GET['bookings']) && $_GET['bookings'] == 'all' ) ) {
				if ( !isset( $_GET['db-page'] ) || intval( $_GET['db-page'] ) == 1 ) {
					$listing_limit = '25';
				} else {
					$listing_limit = (intval( $_GET['db-page'] )-1)*25 . ', 25';
				}
			}
			$user_listings = $wpdb->get_results('SELECT * FROM '.$wpdb->posts.' WHERE post_type="listings" && ( post_status != "auto-draft" && post_status != "trash" ) && post_author="'.get_current_user_id().'" ORDER BY id DESC LIMIT '.$listing_limit);
		} else {
			$user_listings = $wpdb->get_results('SELECT * FROM '.$wpdb->posts.' WHERE id="'.intval($_GET['edit-listing']).'" && post_author="'.get_current_user_id().'" ORDER BY id DESC');
		}

		$users_are_allowed = $main_settings['users_are_allowed'];

		wp_enqueue_script( 'jquery.mo' );

		$output .= '
		<div class="db-account-wrapper">
		<ul class="db-account-menu">
			<li><a href="'.get_permalink().'" class="'.($main_dashboard?'active':'').'">'.__('Dashboard', 'directory-builder').'</a></li>
			<li><a href="'.add_query_arg('my-profile', '', get_permalink()).'" class="'.(isset($_GET['my-profile'])?'active':'').'">'.__('Edit profile', 'directory-builder').'</a></li>
			<li><a href="'.add_query_arg('my-listings', '', get_permalink()).'" class="'.(isset($_GET['my-listings'])?'active':'').'">'.__('My listings', 'directory-builder').'</a></li>
			<li><a href="'.add_query_arg('my-favorites', '', get_permalink()).'" class="'.(isset($_GET['my-favorites'])?'active':'').'">'.__('My favorites', 'directory-builder').'</a></li>
			<li><a href="'.add_query_arg('reviews', '', get_permalink()).'" class="'.(isset($_GET['reviews'])?'active':'').'">'.__('Reviews', 'directory-builder').'</a></li>
			<li><a href="'.add_query_arg('invoices', '', get_permalink()).'" class="'.(isset($_GET['invoices'])?'active':'').'">'.__('Invoices', 'directory-builder').'</a></li>
			<li><a href="'.add_query_arg('tickets', 'all', get_permalink()).'" class="'.(isset($_GET['tickets'])?'active':'').'">'.__('My tickets', 'directory-builder').'</a></li>
			<li><a href="'.add_query_arg('bookings', 'all', get_permalink()).'" class="'.(isset($_GET['bookings'])?'active':'').'">'.__('Bookings', 'directory-builder').'</a></li>';
			if ( $main_settings['add_page_id'] != '' ) {
				$output .= '<li><a href="'.get_permalink($main_settings['add_page_id']).'" class="db-logout dt-button dt-button-danger dt-button-middle">'.__('Add new listing', 'directory-builder').'</a></li>';
			}
			$output .= '
		</ul>';

		if ( $main_dashboard === true ) {
			$output .= '<p class="db-account-intro">'.__('Welcome to your dashboard! From here you can manage all  your listings, check your favorites and edit your profile.', 'directory-builder').'</p>';

			$user_data = get_userdata(get_current_user_id());
			$output .= '
			<h2 class="db-account-title">'.__('Profile', 'directory-builder').'</h2>
			<div class="db-account-profile-intro">
				<span class="db-account-row">
					<span class="db-account-label">'.__('Username', 'directory-builder').':</span>
					<span class="db-account-value">'.$user_data->data->display_name.'</span>
				</span>
				<span class="db-account-row">
					<span class="db-account-label">'.__('Email', 'directory-builder').':</span>
					<span class="db-account-value">'.$user_data->data->user_email.'</span>
				</span>
				<span class="db-account-row">
					<span class="db-account-label">'.__('Password', 'directory-builder').':</span>
					<span class="db-account-value">**********</span>
				</span>
				<a href="'.add_query_arg('my-profile', '', get_permalink()).'">'.__('Edit profile', 'directory-builder').'</a>
				<div class="clearfix"></div>
			</div>';
		}

		if ( $main_dashboard || isset($_GET['activities']) && $_GET['activities'] == 'all' ) {
			if ( isset($_GET['activities']) && $_GET['activities'] == 'all' ) {
				if ( !isset( $_GET['db-page'] ) || intval( $_GET['db-page'] ) == 1 ) {
					$activities_limit = '25';
				} else {
					$activities_limit = (intval( $_GET['db-page'] )-1)*25 . ', 25';
				}
			} else {
				$activities_limit = '5';
			}

			$activities_table = $wpdb->prefix.'directory_activities';
			$all_activities = $wpdb->get_results( "SELECT * FROM $activities_table WHERE user_id='".get_current_user_id()."' ORDER BY timestamp DESC LIMIT ".$activities_limit );

			$view_allowed = array( 'helpful', 'unhelpful', 'addreview', 'improvement', 'claimapproved', 'newfavorite', 'payment', 'supportnew', 'supportreply', 'newbooking' );

			$output .= '
			<div class="db-account-favorites">
				<h2 class="db-account-title">'.esc_html__('Recent activities', 'directory-builder').'</h2>
				<table class="db-account-listings table table-striped table-hover">
					<thead>
						<tr>
							<th style="width: 50.5%;">'.__('Activity', 'directory-builder').'</th>
							<th style="width: 12%;">'.__('Date', 'directory-builder').'</th>
							<th style="width: 12%;"></th>
						</tr>
					</thead>
					<tbody>';
					if ( !empty($all_activities) ) {
						$date_format = get_option('date_format');
						foreach ($all_activities as $ticket_data) {
							$activity_settings = json_decode( $ticket_data->settings, true );
							if ( $ticket_data->type == 'addreview' && is_null( get_comment($activity_settings['comment-id']) ) ) {
								continue;
							}
							$output .= '
								<tr>
									<td>'.db_get_activity( $ticket_data->type, $ticket_data->listing_id, $ticket_data->settings ).'</td>
									<td>'.date($date_format, $ticket_data->timestamp).'</td>
									<td>';
										if ( in_array($ticket_data->type, $view_allowed) ) {
											if ( in_array($ticket_data->type, array('helpful','unhelpful','addreview')) ) {
												$view_url = add_query_arg( '#comment-'.$activity_settings['comment-id'], '', get_permalink($ticket_data->listing_id) );
												$view_text = esc_html__('View review', 'directory-builder');
											} else if ( $ticket_data->type == 'payment' ) {
												$invoice_data = explode('-', $activity_settings['invoice-id']);
												$view_url = esc_url(add_query_arg(array( 'invoices' => '', 'lid' => $ticket_data->listing_id, 'prow' => $invoice_data['2'] ), get_permalink($main_settings['account_page_id'])));
												$view_text = esc_html__('View invoice', 'directory-builder');
											} else if ( $ticket_data->type == 'supportnew' || $ticket_data->type == 'supportreply' ) {
												$view_url = add_query_arg( 'tid', $activity_settings['support-parent'], get_permalink() );
												$view_text = esc_html__('View ticket', 'directory-builder');
											} else if ( $ticket_data->type == 'newbooking' ) {
												$view_url = add_query_arg( 'bookings', $activity_settings['listing_id'], get_permalink() );
												$view_text = esc_html__('View calendar', 'directory-builder');
											} else {
												$view_url = get_permalink($ticket_data->listing_id);
												$view_text = esc_html__('View listing', 'directory-builder');
											}
											$output .= '
											<a href="'.esc_url($view_url).'" class="db-account-listing-option view">
												<span class="db-account-listing-option-hover">'.$view_text.'</span>
												<svg width="18px" height="12px" viewBox="0 0 18 12" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"><g   transform="translate(-1164.000000, -859.000000)" fill="#53666D"><g id="listings" transform="translate(149.000000, 683.000000)"><g id="eye-copy" transform="translate(1008.000000, 166.000000)"><g id="eye-(2)" transform="translate(7.000000, 10.000000)"><g id="Layer_1"><g id="Group"><path d="M17.9640352,5.82672414 C16.4323125,2.29437931 12.9136289,0.011862069 9,0.011862069 C5.08637109,0.011862069 1.56775781,2.29431034 0.0359648437,5.82672414 C-0.0119882812,5.93727586 -0.0119882812,6.06213793 0.0359648437,6.17268966 C1.56765234,9.70544828 5.08630078,11.9881379 9,11.9881379 C12.9138047,11.9881379 16.432418,9.70544828 17.9640352,6.17268966 C18.0119883,6.06213793 18.0119883,5.93727586 17.9640352,5.82672414 L17.9640352,5.82672414 Z M9,11.1042069 C5.51271094,11.1042069 2.37104297,9.10689655 0.942503906,5.99975862 C2.37107813,2.89293103 5.51281641,0.895827586 9,0.895827586 C12.4872539,0.895827586 15.628957,2.89293103 17.0574961,5.99968966 C15.628957,9.10682759 12.4872891,11.1042069 9,11.1042069 L9,11.1042069 Z"  ></path><path d="M9,2.61465517 C7.09685156,2.61465517 5.54857031,4.13331034 5.54857031,5.99996552 C5.54857031,7.86662069 7.09688672,9.38527586 9,9.38527586 C10.9031133,9.38527586 12.4514297,7.86665517 12.4514297,5.99996552 C12.4514297,4.13327586 10.9031133,2.61465517 9,2.61465517 L9,2.61465517 Z M9,8.50141379 C7.59382031,8.50141379 6.44976563,7.37927586 6.44976563,6.00003448 C6.44976563,4.6207931 7.59382031,3.49865517 9,3.49865517 C10.4061797,3.49865517 11.5502344,4.6207931 11.5502344,6.00003448 C11.5502344,7.37927586 10.4061797,8.50141379 9,8.50141379 L9,8.50141379 Z"  ></path><path d="M9,4.20268966 C7.98964453,4.20268966 7.16755078,5.00896552 7.16755078,6.00003448 C7.16755078,6.24410345 7.36924219,6.442 7.61814844,6.442 C7.86705469,6.442 8.06874609,6.24410345 8.06874609,6.00003448 C8.06874609,5.49637931 8.48647266,5.08662069 9,5.08662069 C9.24890625,5.08662069 9.45059766,4.88872414 9.45059766,4.64465517 C9.45059766,4.40051724 9.24883594,4.20268966 9,4.20268966 L9,4.20268966 Z"  ></path></g></g></g></g></g></g></g></svg>
											</a>';
										}
										if ( in_array($ticket_data->type, array( 'payment' )) ) {
											$invoice_data = explode('-', $activity_settings['invoice-id']);
											$output .= '
											<a href="'.esc_url(add_query_arg(array( 'invoices' => '', 'lid' => $ticket_data->listing_id, 'prow' => $invoice_data['2'] ), get_permalink($main_settings['account_page_id']))).'" class="db-account-listing-option download" download>
												<span class="db-account-listing-option-hover">'.esc_html__('Download invoice', 'directory-builder').'</span>
												<svg width="16px" height="15px" viewBox="0 0 16 15" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <g id="My-account" transform="translate(-1207.000000, -1734.000000)" fill-rule="nonzero" fill="#53666D"> <g id="listings-copy" transform="translate(149.000000, 1499.000000)"> <g id="download" transform="translate(1050.000000, 228.000000)"> <path d="M19.4681977,14.9806033 C19.6294045,14.8193964 19.6294045,14.5656045 19.4681977,14.4043977 C19.312437,14.2431908 19.0531989,14.2431908 18.8978013,14.4043977 L15.9761086,17.3206442 L15.9761086,7.68490376 C15.9761086,7.46015817 15.797474,7.27571429 15.5727284,7.27571429 C15.3479828,7.27571429 15.1635389,7.46015817 15.1635389,7.68490376 L15.1635389,17.3206442 L12.2476554,14.4043977 C12.0864486,14.2431908 11.8268474,14.2431908 11.6714498,14.4043977 C11.510243,14.5656045 11.510243,14.8193964 11.6714498,14.9806033 L15.2848071,18.5939605 C15.4405678,18.7497212 15.6998059,18.7497212 15.8610127,18.5939605 L19.4681977,14.9806033 Z M22.3321609,17.6259932 C22.3321609,17.4012476 22.5107956,17.222613 22.7355411,17.222613 C22.9602867,17.222613 23.1447306,17.4012476 23.1447306,17.6259932 L23.1447306,21.5908105 C23.1447306,21.8155561 22.9602867,22 22.7355411,22 L8.40338022,22 C8.17863462,22 8,21.8155561 8,21.5908105 L8,17.6259932 C8,17.4012476 8.17863462,17.222613 8.40338022,17.222613 C8.62812581,17.222613 8.8125697,17.4012476 8.8125697,17.6259932 L8.8125697,21.1874303 L22.3321609,21.1874303 L22.3321609,17.6259932 Z" id="Shape"></path> </g> </g> </g> </g> </svg>
											</a>';
										}
										if ( in_array('delete', $users_are_allowed) && in_array($ticket_data->type, array('claimapproved')) ) {
											$output .= '
											<a href="javascript:void(0)" class="db-delete-listing db-account-listing-option delete" data-id="'.$ticket_data->listing_id.'">
												<span class="db-account-listing-option-hover">'.__('Delete', 'directory-builder').'</span>
												<svg width="11px" height="14px" viewBox="0 0 11 14" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"><g   transform="translate(-1208.000000, -858.000000)" fill="#53666D"><g id="listings" transform="translate(149.000000, 683.000000)"><g id="rubbish-bin-copy" transform="translate(1049.000000, 166.000000)"><g   transform="translate(10.000000, 9.000000)"><g id="Group"><path d="M10.0372757,1.64692387 L8.1821876,1.64692387 L8.1821876,0.433385806 C8.1821876,0.189117419 7.98646656,0 7.7438385,0 C7.72029527,0 7.7045938,0.00791225806 7.69693148,0.0158064516 C7.68907178,0.00791225806 7.67337031,0 7.66552855,0 L3.30559869,0 L3.2743752,0 L3.24297227,0 C3.00034421,0 2.81248287,0.189117419 2.81248287,0.433385806 L2.81248287,1.64694194 L0.949553018,1.64694194 C0.417192496,1.64694194 0.00238662316,2.06452129 0.00238662316,2.60044129 L0.00238662316,3.29388387 L0.00238662316,4.16063742 L0.824300163,4.16063742 L0.824300163,13.0411535 C0.824300163,13.5770916 1.23126427,13.9867587 1.7636248,13.9867587 L9.22322186,13.9867587 C9.75558238,13.9867587 10.1703703,13.5770916 10.1703703,13.0411535 L10.1703703,4.16063742 L10.9844421,4.16063742 L10.9844421,3.29388387 L10.9844421,2.60044129 C10.9844421,2.06452129 10.5694747,1.64692387 10.0372757,1.64692387 L10.0372757,1.64692387 Z M3.67347961,0.866753548 L7.3133491,0.866753548 L7.3133491,1.64692387 L3.67347961,1.64692387 L3.67347961,0.866753548 L3.67347961,0.866753548 Z M9.30153181,13.0411716 C9.30153181,13.0964671 9.27798858,13.1199871 9.22322186,13.1199871 L1.7636248,13.1199871 C1.70885808,13.1199871 1.68531485,13.096449 1.68531485,13.0411716 L1.68531485,4.16061935 L9.30153181,4.16061935 L9.30153181,13.0411716 L9.30153181,13.0411716 Z M10.1156036,3.29386581 L0.871225122,3.29386581 L0.871225122,2.60042323 C0.871225122,2.54527226 0.894768352,2.51367742 0.949535073,2.51367742 L10.0372757,2.51367742 C10.0920604,2.51367742 10.1156036,2.54527226 10.1156036,2.60042323 L10.1156036,3.29386581 L10.1156036,3.29386581 Z"  ></path><rect id="Rectangle-path" x="7.0707031" y="5.17716387" width="0.868838499" height="7.17056516"></rect><rect id="Rectangle-path" x="5.06683687" y="5.17716387" width="0.868838499" height="7.17056516"></rect><rect id="Rectangle-path" x="3.06295269" y="5.17716387" width="0.868838499" height="7.17056516"></rect></g></g></g></g></g></g></svg>
											</a>';
										}
										if ( in_array('edit', $users_are_allowed) && in_array($ticket_data->type, array('claimapproved')) ) {
											$output .= '
											<a href="'.add_query_arg('edit-listing', $ticket_data->listing_id, get_permalink($main_settings['add_page_id'])).'" class="db-edit-listing db-account-listing-option edit" data-id="'.$ticket_data->listing_id.'">
												<span class="db-account-listing-option-hover">'.__('Edit', 'directory-builder').'</span>
												<svg width="14px" height="14px" viewBox="0 0 14 14" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"><g   transform="translate(-1248.000000, -858.000000)" fill="#53666D"><g id="listings" transform="translate(149.000000, 683.000000)"><g id="edit-copy" transform="translate(1090.000000, 166.000000)"><g   transform="translate(9.000000, 9.000000)"><path d="M13.0745404,0.905621277 C11.8711362,-0.300761702 9.91411489,-0.300761702 8.71071064,0.905621277 L0.709859574,8.90349362 C0.647306383,8.96604681 0.608582979,9.04647234 0.596668085,9.13285532 L0.00390212766,13.5234936 C-0.0139702128,13.6486 0.0307106383,13.7737064 0.117093617,13.8600894 C0.191561702,13.9345574 0.295817021,13.9792383 0.40007234,13.9792383 C0.417944681,13.9792383 0.435817021,13.9792383 0.453689362,13.9762596 L3.09879574,13.6188128 C3.31922128,13.5890255 3.47411489,13.3864723 3.44432766,13.1660468 C3.41454043,12.9456213 3.21198723,12.7907277 2.9915617,12.8205149 L0.870710638,13.1064723 L1.28475319,10.0443447 L4.50773191,13.2673234 C4.5822,13.3417915 4.68645532,13.3864723 4.79071064,13.3864723 C4.89496596,13.3864723 4.99922128,13.3447702 5.07368936,13.2673234 L13.0745404,5.26945106 C13.6583702,4.68562128 13.9800723,3.91115319 13.9800723,3.08604681 C13.9800723,2.26094043 13.6583702,1.48647234 13.0745404,0.905621277 L13.0745404,0.905621277 Z M8.86560426,1.8886 L10.2090085,3.23200426 L2.90815745,10.5328553 L1.56475319,9.18945106 L8.86560426,1.8886 L8.86560426,1.8886 Z M4.79368936,12.4154085 L3.48007234,11.1017915 L10.7809234,3.80094043 L12.0945404,5.11455745 L4.79368936,12.4154085 L4.79368936,12.4154085 Z M12.6545404,4.53966383 L9.44049787,1.32562128 C9.84858298,0.989025532 10.3579447,0.804344681 10.8941149,0.804344681 C11.5047532,0.804344681 12.0766681,1.04264255 12.508583,1.47157872 C12.9404979,1.90051489 13.175817,2.47540851 13.175817,3.08604681 C13.175817,3.62519574 12.9911362,4.13157872 12.6545404,4.53966383 L12.6545404,4.53966383 Z"  ></path></g></g></g></g></g></svg>
											</a>';
										}
									$output .= '
									</td>
								</tr>';
						}
					} else {
						$output .= '<tr><td colspan="5" class="db-nothing-found">'.esc_html__('No recent activities found!', 'directory-builder').'</td></tr>';
					}
					$output .= '</tbody>
				</table>';
				if ( !isset($_GET['activities']) && count($all_activities) == 5 ) {
					$output .= '<a href="'.esc_url(add_query_arg('activities', 'all', get_permalink())).'" class="db-see-all-listing dt-button dt-button-invert">'.esc_html__('See all activities', 'directory-builder').'</a>';
				}
			$output .= '
				<div class="clearfix"></div>
			</div>';

			if ( isset($_GET['activities']) && $_GET['activities'] == 'all' ) {
				$activities_total = $wpdb->get_results( "SELECT count(ID) as count FROM $activities_table WHERE user_id='".get_current_user_id()."'" );
				$total_activity_pages = intval($activities_total['0']->count)/25;
				$pages_rounded = ( is_float( $total_activity_pages ) ? ceil( $total_activity_pages ) : round( $total_activity_pages ) );

				if ( $pages_rounded > 1 ) {
					$output .= '<div class="navigation paging-navigation">' . paginate_links( array(
						'format' => '?db-page=%#%',
						'total' => $pages_rounded,
						'current' => ( isset( $_GET['db-page'] ) ? intval( $_GET['db-page'] ) : 1 ),
						'prev_text' => '',
						'next_text' => '',
					) ) . '</div>';
				}
			}
		}

		if ( $main_dashboard || ( !empty($user_listings) && isset($_GET['my-listings']) ) ) {
			$output .= db_checkout_html();
			$output .= '
			<div class="db-account-favorites">
				<h2 class="db-account-title">'.__('Listings', 'directory-builder').'</h2>
				<table class="db-account-listings table table-striped table-hover">
					<thead>
						<tr>
							<th style="width: 28.6%;">'.__('Name', 'directory-builder').'</th>
							<th style="width: 12.5%;">'.__('Status', 'directory-builder').'</th>
							<th style="width: 15%;">'.__('Package', 'directory-builder').'</th>
							<th style="width: 20%;">'.__('Expires on', 'directory-builder').'</th>
							<th style="width: 10%;">'.__('Sticky', 'directory-builder').'</th>
							<th style="width: 15%;"></th>
						</tr>
					</thead>
					<tbody>';
						$listing_loop = 1;
						foreach ($user_listings as $listing_data) {
							$order_options = get_post_meta( $listing_data->ID, 'db_order_info', true );
							if ( $order_options == '' ) {
								$order_options = array();
							}
							$ratings = get_post_meta( $listing_data->ID, 'listing_ratings', true);
							if ( $ratings == '' ) {
								$rating_stars = '<i class="dbicon-star-empty"></i><i class="dbicon-star-empty"></i><i class="dbicon-star-empty"></i><i class="dbicon-star-empty"></i><i class="dbicon-star-empty"></i>';
							} else {
								$listing_rating = 0;
								foreach ($ratings as $rating_value) {
									$listing_rating += $rating_value;
								}
								$listing_rating = $listing_rating/count($ratings);
								$rating_stars = db_get_rating_stars(round($listing_rating, 0, PHP_ROUND_HALF_DOWN));
							}

							if ( isset($order_options['listing_package']) ) {
								$package_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_packages WHERE ID="'.$order_options['listing_package'].'"');
								if ( !empty($package_list) ) {
									$field_settings = json_decode($package_list['0']->package_settings, true);

									if ( $field_settings['listing_run_type'] == 'forever' ) {
										$listing_expiration = __('Never', 'directory-builder');
									} else if ( $field_settings['listing_run_type'] == 'days' && isset($order_options['listing_expires']) && $order_options['listing_expires'] != 'Unknown' ) {
										$listing_expiration = date( get_option('date_format'), $order_options['listing_expires']);
									} else {
										$listing_expiration = __('Unknown', 'directory-builder');
									}

									$package_amount = $field_settings['fee_amount'];
									$package_run_type = $field_settings['listing_run_type'];
								}
							} else {
								$listing_expiration = __('Unknown', 'directory-builder');
							}

							$sticky_listings = get_option('db_sticky_listings', array());
							$refunds = get_post_meta( $listing_data->ID, 'db_refunds', true );
							$refunds = is_array($refunds) ? array_reverse($refunds) : '';

							$output .= '
							<tr>
								<td>'.$listing_data->post_title.'</td>
								<td class="db-align-center db-status">'.(isset($order_options['payment_status'])&&$order_options['payment_status']=='Refunded'&&!empty($refunds)&&$refunds['0']['reason']!=''?'<span class="db-account-listing-option-hover">'.__('Reason', 'directory-builder').': '.$refunds['0']['reason'].'</span>':'').(isset($order_options['payment_status'])?$order_options['payment_status']:$listing_data->post_status).'</td>
								<td class="db-align-center">'.(isset($order_options['listing_package_name'])?$order_options['listing_package_name']:__('Unknown', 'directory-builder')).'</td>
								<td class="db-align-center">'.$listing_expiration.'</td>
								<td class="db-align-center">'.(in_array($listing_data->ID, $sticky_listings)?__('Yes', 'directory-builder'):__('No', 'directory-builder')).'</td>
								<td>';
									if ( isset($order_options['completed_on']) && is_numeric($order_options['completed_on']) && $package_amount != '0' && $package_run_type == 'days' ) {
										$output .= '<a href="javascript:void(0)" data-id="'.$order_options['listing_package'].'" data-list-id="'.$listing_data->ID.'" class="db-account-listing-option renew"><span class="db-account-listing-option-hover">'.esc_html__('Renew', 'directory-builder').'</span><svg width="14px" height="14px" viewBox="0 0 14 14" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"><g   transform="translate(-1125.000000, -858.000000)" fill="#247BA0"><g id="listings" transform="translate(149.000000, 683.000000)"><g id="add" transform="translate(951.000000, 123.000000)"><g   transform="translate(25.000000, 52.000000)"><g id="Group"><path d="M13.5826638,0 L3.09598309,0 C2.87399577,0 2.69640592,0.177589852 2.69640592,0.399577167 L2.69640592,10.8862579 C2.69640592,11.1082452 2.87399577,11.2858351 3.09598309,11.2858351 L13.5826638,11.2858351 C13.8046512,11.2858351 13.982241,11.1082452 13.982241,10.8862579 L13.982241,0.399577167 C13.982241,0.177589852 13.8046512,0 13.5826638,0 L13.5826638,0 Z M13.1830867,10.4866808 L3.49556025,10.4866808 L3.49556025,0.799154334 L13.1830867,0.799154334 L13.1830867,10.4866808 L13.1830867,10.4866808 L13.1830867,10.4866808 Z"  ></path><path d="M10.8862579,13.1830867 L0.799154334,13.1830867 L0.799154334,3.09598309 C0.799154334,2.87399577 0.621564482,2.69640592 0.399577167,2.69640592 C0.177589852,2.69640592 0,2.87399577 0,3.09598309 L0,13.5826638 C0,13.8046512 0.177589852,13.982241 0.399577167,13.982241 L10.8862579,13.982241 C11.1082452,13.982241 11.2858351,13.8046512 11.2858351,13.5826638 C11.2858351,13.3606765 11.1082452,13.1830867 10.8862579,13.1830867 L10.8862579,13.1830867 Z"  ></path><path d="M6.07357294,6.04397463 L7.93826638,6.04397463 L7.93826638,7.90866808 C7.93826638,8.13065539 8.11585624,8.30824524 8.33784355,8.30824524 C8.55983087,8.30824524 8.73742072,8.13065539 8.73742072,7.90866808 L8.73742072,6.04397463 L10.605074,6.04397463 C10.8270613,6.04397463 11.0046512,5.86638478 11.0046512,5.64439746 C11.0046512,5.42241015 10.8270613,5.2448203 10.605074,5.2448203 L8.73742072,5.2448203 L8.73742072,3.37716702 C8.73742072,3.1551797 8.55983087,2.97758985 8.33784355,2.97758985 C8.11585624,2.97758985 7.93826638,3.1551797 7.93826638,3.37716702 L7.93826638,5.2448203 L6.07357294,5.2448203 C5.85158562,5.2448203 5.67399577,5.42241015 5.67399577,5.64439746 C5.67399577,5.86638478 5.85158562,6.04397463 6.07357294,6.04397463 L6.07357294,6.04397463 Z"  ></path></g></g></g></g></g></g></svg></a>';
									}

									$view_text = '';
									$view_url = '#';
									if ( $listing_data->post_status == 'publish' ) {
										$view_text = __('View', 'directory-builder');
										$view_url = get_permalink($listing_data->ID);
									} else {
										$view_text = __('Preview', 'directory-builder');
										$view_url = add_query_arg('preview', 'true', get_permalink($listing_data->ID));
									}

									if ( $listing_data->post_status != 'pending' ) {
										$output .= '
										<a href="'.$view_url.'" class="db-account-listing-option view">
											<span class="db-account-listing-option-hover">'.$view_text.'</span>
											<svg width="18px" height="12px" viewBox="0 0 18 12" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"><g   transform="translate(-1164.000000, -859.000000)" fill="#53666D"><g id="listings" transform="translate(149.000000, 683.000000)"><g id="eye-copy" transform="translate(1008.000000, 166.000000)"><g id="eye-(2)" transform="translate(7.000000, 10.000000)"><g id="Layer_1"><g id="Group"><path d="M17.9640352,5.82672414 C16.4323125,2.29437931 12.9136289,0.011862069 9,0.011862069 C5.08637109,0.011862069 1.56775781,2.29431034 0.0359648437,5.82672414 C-0.0119882812,5.93727586 -0.0119882812,6.06213793 0.0359648437,6.17268966 C1.56765234,9.70544828 5.08630078,11.9881379 9,11.9881379 C12.9138047,11.9881379 16.432418,9.70544828 17.9640352,6.17268966 C18.0119883,6.06213793 18.0119883,5.93727586 17.9640352,5.82672414 L17.9640352,5.82672414 Z M9,11.1042069 C5.51271094,11.1042069 2.37104297,9.10689655 0.942503906,5.99975862 C2.37107813,2.89293103 5.51281641,0.895827586 9,0.895827586 C12.4872539,0.895827586 15.628957,2.89293103 17.0574961,5.99968966 C15.628957,9.10682759 12.4872891,11.1042069 9,11.1042069 L9,11.1042069 Z"  ></path><path d="M9,2.61465517 C7.09685156,2.61465517 5.54857031,4.13331034 5.54857031,5.99996552 C5.54857031,7.86662069 7.09688672,9.38527586 9,9.38527586 C10.9031133,9.38527586 12.4514297,7.86665517 12.4514297,5.99996552 C12.4514297,4.13327586 10.9031133,2.61465517 9,2.61465517 L9,2.61465517 Z M9,8.50141379 C7.59382031,8.50141379 6.44976563,7.37927586 6.44976563,6.00003448 C6.44976563,4.6207931 7.59382031,3.49865517 9,3.49865517 C10.4061797,3.49865517 11.5502344,4.6207931 11.5502344,6.00003448 C11.5502344,7.37927586 10.4061797,8.50141379 9,8.50141379 L9,8.50141379 Z"  ></path><path d="M9,4.20268966 C7.98964453,4.20268966 7.16755078,5.00896552 7.16755078,6.00003448 C7.16755078,6.24410345 7.36924219,6.442 7.61814844,6.442 C7.86705469,6.442 8.06874609,6.24410345 8.06874609,6.00003448 C8.06874609,5.49637931 8.48647266,5.08662069 9,5.08662069 C9.24890625,5.08662069 9.45059766,4.88872414 9.45059766,4.64465517 C9.45059766,4.40051724 9.24883594,4.20268966 9,4.20268966 L9,4.20268966 Z"  ></path></g></g></g></g></g></g></g></svg>
										</a>';
									}
									
									if ( in_array('delete', $users_are_allowed) ) {
										$output .= '
										<a href="javascript:void(0)" class="db-delete-listing db-account-listing-option delete" data-id="'.$listing_data->ID.'">
											<span class="db-account-listing-option-hover">'.__('Delete', 'directory-builder').'</span>
											<svg width="11px" height="14px" viewBox="0 0 11 14" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"><g   transform="translate(-1208.000000, -858.000000)" fill="#53666D"><g id="listings" transform="translate(149.000000, 683.000000)"><g id="rubbish-bin-copy" transform="translate(1049.000000, 166.000000)"><g   transform="translate(10.000000, 9.000000)"><g id="Group"><path d="M10.0372757,1.64692387 L8.1821876,1.64692387 L8.1821876,0.433385806 C8.1821876,0.189117419 7.98646656,0 7.7438385,0 C7.72029527,0 7.7045938,0.00791225806 7.69693148,0.0158064516 C7.68907178,0.00791225806 7.67337031,0 7.66552855,0 L3.30559869,0 L3.2743752,0 L3.24297227,0 C3.00034421,0 2.81248287,0.189117419 2.81248287,0.433385806 L2.81248287,1.64694194 L0.949553018,1.64694194 C0.417192496,1.64694194 0.00238662316,2.06452129 0.00238662316,2.60044129 L0.00238662316,3.29388387 L0.00238662316,4.16063742 L0.824300163,4.16063742 L0.824300163,13.0411535 C0.824300163,13.5770916 1.23126427,13.9867587 1.7636248,13.9867587 L9.22322186,13.9867587 C9.75558238,13.9867587 10.1703703,13.5770916 10.1703703,13.0411535 L10.1703703,4.16063742 L10.9844421,4.16063742 L10.9844421,3.29388387 L10.9844421,2.60044129 C10.9844421,2.06452129 10.5694747,1.64692387 10.0372757,1.64692387 L10.0372757,1.64692387 Z M3.67347961,0.866753548 L7.3133491,0.866753548 L7.3133491,1.64692387 L3.67347961,1.64692387 L3.67347961,0.866753548 L3.67347961,0.866753548 Z M9.30153181,13.0411716 C9.30153181,13.0964671 9.27798858,13.1199871 9.22322186,13.1199871 L1.7636248,13.1199871 C1.70885808,13.1199871 1.68531485,13.096449 1.68531485,13.0411716 L1.68531485,4.16061935 L9.30153181,4.16061935 L9.30153181,13.0411716 L9.30153181,13.0411716 Z M10.1156036,3.29386581 L0.871225122,3.29386581 L0.871225122,2.60042323 C0.871225122,2.54527226 0.894768352,2.51367742 0.949535073,2.51367742 L10.0372757,2.51367742 C10.0920604,2.51367742 10.1156036,2.54527226 10.1156036,2.60042323 L10.1156036,3.29386581 L10.1156036,3.29386581 Z"  ></path><rect id="Rectangle-path" x="7.0707031" y="5.17716387" width="0.868838499" height="7.17056516"></rect><rect id="Rectangle-path" x="5.06683687" y="5.17716387" width="0.868838499" height="7.17056516"></rect><rect id="Rectangle-path" x="3.06295269" y="5.17716387" width="0.868838499" height="7.17056516"></rect></g></g></g></g></g></g></svg>
										</a>';
									}
									if ( in_array('edit', $users_are_allowed) ) {
										$output .= '
										<a href="'.add_query_arg('edit-listing', $listing_data->ID, get_permalink($main_settings['add_page_id'])).'" class="db-edit-listing db-account-listing-option edit" data-id="'.$listing_data->ID.'">
											<span class="db-account-listing-option-hover">'.__('Edit', 'directory-builder').'</span>
											<svg width="14px" height="14px" viewBox="0 0 14 14" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"><g   transform="translate(-1248.000000, -858.000000)" fill="#53666D"><g id="listings" transform="translate(149.000000, 683.000000)"><g id="edit-copy" transform="translate(1090.000000, 166.000000)"><g   transform="translate(9.000000, 9.000000)"><path d="M13.0745404,0.905621277 C11.8711362,-0.300761702 9.91411489,-0.300761702 8.71071064,0.905621277 L0.709859574,8.90349362 C0.647306383,8.96604681 0.608582979,9.04647234 0.596668085,9.13285532 L0.00390212766,13.5234936 C-0.0139702128,13.6486 0.0307106383,13.7737064 0.117093617,13.8600894 C0.191561702,13.9345574 0.295817021,13.9792383 0.40007234,13.9792383 C0.417944681,13.9792383 0.435817021,13.9792383 0.453689362,13.9762596 L3.09879574,13.6188128 C3.31922128,13.5890255 3.47411489,13.3864723 3.44432766,13.1660468 C3.41454043,12.9456213 3.21198723,12.7907277 2.9915617,12.8205149 L0.870710638,13.1064723 L1.28475319,10.0443447 L4.50773191,13.2673234 C4.5822,13.3417915 4.68645532,13.3864723 4.79071064,13.3864723 C4.89496596,13.3864723 4.99922128,13.3447702 5.07368936,13.2673234 L13.0745404,5.26945106 C13.6583702,4.68562128 13.9800723,3.91115319 13.9800723,3.08604681 C13.9800723,2.26094043 13.6583702,1.48647234 13.0745404,0.905621277 L13.0745404,0.905621277 Z M8.86560426,1.8886 L10.2090085,3.23200426 L2.90815745,10.5328553 L1.56475319,9.18945106 L8.86560426,1.8886 L8.86560426,1.8886 Z M4.79368936,12.4154085 L3.48007234,11.1017915 L10.7809234,3.80094043 L12.0945404,5.11455745 L4.79368936,12.4154085 L4.79368936,12.4154085 Z M12.6545404,4.53966383 L9.44049787,1.32562128 C9.84858298,0.989025532 10.3579447,0.804344681 10.8941149,0.804344681 C11.5047532,0.804344681 12.0766681,1.04264255 12.508583,1.47157872 C12.9404979,1.90051489 13.175817,2.47540851 13.175817,3.08604681 C13.175817,3.62519574 12.9911362,4.13157872 12.6545404,4.53966383 L12.6545404,4.53966383 Z"  ></path></g></g></g></g></g></svg>
										</a>';
									}
									$output .= ' ';
								$output .= '    
								</td>
							</tr>';
							if ( $listing_loop == 5 && !isset($_GET['my-listings']) ) {
								break;
							}
							$listing_loop++;
						}
						$output .= '
					</tbody>
				</table>';

				if ( count($user_listings) > 5 && !isset($_GET['my-listings']) ) {
					$output .= '<a href="'.add_query_arg('my-listings', '', get_permalink()).'" class="db-see-all-listing dt-button dt-button-invert">'.__('See all listings', 'directory-builder').'</a><div class="clearfix"></div>';
				} else if ( isset($_GET['my-listings']) ) {
					$total_listings = $wpdb->get_results('SELECT count(ID) as count FROM '.$wpdb->posts.' WHERE post_type="listings" && ( post_status != "auto-draft" && post_status != "trash" ) && post_author="'.get_current_user_id().'"');
					$total_pages = $total_listings['0']->count/25;

					$output .= '<div class="navigation paging-navigation">' . paginate_links( array(
						'format' => '?db-page=%#%',
						'total' => ( is_float( $total_pages ) ? ceil( $total_pages ) : round( $total_pages ) ),
						'current' => ( isset( $_GET['db-page'] ) ? intval( $_GET['db-page'] ) : 1 ),
						'prev_text' => '',
						'next_text' => '',
					) ) . '</div>';
				}
			$output .= '<div class="clearfix"></div></div>';
		}

		if ( $main_dashboard || isset($_GET['tickets']) && $_GET['tickets'] == 'all' ) {
			if ( isset($_GET['tickets']) && $_GET['tickets'] == 'all' ) {
				if ( !isset( $_GET['db-page'] ) || intval( $_GET['db-page'] ) == 1 ) {
					$support_limit = '25';
				} else {
					$support_limit = (intval( $_GET['db-page'] )-1)*25 . ', 25';
				}
			} else {
				$support_limit = '5';
			}

			$support_table = $wpdb->prefix.'directory_support';
			$support_tickets = $wpdb->get_results( "SELECT * FROM $support_table WHERE author='".get_current_user_id()."' && parent='0' ORDER BY `date` DESC LIMIT ".$support_limit );

			$output .= '
			<div class="db-account-favorites">
				<h2 class="db-account-title">'.esc_html__('Support tickets', 'directory-builder').'</h2>
				<table class="db-account-listings table table-striped table-hover">
					<thead>
						<tr>
							<th style="width: 50.5%;">'.__('Subject', 'directory-builder').'</th>
							<th style="width: 12%;">'.__('Status', 'directory-builder').'</th>
							<th style="width: 17.5%;">'.__('Created', 'directory-builder').'</th>
							<th style="width: 12%;">'.__('Last reply', 'directory-builder').'</th>
							<th style="width: 12%;"></th>
						</tr>
					</thead>
					<tbody>';
					if ( !empty($support_tickets) ) {
						$date_format = get_option('date_format');
						foreach ($support_tickets as $ticket_data) {
							$last_reply = $wpdb->get_results( $wpdb->prepare( "SELECT `date` FROM $support_table WHERE parent='%d' ORDER BY `date` DESC LIMIT 1", $ticket_data->ID ) );
							if ( empty($last_reply) ) {
								$last_reply_time = $ticket_data->date;
							} else {
								$last_reply_time = $last_reply['0']->date;
							}
							$output .= '
								<tr>
									<td>'.$ticket_data->subject.'</td>
									<td>'.ucwords($ticket_data->status).'</td>
									<td>'.date($date_format, $ticket_data->date).'</td>
									<td>'.human_time_diff($last_reply_time,time()).'</td>
									<td>
										<a href="'.esc_url(add_query_arg(array( 'tid' => $ticket_data->ID ), get_permalink())).'" class="db-account-listing-option view">
											<span class="db-account-listing-option-hover">'.esc_html__('View ticket', 'directory-builder').'</span>
											<svg width="18px" height="12px" viewBox="0 0 18 12" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"><g   transform="translate(-1164.000000, -859.000000)" fill="#53666D"><g id="listings" transform="translate(149.000000, 683.000000)"><g id="eye-copy" transform="translate(1008.000000, 166.000000)"><g id="eye-(2)" transform="translate(7.000000, 10.000000)"><g id="Layer_1"><g id="Group"><path d="M17.9640352,5.82672414 C16.4323125,2.29437931 12.9136289,0.011862069 9,0.011862069 C5.08637109,0.011862069 1.56775781,2.29431034 0.0359648437,5.82672414 C-0.0119882812,5.93727586 -0.0119882812,6.06213793 0.0359648437,6.17268966 C1.56765234,9.70544828 5.08630078,11.9881379 9,11.9881379 C12.9138047,11.9881379 16.432418,9.70544828 17.9640352,6.17268966 C18.0119883,6.06213793 18.0119883,5.93727586 17.9640352,5.82672414 L17.9640352,5.82672414 Z M9,11.1042069 C5.51271094,11.1042069 2.37104297,9.10689655 0.942503906,5.99975862 C2.37107813,2.89293103 5.51281641,0.895827586 9,0.895827586 C12.4872539,0.895827586 15.628957,2.89293103 17.0574961,5.99968966 C15.628957,9.10682759 12.4872891,11.1042069 9,11.1042069 L9,11.1042069 Z"  ></path><path d="M9,2.61465517 C7.09685156,2.61465517 5.54857031,4.13331034 5.54857031,5.99996552 C5.54857031,7.86662069 7.09688672,9.38527586 9,9.38527586 C10.9031133,9.38527586 12.4514297,7.86665517 12.4514297,5.99996552 C12.4514297,4.13327586 10.9031133,2.61465517 9,2.61465517 L9,2.61465517 Z M9,8.50141379 C7.59382031,8.50141379 6.44976563,7.37927586 6.44976563,6.00003448 C6.44976563,4.6207931 7.59382031,3.49865517 9,3.49865517 C10.4061797,3.49865517 11.5502344,4.6207931 11.5502344,6.00003448 C11.5502344,7.37927586 10.4061797,8.50141379 9,8.50141379 L9,8.50141379 Z"  ></path><path d="M9,4.20268966 C7.98964453,4.20268966 7.16755078,5.00896552 7.16755078,6.00003448 C7.16755078,6.24410345 7.36924219,6.442 7.61814844,6.442 C7.86705469,6.442 8.06874609,6.24410345 8.06874609,6.00003448 C8.06874609,5.49637931 8.48647266,5.08662069 9,5.08662069 C9.24890625,5.08662069 9.45059766,4.88872414 9.45059766,4.64465517 C9.45059766,4.40051724 9.24883594,4.20268966 9,4.20268966 L9,4.20268966 Z"  ></path></g></g></g></g></g></g></g></svg>
										</a>
									</td>
								</tr>';
						}
					} else {
						$output .= '<tr><td colspan="5" class="db-nothing-found">'.esc_html__('No support tickets found!', 'directory-builder').'</td></tr>';
					}
					$output .= '</tbody>
				</table>';
				if ( !isset($_GET['tickets']) && count($support_tickets) == 5 ) {
					$output .= '<a href="'.esc_url(add_query_arg('tickets', 'all', get_permalink())).'" class="db-see-all-listing view-all-tickets dt-button dt-button-invert">'.esc_html__('See all tickets', 'directory-builder').'</a>';
				}
				$output .= '<a href="'.esc_url(add_query_arg('tickets', 'submit', get_permalink())).'" class="db-see-all-listing dt-button dt-button-invert">'.esc_html__('Create a ticket', 'directory-builder').'</a>';
			$output .= '
				<div class="clearfix"></div>
			</div>';

			if ( isset($_GET['tickets']) && $_GET['tickets'] == 'all' ) {
				$support_total = $wpdb->get_results( "SELECT count(ID) as count FROM $support_table WHERE author='".get_current_user_id()."' && parent='0'" );
				$total_support_pages = intval($support_total['0']->count)/25;
				$pages_rounded = ( is_float( $total_support_pages ) ? ceil( $total_support_pages ) : round( $total_support_pages ) );

				if ( $pages_rounded > 1 ) {
					$output .= '<div class="navigation paging-navigation">' . paginate_links( array(
						'format' => '?db-page=%#%',
						'total' => $pages_rounded,
						'current' => ( isset( $_GET['db-page'] ) ? intval( $_GET['db-page'] ) : 1 ),
						'prev_text' => '',
						'next_text' => '',
					) ) . '</div>';
				}
			}
		}

		if ( $main_dashboard || ( !empty($user_listings) && isset($_GET['my-favorites']) ) ) {
			$favorite_limit = '3';
			if ( isset($_GET['my-favorites']) ) {
				if ( !isset( $_GET['db-page'] ) || intval( $_GET['db-page'] ) == 1 ) {
					$favorite_limit = '25';
				} else {
					$favorite_limit = (intval( $_GET['db-page'] )-1)*25 . ', 25';
				}
			}
			$output .= '
			<div class="db-account-favorites"'.(isset($_GET['my-favorites'])?' style="margin-top: 0;"':'').'>
				<h2 class="db-account-title">'.__('Favorites', 'directory-builder').'</h2>
				'.do_shortcode('[directory_featured_listings limit="'.$favorite_limit.'" type="favorites"]');
				if ( !isset($_GET['my-favorites']) ) {
					$output .= '<a href="'.add_query_arg('my-favorites', '', get_permalink()).'" class="db-see-all-favorites dt-button dt-button-invert">'.__('See all favorites', 'directory-builder').'</a><div class="clearfix"></div>';
				} else if ( isset($_GET['my-favorites']) ) {
					$total_favorites = $wpdb->get_results('SELECT count(ID) as count FROM '.$wpdb->posts.' as posts, '.$wpdb->postmeta.' as meta WHERE posts.post_type="listings" && posts.post_status="publish" && meta.meta_key="directory_post_likes" && meta.meta_value LIKE "%i:'.get_current_user_id().';%" && meta.post_id=posts.ID');
					$total_fav_pages = $total_favorites['0']->count/25;

					$output .= '<div class="navigation paging-navigation">' . paginate_links( array(
						'format' => '?db-page=%#%',
						'total' => ( is_float( $total_fav_pages ) ? ceil( $total_fav_pages ) : round( $total_fav_pages ) ),
						'current' => ( isset( $_GET['db-page'] ) ? intval( $_GET['db-page'] ) : 1 ),
						'prev_text' => '',
						'next_text' => '',
					) ) . '</div>';
				}
			$output .= '
				<div class="clearfix"></div>
			</div>';
		}

		if ( isset($_GET['my-profile']) ) {
			$user_data = get_userdata(get_current_user_id());
			global $update_message;

			$output .= '
			<div class="db-account-profile">
				<h2 class="db-account-title">'.__('My profile', 'directory-builder').'</h2>'
				.$update_message.
				'<form method="post" id="db-edit-profile">
					<div class="db-field-row">
						<label for="display_name">'.__('Username', 'directory-builder').'</label>
						<input type="text" name="display_name" id="display_name" placeholder="'.__('Username', 'directory-builder').'" value="'.(isset($_POST['display_name'])?sanitize_text_field($_POST['display_name']):$user_data->data->display_name).'">
					</div>
					<div class="db-field-row">
						<label for="user_email">'.__('Email', 'directory-builder').'</label>
						<input type="email" name="user_email" id="user_email" placeholder="'.__('Email', 'directory-builder').'" value="'.(isset($_POST['user_email'])?sanitize_email($_POST['user_email']):$user_data->data->user_email).'">
					</div>
					<div class="db-field-row">
						<label for="user_password">'.__('Password', 'directory-builder').'</label>
						<input type="password" name="user_password" id="user_password" placeholder="'.__('Password', 'directory-builder').'" value="">
					</div>
					<div class="db-field-row">
						<label for="user_conf_password">'.__('Confirm password', 'directory-builder').'</label>
						<input type="password" name="user_conf_password" id="user_conf_password" placeholder="'.__('Confirm password', 'directory-builder').'" value="">
					</div>
					<input type="hidden" name="action" value="edit-profile">
					<input type="submit" value="'.__('Save', 'directory-builder').'">
				</form>';
		}

		if ( isset($_GET['reviews']) ) {
			if ( !isset( $_GET['db-page'] ) || intval( $_GET['db-page'] ) == 1 ) {
				$review_limit = '25';
			} else {
				$review_limit = (intval( $_GET['db-page'] )-1)*25 . ', 25';
			}

			$author_listings = $wpdb->get_results( "SELECT ID FROM $wpdb->posts WHERE post_author='".get_current_user_id()."' && post_type='listings' && post_status='publish'" );
			$valid_posts = array();
			if ( !empty($author_listings) ) {
				foreach ($author_listings as $post_data) {
					$valid_posts[] = $post_data->ID;
				}
			}

			if ( $_GET['reviews'] == 'sent' ) {
				$queried_comments = $wpdb->get_results( "SELECT comment_post_ID, comment_ID, comment_approved, comment_date FROM $wpdb->comments WHERE comment_parent='0' && ( comment_approved='1' || comment_approved='0' ) && user_id='".get_current_user_id()."' ORDER BY comment_ID DESC LIMIT ".$review_limit );
				$total_reviews = $wpdb->get_results( "SELECT count(comment_ID) as count FROM $wpdb->comments WHERE comment_parent='0' && ( comment_approved='1' || comment_approved='0' ) && user_id='".get_current_user_id()."'" );
				$all_reviews = array( array(
					'title' => esc_html__('Sent reviews'),
					'url' => '',
					'data' => $queried_comments
				) );
			} else if ( $_GET['reviews'] == 'received' ) {
				if ( !empty($author_listings) ) {
					$queried_comments = $wpdb->get_results( "SELECT comment_post_ID, comment_ID, comment_approved, comment_date FROM $wpdb->comments WHERE comment_parent='0' && comment_approved='1' && user_id!='".get_current_user_id()."' && comment_post_ID IN (".implode(',', $valid_posts).") ORDER BY comment_ID DESC LIMIT ".$review_limit );
					$total_reviews = $wpdb->get_results( "SELECT count(comment_ID) as count FROM $wpdb->comments WHERE comment_parent='0' && comment_approved='1' && user_id!='".get_current_user_id()."' && comment_post_ID IN (".implode(',', $valid_posts).")" );
				} else {
					$queried_comments = array();
				}

				$all_reviews = array( array(
					'title' => esc_html__('Received reviews'),
					'url' => '',
					'data' => $queried_comments
				) );
			} else {
				$queried_comments = array();
				$queried_sent_comments = $wpdb->get_results( "SELECT comment_post_ID, comment_ID, comment_approved, comment_date FROM $wpdb->comments WHERE comment_parent='0' && ( comment_approved='1' || comment_approved='0' ) && user_id='".get_current_user_id()."' ORDER BY comment_ID DESC LIMIT 5" );
				$queried_rec_comments = $wpdb->get_results( "SELECT comment_post_ID, comment_ID, comment_approved, comment_date FROM $wpdb->comments WHERE comment_parent='0' && comment_approved='1' && user_id!='".get_current_user_id()."' && comment_post_ID IN (".implode(',', $valid_posts).") ORDER BY comment_ID DESC LIMIT 5" );

				$all_reviews = array( 
					array( 'title' => esc_html__('Sent reviews'),
						   'url' => (count($queried_sent_comments)==5?add_query_arg('reviews', 'sent', get_permalink(intval($main_settings['account_page_id']))):''),
						   'data' => $queried_sent_comments ),
					array( 'title' => esc_html__('Received reviews'),
						   'url' => (count($queried_rec_comments)==5?add_query_arg('reviews', 'received', get_permalink(intval($main_settings['account_page_id']))):''),
						   'data' => $queried_rec_comments )
					);
			}

			foreach ($all_reviews as $comment_segment_data) {
				$output .= '
				<div class="db-review-wrapper-item">
					<h2 class="db-account-title">'.$comment_segment_data['title'].'</h2>
					<table class="db-account-listings table table-striped table-hover">
						<thead>
							<tr>
								<th style="width: 60%;">'.__('Name', 'directory-builder').'</th>
								<th style="width: 10%;">'.__('Status', 'directory-builder').'</th>
								<th style="width: 20%;">'.__('Date', 'directory-builder').'</th>
								<th style="width: 10%;"></th>
							</tr>
						</thead>
						<tbody>';
							$listing_loop = 1;
							if ( !empty($comment_segment_data['data']) ) {
								$date_format = get_option('date_format').' '.get_option('time_format');
								foreach ($comment_segment_data['data'] as $comment_data) {
									$output .= '
									<tr>
										<td><a href="'.esc_url(get_permalink($comment_data->comment_post_ID)).'">'.esc_attr(get_the_title($comment_data->comment_post_ID)).'</a></td>
										<td class="db-align-center db-status">'.($comment_data->comment_approved=='1'?esc_html__('Approved', 'directory-builder'):esc_html__('Pending', 'directory-builder')).'</td>
										<td class="db-align-center">'.date($date_format, strtotime($comment_data->comment_date)).'</td>
										<td>
											<a href="'.esc_url(add_query_arg('#comment-'.$comment_data->comment_ID, '', get_permalink($comment_data->comment_post_ID))).'" class="db-account-listing-option view">
												<span class="db-account-listing-option-hover">'.esc_html__('View comment', 'directory-builder').'</span>
												<svg width="18px" height="12px" viewBox="0 0 18 12" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"><g   transform="translate(-1164.000000, -859.000000)" fill="#53666D"><g id="listings" transform="translate(149.000000, 683.000000)"><g id="eye-copy" transform="translate(1008.000000, 166.000000)"><g id="eye-(2)" transform="translate(7.000000, 10.000000)"><g id="Layer_1"><g id="Group"><path d="M17.9640352,5.82672414 C16.4323125,2.29437931 12.9136289,0.011862069 9,0.011862069 C5.08637109,0.011862069 1.56775781,2.29431034 0.0359648437,5.82672414 C-0.0119882812,5.93727586 -0.0119882812,6.06213793 0.0359648437,6.17268966 C1.56765234,9.70544828 5.08630078,11.9881379 9,11.9881379 C12.9138047,11.9881379 16.432418,9.70544828 17.9640352,6.17268966 C18.0119883,6.06213793 18.0119883,5.93727586 17.9640352,5.82672414 L17.9640352,5.82672414 Z M9,11.1042069 C5.51271094,11.1042069 2.37104297,9.10689655 0.942503906,5.99975862 C2.37107813,2.89293103 5.51281641,0.895827586 9,0.895827586 C12.4872539,0.895827586 15.628957,2.89293103 17.0574961,5.99968966 C15.628957,9.10682759 12.4872891,11.1042069 9,11.1042069 L9,11.1042069 Z"  ></path><path d="M9,2.61465517 C7.09685156,2.61465517 5.54857031,4.13331034 5.54857031,5.99996552 C5.54857031,7.86662069 7.09688672,9.38527586 9,9.38527586 C10.9031133,9.38527586 12.4514297,7.86665517 12.4514297,5.99996552 C12.4514297,4.13327586 10.9031133,2.61465517 9,2.61465517 L9,2.61465517 Z M9,8.50141379 C7.59382031,8.50141379 6.44976563,7.37927586 6.44976563,6.00003448 C6.44976563,4.6207931 7.59382031,3.49865517 9,3.49865517 C10.4061797,3.49865517 11.5502344,4.6207931 11.5502344,6.00003448 C11.5502344,7.37927586 10.4061797,8.50141379 9,8.50141379 L9,8.50141379 Z"  ></path><path d="M9,4.20268966 C7.98964453,4.20268966 7.16755078,5.00896552 7.16755078,6.00003448 C7.16755078,6.24410345 7.36924219,6.442 7.61814844,6.442 C7.86705469,6.442 8.06874609,6.24410345 8.06874609,6.00003448 C8.06874609,5.49637931 8.48647266,5.08662069 9,5.08662069 C9.24890625,5.08662069 9.45059766,4.88872414 9.45059766,4.64465517 C9.45059766,4.40051724 9.24883594,4.20268966 9,4.20268966 L9,4.20268966 Z"  ></path></g></g></g></g></g></g></g></svg>
											</a>   
										</td>
									</tr>';
									$listing_loop++;
								}
							} else {
								$output .= '
									<tr>
										<td colspan="4" class="db-nothing-found">'.esc_html__('Nothing was found!', 'directory-builder').'</td>
									</tr>';
							}
							$output .= '
						</tbody>
					</table>';
					if ( $comment_segment_data['url'] != '' ) {
						$output .= '<a href="'.esc_url($comment_segment_data['url']).'" class="db-see-all-listing dt-button dt-button-invert">'.esc_html__('See all reviews', 'directory-builder').'</a>';
					}
					$output .= '
					<div class="clearfix"></div>
				</div>';
			}

			if ( isset($_GET['reviews']) && $_GET['reviews'] != '' && intval($total_reviews['0']->count) > 25 ) {
				$total_review_pages = intval($total_reviews['0']->count)/25;
				$output .= '<div class="navigation paging-navigation">' . paginate_links( array(
					'format' => '?db-page=%#%',
					'total' => ( is_float( $total_review_pages ) ? ceil( $total_review_pages ) : round( $total_review_pages ) ),
					'current' => ( isset( $_GET['db-page'] ) ? intval( $_GET['db-page'] ) : 1 ),
					'prev_text' => '',
					'next_text' => '',
				) ) . '</div>';
			}
		}

		if ( isset($_GET['invoices']) ) {
			$author_listings = $wpdb->get_results( "SELECT ID FROM $wpdb->posts WHERE post_author='".get_current_user_id()."' && post_type='listings' && post_status='publish'" );
			$valid_posts = array();
			if ( !empty($author_listings) ) {
				foreach ($author_listings as $post_data) {
					$valid_posts[] = $post_data->ID;
				}
			}

			$author_invoice_info = array();
			if ( !empty($valid_posts) ) {
				foreach ($valid_posts as $listing_id) {
					$meta_info = get_post_meta($listing_id, 'db_order_info', true);
					if ( isset($meta_info['payment_history']) && !empty($meta_info['payment_history']) ) {
						foreach ($meta_info['payment_history'] as $history_key => $history_value) {
							$history_info = explode('===', $history_value);
							$author_invoice_info[strtotime($history_info['0'])] = array( 'amount' => $history_info['1'], 'status' => $history_info['2'], 'gateway' => $history_info['3'], 'listing_id' => $listing_id, 'prow' => $history_key );
						}
					}
				}
			}

			krsort($author_invoice_info);

			$output .= '
			<h2 class="db-account-title">'.esc_html__('Your invoices', 'directory-builder').'</h2>
			<table class="db-account-listings table table-striped table-hover">
				<thead>
					<tr>
						<th style="width: 20%;">'.__('Listing name', 'directory-builder').'</th>
						<th style="width: 20%;">'.__('Invoice date', 'directory-builder').'</th>
						<th style="width: 15%;">'.__('Invoice number', 'directory-builder').'</th>
						<th style="width: 15%;">'.__('Invoice status', 'directory-builder').'</th>
						<th style="width: 15%;">'.__('Payment gateway', 'directory-builder').'</th>
						<th style="width: 10%;"></th>
					</tr>
				</thead>
				<tbody>';
				if ( !empty($author_invoice_info) ) {
					$date_format = get_option('date_format').' '.get_option('time_format');
					$loops = 0;
					foreach ($author_invoice_info as $timestamp => $invoice_data) {
						$output .= '
							<tr>
								<td><a href="'.esc_url(get_permalink($invoice_data['listing_id'])).'">'.esc_attr(get_the_title($invoice_data['listing_id'])).'</a></td>
								<td class="db-align-center db-status">'.date($date_format, $timestamp).'</td>
								<td class="db-align-center">'.sprintf('%d-%d-%d', $invoice_data['listing_id'], get_current_user_id(), $invoice_data['prow']).'</td>
								<td class="db-align-center">'.$invoice_data['status'].'</td>
								<td class="db-align-center">'.$invoice_data['gateway'].'</td>
								<td>
									<a href="'.esc_url(add_query_arg(array( 'invoices' => '', 'lid' => $invoice_data['listing_id'], 'prow' => $invoice_data['prow'] ), get_permalink())).'" class="db-account-listing-option view" target="_blank">
										<span class="db-account-listing-option-hover">'.esc_html__('View invoice', 'directory-builder').'</span>
										<svg width="18px" height="12px" viewBox="0 0 18 12" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"><g   transform="translate(-1164.000000, -859.000000)" fill="#53666D"><g id="listings" transform="translate(149.000000, 683.000000)"><g id="eye-copy" transform="translate(1008.000000, 166.000000)"><g id="eye-(2)" transform="translate(7.000000, 10.000000)"><g id="Layer_1"><g id="Group"><path d="M17.9640352,5.82672414 C16.4323125,2.29437931 12.9136289,0.011862069 9,0.011862069 C5.08637109,0.011862069 1.56775781,2.29431034 0.0359648437,5.82672414 C-0.0119882812,5.93727586 -0.0119882812,6.06213793 0.0359648437,6.17268966 C1.56765234,9.70544828 5.08630078,11.9881379 9,11.9881379 C12.9138047,11.9881379 16.432418,9.70544828 17.9640352,6.17268966 C18.0119883,6.06213793 18.0119883,5.93727586 17.9640352,5.82672414 L17.9640352,5.82672414 Z M9,11.1042069 C5.51271094,11.1042069 2.37104297,9.10689655 0.942503906,5.99975862 C2.37107813,2.89293103 5.51281641,0.895827586 9,0.895827586 C12.4872539,0.895827586 15.628957,2.89293103 17.0574961,5.99968966 C15.628957,9.10682759 12.4872891,11.1042069 9,11.1042069 L9,11.1042069 Z"  ></path><path d="M9,2.61465517 C7.09685156,2.61465517 5.54857031,4.13331034 5.54857031,5.99996552 C5.54857031,7.86662069 7.09688672,9.38527586 9,9.38527586 C10.9031133,9.38527586 12.4514297,7.86665517 12.4514297,5.99996552 C12.4514297,4.13327586 10.9031133,2.61465517 9,2.61465517 L9,2.61465517 Z M9,8.50141379 C7.59382031,8.50141379 6.44976563,7.37927586 6.44976563,6.00003448 C6.44976563,4.6207931 7.59382031,3.49865517 9,3.49865517 C10.4061797,3.49865517 11.5502344,4.6207931 11.5502344,6.00003448 C11.5502344,7.37927586 10.4061797,8.50141379 9,8.50141379 L9,8.50141379 Z"  ></path><path d="M9,4.20268966 C7.98964453,4.20268966 7.16755078,5.00896552 7.16755078,6.00003448 C7.16755078,6.24410345 7.36924219,6.442 7.61814844,6.442 C7.86705469,6.442 8.06874609,6.24410345 8.06874609,6.00003448 C8.06874609,5.49637931 8.48647266,5.08662069 9,5.08662069 C9.24890625,5.08662069 9.45059766,4.88872414 9.45059766,4.64465517 C9.45059766,4.40051724 9.24883594,4.20268966 9,4.20268966 L9,4.20268966 Z"  ></path></g></g></g></g></g></g></g></svg>
									</a>
									<a href="'.esc_url(add_query_arg(array( 'invoices' => '', 'lid' => $invoice_data['listing_id'], 'prow' => $invoice_data['prow'] ), get_permalink())).'" class="db-account-listing-option download" target="_blank" download>
										<span class="db-account-listing-option-hover">'.esc_html__('Download invoice', 'directory-builder').'</span>
										<svg width="16px" height="15px" viewBox="0 0 16 15" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <g id="My-account" transform="translate(-1207.000000, -1734.000000)" fill-rule="nonzero" fill="#53666D"> <g id="listings-copy" transform="translate(149.000000, 1499.000000)"> <g id="download" transform="translate(1050.000000, 228.000000)"> <path d="M19.4681977,14.9806033 C19.6294045,14.8193964 19.6294045,14.5656045 19.4681977,14.4043977 C19.312437,14.2431908 19.0531989,14.2431908 18.8978013,14.4043977 L15.9761086,17.3206442 L15.9761086,7.68490376 C15.9761086,7.46015817 15.797474,7.27571429 15.5727284,7.27571429 C15.3479828,7.27571429 15.1635389,7.46015817 15.1635389,7.68490376 L15.1635389,17.3206442 L12.2476554,14.4043977 C12.0864486,14.2431908 11.8268474,14.2431908 11.6714498,14.4043977 C11.510243,14.5656045 11.510243,14.8193964 11.6714498,14.9806033 L15.2848071,18.5939605 C15.4405678,18.7497212 15.6998059,18.7497212 15.8610127,18.5939605 L19.4681977,14.9806033 Z M22.3321609,17.6259932 C22.3321609,17.4012476 22.5107956,17.222613 22.7355411,17.222613 C22.9602867,17.222613 23.1447306,17.4012476 23.1447306,17.6259932 L23.1447306,21.5908105 C23.1447306,21.8155561 22.9602867,22 22.7355411,22 L8.40338022,22 C8.17863462,22 8,21.8155561 8,21.5908105 L8,17.6259932 C8,17.4012476 8.17863462,17.222613 8.40338022,17.222613 C8.62812581,17.222613 8.8125697,17.4012476 8.8125697,17.6259932 L8.8125697,21.1874303 L22.3321609,21.1874303 L22.3321609,17.6259932 Z" id="Shape"></path> </g> </g> </g> </g> </svg>
									</a> 
								</td>
							</tr>';

							if ( $loops == 4 && $_GET['invoices'] != 'all' ) {
								break;
							}

							$loops++;
					}
				} else {
					$output .= '<tr><td colspan="6" class="db-nothing-found">'.esc_html__('No invoices found!', 'directory-builder').'</td></tr>';
				}
				$output .= '</tbody>
			</table>';

			if ( count($author_invoice_info) > 5 ) {
				$output .= '<a href="'.esc_url(add_query_arg('invoices', 'all', get_permalink())).'" class="db-see-all-listing dt-button dt-button-invert">'.esc_html__('See all invoices', 'directory-builder').'</a>';
			}
		}

		if ( isset($_GET['tid']) && is_numeric($_GET['tid']) ) {
			$support_table = $wpdb->prefix.'directory_support';
			$check_author = $wpdb->get_results( $wpdb->prepare( "SELECT author FROM $support_table WHERE ID='%d'", $_GET['tid'] ) );
			if ( isset($check_author['0']->author) && $check_author['0']->author == get_current_user_id() ) { // Check if user is tickets author
				if ( isset($_POST['db-support-content']) && $_POST['db-support-content'] != '' && isset($_GET['tid']) && is_numeric($_GET['tid']) ) { // Insert a reply
					$reply_status = $wpdb->query( $wpdb->prepare( "INSERT INTO $support_table (`author`,`content`,`date`,`parent`) VALUES ('%d','%s','%d','%d')", get_current_user_id(), $_POST['db-support-content'], time(), $_GET['tid'] ) );

					if ( $reply_status ) {
						$status_type = true;
						$status_message = esc_html__('Your reply was added!','directory-builder');
					} else {
						$status_type = false;
						$status_message = esc_html__('There was an issue while adding your reply!','directory-builder');
					}
				}

				$support_tickets = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM $support_table WHERE ID='%d' || parent='%d' ORDER BY `date` ASC", intval($_GET['tid']), intval($_GET['tid']) ) );
				if ( !empty($support_tickets) ) {

					if ( isset($status_message) ) {
						$output .= '<span class="db-support-notice'.($status_type?' success':' failed').'">'.$status_message.'</span>';
					}

					$output .= '
					<h2 class="db-account-title">'.$support_tickets['0']->subject.'</h2>
					<div class="db-support-tickets">';
						if ( !empty($support_tickets) ) {
							$date_format = get_option('date_format').' '.get_option('time_format');
							foreach ($support_tickets as $ticket_data) {
								$output .= '
								<div class="db-support-ticket '.($ticket_data->author==get_current_user_id()?'right':'left').'">
									<span class="db-support-author">'.get_avatar($ticket_data->author, 40).'</span>
									<div class="db-support-text">'.esc_attr(stripslashes($ticket_data->content)).'<span class="db-support-time">'.sprintf( esc_html__('%s ago'), human_time_diff($ticket_data->date, time()) ).'</span></div>
									<div class="clearfix"></div>
								</div>';
							}
						}
						$output .= '
					</div>';

					if ( $support_tickets['0']->status != 'closed' ) {
						$output .= '
						<form method="post" class="db-support-form">
							<h2 class="db-account-title">'.esc_html__('Leave a reply', 'directory-builder').'</h2>
							<textarea name="db-support-content" placeholder="'.esc_attr__('Your reply', 'directory-builder').'" required></textarea>
							<button type="submit" name="db-support-reply"></button>
						</form>';
					}
				}
			} else {
				$output .= esc_html__('Nothing to see here!', 'directory-builder');
			}
		}

		if ( isset($_GET['tickets']) && $_GET['tickets'] == 'submit' ) {
			if ( isset($_POST['db-support-subject']) && $_POST['db-support-subject'] != '' && isset($_POST['db-support-content']) && $_POST['db-support-content'] != '' ) {
				$support_table = $wpdb->prefix.'directory_support';
				$new_status = $wpdb->query( $wpdb->prepare( "INSERT INTO $support_table (`author`,`subject`,`content`,`date`,`status`,`parent`) VALUES ('%d','%s','%s','%d','%s','%s')", get_current_user_id(), $_POST['db-support-subject'], $_POST['db-support-content'], time(), 'waiting', '0' ) );

				if ( $new_status ) {
					$status_type = true;
					$status_message = esc_html__('Your message was sent!','directory-builder');
					db_insert_activity( '0', 'supportnew', array( 'support-parent' => $wpdb->insert_id ), get_current_user_id() );
				} else {
					$status_type = false;
					$status_message = esc_html__('There was an issue while sending your message!','directory-builder');
				}
			}

			if ( isset($status_message) ) {
				$output .= '<span class="db-support-notice'.($status_type?' success':' failed').'">'.$status_message.'</span>';
			}

			$output .= '
			<h2 class="db-account-title">'.esc_html__('Submit a ticket', 'directory-builder').'</h2>
			<form method="post" class="db-support-form new">
				<input type="text" name="db-support-subject" placeholder="'.esc_attr__('Subject', 'directory-builder').'" required>
				<textarea name="db-support-content" placeholder="'.esc_attr__('Message', 'directory-builder').'" required></textarea>
				<button type="submit" name="db-support-reply"></button>
			</form>';
		}

		if ( isset($_GET['bookings']) && $_GET['bookings'] == 'all' ) {
			$output .= '
			<div class="db-account-favorites">
				<h2 class="db-account-title">'.esc_html__('Your bookings', 'directory-builder').'</h2>
				<table class="db-account-listings table table-striped table-hover">
					<thead>
						<tr>
							<th style="width: 80%;">'.__('Listing', 'directory-builder').'</th>
							<th style="width: 20%;"></th>
						</tr>
					</thead>
					<tbody>';
					if ( !empty($user_listings) ) {
						$date_format = get_option('date_format') . ' ' . get_option('time_format');
						$booking_table = $wpdb->prefix . 'directory_booking';
						$bookings = $wpdb->get_results( $wpdb->prepare( "SELECT distinct listing_id FROM $booking_table WHERE user_id='%d'", get_current_user_id() ) );

						if ( !empty($bookings) ) {
							foreach ($bookings as $booking_listing) {
								$output .= '
								<tr>
									<td><a href="'.esc_url(get_the_permalink($booking_listing->listing_id)).'">'.get_the_title($booking_listing->listing_id).'</a></td>
									<td>';
										if ( !empty($bookings) ) {
											$output .= '
											<a href="'.esc_url(add_query_arg('bookings', intval($booking_listing->listing_id), get_the_permalink())).'" class="db-account-listing-option view">
												<span class="db-account-listing-option-hover">'.esc_html__('View calendar', 'directory-builder').'</span>
												<svg width="18px" height="12px" viewBox="0 0 18 12" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><g stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"><g   transform="translate(-1164.000000, -859.000000)" fill="#53666D"><g id="listings" transform="translate(149.000000, 683.000000)"><g id="eye-copy" transform="translate(1008.000000, 166.000000)"><g id="eye-(2)" transform="translate(7.000000, 10.000000)"><g id="Layer_1"><g id="Group"><path d="M17.9640352,5.82672414 C16.4323125,2.29437931 12.9136289,0.011862069 9,0.011862069 C5.08637109,0.011862069 1.56775781,2.29431034 0.0359648437,5.82672414 C-0.0119882812,5.93727586 -0.0119882812,6.06213793 0.0359648437,6.17268966 C1.56765234,9.70544828 5.08630078,11.9881379 9,11.9881379 C12.9138047,11.9881379 16.432418,9.70544828 17.9640352,6.17268966 C18.0119883,6.06213793 18.0119883,5.93727586 17.9640352,5.82672414 L17.9640352,5.82672414 Z M9,11.1042069 C5.51271094,11.1042069 2.37104297,9.10689655 0.942503906,5.99975862 C2.37107813,2.89293103 5.51281641,0.895827586 9,0.895827586 C12.4872539,0.895827586 15.628957,2.89293103 17.0574961,5.99968966 C15.628957,9.10682759 12.4872891,11.1042069 9,11.1042069 L9,11.1042069 Z"  ></path><path d="M9,2.61465517 C7.09685156,2.61465517 5.54857031,4.13331034 5.54857031,5.99996552 C5.54857031,7.86662069 7.09688672,9.38527586 9,9.38527586 C10.9031133,9.38527586 12.4514297,7.86665517 12.4514297,5.99996552 C12.4514297,4.13327586 10.9031133,2.61465517 9,2.61465517 L9,2.61465517 Z M9,8.50141379 C7.59382031,8.50141379 6.44976563,7.37927586 6.44976563,6.00003448 C6.44976563,4.6207931 7.59382031,3.49865517 9,3.49865517 C10.4061797,3.49865517 11.5502344,4.6207931 11.5502344,6.00003448 C11.5502344,7.37927586 10.4061797,8.50141379 9,8.50141379 L9,8.50141379 Z"  ></path><path d="M9,4.20268966 C7.98964453,4.20268966 7.16755078,5.00896552 7.16755078,6.00003448 C7.16755078,6.24410345 7.36924219,6.442 7.61814844,6.442 C7.86705469,6.442 8.06874609,6.24410345 8.06874609,6.00003448 C8.06874609,5.49637931 8.48647266,5.08662069 9,5.08662069 C9.24890625,5.08662069 9.45059766,4.88872414 9.45059766,4.64465517 C9.45059766,4.40051724 9.24883594,4.20268966 9,4.20268966 L9,4.20268966 Z"  ></path></g></g></g></g></g></g></g></svg>
											</a>';
										} else {
											$output .= esc_html__('No active bookings!','directory-builder');
										}
									$output .= '
									</td>
								</tr>';
							}
						} else {
							$output .= '<tr><td colspan="6" class="db-nothing-found">'.esc_html__('No bookings found!', 'directory-builder').'</td></tr>';
						}
					} else {
						$output .= esc_html__('No active bookings!','directory-builder');
					}
					$output .= '</tbody>
				</table>
				<div class="clearfix"></div>
			</div>';
		} else if ( isset($_GET['bookings']) && is_numeric($_GET['bookings']) ) {
			$current_listing = get_post( intval($_GET['bookings']) );
			if ( !is_null($current_listing) && $current_listing->post_author == get_current_user_id() ) {
				$listing_hop_value = get_post_meta( intval($_GET['bookings']), 'hop', true );
				$listing_hop = ($listing_hop_value!='always'?json_decode($listing_hop_value, true):'always');
				if ( ( is_array($listing_hop) && !empty($listing_hop) ) || $listing_hop == 'always' ) {
					if ( !isset($_GET['wn']) ) {
						$first_monday = (date('D', time())=='Mon'?strtotime('today'):strtotime('previous monday'));
					} else {
						$first_monday = strtotime(date('Y',time()).'W'.intval($_GET['wn']));
					}
					if ( is_array($listing_hop) ) {
						$listing_timezone = $listing_hop['0'];
						$listing_format = $listing_hop['1'];
						unset($listing_hop['0']);
						unset($listing_hop['1']);
						$listing_hop = array_values($listing_hop);
						$listing_time_format = ($listing_format=='12h'?'g:i a':'H:i');
					} else {
						$listing_timezone = 'UTC+0';
						$listing_format = '24h';
						$listing_time_format = 'H:i';
					}

					if ( is_array($listing_hop) && !empty($listing_hop) ) {
						$listing_starts = 9999999999999;
						$listing_ends = 0;
						foreach ($listing_hop as $hop_data) {
							if ( $hop_data['0']['0'] < $listing_starts ) {
								$listing_starts = $hop_data['0']['0'];
							}
							if ( $hop_data['0']['1'] > $listing_ends ) {
								$listing_ends = $hop_data['0']['1'];
							}
						}

						

						$listing_starts_at = strtotime( '1970-01-01 '.date($listing_time_format, $listing_starts) );
						$listing_ends_at = strtotime( '1970-01-01 '.date($listing_time_format, $listing_ends) );

						$listing_hours = array();

						for ($hours_i=0; $hours_i < 24; $hours_i++) {
							$current_oclock = strtotime(date('1970-01-01 '.$listing_time_format, $listing_starts) . ' +' . $hours_i . ' hours');
	
							if ( $current_oclock <= $listing_ends_at && $current_oclock >= $listing_starts_at ) {
								$listing_hours[$current_oclock] = date($listing_time_format, $current_oclock);
							}
						}
					} else if ( $listing_hop == 'always' ) {
						for ($i=0; $i < 24; $i++) { 
							$listing_hours[] = ($i<10?'0'.$i:$i).':00';
						}
					}

					$bookings_table = $wpdb->prefix.'directory_booking';
					$date_format = get_option('date_format') . ' ' . get_option('time_format');
					$curr_week_nr = date( 'W', $first_monday );

					$output .= '
					<div class="db-booking-calendar">
						<span class="db-booking-week">
							<a href="'.esc_url(add_query_arg( array( 'bookings' => intval($_GET['bookings']), 'wn' => $curr_week_nr-1 ), get_permalink() )).'" title="'.esc_attr__('Previous week', 'directory-builder').'"><svg width="7px" height="11px" viewBox="0 0 7 11" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" stroke-linecap="square"> <g id="Single-listing" transform="translate(-685.000000, -623.000000)" stroke="#9B9B9B" stroke-width="2"> <g id="Listing" transform="translate(-1.000000, 172.000000)"> <g id="book-now" transform="translate(229.000000, 430.000000)"> <g id="step-1" transform="translate(431.000000, 0.000000)"> <g id="month" transform="translate(27.000000, 12.000000)"> <g id="left-bullet-copy-2" transform="translate(2.500000, 14.500000) rotate(-270.000000) translate(-2.500000, -14.500000) translate(-2.000000, 12.000000)"> <path d="M0.5,0.5 C0.5,0.5 1.13381189,1.13381189 1.91025037,1.91025037 L4.5,4.5" id="Line" fill="#D8D8D8"></path> <path d="M8.5,0.5 C8.5,0.5 7.86618811,1.13381189 7.08974963,1.91025037 L4.5,4.5" id="Line-Copy-2"></path> </g> </g> </g> </g> </g> </g> </g> </svg></a>
							<span>'.sprintf( __('Week <strong>%d</strong>', 'directory-builder'), $curr_week_nr ).'</span>
							<a href="'.esc_url(add_query_arg( array( 'bookings' => intval($_GET['bookings']), 'wn' => $curr_week_nr+1 ), get_permalink() )).'" title="'.esc_attr__('Next week', 'directory-builder').'"><svg width="7px" height="11px" viewBox="0 0 7 11" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd" stroke-linecap="square"> <g id="Single-listing" transform="translate(-977.000000, -623.000000)" stroke="#9B9B9B" stroke-width="2"> <g id="Listing" transform="translate(-1.000000, 172.000000)"> <g id="book-now" transform="translate(229.000000, 430.000000)"> <g id="step-1" transform="translate(431.000000, 0.000000)"> <g id="month" transform="translate(27.000000, 12.000000)"> <g id="left-bullet-copy-3" transform="translate(294.500000, 14.500000) rotate(-90.000000) translate(-294.500000, -14.500000) translate(290.000000, 12.000000)"> <path d="M0.5,0.5 C0.5,0.5 1.13381189,1.13381189 1.91025037,1.91025037 L4.5,4.5" id="Line" fill="#D8D8D8"></path> <path d="M8.5,0.5 C8.5,0.5 7.86618811,1.13381189 7.08974963,1.91025037 L4.5,4.5" id="Line-Copy-2"></path> </g> </g> </g> </g> </g> </g> </g> </svg></a>
						</span>
						<span class="db-booking-month">'.sprintf( '<strong>%s</strong> %d', date( 'F', $first_monday ), date( 'Y', $first_monday ) ).'</span>
						<div class="clearfix"></div>
						<div class="db-booking-calendar-items">';
							$output .= '
							<div class="db-booking-calendar-day hour-names">
								<div class="db-booking-calendar-item"> </div>';
								foreach ($listing_hours as $h_timestamp => $h_value) {
									$output .= '<div class="db-booking-calendar-item">'.$h_value.'</div>';
								}
							$output .= '
							</div>';
							for ($day_i=0; $day_i <= 6; $day_i++) {
								$current_starts_at = strtotime( date('Y-m-d', $first_monday) . ' +' . $day_i . ' days' );
								$current_ends_at = strtotime(date('Y-m-d H:i', $current_starts_at)  . ' +1 days');

								$current_day_bookings = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM $bookings_table WHERE `timestamp` >= %d && `timestamp` <= %d && listing_id='%d'", $current_starts_at, $current_ends_at, $_GET['bookings'] ) );

								$output .= '
								<div class="db-booking-calendar-day'.(isset($listing_hop[$day_i])&&!empty($listing_hop[$day_i])?'':' closed').'">
									<span class="db-booking-cal-day">'.sprintf( '<strong>%d</strong><span>%s</span>', date('j', $current_starts_at), date('D', $current_starts_at) ).'</span>
									<div class="db-booking-calendar-items">';
									foreach ($listing_hours as $h_timestamp => $h_value) {
										$booking_day_item = ' ';
										if ( !empty($current_day_bookings) ) {
											foreach ($current_day_bookings as $current_booking_data) {
												$current_booking_info = json_decode( $current_booking_data->booking_info, true );
												if ( date( $listing_time_format, $current_booking_data->timestamp ) == $h_value ) {
													$booking_day_item = '
													<div class="db-booking-item '.$current_booking_data->status.'">
														<span class="db-curr-booking-info">'.$current_booking_info['name'].'</span>
														<div class="db-curr-booking-data-wrapper">
															<div class="db-curr-booking-data" data-cancelled="'.esc_attr__('This appointment is cancelled!', 'directory-builder').'">
																<span class="db-curr-booking-data-item">'.sprintf( __( '<span>Appointment:</span> %s %s', 'directory-builder' ), date($date_format, $current_booking_data->timestamp), $listing_timezone ).'</span>
																<span class="db-curr-booking-data-item">'.sprintf( __( '<span>Name:</span> %s', 'directory-builder' ), $current_booking_info['name'] ).'</span>
																<span class="db-curr-booking-data-item">'.sprintf( __( '<span>Email:</span> <a href="mailto:%s">%s</a>', 'directory-builder' ), $current_booking_info['email'], $current_booking_info['email'] ).'</span>
																<span class="db-curr-booking-data-item comments">'.sprintf( __( '<span>Comments:</span> %s', 'directory-builder' ), ($current_booking_info['comments']!=''?$current_booking_info['comments']:esc_html__('None', 'directory-builder')) ).'</span>';
																if ( $current_booking_data->status == 'active' ) {
																	$booking_day_item .= '<a href="javascript:void(0)" class="db-cancel-booking dt-button dt-button-danger" data-id="'.intval($current_booking_data->ID).'">'.esc_html__('Cancel appointment','directory-builder').'</a>';
																} else {
																	$booking_day_item .= '<span class="db-curr-booking-data-item cancelled">'.esc_attr__('This appointment is cancelled!', 'directory-builder').'</span>';
																}
															$booking_day_item .= '
															</div>
														</div>
													</div>';
													break;
												}
											}
										}
										$output .= '<div class="db-booking-calendar-item">'.$booking_day_item.'</div>';
									}
								$output .= '
									</div>
								</div>';
							}
							$output .= '
							<div class="clearfix"></div>
						</div>
					</div>';
				}
			} else {
				$output .= '<span class="db-support-notice failed">'.esc_html__('There\'s no valid data to display!', 'directory-builder').'</span>';
			}
		}
	}
	$output .= '</div></div>';

	return $output;
}
add_shortcode('directory_account','db_account_shortcode');

function db_account_delete_listing_func() {
	if ( !current_user_can('manage_options') ) die(0);

	$listing_id = ( isset($_POST['listing_id']) ? intval($_POST['listing_id']) : '' );
	$deleting = false;

	global $wpdb;
	$package_list = $wpdb->get_results('SELECT * FROM '.$wpdb->posts.' WHERE ID="'.$listing_id.'" && post_author="'.get_current_user_id().'"');
	if ( !empty($package_list) ) {
		$deleting = wp_delete_post( $package_list['0']->ID, true );
	}

	if ( $deleting ) {
		echo '{"save_response": "0"}';
	} else {
		echo '{"save_response": "failed"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_account_delete_listing', 'db_account_delete_listing_func' );

function db_add_to_url( $name, $value ) {
	$params = $_GET;
	unset($params[$name]);
	$params[$name] = $value;
	return basename($_SERVER['PHP_SELF']).'?'.http_build_query($params);
}

function db_install_theme( $file ) {
	require_once plugin_dir_path( __FILE__ ) . 'includes/file_system.php';
	$themes_dir = wp_normalize_path( WP_CONTENT_DIR . '/db-plugin-themes/' );
	list( $temp_dir, $unzipped_dir, ) = WPDB_FS::unzip_to_temp_dir( $file );
	$package_dir = $unzipped_dir;

	// Search for a dir containing 'theme.json'.
	$files = WPDB_FS::ls( $unzipped_dir, 'recursive=1' );
	foreach ( $files as $f ) {
		if ( 'theme_data.json' == basename( $f ) ) {
			$package_dir = dirname( $f );
			break;
		}
	}

	if ( ! file_exists( WPDB_FS::join( $package_dir, 'theme_data.json' ) ) ) {
		WPDB_FS::rmdir( $temp_dir );
		return __( 'ZIP file is not a valid Directory builder theme file.', 'directory-builder' );
	}

	if ( ! WPDB_FS::mkdir( $themes_dir ) ) {
		WPDB_FS::rmdir( $temp_dir );
		return __( 'Could not create themes directory.', 'directory-builder' );
	}

	$dest_dir = $themes_dir . basename( $package_dir );

	if ( ! WPDB_FS::rmdir( $dest_dir ) ) {
		WPDB_FS::rmdir( $temp_dir );
		return sprintf( __( 'Could not remove previous theme directory "%s".', 'directory-builder' ), $dest_dir );
	}

	if ( ! WPDB_FS::movedir( $package_dir, $themes_dir ) ) {
		WPDB_FS::rmdir( $temp_dir );
		return __( 'Could not move new theme into theme directory.', 'directory-builder');
	}

	WPDB_FS::rmdir( $temp_dir );

	return '';
}

function db_upload_theme( $theme_file ) {
	$file_extension = pathinfo($theme_file['name'], PATHINFO_EXTENSION);

	if ( $file_extension != 'zip' || !is_uploaded_file( $theme_file['tmp_name'] ) || UPLOAD_ERR_OK != $theme_file['error'] ) {
		return '<p class="db-theme-status-inner error">'.__('This is not a valid Directory builder plugin theme!', 'directory-builder').'</p>';
	}

	$dest = wp_normalize_path( untrailingslashit( get_temp_dir() ) . DIRECTORY_SEPARATOR . $theme_file['name'] );

	if ( ! move_uploaded_file( $theme_file['tmp_name'], $dest ) ) {
		return '<p class="db-theme-status-inner error">'.$res->get_error_message().'</p>';
	}

	$res = db_install_theme( $dest );

	if ( is_wp_error( $res ) ) {
		return '<p class="db-theme-status-inner error">'.$res->get_error_message().'</p>';
	} else {
		return $res;
	}
}

function db_theme_html() {
	if ( !current_user_can('manage_options') )  {
		wp_die( __('You do not have sufficient permissions to access this page.', 'directory-builder') );
	}
	$main_settings = get_option( 'db_main_settings');
	$error_message = '';
	?>

	<?php
	if ( isset( $_FILES['db-theme-zip'] ) ) {
		$theme_file = isset( $_FILES['db-theme-zip'] ) ? $_FILES['db-theme-zip'] : false;

		if ( $theme_file !== false ) {
			$error_message = db_upload_theme( $theme_file );
		}

	}
	?>

	<div class="db-main-wrapper container-fluid" id="db-main-wrapper">
		<div class="db-main-content main-card clearfix">
			<div class="db-box-title">
				<h3 class="db-main-title">Theme settings</h3>
			</div>
			<div class="db-theme-status"><?php echo $error_message; ?></div>
			<div class="db-row-group clearfix">
				<span class="db-row-label col-sm-2">Upload theme</span>
				<div class="col-sm-10">
					<form action="" method="post" enctype="multipart/form-data">
						<input type="file" name="db-theme-zip">
						<input type="submit" value="Upload">
					</form>
				</div>
			</div>
		</div>
		<div class="db-theme-list">
			<?php
				$theme_list = db_get_theme_list();
				$theme_list_output = '';

				foreach ( $theme_list as $theme_value ) {
					$theme_list_output .= '
					<div class="db-theme-list-item col-md-4">
						<div class="db-theme-list-inner main-card">
							<div class="db-box-title">
								<h3 class="db-main-title">'.(isset($theme_value['theme_name'])?$theme_value['theme_name']:__('No name', 'directory-builder')).'</h3>';
								if ( ( $main_settings['db_theme_id'] != '' && $main_settings['db_theme_id'] == $theme_value['theme_id'] ) ) {
									$theme_list_output .= '<span class="db-active-theme db-button db-default-button non-clickable">'.__('Active', 'directory-builder').'</span>';
								} else {
									$theme_list_output .= '<a href="javascript:void(0)" class="db-activate-theme db-button db-primary-button" data-id="'.$theme_value['theme_id'].'" data-path="'.$theme_value['theme_path'].'" data-url="'.$theme_value['theme_url'].'">'.__('Activate', 'directory-builder').'</a>';
								}
							$theme_list_output .= '
							</div>
							<div class="db-theme-list-overlay clearfix">
								<img src="'.$theme_value['theme_image'].'">
								<div class="db-theme-info">';
									if ( isset($theme_value['theme_version']) ) {
										$theme_list_output .= '
										<div class="db-theme-list-row">
											<span class="db-theme-row-label">'.__('Version', 'directory-builder').':</span>
											<span class="db-theme-row-value">'.$theme_value['theme_version'].'</span>
										</div>';
									}
									if ( isset($theme_value['updated']) ) {
										$theme_list_output .= '
										<div class="db-theme-list-row">
											<span class="db-theme-row-label">'.__('Updated', 'directory-builder').':</span>
											<span class="db-theme-row-value">'.$theme_value['updated'].'</span>
										</div>';
									}
									if ( isset($theme_value['theme_author']) ) {
										$theme_list_output .= '
										<div class="db-theme-list-row">
											<span class="db-theme-row-label">'.__('Author', 'directory-builder').':</span>
											<span class="db-theme-row-value">'.$theme_value['theme_author'].'</span>
										</div>';
									}
									if ( isset($theme_value['theme_description']) ) {
										$theme_list_output .= '
										<div class="db-theme-list-row description">
											<span class="db-theme-row-value">'.$theme_value['theme_description'].'</span>
										</div>';
									}
							$theme_list_output .= '
								</div>
							</div>
						</div>
					</div>';
				}

				echo $theme_list_output;
			?>
		</div>
	</div>
	<?php
}

function db_get_theme_list() {
	$available_themes = array();

	// Check plugin theme
	if ( file_exists( plugin_dir_path( __FILE__ ).'/template/theme_data.json' ) ) {
		$theme_info = json_decode( file_get_contents( plugin_dir_path( __FILE__ ).'/template/theme_data.json' ), true );
		$theme_info['theme_image'] = plugin_dir_url( __FILE__ ).'template/theme_preview.jpg';
		$theme_info['theme_path'] = plugin_dir_path( __FILE__ ).'template/';
		$theme_info['theme_url'] = plugin_dir_url( __FILE__ ).'template/';

		$available_themes[] = $theme_info;
	}

	// Check WordPress theme
	if ( file_exists( get_template_directory().'/directory-template/theme_data.json' ) ) {
		$theme_info = json_decode( file_get_contents( get_template_directory().'/directory-template/theme_data.json' ), true );
		$theme_info['theme_image'] = get_template_directory_uri().'/directory-template/theme_preview.jpg';
		$theme_info['theme_path'] = get_template_directory().'/directory-template/';
		$theme_info['theme_url'] = get_template_directory_uri().'/directory-template/';

		$available_themes[] = $theme_info;
	}

	// Check uploaded themes
	$themes_dir = wp_normalize_path( WP_CONTENT_DIR . '/db-plugin-themes/' );
	if ( file_exists( $themes_dir ) ) {
		$themes_dir_url = WP_CONTENT_URL . '/db-plugin-themes/';
		$plugin_custom_themes = scandir($themes_dir);
		unset($plugin_custom_themes['0']);
		unset($plugin_custom_themes['1']);
		
		if ( !empty($plugin_custom_themes) ) {
			foreach ($plugin_custom_themes as $file_directory) {
				if ( file_exists($themes_dir.$file_directory.'/theme_data.json') ) {
					$theme_info = json_decode( file_get_contents( $themes_dir.$file_directory.'/theme_data.json' ), true );
					$theme_info['theme_image'] = $themes_dir_url.$file_directory.'/theme_preview.jpg';
					$theme_info['theme_path'] = $themes_dir.$file_directory.'/';
					$theme_info['theme_url'] = $themes_dir_url.$file_directory.'/';

					$available_themes[] = $theme_info;
				}
			}
		}
	}

	return $available_themes;
}

function db_activate_theme() {
	if ( !current_user_can('manage_options') ) die(0);

	global $wpdb;
	$theme_id = ( isset($_POST['theme_id']) ? sanitize_text_field($_POST['theme_id']) : '' );
	$theme_path = ( isset($_POST['theme_path']) ? sanitize_text_field($_POST['theme_path']) : '' );
	$theme_url = ( isset($_POST['theme_url']) ? esc_url($_POST['theme_url']) : '' );
	$main_settings = get_option( 'db_main_settings');

	$main_settings['db_theme_id'] = $theme_id;
	$main_settings['db_theme_path'] = $theme_path;
	$main_settings['db_theme_url'] = $theme_url;

	if ( !update_option( 'db_main_settings', $main_settings ) ) {
		echo '{"save_response": "failed"}';
	} else {
		echo '{"save_response": "0"}';
	}


	die(0);
}
add_action( 'wp_ajax_db_activate_theme', 'db_activate_theme' );

function db_directory_login_shortcode() {
	global $db_user_login;

	$output = '
	<div class="db-main-wrapper">';
		if ( is_wp_error($db_user_login) ) {
			$output .= '<p>'.$db_user_login->get_error_message().'</p>';
		}
		$output .= '
		<form method="post" id="db-login-form">
			<input type="text" name="login_user_email" placeholder="'.__('Username or email address', 'directory-builder').'" value="'.(isset($_POST['login_user_email'])?sanitize_email($_POST['login_user_email']):'').'" required>
			<input type="password" name="login_user_password" placeholder="'.__('Password', 'directory-builder').'" required>
			<input type="submit" name="db-sign-in" value="'.__('Sign in', 'directory-builder').'">
		</form>';
	$output .= '</div>';

	if ( !is_user_logged_in() ) {
		return $output;
	} else {
		$current_user = wp_get_current_user();
		return '<p>'.__('Nice to see you back', 'directory-builder').', '.$current_user->data->display_name.'. '.__('Not you?', 'directory-builder').' <a href="'.wp_logout_url( home_url( '/' ) ).'">'.__('Logout', 'directory-builder').'</a></p>';
	}
}
add_shortcode('directory_login','db_directory_login_shortcode');

function db_directory_register_shortcode() {
	global $db_user_register;

	$output = '
	<div class="db-main-wrapper">';
		if ( is_wp_error($db_user_register) ) {
			$output .= '<p><b>'.__('ERROR', 'directory-builder').':</b> '.$db_user_register->get_error_message().'</p>';
		} else if ( isset($db_user_register) ) {
			$output .= '<p>'.__('You are successfully registered and will shortly receive a confirmation email!', 'directory-builder').'</p>';
			$main_settings = get_option( 'db_main_settings', array() );
			$output .= '<script type="text/javascript">
			jQuery(document).ready(function($) {
				"use strict";
				jQuery(".db-register-form").hide();
			});
			</script>';
		}
		$output .= '
		<form method="post" id="db-register-form">';
			$reg_fields = array();
			if ( function_exists('db_get_registration_fields') ) {
				$reg_fields = db_get_registration_fields( 'shortcode' );
			}

			if ( !empty( $reg_fields ) ) {
				foreach ($reg_fields as $field_id => $field_settings) {
					if ( $field_settings['field_type'] == 'select' ) {
						$output .= '<div class="db-field-row single-select">';
					}
					$output .= $field_settings['field_html'];
					if ( $field_settings['field_type'] == 'select' ) {
						$output .= '</div>';
					}
				}
			}

			$gcaptcha_options = get_option( 'gglcptch_options', array() );
			if ( function_exists( 'gglcptch_init' ) && isset( $gcaptcha_options['public_key'] ) && $gcaptcha_options['public_key'] != '' && isset( $gcaptcha_options['private_key'] ) && $gcaptcha_options['private_key'] != '' ) {
				$output .= do_shortcode( '[bws_google_captcha]' );
			}

			$output .= '
			<input type="submit" name="db-register-action" value="'.__('Register', 'directory-builder').'">
		</form>';
	$output .= '</div>';

	return $output;
}
add_shortcode('directory_register','db_directory_register_shortcode');

function db_change_status_func() {
	if ( !current_user_can('manage_options') ) die(0);

	$listing_id = ( isset($_POST['listing_id']) ? intval($_POST['listing_id']) : '' );
	$listing_status = ( isset($_POST['listing_status']) ? sanitize_text_field($_POST['listing_status']) : '' );

	$listing_info = get_post_meta( $listing_id, 'db_order_info', true );

	$listing_info['payment_status'] = $listing_status;
	if ( $listing_status == 'Completed' ) {
		$listing_info['completed_on'] = time();
	} else {
		if ( isset($listing_info['completed_on']) ) {
			unset($listing_info['completed_on']);
		}
	}

	if ( update_post_meta( $listing_id, 'db_order_info', $listing_info ) ) {
		$db_listing = array( 'ID' => $listing_id );
		if ( $listing_status == 'Processing' || $listing_status == 'Pending' || $listing_status == 'Refunded' ) {
			$db_listing['post_status'] = 'pending';
		} else if ( $listing_status == 'Completed' ) {
			$db_listing['post_status'] = 'publish';
		}
		wp_update_post( $db_listing );

		echo '{"save_response": "0", "listing_status": "'.$listing_status.'"}';
	} else {
		echo '{"save_response": "failed"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_change_status', 'db_change_status_func' );

function db_body_classes($classes) {

	if ( is_page_template('template-listing_search.php') ) {
		$main_settings = get_option( 'db_main_settings');

		if ( $main_settings['search_position'] == 'bottom' || isset($_GET['mapontop']) ) {
			$classes[] = 'db-bottom-search';
		}
	}

	return $classes;
}
add_filter('body_class', 'db_body_classes');

function db_upload_images_func() {

	require_once( ABSPATH . 'wp-admin/includes/image.php' );
	require_once( ABSPATH . 'wp-admin/includes/file.php' );
	require_once( ABSPATH . 'wp-admin/includes/media.php' );

	$main_settings = get_option( 'db_main_settings', array());

	if ( isset($_FILES['file']) ) {
		$image_file_size = $_FILES['file']['size'];
		$file_size = getimagesize($_FILES['file']['tmp_name']);

		if ( !isset($_POST['valid']) ) {
			if ( $main_settings['image_min_size'] != '0' && round( $image_file_size/1000, 0 ) < intval($main_settings['image_min_size']) ) { // Check image min size
				echo '{"save_status": "false", "save_msg": "Image is too small, min image size is '.round($main_settings['image_min_size']/1000, 1).'MB"}';
				die(0);
			}

			if ( $main_settings['image_min_size'] != '0' && round( $image_file_size/1000, 0 ) > intval($main_settings['image_max_size']) ) { // Check image max size
				echo '{"save_status": "false", "save_msg": "Image is too large, max image size is '.round($main_settings['image_max_size']/1000, 1).'MB"}';
				die(0);
			}

			if ( $main_settings['image_min_width'] != '0' && $file_size['0'] < intval($main_settings['image_min_width']) ) { // Check image min width
				echo '{"save_status": "false", "save_msg": "Image is too small, min image width is '.$main_settings['image_min_width'].'px"}';
				die(0);
			}

			if ( $main_settings['image_max_width'] != '0' && $file_size['0'] > intval($main_settings['image_max_width']) ) { // Check image max width
				echo '{"save_status": "false", "save_msg": "Image is too large, max image width is '.$main_settings['image_max_width'].'px"}';
				die(0);
			}

			if ( $main_settings['image_min_height'] != '0' && $file_size['1'] < intval($main_settings['image_min_height']) ) { // Check image min height
				echo '{"save_status": "false", "save_msg": "Image is too small, min image height is '.$main_settings['image_min_height'].'px"}';
				die(0);
			}

			if ( $main_settings['image_max_height'] != '0' && $file_size['1'] > intval($main_settings['image_max_height']) ) { // Check image max height
				echo '{"save_status": "false", "save_msg": "Image is too large, max image height is '.$main_settings['image_max_height'].'px"}';
				die(0);
			}
		}

		$attachment_id = media_handle_upload( 'file', '0' );

		if ( !is_wp_error( $attachment_id ) ) {
			echo '{"save_status": "true", "save_msg": "File successfully uploaded", "attachment_id": "'.$attachment_id.'"}';
		} else {
			echo '{"save_status": "false", "save_msg": "Sorry, there was an error uploading your file"}';
		}
	} else {
		echo '{"save_status": "false", "save_msg": "Sorry, there was no file uploaded"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_upload_images', 'db_upload_images_func' );
add_action( 'wp_ajax_nopriv_db_upload_images', 'db_upload_images_func' );

function db_search_marker_window() {
	$output = '';
	$marker_id = ( isset($_POST['marker_id']) ? sanitize_text_field($_POST['marker_id']) : '' );
	$featured_listings = get_option('db_sticky_listings', array());

	if ( $marker_id == '' ) {
		die(0);
	}

	$listing_ratings = get_post_meta( $marker_id, 'directory_post_likes', true);
	if ( $listing_ratings != '' ) {
		$liked = $listing_ratings;
	} else {
		$liked = array();
	}

	$listing_phone = get_post_meta($marker_id, 'listingphone', true);
	$listing_address = get_post_meta($marker_id, 'listing_address', true);
	$listing_category = get_the_terms($marker_id, 'listing_category');
	$img = wp_get_attachment_image_src( get_post_thumbnail_id($marker_id), 'medium' );

	$output .= '<div class="dt-featured-listings-item">';
		$output .= '<div class="dt-featured-listings-item-inner">';
			$output .= '<div class="dt-featured-listings-image">';
				$output .= '<a href="'.get_permalink($marker_id).'" class="dt-featured-item-image" '.(isset($img['0'])?'style="background: url('.preg_replace('#^https?://#', '//', $img['0']).')"':'').'></a>';
				$output .= '<div class="dt-featured-image-overlay"></div>';
				if ( in_array($marker_id, $featured_listings) ) {
					$output .= '<span class="dt-featured-listings-image-note">
									<div class="db-favorite-tooltip">'.esc_html__( 'A business owner paid for this listing.', 'directory-builder' ).'</div>
									'.__('Featured', 'directory-builder').'
								</span>';
				}
				$output .= '<div class="dt-featured-listings-image-meta">';
					if ( isset($listing_phone) && $listing_phone != '' ) {
						$output .= '<span class="dt-featured-listings-phone"><img src="'.DIRECTORY_PUBLIC.'images/phone.svg">'.$listing_phone.'</span>';
					}
					if ( isset($listing_address) && $listing_address != '' ) {
						$output .= '<span class="dt-featured-listings-address"><img src="'.DIRECTORY_PUBLIC.'images/location.svg">'.$listing_address.'</span>';
					}
				$output .= '</div>';
			$output .= '</div>';
			$output .= '<div class="dt-featured-listings-data">';
				$output .= '<a href="'.get_permalink($marker_id).'" class="dt-featured-listings-title">'.get_the_title($marker_id).'</a>';
				$output .= '<p class="dt-featured-listings-description">'.(get_the_excerpt($marker_id)!=''?get_the_excerpt($marker_id):strip_shortcodes(strip_tags(get_post_field('post_content', $marker_id)))).'</p>';
				$output .= '<div class="dt-featured-listings-meta clearfix">';
					if ( isset($listing_category['0']) ) {
						$cat_meta = get_option( "listing_category_".$listing_category['0']->term_id);
						$tag_color = (isset($cat_meta['tag-category-color'])?$cat_meta['tag-category-color']:'#555');
						$output .= '
						<a href="'.get_permalink($main_settings['search_page_id']).'?search_category='.$listing_category['0']->term_id.'" class="dt-featured-listings-category '.$listing_category['0']->slug.'" style="color: '.$tag_color.'"><style type="text/css">.dt-featured-listings-category.'.$listing_category['0']->slug.':before { border-color: '.$tag_color.'; }</style>'.$listing_category['0']->name.'</a>';
					}
					$ratings = get_post_meta( $marker_id, 'listing_ratings', true);

					if ( $ratings == '' ) {
						$rating_stars = '<img src="'.DIRECTORY_PUBLIC.'images/star-empty.svg"><img src="'.DIRECTORY_PUBLIC.'images/star-empty.svg"><img src="'.DIRECTORY_PUBLIC.'images/star-empty.svg"><img src="'.DIRECTORY_PUBLIC.'images/star-empty.svg"><img src="'.DIRECTORY_PUBLIC.'images/star-empty.svg">';
						$listing_rating = 0;
					} else {
						$listing_rating = 0;
						$valid_ratings = 0;
						foreach ($ratings as $rating_value) {
							if ( $rating_value != null ) {
								$listing_rating += $rating_value;
								$valid_ratings++;
							}
						}
	
						$listing_rating = round(($listing_rating/$valid_ratings), 0, PHP_ROUND_HALF_DOWN);
						$rating_stars = '';
						for ($i=0; $i < $listing_rating; $i++) { 
							$rating_stars .= '<img src="'.DIRECTORY_PUBLIC.'images/star-colored.svg">';
						}
						if ( $listing_rating < 5 ) {
							for ($i=0; $i < 5-$listing_rating; $i++) { 
								$rating_stars .= '<img src="'.DIRECTORY_PUBLIC.'images/star-empty.svg">';
							}
						}
					}

					if ( !isset($_COOKIE['dt-data']) ) {
						$can_rate = true;
					} else {
						$rated_listings = json_decode(stripslashes($_COOKIE['dt-data']));
						if ( !in_array($marker_id, $rated_listings) ) {
							$can_rate = true;
						} else {
							$can_rate = false;
						}
					}

					$output .= '<span class="dt-featured-listings-rating'.(!$can_rate?' rated':'').'" data-original="'.$listing_rating.'" data-id="'.$marker_id.'">'.$rating_stars.'</span>';
				$output .= '</div>';
			$output .= '</div>';
		$output .= '</div>';
	$output .= '</div>';

	echo $output;

	die(0);
}
add_action( 'wp_ajax_db_marker_window', 'db_search_marker_window' );
add_action( 'wp_ajax_nopriv_db_marker_window', 'db_search_marker_window' );

function db_featured_status_func() {
	if ( !current_user_can('manage_options') ) die(0);

	global $wpdb;
	$listing_id = ( isset($_POST['listing_id']) ? intval($_POST['listing_id']) : '' );
	$featured_status = ( isset($_POST['featured_status']) ? sanitize_text_field($_POST['featured_status']) : '' );
	
	$featured_listings = get_option('db_sticky_listings', array());
	$featured_changed = false;

	if ( $featured_status == 'No' ) {
		if( ($key = array_search($listing_id, $featured_listings)) !== false ) {
			unset($featured_listings[$key]);
			$featured_changed = true;
		}
	} else if ( $featured_status == 'Yes' ) {
		if ( array_search($listing_id, $featured_listings) === false ) {
			$featured_listings[] = $listing_id;
			$featured_changed = true;
		}
	}
	
	if ( $featured_changed ) {
		update_option('db_sticky_listings', $featured_listings);
		echo '{"save_response": "0"}';
	} else {
		echo '{"save_response": "failed"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_featured_status', 'db_featured_status_func' );

function db_do_cities_autocomplete() {
	$city_value = ( isset($_POST['city_value']) ? esc_attr($_POST['city_value']) : '' );
	global $wpdb;
	$prepared_data = array();
	$cities = $wpdb->get_results('SELECT DISTINCT meta_value as city FROM ' . $wpdb->prefix . 'postmeta WHERE meta_key="listing_city" && meta_value LIKE "%' . $city_value . '%"');
	
	if ( !empty($cities) ) {
		foreach ($cities as $city_value) {
			$prepared_data[] =  $city_value->city;
		}

		echo json_encode( $prepared_data );
	} else {
		echo 'failed';
	}
	
	die(0);
}
add_action( 'wp_ajax_db_city_autocomplete', 'db_do_cities_autocomplete' );
add_action( 'wp_ajax_nopriv_db_city_autocomplete', 'db_do_cities_autocomplete' );

function db_do_address_autocomplete() {
	$address_value = ( isset($_POST['address_value']) ? esc_attr($_POST['address_value']) : '' );
	global $wpdb;
	$prepared_data = array();
	$addresses = $wpdb->get_results('SELECT DISTINCT meta_key, meta_value FROM ' . $wpdb->prefix . 'postmeta WHERE meta_key IN ("listing_address","listing_city","listing_neighborhood","listing_zip","listing_state","listing_country") && meta_value LIKE "%' . $address_value . '%"');

	if ( !empty($addresses) ) {
		$simplified_data = array();
		foreach ($addresses as $address_data) {
			if ( $address_data->meta_key != 'listing_address' ) {
				$simplified_data[] = $address_data->meta_value;
			} else {
				$exploded_address = explode(', ', $address_data->meta_value);
				if ( strpos(strtolower($exploded_address['0']), strtolower($address_value)) !== false ) {
					$simplified_data[] = $exploded_address['0'];
				}
			}
		}

		echo json_encode( array_unique( $simplified_data ) );
	} else {
		echo 'failed';
	}
	
	die(0);
}
add_action( 'wp_ajax_db_address_autocomplete', 'db_do_address_autocomplete' );
add_action( 'wp_ajax_nopriv_db_address_autocomplete', 'db_do_address_autocomplete' );

function db_setup_vc_modules() {
	// Extend Visual Composer
	if ( defined('WPB_VC_VERSION') ) {
		vc_map( array(
			"name" => __("Directory builder search", "directory-builder" ),
			"base" => "directory_listings",
			"class" => "",
			"icon" => "icon-wpb-ui-gap-content",
			"category" => __( "by Directory builder", "directory-builder" ),
			"show_settings_on_create" => false
		));

		vc_map( array(
			"name" => __("Directory builder add listing", "directory-builder" ),
			"base" => "directory_add_listing",
			"class" => "",
			"icon" => "icon-wpb-ui-gap-content",
			"category" => __( "by Directory builder", "directory-builder" ),
			"show_settings_on_create" => false
		));

		vc_map( array(
			"name" => __("Directory builder author dashboard", "directory-builder" ),
			"base" => "directory_account",
			"class" => "",
			"icon" => "icon-wpb-ui-gap-content",
			"category" => __( "by Directory builder", "directory-builder" ),
			"show_settings_on_create" => false
		));

		vc_map( array(
			"name" => __("Directory builder login", "directory-builder" ),
			"base" => "directory_login",
			"class" => "",
			"icon" => "icon-wpb-ui-gap-content",
			"category" => __( "by Directory builder", "directory-builder" ),
			"show_settings_on_create" => false
		));

		vc_map( array(
			"name" => __("Directory builder register", "directory-builder" ),
			"base" => "directory_register",
			"class" => "",
			"icon" => "icon-wpb-ui-gap-content",
			"category" => __( "by Directory builder", "directory-builder" ),
			"show_settings_on_create" => false
		));
	}	
}
add_action('after_setup_theme', 'db_setup_vc_modules');



function db_profile_configuration( $user ) { ?>

	<h3><?php esc_html_e('Directory builder', 'directory-builder'); ?></h3>

	<table class="form-table">
		<tr>
			<th><label for="db_listing_claims"><?php esc_html_e('Listing claims', 'directory-builder'); ?></label></th>
			<td>
				<input type="number" name="db_listing_claims" id="db_listing_claims" value="<?php echo esc_attr( get_the_author_meta( 'db_listing_claims', $user->ID ) ); ?>" class="regular-number" /><br />
				<span class="description"><?php esc_html_e('Number of listings this user can claim.', 'directory-builder'); ?></span>
			</td>
		</tr>
		<?php
		global $wpdb;
		$field_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_registration WHERE field_active="yes" ORDER BY field_order, ID ASC');
		if ( !empty($field_list) ) {
			$active_fields = array();
			foreach ($field_list as $field_value) {
				$field_settings = json_decode($field_value->field_settings, true);

				$do_not_show = array( 'db_registerusername', 'db_registeremail', 'db_registerpassword', 'db_registerpasswordconfirm' );
				$field_settings['field_name'] = 'db_'.$field_settings['field_name'];

				if ( !in_array( $field_settings['field_name'], $do_not_show ) ) {
					?>
					<tr>
						<th><label for="<?php echo $field_settings['field_name']; ?>"><?php echo $field_settings['frontend_title']; ?></label></th>
						<td>
							<?php
							if ( $field_settings['field_type'] == 'textarea' ) {
								echo '<textarea class="db_'.$field_settings['field_name'].' form-input" name="'.$field_settings['field_name'].'" placeholder="'.$field_settings['frontend_title'].'"'.($field_settings['required']=='yes'?' required':'').'>'.esc_attr( get_the_author_meta( $field_settings['field_name'], $user->ID ) ).'</textarea>';
							} else if ( $field_settings['field_type'] == 'checkbox' ) {
								$checkbox_val = esc_attr( get_the_author_meta( $field_settings['field_name'], $user->ID ) );
								echo '<label for="db_'.$field_settings['field_name'].'" class="dt-checkbox"><input type="checkbox" class="db_'.$field_settings['field_name'].' form-input" id="db_'.$field_settings['field_name'].'" name="'.$field_settings['field_name'].'"'.($field_settings['required']=='yes'?' required':'').($checkbox_val=='1'?' checked':'').'>'.$field_settings['frontend_title'].'</label>';
							} else if ( $field_settings['field_type'] == 'radio' ) {
								if ( $field_settings['radio_options'] != '' ) {
									$radio_options = explode(',', $field_settings['radio_options']);
									if ( !empty($radio_options) ) {
										$field_html = '';
										$loops = 1;
										$radio_val = (array)get_the_author_meta( $field_settings['field_name'], $user->ID );
										foreach ($radio_options as $radio_value) {
											$field_html .= '<label class="dt-radio" for="db_'.$field_settings['field_name'].$loops.'"><input type="radio" class="db_'.$field_settings['field_name'].' form-input" id="db_'.$field_settings['field_name'].$loops.'" name="'.$field_settings['field_name'].'[]" value="'.$radio_value.'"'.($field_settings['required']=='yes'?' required':'').(in_array($radio_value, $radio_val)?' checked':'').'>'.$radio_value.'</label>';
											$loops++;
										}
										echo $field_html;
									}
								}
							} else if ( $field_settings['field_type'] == 'select' ) {
								$select_options = explode('<br />', nl2br($field_settings['select_options']));
								if ( !empty($select_options) ) {
									$select_html = '<select class="db_'.$field_settings['field_name'].' form-input" name="'.$field_settings['field_name'].'"'.($field_settings['required']=='yes'?' required':'').'>';
									$select_val = esc_attr( get_the_author_meta( $field_settings['field_name'], $user->ID ) );
									foreach ($select_options as $select_data) {
										$curr_select_data = explode(':', $select_data);
										$select_html .= '<option value="'.$curr_select_data['0'].'"'.($select_val==$curr_select_data['0']?' selected':'').'>'.$curr_select_data['1'].'</option>';
									}
									$select_html .= '</select>';
								}
								echo $select_html;
							} else {
								echo '<input type="'.$field_settings['field_type'].'" class="db_'.$field_settings['field_name'].' form-input" name="'.$field_settings['field_name'].'" placeholder="'.$field_settings['frontend_title'].'" value="'.esc_attr( get_the_author_meta( $field_settings['field_name'], $user->ID ) ).'"'.($field_settings['required']=='yes'?' required':'').'>';
							}
							?>
						</td>
					</tr>
					<?php
				}
			}
		}
		?>
	</table>
	<?php
}
add_action( 'show_user_profile', 'db_profile_configuration' );
add_action( 'edit_user_profile', 'db_profile_configuration' );

function db_profile_configuration_save( $user_id ) {
	if ( !current_user_can( 'edit_user', $user_id ) ) { return false; }
		
	update_user_meta( $user_id, 'db_listing_claims', intval($_POST['db_listing_claims']) );

	foreach ($_POST as $field_key => $field_value) {
		if ( strpos($field_key, 'db_') === 0 && $field_key != 'db_listing_claims' ) {
			update_user_meta( $user_id, $field_key, $field_value );
		}
	}
}
add_action( 'personal_options_update', 'db_profile_configuration_save' );
add_action( 'edit_user_profile_update', 'db_profile_configuration_save' );

function db_get_claim_limit( $user_id ) {
	$user_meta = get_user_meta( $user_id, 'db_listing_claims', true );
	if ( $user_meta == '' ) {
		$main_settings = get_option( 'db_main_settings', array());
		return (isset($main_settings['claim_amount'])?intval($main_settings['claim_amount']):5);
	} else {
		return intval($user_meta);
	}
}

function db_get_listing_custom_fields( $listing_id = '', $field_location = 'all', $field_name = '' ) {
	global $wpdb;

	$field_query = $wpdb->get_results( $wpdb->prepare('SELECT field_settings FROM '.$wpdb->prefix.'directory_fields WHERE field_active="%s"'.($field_name!=''?' AND field_settings LIKE \'%%"field_name":"'.$field_name.'"%%\'':'').' ORDER BY field_order', 'yes') );

	$all_fields = array();
	if ( !empty($field_query) ) {
		foreach ($field_query as $field_data) {
			$field_settings = json_decode($field_data->field_settings, true);

			if ( $field_location != 'all' && ( isset($field_settings[$field_location]) && $field_settings[$field_location] != 'yes' ) ) {
				continue;
			} else if ( !isset($field_settings[$field_location]) ) {
				continue;
			}
			
			if ( $listing_id != '' ) {
				$field_value = get_post_meta( $listing_id, $field_settings['field_name'], true );
				if ( $field_settings['field_type'] == 'checkbox' ) {
					if ( $field_value == 'true' ) {
						$field_value = (isset($field_settings['checkbox_true'])&&$field_settings['checkbox_true']!=''?$field_settings['checkbox_true']:esc_html__('Yes','directory-builder'));
					} else {
						$field_value = (isset($field_settings['checkbox_false'])&&$field_settings['checkbox_false']!=''?$field_settings['checkbox_false']:esc_html__('No','directory-builder'));
					}
				}
			} else {
				$field_value = '';
			}

			$returned_data = array(
				'title' => esc_html( $field_settings['frontend_title'] ),
				'value' => $field_value,
				'type'  => esc_html( $field_settings['field_type'] ),
				'icon'  => (isset($field_settings['field_icon'])?esc_attr($field_settings['field_icon']):'')
				);

			if ( $field_settings['field_type'] == 'select' || $field_settings['field_type'] == 'multi-select' ) {
				$returned_data['select_options'] = $field_settings['select_options'];
			}

			$all_fields[$field_settings['field_name']] = $returned_data;
		}
	}

	return $all_fields;
}

function db_get_current_package_func() {
	$package_id = ( isset($_POST['package_id']) ? intval($_POST['package_id']) : '' );
	global $wpdb;
	$package_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_packages WHERE ID="'.$package_id.'"');
	if ( !empty($package_list) ) {
		$field_settings = json_decode($package_list['0']->package_settings, true);

		echo json_encode( array( 'status' => 'success', 'fee_label' => $field_settings['fee_label'], 'fee_amount' => $field_settings['fee_amount'], 'listing_run_type' => $field_settings['listing_run_type'], 'listing_run_days' => $field_settings['listing_run_days'], 'payment_cycle' => $field_settings['payment_cycle'], 'payment_interval' => $field_settings['payment_interval'], 'payment_type' => (isset($field_settings['payment_type'])?$field_settings['payment_type']:'onetime'), 'author' => get_current_user_id() ) );
	} else {
		echo json_encode( array( 'status' => 'failed' ) );
	}

	die(0);
}
add_action( 'wp_ajax_db_get_current_package', 'db_get_current_package_func' );
add_action( 'wp_ajax_nopriv_db_get_current_package', 'db_get_current_package_func' );


function db_save_billing_function() {
	$field_data = ( isset($_POST['field_data']) ? json_decode(htmlspecialchars_decode(stripslashes($_POST['field_data'])), true) : '' );
	$listing_id = ( isset($_POST['listing_id']) ? intval($_POST['listing_id']) : '' );
	$card_data = ( isset($_POST['card_data']) ? json_decode(htmlspecialchars_decode(stripslashes($_POST['card_data'])), true) : '' );
	$gateway = ( isset($_POST['gateway']) ? $_POST['gateway'] : '' );
	$billing_info = get_post_meta( $listing_id, 'db_billing_info', true );

	if ( $billing_info == '' ) {
		update_post_meta( $listing_id, 'db_billing_info', $field_data );
	}

	if ( $listing_id ) {
		if ( $gateway == 'authorizenet' ) {
			if ( function_exists('db_check_authorize_card') ) {
				db_check_authorize_card( $card_data );
			} else {
				echo '{"save_response": "failed", "message": "'.__('Couldn\'t find Authorize.Net', 'directory-builder').'"}';
			}
		} else if ( $gateway == 'stripe' ) {
			if ( function_exists('db_check_stripe_card') ) {
				db_check_stripe_card( $card_data );
			} else {
				echo '{"save_response": "failed", "message": "'.__('Couldn\'t find Stripe', 'directory-builder').'"}';
			}
		} else {
			echo '{"save_response": "'.$listing_id.'"}';
		}
	} else {
		echo '{"save_response": "failed", "message": "'.__('There was an issue while saving your billing information!', 'directory-builder').'"}';
	}

	die(0);
}
add_action( 'wp_ajax_db_save_billing', 'db_save_billing_function' );
add_action( 'wp_ajax_nopriv_db_save_billing', 'db_save_billing_function' );

function db_update_ipn_notes( $listing_id, $message ) {
	$current_notes = get_post_meta( $listing_id, 'db_notes', true );
	$current_notes[time()] = $message;
	update_post_meta( $listing_id, 'db_notes', $current_notes );
}

function db_cancel_subscription_func() {
	require 'vendor/autoload.php';
	require 'auth_cancel.php';

	die(0);
}
add_action( 'wp_ajax_db_cancel_subscription', 'db_cancel_subscription_func' );
add_action( 'wp_ajax_nopriv_db_cancel_subscription', 'db_cancel_subscription_func' );

function db_cancel_stripe_subscription_func() {
	require 'stripe_cancel.php';

	die(0);
}
add_action( 'wp_ajax_db_cancel_stripe_subscription', 'db_cancel_stripe_subscription_func' );
add_action( 'wp_ajax_nopriv_db_cancel_stripe_subscription', 'db_cancel_stripe_subscription_func' );

function db_authorize_refund_func() {
	require 'vendor/autoload.php';
	require 'auth_refund.php';

	die(0);
}
add_action( 'wp_ajax_db_authorize_refund', 'db_authorize_refund_func' );
add_action( 'wp_ajax_nopriv_db_authorize_refund', 'db_authorize_refund_func' );

function db_stripe_refund_func() {
	require 'vendor/autoload.php';
	require 'stripe_refund.php';

	die(0);
}
add_action( 'wp_ajax_db_stripe_refund', 'db_stripe_refund_func' );
add_action( 'wp_ajax_nopriv_db_stripe_refund', 'db_stripe_refund_func' );

function db_get_registration_fields( $placement ) {
	global $wpdb;

	$field_list = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'directory_registration WHERE field_active="yes" ORDER BY field_order, ID ASC');
	if ( !empty($field_list) ) {
		$active_fields = array();
		foreach ($field_list as $field_value) {
			$field_settings = json_decode($field_value->field_settings, true);
			if ( !is_array($field_settings['field_for']) ) {
				$field_settings['field_for'] = json_decode( $field_settings['field_for'], true );
			}
			if ( in_array( $placement, $field_settings['field_for'] ) ) {
				if ( $field_settings['field_type'] == 'textarea' ) {
					$field_settings['field_html'] = '<textarea class="db_'.$field_settings['field_name'].' form-input" name="db_'.$field_settings['field_name'].'" placeholder="'.$field_settings['frontend_title'].'"'.($field_settings['required']=='yes'?' required':'').'></textarea>';
				} else if ( $field_settings['field_type'] == 'checkbox' ) {
					$field_settings['field_html'] = '<label for="db_'.$field_settings['field_name'].'" class="dt-checkbox"><input type="checkbox" class="db_'.$field_settings['field_name'].' form-input" id="db_'.$field_settings['field_name'].'" name="db_'.$field_settings['field_name'].'"'.($field_settings['required']=='yes'?' required':'').'>'.$field_settings['frontend_title'].'</label>';
				} else if ( $field_settings['field_type'] == 'radio' ) {
					if ( $field_settings['radio_options'] != '' ) {
						$radio_options = explode(',', $field_settings['radio_options']);
						if ( !empty($radio_options) ) {
							$field_html = '';
							$loops = 1;
							foreach ($radio_options as $radio_value) {
								$field_html .= '<label class="dt-radio" for="db_'.$field_settings['field_name'].$loops.'"><input type="radio" class="db_'.$field_settings['field_name'].' form-input" id="db_'.$field_settings['field_name'].$loops.'" name="db_'.$field_settings['field_name'].'[]" value="'.$radio_value.'"'.($field_settings['required']=='yes'?' required':'').'>'.$radio_value.'</label>';
								$loops++;
							}
							$field_settings['field_html'] = $field_html;
						}
					}
				} else if ( $field_settings['field_type'] == 'select' ) {
					$select_options = explode('<br />', nl2br($field_settings['select_options']));
					if ( !empty($select_options) ) {
						$select_html = '
						<input type="text" class="dt-custom-select form-input" placeholder="'.$field_settings['frontend_title'].'" readonly="">
						<input type="hidden" class="dt-custom-select-value form-input" id="db_'.$field_settings['field_name'].'" name="db_'.$field_settings['field_name'].'">
						<div class="dt-custom-select-container">
							<div class="dt-custom-select-inner">
								<div class="dt-custom-select-items">';
									foreach ($select_options as $select_data) {
										$curr_select_data = explode(':', $select_data);
										$select_html .= '<div class="dt-custom-select-item" data-value="'.$curr_select_data['0'].'">'.$curr_select_data['1'].'</div>';
									}
								$select_html .= '
								</div>
								<div class="dt-custom-select-scrollbar-wrapper">
									<span class="dt-custom-select-scrollbar"></span>
								</div>
							</div>
						</div>';
					}
					$field_settings['field_html'] = $select_html;
				} else {
					$field_settings['field_html'] = '<input type="'.$field_settings['field_type'].'" class="db_'.$field_settings['field_name'].' form-input" name="db_'.$field_settings['field_name'].'" placeholder="'.$field_settings['frontend_title'].'"'.($field_settings['required']=='yes'?' required':'').'>';
				}
				$active_fields[$field_value->ID] = $field_settings;
			}
		}
		return $active_fields;
	} else {
		return array();
	}
}

function db_generate_invoice( $listing_id, $payment_row ) {
	require('includes/pdf/tfpdf.php');

	if ( get_post_type( $listing_id ) != 'listings' ) {
		printf( __( 'There\'s no listing found with ID %d', 'directory-builder' ), $listing_id );
		return;
	}

	$main_settings = get_option( 'db_main_settings', array() );
	$listing_data = get_post( $listing_id );
	$invoice_id = sprintf( '%d-%d-%d', $listing_id, $listing_data->post_author, $payment_row );
	$order_data = get_post_meta( $listing_id, 'db_order_info', true );
	$package_name = (isset($order_data['listing_package_name'])?$order_data['listing_package_name']:'');

	class dbPDF extends tFPDF {
		function FancyTable($header, $data) { // Colored table
			// Colors, line width and bold font
			$this->SetFillColor(0,0,0);
			$this->SetTextColor(255);
			$this->SetDrawColor(0,0,0);
			$this->SetLineWidth(.3);
			// $this->SetFont('','B');
			// Header
			$w = array(85, 35, 35, 35);
			for($i=0;$i<count($header);$i++)
				$this->Cell($w[$i],7,$header[$i],1,0,($i==0?'L':'C'),true);
			$this->Ln();
			// Color and font restoration
			$this->SetFillColor(224,235,255);
			$this->SetTextColor(0);
			$this->SetFont('');
			// Data
			$fill = false;
			foreach($data as $row) {
				$this->Cell($w[0],10,$row[0],'LR',0,'L',$fill);
				$this->Cell($w[1],10,$row[1],'LR',0,'C',$fill);
				$this->Cell($w[1],10,$row[2],'LR',0,'C',$fill);
				$this->Cell($w[1],10,$row[3],'LR',0,'C',$fill);
				$this->Ln();
				$fill = !$fill;
			}
			// Closing line
			$this->Cell(array_sum($w),0,'','T');
		}
	}

	$pdf = new dbPDF();
	$pdf->AddPage();
	// $pdf->SetFont('Arial','B',14);
	$pdf->AddFont('DejaVu','','DejaVuSansCondensed.ttf',true);
	$pdf->SetFont('DejaVu','',14);
	$logo_set = $info_set = false;

	if ( isset($main_settings['invoice_logo']) && $main_settings['invoice_logo'] != '' ) { // Check if logo is set
		$logo_id = db_get_image_id($main_settings['invoice_logo']);
		
		if ( $logo_id !== false ) {
			$uploads_dir = wp_upload_dir();
			$image_meta = wp_get_attachment_metadata($logo_id);
			
			$pdf->Image( $uploads_dir['basedir'] . '/' . $image_meta['file'], 10, 10, 0, 35 );
		}

		$logo_set = true;
	}

	if ( isset($main_settings['invoice_business']) && $main_settings['invoice_business'] != '' ) { // Check if business info is set
		$business_information = preg_split("/\\r\\n|\\r|\\n/", $main_settings['invoice_business']);

		if ( !empty($business_information) ) {
			$info_loops = 0;
			foreach ($business_information as $business_info_line) {
				if ( $info_loops == 0 ) {
					$pdf->SetFont( 'DejaVu', '', 10 );
				} else {
					$pdf->SetFont( 'DejaVu', '', 10 );
				}

				if ( $logo_set ) {
					$pdf->Cell( 100 );
				}
				
				$pdf->Cell( 0, 5, $business_info_line, 0, 1 );

				$info_loops++;

				$info_set = true;
			}
		}
	}

	if ( $info_set ) {
		if ( $info_loops >= 7 ) {
			$cell_height = 20;
		} else {
			if ( $logo_set ) {
				$cell_height = 20 + ( 7 - $info_loops ) * 5;
			} else {
				$cell_height = ( 7 - $info_loops ) * 5;
			}
		}

		$pdf->Cell( 0, $cell_height, '', 0, 1 );
	} else if ( $logo_set ) {
		$pdf->Cell( 0, 50, '', 0, 1 );
	}
	

	$pdf->SetFont( 'DejaVu', '', 20 );
	$pdf->Cell( 0, 5, esc_html__( 'INVOICE', 'directory-builder' ) );
	$pdf->Cell( 0, 10, '', 0, 1 );

	$user_billing = get_post_meta( $listing_id, 'db_billing_info', true );
	if ( $user_billing != '' ) {
		$pdf->SetFont( 'DejaVu', '', 10 );
		if ( isset($user_billing['x_full_name']) ) {
			$pdf->Cell( 0, 5, $user_billing['x_full_name'] );
			$pdf->Ln();
		}

		if ( isset($user_billing['x_address']) && isset($user_billing['x_city']) && isset($user_billing['x_zip']) ) {
			$pdf->Cell( 0, 5, $user_billing['x_address'].', '.$user_billing['x_city'].', '.$user_billing['x_zip'] );
			$pdf->Ln();
		}

		if ( isset($user_billing['x_country']) ) {
			$pdf->Cell( 0, 5, $user_billing['x_country'] );
			$pdf->Ln();
		}
	}

	$invoice_extra = db_get_invoice_table_data( $listing_id, $payment_row );
	$date_format = get_option( 'date_format' );

	if ( $invoice_extra === false ) {
		esc_html_e( 'There\'s no valid data to display!', 'directory-builder' );
		return;
	}

	$pdf->SetFont( 'DejaVu', '', 10 );

	$pdf->Cell( 100 );
	$pdf->Cell( 0, -25, sprintf( __( 'Invoice number:      %s', 'directory-builder' ), $invoice_id ), 0, 1 );
	$pdf->Cell( 100 );
	$pdf->Cell( 0, 35, sprintf( __( 'Invoice date:           %s', 'directory-builder' ), date( $date_format, time() ) ), 0, 1 );
	$pdf->Cell( 100 );
	$pdf->Cell( 0, -25, sprintf( __( 'Order date:             %s', 'directory-builder' ), date( $date_format, $invoice_extra['order_date'] ) ), 0, 1 );
	$pdf->Cell( 100 );
	$pdf->Cell( 0, 35, sprintf( __( 'Payment method:   %s', 'directory-builder' ), $invoice_extra['payment_method'] ), 0, 1 );

	$pdf->Cell( 100, 0, '', 0, 1 );
	$pdf->FancyTable( array( esc_html__('Description', 'directory-builder'), esc_html__('Package', 'directory-builder'), esc_html__('Status', 'directory-builder'), esc_html__('Price', 'directory-builder')), array( array( $invoice_extra['product_text'], $package_name, $invoice_extra['payment_status'], $invoice_extra['price_text'] ) ) );

	$pdf->Cell( 0, 5, '', 0, 1 );

	$pdf->Cell( 140 );
	$pdf->SetFont( 'DejaVu', '', 10 );
	$pdf->Cell( 26, 5, __( 'Subtotal:', 'directory-builder' ) );
	$pdf->SetFont( 'DejaVu', '', 10 );
	$pdf->Cell( 0, 5, $invoice_extra['price_text'] );

	$pdf->SetLineWidth( 0.5 );
	$pdf->Line( $pdf->GetX()-50, $pdf->GetY()+7, $pdf->GetX(), $pdf->GetY()+7 );
	

	$pdf->Cell( 0, 10, '', 0, 1 );

	$pdf->Cell( 140 );
	$pdf->SetFont( 'DejaVu', '', 13 );
	$pdf->Cell( 26, 5, __( 'Total:', 'directory-builder' ) );
	$pdf->SetFont( 'DejaVu', '', 13 );
	$pdf->Cell( 0, 5, $invoice_extra['price_text'] );
	
	$pdf->Output();
	//  'I', 'invoice-'.$invoice_id.'.pdf' 
	// $pdf->Output( 'D', 'invoice.pdf' );
}

function db_get_invoice_data() {
	if ( is_user_logged_in() && current_user_can('manage_options') && isset($_GET['dbgetinvoice']) && is_numeric($_GET['dbgetinvoice']) && isset($_GET['r']) && is_numeric($_GET['r']) ) {
		db_generate_invoice( intval($_GET['dbgetinvoice']), intval($_GET['r']) );
		exit;
	}

	if ( is_user_logged_in() && isset($_GET['invoices']) && isset($_GET['lid']) && is_numeric($_GET['lid']) && isset($_GET['prow']) && is_numeric($_GET['prow']) ) {
		$get_listing = get_post(intval($_GET['lid']));
		if ( isset($get_listing->post_author) && $get_listing->post_author == get_current_user_id() ) {
			db_generate_invoice( intval($_GET['lid']), intval($_GET['prow']) );
			exit;
		}
	}
}
add_action( 'init', 'db_get_invoice_data' );

function db_get_image_id( $image_url ) {
	global $wpdb;
	$attachment = $wpdb->get_col($wpdb->prepare("SELECT ID FROM $wpdb->posts WHERE guid='%s';", $image_url ));

	if ( !empty($attachment) ) {
		return $attachment[0];
	} else {
		return false;
	}
}

function db_get_invoice_table_data( $listing_id, $payment_row ) {
	$main_settings = get_option( 'db_main_settings', array() );

	$order_info = get_post_meta( $listing_id, 'db_order_info', true );
	if ( isset($order_info['payment_history'][$payment_row]) ) {
		$history_row = explode( '===', $order_info['payment_history'][$payment_row] );

		if ( $history_row['2'] == 'Completed' ) {
			$desc_text = sprintf( __( 'Payment for listing - %s', 'directory-builder' ), get_the_title( $listing_id ) );
		} else if ( $history_row['2'] == 'Refunded' ) {
			$desc_text = sprintf( __( 'Refund for listing - %s', 'directory-builder' ), get_the_title( $listing_id ) );
		}

		return array(
			'order_date' => strtotime( $history_row['0'] ),
			'payment_method' => $history_row['3'],
			'payment_status' => $history_row['2'],
			'product_text' => $desc_text,
			'price_text' => (!is_numeric($history_row['1'])?$history_row['1']:$main_settings['default_currency_symbol'].round($history_row['1'], 2))
		);
	} else {
		return false;
	}
}

function db_generate_schema_data() {
	if ( is_single() && get_post_type() == 'listings' ) {
		$field_list = db_get_active_fields();
		$custom_field_data = db_get_listing_custom_values($field_list, get_the_ID());
		$img = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full' );
		$schema_info = array(
			"@context" => "http://schema.org",
			"@type" => "Place",
			"name" => get_the_title(),
			"url" =>get_the_permalink(),
			"address" =>  $custom_field_data['listing_address'],
			"geo" => array(
				"@type" => "GeoCoordinates",
				"latitude" => $custom_field_data['listing_address_lat'],
				"longitude" => $custom_field_data['listing_address_lng']
			),
			"hasMap" => "https://www.google.lv/maps/@".$custom_field_data['listing_address_lat'].",".$custom_field_data['listing_address_lng'].",14z"
		);

		if ( isset($img['0']) ) {
			$schema_info['image'] = $img['0'];
		}

		if ( isset($custom_field_data['listingphone']) && $custom_field_data['listingphone'] != '' ) {
			$schema_info['telephone'] = $custom_field_data['listingphone'];
		}

		if ( isset($custom_field_data['hop']) && $custom_field_data['hop'] != '' && $custom_field_data['hop'] != 'always|' ) {
			$custom_times = explode('|', $custom_field_data['hop']);
			unset($custom_times['0']);
			if ( !empty($custom_times) ) {
				$hoo_days = array(
					'mon' => esc_html__('Monday', 'directory-builder'),
					'tue' => esc_html__('Tuesday', 'directory-builder'),
					'wed' => esc_html__('Wednesday', 'directory-builder'),
					'thu' => esc_html__('Thursday', 'directory-builder'),
					'fri' => esc_html__('Friday', 'directory-builder'),
					'sat' => esc_html__('Saturday', 'directory-builder'),
					'sun' => esc_html__('Sunday', 'directory-builder'),
					'--' => ' - '
					);

				$opening_hours = array();

				foreach ($custom_times as $hoo_values) {
					$parsed_data = explode('==', $hoo_values);

					if ( $parsed_data['0'] == '' ) {
						continue;
					}

					$hoo_day = $parsed_data['0'];
					$schema_day = '';

					switch ( $hoo_day ) {
						case 'mon': $schema_day = 'Monday'; break;
						case 'tue': $schema_day = 'Tuesday'; break;
						case 'wed': $schema_day = 'Wednesday'; break;
						case 'thu': $schema_day = 'Thursday'; break;
						case 'fri': $schema_day = 'Friday'; break;
						case 'sat': $schema_day = 'Saturday'; break;
						case 'sun': $schema_day = 'Sunday'; break;
						default: $schema_day = 'Monday'; break;
					}
					
					$hoo_times = str_replace('0-0', esc_html__('Closed', 'directory-builder'), $parsed_data['1']);
					$exploded_times = explode( '-',$hoo_times );

					$opening_hours[] = array(
						"@type" => "OpeningHoursSpecification",
						"dayOfWeek" => "http://schema.org/".$schema_day,
						"opens" => (isset($exploded_times['0'])?$exploded_times['0']:''),
						"closes" => (isset($exploded_times['1'])?$exploded_times['1']:'')
					);
				}
				$schema_info['openingHoursSpecification'] = $opening_hours;
			}
		}

		$all_comments = get_comments( array( 'post_id' => get_the_ID() ) );
		$all_ratings = 0;
		if ( !empty($all_comments) ) {
			foreach ($all_comments as $review_data) {
				if ( $review_data->comment_approved == '1' ) {
					$rating_value = get_comment_meta( intval($review_data->comment_ID), 'listing_review_rating', true );
					if ( is_array($rating_value) ) {
						$rating_total = $rating_count = 0;
						foreach ($rating_value as $rating_data) {
							$rating_total += intval($rating_data['overall']);
							$rating_count++;
						}
						$rating_value_number = floor($rating_total/$rating_count);
					} else {
						$rating_value_number = intval($rating_value);
					}
					$all_ratings += $rating_value_number;
				}
			}

			$schema_info['AggregateRating'] = array(
				"ratingValue" => ( $all_ratings != 0 ? round($all_ratings/3, 1) : '1' ),
				"reviewCount" => get_comments_number()
			);
		}

		if ( isset($custom_field_data['amenities']) && !empty($custom_field_data['amenities']) ) {
			$amenities = array();
			$amenities_field = db_get_listing_custom_fields( get_the_ID(), 'on_detail', 'amenities' );
			$select_data = preg_split("/\\r\\n|\\r|\\n/", $amenities_field['amenities']['select_options']);
			$formatted_data = array();

			foreach ($select_data as $select_value) {
				$exploded_data = explode( ':', $select_value );
				$formatted_data[$exploded_data['0']] = $exploded_data['1'];
			}

			if ( !is_array( $custom_field_data['amenities'] ) ) {
				$custom_field_data['amenities'] = explode( ',', $custom_field_data['amenities'] );
			}

			foreach ($custom_field_data['amenities'] as $amenities_value) {
				$amenities[] = array(
					'@type' => 'LocationFeatureSpecification',
					'name' => $formatted_data[$amenities_value],
					'value' => 'True'
				);
			}
			$schema_info['amenityFeature'] = $amenities;
		}

		echo '<script type="application/ld+json">'.json_encode($schema_info).'</script>';
	}

}
add_action( 'wp_head', 'db_generate_schema_data' );

add_filter( 'term_link', 'db_change_term_link' );
function db_change_term_link( $term_url ) {
	$term_full_url = parse_url( $term_url );
	$url_exploded = explode( '/', $term_full_url['path'] );
	$term_data = get_term_by( 'slug', $url_exploded[count($url_exploded)-2], 'listing_category' );

	if ( $term_data !== false ) {
		$main_settings = get_option( 'db_main_settings', array());

		if ( isset( $main_settings['search_page_id'] ) && $main_settings['search_page_id'] != '' ) {
			return add_query_arg( 'search_category', $term_data->term_id, get_permalink( $main_settings['search_page_id'] ) );
		}
	}

	return $term_url;
}

function db_custom_wp_mail_from( $original_email_address ) {
	return get_bloginfo('admin_email');
}

function db_custom_wp_mail_from_name( $original_email_from ) {
	return get_bloginfo('name');
}

function db_check_post_statuses() {
	global $pagenow, $wpdb;

	if ( !isset( $_GET['post_type'] ) || $_GET['post_type'] != 'listings' || !is_admin() || $pagenow != 'edit.php' ) {
		return;
	}

	$listings = $wpdb->get_results('SELECT * FROM '.$wpdb->prefix.'posts WHERE post_type="listings" && post_status="published"');
	if ( !empty( $listings ) ) {
		foreach ( $listings as $listing_data ) {
			$wpdb->update( $wpdb->prefix.'posts', array( 'post_status' => 'publish' ), array( 'ID' => $listing_data->ID ) );
		}
	}
	
}
add_action( 'admin_init', 'db_check_post_statuses' );

add_filter( 'gglcptch_exclude_forms', function() {
	return array('.dt-register-form', '#db-add-listing-form');
});

function db_wp_login() {
	global $user;

	$user_validation = get_user_meta( $user->data->ID, 'db_validation', true );
	if ( $user_validation !== false && $user_validation != '' ) {
		if ( $user_validation !== 'validated' ) {
			wp_logout();
		}
	}
}
add_action( 'wp_login', 'db_wp_login' );

function db_review_helpful_func() {
	$comment_id = ( isset($_POST['comment_id']) ? intval( $_POST['comment_id'] ) : '' );
	$helpful = ( isset($_POST['helpful']) ? esc_attr( $_POST['helpful'] ) : '' );
	
	if ( $comment_id != '' && $helpful != '' ) {
		$old_meta = get_comment_meta( $comment_id, 'db_review_helpful', true );

		if ( is_user_logged_in() ) {
			$user_id = get_current_user_id();
		} else {
			if ( !isset($_COOKIE['directory_helpful_'.$comment_id]) ) {
				$user_id = 'anon-'.rand('1000000','9999999');
				setcookie('directory_helpful_'.$comment_id, $user_id, time() + (86400 * 365), '/');
			} else {
				$user_id = $_COOKIE['directory_helpful_'.$comment_id];
			}
		}

		if ( $old_meta == '' ) {
			$old_meta = array();
		}

		$old_meta[$user_id] = $helpful;

		$helpful_update = update_comment_meta( $comment_id, 'db_review_helpful', $old_meta );

		if ( $helpful_update !== false ) {
			$helpful_arr = array( 'yes' => 0, 'no' => 0 );
			foreach ($old_meta as $meta_value) {
				$helpful_arr[$meta_value] = $helpful_arr[$meta_value]+1;
			}

			if ( $helpful_arr['yes'] >= $helpful_arr['no'] ) {
				$response_text = sprintf( esc_html__('%d people found this helpful.', 'directory-builder'), $helpful_arr['yes'] );
			} else {
				$response_text = sprintf( esc_html__('%d people found this unhelpful.', 'directory-builder'), $helpful_arr['no'] );
			}

			$comment_data = get_comment( $comment_id );
			if ( $helpful == 'yes' ) {
				db_insert_activity( $comment_data->comment_post_ID, 'helpful', array( 'comment-id' => $comment_id ) );
			} else {
				db_insert_activity( $comment_data->comment_post_ID, 'unhelpful', array( 'comment-id' => $comment_id ) );
			}

			echo json_encode( array( 'status' => true, 'response' => $response_text ) );
		} else {
			echo json_encode( array( 'status' => false, 'response' => 'Failed to update' ) );
		}
	} else {
		echo json_encode( array( 'status' => false, 'response' => 'Invalid data' ) );
	}

	die(0);
}
add_action( 'wp_ajax_db_review_helpful', 'db_review_helpful_func' );
add_action( 'wp_ajax_nopriv_db_review_helpful', 'db_review_helpful_func' );

function db_listing_improvement_func() {
	if ( !current_user_can('manage_options') ) die(0);

	$data_id = ( isset($_POST['imp_id']) ? intval($_POST['imp_id']) : '' );
	$data_key = ( isset($_POST['imp_key']) ? esc_attr($_POST['imp_key']) : '' );
	$data_type = ( isset($_POST['imp_type']) ? esc_attr($_POST['imp_type']) : '' );
	$data_author = ( isset($_POST['imp_auth']) ? intval($_POST['imp_auth']) : '0' );

	if ( $data_id != '' && $data_key != '' && $data_type != '' ) {
		global $wpdb;
		$imp_table = $wpdb->prefix.'directory_improvements';
		$improvements = $wpdb->get_results('SELECT listing_id, improvements FROM '.$imp_table.' WHERE ID="'.$data_id.'"');
		$sent_improvements = json_decode($improvements['0']->improvements, true);

		if ( $data_type == 'accept' ) {
			if ( isset($sent_improvements[$data_key]) ) {
				if ( is_array($sent_improvements[$data_key]) ) {
					$sent_improvements[$data_key] = implode(',', $sent_improvements[$data_key]);
				}

				$valid_keys = array( 'post_title', 'post_excerpt', 'post_content', 'listing_featured_img' );
				if ( in_array($data_key, $valid_keys) ) {
					if ( $data_key == 'post_title' ) {
						$db_listing = array(
							'ID'           => intval($improvements['0']->listing_id),
							'post_title'   => esc_attr($sent_improvements[$data_key]),
						);
						$save_new_data = wp_update_post( $db_listing );
					} else if ( $data_key == 'post_excerpt' ) {
						$db_listing = array(
							'ID'           => intval($improvements['0']->listing_id),
							'post_excerpt'   => esc_attr($sent_improvements[$data_key]),
						);
						$save_new_data = wp_update_post( $db_listing );
					} else if ( $data_key == 'post_content' ) {
						$db_listing = array(
							'ID'           => intval($improvements['0']->listing_id),
							'post_content'   => esc_attr($sent_improvements[$data_key]),
						);
						$save_new_data = wp_update_post( $db_listing );
					} else if ( $data_key == 'listing_featured_img' ) {
						$save_new_data = set_post_thumbnail( intval($improvements['0']->listing_id), $sent_improvements[$data_key] );
					}
				} else {
					$save_new_data = update_post_meta( $improvements['0']->listing_id, $data_key, $sent_improvements[$data_key] );
				}

				if ( $save_new_data ) {
					db_insert_activity( $improvements['0']->listing_id, 'improvement', array(), $data_author );
					$wpdb->query("UPDATE $imp_table SET status='reviewed' WHERE ID='".$data_id."'");
					echo json_encode( array( 'response' => true, 'message' => 'Changes saved!' ) );
				} else {
					echo json_encode( array( 'response' => false, 'message' => 'Failed to save the data' ) );
				}
			} else {
				echo json_encode( array( 'response' => false, 'message' => 'Data can\'t be found' ) );
			}
		} else {
			unset($sent_improvements[$data_key]);
			if ( $wpdb->query( $wpdb->prepare( "UPDATE $imp_table SET improvements='%s' WHERE ID='%d'", json_encode($sent_improvements), $data_id ) ) !== false ) {
				echo json_encode( array( 'response' => true, 'message' => 'Changes discarded!' ) );
			} else {
				echo json_encode( array( 'response' => false, 'message' => 'Failed to discard the changes' ) );
			}
		}
	} else {
		echo json_encode( array( 'response' => false, 'message' => 'Not enough data!' ) );
	}

	die(0);
}
add_action( 'wp_ajax_db_listing_improvement', 'db_listing_improvement_func' );

function whitelab_cat_markers_func() {
	$active_cat = ( isset($_POST['active_cat']) ? esc_attr($_POST['active_cat']) : false);
	$exclude = ( isset($_POST['exclude']) ? intval($_POST['exclude']) : 0);

	if ( $active_cat !== false && $active_cat != '' ) {
		global $wpdb;

		$selected_listings = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM $wpdb->posts as posts, $wpdb->term_relationships as term_rel WHERE posts.post_type='listings' && posts.post_status='publish' && term_rel.object_id=posts.ID && term_rel.term_taxonomy_id IN ($active_cat)" ) );
		
		if ( !empty($selected_listings) ) {
			$returned_markers = array();
			foreach ($selected_listings as $current_list_val) {
				if ( $current_list_val->ID != $exclude ) {
					$listing_category = get_the_terms($current_list_val->ID, 'listing_category');
					if ( isset($listing_category['0']) ) {
						$listing_category_meta = get_option( "listing_category_".intval($listing_category['0']->term_id));
					}
					$returned_markers[$current_list_val->ID] = array(
						'lat' => get_post_meta( $current_list_val->ID, 'listing_address_lat', true ),
						'lng' => get_post_meta( $current_list_val->ID, 'listing_address_lng', true ),
						'cat-icon' => (isset($listing_category_meta['tag-category-icon'])?$listing_category_meta['tag-category-icon']:'')
					);
				}
			}

			echo json_encode( $returned_markers );
		} else {
			echo json_encode( false );
		}
	} else {
		echo json_encode( false );
	}

	die(0);
}
add_action( 'wp_ajax_whitelab_cat_markers', 'whitelab_cat_markers_func' );
add_action( 'wp_ajax_nopriv_whitelab_cat_markers', 'whitelab_cat_markers_func' );

function db_get_marker_colors() {
	$extra_css = '';
	$listing_categories = get_terms( array( 'taxonomy' => 'listing_category', 'hide_empty' => true ) );
	if ( !empty($listing_categories) ) {
		foreach ($listing_categories as $category_data) {
			$single_category_data = get_option( "listing_category_".intval($category_data->term_id));
			$single_category_color = (isset($single_category_data['tag-category-color'])&&$single_category_data['tag-category-color']!=''?$single_category_data['tag-category-color']:'#f25f5c');
			$single_category_icon = (isset($single_category_data['tag-category-icon'])?$single_category_data['tag-category-icon']:'');

			$extra_css .= '.db-map-marker.'.$single_category_icon.' { border-color: '.$single_category_color.'; }';
			$extra_css .= '.db-map-marker.'.$single_category_icon.'.hovered { background: '.$single_category_color.'; }';
			$extra_css .= '.db-map-marker.'.$single_category_icon.':after { border-top-color: '.$single_category_color.'; }';
			$extra_css .= '.db-map-marker.'.$single_category_icon.':before { color: '.$single_category_color.'; }';
			$extra_css .= '.db-map-marker.'.$single_category_icon.'.hovered:before { background-color: '.$single_category_color.' !important; }';
			$extra_css .= '.db-map-marker.'.$single_category_icon.'.hovered:before { color: #fff; }';
			if ( in_array($single_category_icon, array('wl-health','wl-catering','wl-beauty','wl-finances','wl-plants')) ) {
				$extra_css .= '.db-map-marker.'.$single_category_icon.':before { background: url("'.db_get_wl_icon($single_category_icon, $single_category_color).'") no-repeat; }';
				$extra_css .= '.db-map-marker.'.$single_category_icon.'.hovered:before { background: url("'.db_get_wl_icon($single_category_icon, '#ffffff').'") no-repeat; }';
			}

			$extra_css .= '.db-single-listing-category.'.$category_data->slug.':before { border-color: '.$single_category_color.'; }';
			$extra_css .= '.db-single-listing-category.'.$category_data->slug.' { color: '.$single_category_color.'; }';
		}
	}

	return $extra_css;
}

function db_get_wl_icon( $icon, $color = '#ffffff' ) {
	$all_icons = array(
		'wl-health' => '<svg width="47px" height="43px" viewBox="0 0 47 43" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <g id="Home-page" transform="translate(-357.000000, -711.000000)" fill="'.esc_attr($color).'"> <g id="Header-featured-Copy" transform="translate(0.000000, 679.000000)"> <g id="pulse" transform="translate(357.000000, 32.000000)"> <g id="Capa_1"> <path d="M32.9090346,0 C29.4024082,0 26.0894665,1.2725566 23.5,3.59912028 C20.9105335,1.2725566 17.5974903,0 14.0909654,0 C6.32114471,0 0,6.31511792 0,14.0775307 C0,18.9846014 2.66590497,24.8330071 7.50670194,30.5454151 C11.959622,35.8001368 17.6723045,40.2770047 23.17973,42.8281014 C23.2812419,42.875158 23.3906717,42.8986863 23.5,42.8986863 C23.6093283,42.8986863 23.7186566,42.875158 23.82027,42.8281014 C29.3276955,40.2771061 35.040378,35.8002382 39.4932981,30.5454151 C44.334095,24.8329057 47,18.9845 47,14.0775307 C47,6.31511792 40.6788553,0 32.9090346,0 L32.9090346,0 Z M14.0909654,1.52122642 C17.4392333,1.52122642 20.589959,2.82238208 22.9625961,5.18494811 C23.2597214,5.48077594 23.7403801,5.48077594 24.0375054,5.18494811 C26.410041,2.82238208 29.5607667,1.52122642 32.9090346,1.52122642 C39.8392505,1.52122642 45.4773218,7.15392217 45.4773218,14.0775307 C45.4773218,15.7621368 45.1282225,17.577467 44.4555032,19.4716981 L34.8692289,19.4716981 C34.5124147,19.4716981 34.2034125,19.7192524 34.1260605,20.067309 L33.2236199,24.1236085 L30.7374924,13.5676156 C30.6569935,13.2259481 30.3529654,12.9836675 30.0016328,12.9812335 L29.9963542,12.9812335 C29.6472549,12.9812335 29.3425162,13.2186462 29.2577538,13.5573726 L27.7781166,19.4716981 L18.6274298,19.4716981 C18.2706156,19.4716981 17.9616134,19.7192524 17.8842613,20.067309 L16.9820238,24.1233042 L14.4959978,13.5676156 C14.4154989,13.2259481 14.1114708,12.9836675 13.7601382,12.9812335 L13.7547581,12.9812335 C13.4056587,12.9812335 13.1010216,13.2185448 13.0162592,13.5573726 L11.536216,19.4716981 L2.54449676,19.4716981 C1.87177754,17.577467 1.52267819,15.7620354 1.52267819,14.0775307 C1.52267819,7.15392217 7.16074946,1.52122642 14.0909654,1.52122642 L14.0909654,1.52122642 Z M38.3311901,29.5623986 C34.1660562,34.4775825 28.6456371,38.8416769 23.5,41.297342 C18.3543629,38.8416769 12.8340454,34.4775825 8.66880994,29.5623986 C6.21993737,26.6725755 4.35577322,23.7654104 3.14636069,20.9929245 L12.1306695,20.9929245 C12.4799719,20.9929245 12.7845076,20.7554104 12.86927,20.4167854 L13.7324255,16.9673538 L16.2621015,27.7084292 C16.343108,28.0522264 16.6500799,28.2948113 17.0031382,28.2948113 L17.0079093,28.2948113 C17.3629978,28.2925802 17.6693607,28.045533 17.7464082,27.6992005 L19.2382268,20.9929245 L28.3725702,20.9929245 C28.7218726,20.9929245 29.0264082,20.7554104 29.1111706,20.4167854 L29.9740216,16.9677594 L32.5035961,27.7084292 C32.5846026,28.0522264 32.8915745,28.2948113 33.2446328,28.2948113 L33.2494039,28.2948113 C33.6044924,28.2925802 33.9108553,28.045533 33.9879028,27.6992005 L35.4799244,20.9929245 L43.8536393,20.9929245 C42.6442268,23.7654104 40.7800626,26.6725755 38.3311901,29.5623986 L38.3311901,29.5623986 Z" id="Shape"></path> </g> </g> </g> </g> </g> </svg>',
		'wl-catering' => '<svg width="37px" height="43px" viewBox="0 0 37 43" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <g id="Home-page" transform="translate(-516.000000, -711.000000)" fill="'.esc_attr($color).'"> <g id="Header-featured-Copy" transform="translate(0.000000, 679.000000)"> <g id="coffee-cup" transform="translate(516.000000, 32.000000)"> <g id="Group"> <path d="M31.1115288,21.5464363 C30.5879649,21.5464363 30.0765489,21.6153477 29.5814536,21.7486199 L29.5814536,21.5 C29.5814536,20.2965572 28.6038747,19.3174946 27.4022556,19.3174946 L2.17919799,19.3174946 C0.977578947,19.3174946 0,20.2965572 0,21.5 L0,31.9017279 C0,34.9284449 1.41295489,37.8738985 3.70927318,39.6789698 L3.70927318,40.8174946 C3.70927318,42.0209374 4.68685213,43 5.88847118,43 L23.6929825,43 C24.8946015,43 25.8721805,42.0209374 25.8721805,40.8174946 L25.8721805,39.6789698 C27.4945238,38.4037365 28.6750927,36.5590086 29.2287945,34.5186911 C29.8321078,34.7231037 30.4625915,34.8272138 31.1115288,34.8272138 C34.3584411,34.8272138 37,32.1816458 37,28.9298056 L37,27.4438445 C37,24.1920043 34.3584411,21.5464363 31.1115288,21.5464363 L31.1115288,21.5464363 Z M29.5814536,27.4438445 C29.5814536,26.5988898 30.2678546,25.9114471 31.1115288,25.9114471 C31.955203,25.9114471 32.641604,26.5988898 32.641604,27.4438445 L32.641604,28.9298056 C32.641604,29.7747603 31.955203,30.462203 31.1115288,30.462203 C30.2678546,30.462203 29.5814536,29.7747603 29.5814536,28.9298056 L29.5814536,27.4438445 L29.5814536,27.4438445 Z M23.6929825,41.6069114 L5.88847118,41.6069114 C5.45383709,41.6069114 5.10025063,41.2527883 5.10025063,40.8174946 L5.10025063,40.0280778 L24.481203,40.0280778 L24.481203,40.8174946 C24.481203,41.2527883 24.1276165,41.6069114 23.6929825,41.6069114 L23.6929825,41.6069114 Z M28.1904762,31.9017279 C28.1904762,34.5372657 26.9524135,37.0956263 24.9460677,38.6349892 L4.63538596,38.6349892 C2.6290401,37.0955335 1.39097744,34.5372657 1.39097744,31.9017279 L1.39097744,21.5 C1.39097744,21.0647063 1.74456391,20.7105832 2.17919799,20.7105832 L27.4022556,20.7105832 C27.8368897,20.7105832 28.1904762,21.0647063 28.1904762,21.5 L28.1904762,27.4438445 L28.1904762,28.9298056 L28.1904762,31.9017279 L28.1904762,31.9017279 Z M35.6090226,28.9298056 C35.6090226,31.4134968 33.5914561,33.4341253 31.1115288,33.4341253 C30.5537469,33.4341253 30.0143258,33.332987 29.5026316,33.1360043 C29.5540977,32.7278294 29.5814536,32.3156609 29.5814536,31.9017279 L29.5814536,31.4205551 C30.0267519,31.6959222 30.5508722,31.8552916 31.1115288,31.8552916 C32.722188,31.8552916 34.0325815,30.5429093 34.0325815,28.9298056 L34.0325815,27.4438445 C34.0325815,25.8307408 32.722188,24.5183585 31.1115288,24.5183585 C30.5508722,24.5183585 30.0267519,24.6777279 29.5814536,24.953095 L29.5814536,23.2078337 C30.069594,23.0304471 30.5823083,22.9395248 31.1115288,22.9395248 C33.5914561,22.9395248 35.6090226,24.9601533 35.6090226,27.4438445 L35.6090226,28.9298056 L35.6090226,28.9298056 Z" id="Shape"></path> <path d="M14.3209474,13.8055076 C13.5593409,14.5043737 12.6115288,15.3741253 12.6115288,17.0421166 C12.6115288,17.4267948 12.9228296,17.7386609 13.3070175,17.7386609 C13.6912055,17.7386609 14.0025063,17.4267948 14.0025063,17.0421166 C14.0025063,15.9870842 14.5576917,15.4776782 15.2605063,14.8326782 C16.0221128,14.1338121 16.9699248,13.2640605 16.9699248,11.5960691 C16.9699248,9.9272419 16.0222055,9.05702592 15.2606917,8.35769546 C14.5576917,7.71232397 14.0025063,7.20236069 14.0025063,6.1463067 C14.0025063,5.09015983 14.5577845,4.58028942 15.2606917,3.93473218 C16.0222055,3.23558747 16.9699248,2.36537149 16.9699248,0.696544276 C16.9699248,0.311866091 16.6586241,0 16.2744361,0 C15.8902481,0 15.5789474,0.311866091 15.5789474,0.696544276 C15.5789474,1.75259827 15.0237619,2.26246868 14.3207619,2.90802592 C13.5592481,3.6072635 12.6115288,4.47747948 12.6115288,6.1463067 C12.6115288,7.81513391 13.5592481,8.68534989 14.3207619,9.38458747 C15.0236692,10.0301447 15.5789474,10.5400151 15.5789474,11.596162 C15.5789474,12.6511015 15.0237619,13.1606004 14.3209474,13.8055076 L14.3209474,13.8055076 Z" id="Shape"></path> <path d="M18.7720752,13.8055076 C18.0104687,14.5043737 17.0626566,15.3741253 17.0626566,17.0421166 C17.0626566,17.4267948 17.3739574,17.7386609 17.7581454,17.7386609 C18.1423333,17.7386609 18.4536341,17.4267948 18.4536341,17.0421166 C18.4536341,15.9870842 19.0088195,15.4776782 19.7116341,14.8326782 C20.4732406,14.133905 21.4210526,13.2640605 21.4210526,11.5960691 C21.4210526,9.9272419 20.4733333,9.05702592 19.7118195,8.35769546 C19.0088195,7.71232397 18.4536341,7.20236069 18.4536341,6.1463067 C18.4536341,5.76162851 18.1423333,5.44976242 17.7581454,5.44976242 C17.3739574,5.44976242 17.0626566,5.76162851 17.0626566,6.1463067 C17.0626566,7.81513391 18.0103759,8.68534989 18.7718897,9.38458747 C19.474797,10.0301447 20.0300752,10.5400151 20.0300752,11.596162 C20.0300752,12.6511015 19.4748897,13.1606004 18.7720752,13.8055076 L18.7720752,13.8055076 Z" id="Shape"></path> <path d="M9.86981955,13.8055076 C9.10821303,14.5043737 8.160401,15.3741253 8.160401,17.0421166 C8.160401,17.4267948 8.47170175,17.7386609 8.85588972,17.7386609 C9.24007769,17.7386609 9.55137845,17.4267948 9.55137845,17.0421166 C9.55137845,15.9870842 10.1065639,15.4776782 10.8093784,14.8326782 C11.570985,14.133905 12.518797,13.2640605 12.518797,11.5960691 C12.518797,9.9272419 11.5710777,9.05702592 10.8095639,8.35769546 C10.1065639,7.71232397 9.55137845,7.20236069 9.55137845,6.1463067 C9.55137845,5.76162851 9.24007769,5.44976242 8.85588972,5.44976242 C8.47170175,5.44976242 8.160401,5.76162851 8.160401,6.1463067 C8.160401,7.81513391 9.1081203,8.68534989 9.86963409,9.38458747 C10.5725414,10.0301447 11.1278195,10.5400151 11.1278195,11.596162 C11.1278195,12.6511015 10.5726341,13.1606004 9.86981955,13.8055076 L9.86981955,13.8055076 Z" id="Shape"></path> </g> </g> </g> </g> </g> </svg>',
		'wl-beauty' => '<svg width="42px" height="43px" viewBox="0 0 42 43" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <g id="Home-page" transform="translate(-665.000000, -711.000000)" fill="'.esc_attr($color).'"> <g id="Header-featured-Copy" transform="translate(0.000000, 679.000000)"> <g id="cosmetics" transform="translate(665.000000, 32.000000)"> <g id="Capa_1"> <g id="Group"> <path d="M11.5724621,19.8152513 L11.1027191,19.8152513 L11.1027191,16.0011294 C11.1027191,15.5490838 10.7368427,15.1826015 10.2853009,15.1826015 L10.2151119,15.1826015 L10.2151119,7.37930203 C10.2151119,7.06935279 10.0402934,6.78592386 9.76324315,6.64721066 L3.43751606,3.4791802 C3.18422541,3.35236294 2.88330651,3.3657868 2.64222263,3.51497716 C2.40113876,3.66405838 2.25443943,3.92751523 2.25443943,4.21127157 L2.25443943,15.1826015 L2.18425046,15.1826015 C1.73270864,15.1826015 1.36683224,15.5490838 1.36683224,16.0011294 L1.36683224,19.8152513 L0.896326319,19.8152513 C0.444784497,19.8152513 0.0789081049,20.1817335 0.0789081049,20.6337792 L0.0789081049,42.1194822 C0.0789081049,42.5715279 0.444784497,42.9380102 0.896326319,42.9380102 L11.5722441,42.9380102 C12.023786,42.9380102 12.3896624,42.5715279 12.3896624,42.1194822 L12.3896624,20.6337792 C12.3898803,20.1817335 12.0240039,19.8152513 11.5724621,19.8152513 L11.5724621,19.8152513 Z M3.88949384,5.53586802 L8.5803845,7.88515228 L8.5803845,15.1826015 L3.88949384,15.1826015 L3.88949384,5.53586802 L3.88949384,5.53586802 Z M3.00199564,16.8196574 L9.46799169,16.8196574 L9.46799169,19.8152513 L3.00199564,19.8152513 L3.00199564,16.8196574 L3.00199564,16.8196574 Z M10.7550439,41.3009543 L1.71396251,41.3009543 L1.71396251,21.4523071 L10.7550439,21.4523071 L10.7550439,41.3009543 L10.7550439,41.3009543 Z" id="Shape"></path> <path d="M40.2393189,33.2077868 L13.6891393,33.2077868 C13.2375975,33.2077868 12.8717211,33.574269 12.8717211,34.0263147 C12.8717211,34.4783604 13.2375975,34.8448426 13.6891393,34.8448426 L38.938752,34.8448426 L38.7518357,35.2339162 C37.7250495,37.3703832 35.5316439,38.750967 33.1638558,38.750967 L13.6891393,38.750967 C13.2375975,38.750967 12.8717211,39.1174492 12.8717211,39.5694949 C12.8717211,40.0215406 13.2375975,40.3880228 13.6891393,40.3880228 L33.1638558,40.3880228 C36.1559335,40.3880228 38.9276351,38.6435761 40.2249323,35.9437437 L40.9758672,34.3812284 C41.097826,34.1275939 41.0810417,33.8289949 40.9313996,33.5907487 C40.7817576,33.3525025 40.5204018,33.2077868 40.2393189,33.2077868 L40.2393189,33.2077868 Z" id="Shape"></path> <path d="M11.8017752,6.01879949 C14.8496552,3.19324112 18.8172943,1.63705584 22.9740294,1.63705584 C32.0434479,1.63705584 39.4220097,9.02563452 39.4220097,18.1073655 C39.4220097,23.0035812 37.2674042,27.6138579 33.5108771,30.7560228 C33.1642918,31.0458909 33.1180804,31.562 33.4075554,31.9089467 C33.5691863,32.1027741 33.801333,32.2027437 34.0353326,32.2027437 C34.2200691,32.2027437 34.4060045,32.1403173 34.5589162,32.0124086 C38.688622,28.5583299 41.0569551,23.4901142 41.0569551,18.1072563 C41.0568461,8.12296193 32.9448967,0 22.9740294,0 C18.4042256,0 14.042155,1.71094162 10.6910673,4.81763706 C10.3598495,5.12474873 10.3399045,5.64260406 10.6465998,5.97438071 C10.9531861,6.30593909 11.4703393,6.32591117 11.8017752,6.01879949 L11.8017752,6.01879949 Z" id="Shape"></path> <path d="M22.9735934,5.04147716 C30.1686175,5.04147716 36.0222038,10.9030102 36.0222038,18.107802 C36.0222038,25.3125939 30.1686175,31.1741269 22.9735934,31.1741269 C19.738906,31.1741269 16.6362045,29.9803858 14.2367006,27.813033 C13.9016681,27.5102868 13.3847328,27.5368071 13.0821791,27.8725127 C12.7798433,28.2081091 12.8064367,28.7257462 13.1416871,29.0284924 C15.8420009,31.4678147 19.3336846,32.8111827 22.9735934,32.8111827 C31.0700663,32.8111827 37.6570403,26.2152665 37.6570403,18.107802 C37.6570403,10.0003376 31.0700663,3.40442132 22.9735934,3.40442132 C18.3235737,3.40442132 13.8999243,5.64609645 11.1404294,9.40095685 C10.8727521,9.76503807 10.9506793,10.2774365 11.314267,10.545368 C11.6778546,10.8131904 12.1893404,10.7353756 12.4571266,10.3712944 C14.9098172,7.03399239 18.8412719,5.04147716 22.9735934,5.04147716 L22.9735934,5.04147716 Z" id="Shape"></path> <path d="M31.9661747,11.6595482 L17.0490552,26.5969188 C16.7298261,26.9165812 16.7298261,27.4348731 17.0490552,27.7544264 C17.2087242,27.914203 17.4179833,27.9942005 17.6271333,27.9942005 C17.8362834,27.9942005 18.0455425,27.9143122 18.2052115,27.7544264 L33.122222,12.8170558 C33.441451,12.4973934 33.441451,11.9791015 33.122222,11.6595482 C32.8028839,11.3398858 32.2854037,11.3398858 31.9661747,11.6595482 L31.9661747,11.6595482 Z" id="Shape"></path> <path d="M21.5915027,26.6979797 C21.2722736,27.0176421 21.2722736,27.535934 21.5915027,27.8554873 C21.7511717,28.015264 21.9604308,28.0952614 22.1695808,28.0952614 C22.3787309,28.0952614 22.58799,28.0153731 22.747659,27.8554873 L33.9473784,16.6405635 C34.2666075,16.320901 34.2666075,15.8026091 33.9473784,15.4830558 C33.6280404,15.1633934 33.1105602,15.1633934 32.7913311,15.4830558 L21.5915027,26.6979797 L21.5915027,26.6979797 Z" id="Shape"></path> </g> </g> </g> </g> </g> </g> </svg>',
		'wl-finances' => '<svg width="42px" height="43px" viewBox="0 0 42 43" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <g id="Home-page" transform="translate(-820.000000, -711.000000)" fill="'.esc_attr($color).'"> <g id="Header-featured-Copy" transform="translate(0.000000, 679.000000)"> <g id="rich" transform="translate(820.000000, 32.000000)"> <g id="Capa_1"> <g id="Group"> <path d="M11.6580442,7.77383607 C11.9441183,8.60422951 12.7151827,9.16252459 13.5769192,9.16252459 L18.8000548,9.16252459 C19.6617913,9.16252459 20.4328558,8.60422951 20.7189298,7.77383607 C20.991649,6.98009836 21.8484654,5.20440984 22.5133942,4.64047541 C23.0960856,4.14491803 23.3695077,3.3772623 23.2261192,2.63709836 C23.0855423,1.90891803 22.5787625,1.33370492 21.8709577,1.09896721 C19.761601,0.39757377 17.8905221,0.633721311 16.4601519,1.78062295 C16.203599,1.98645902 15.8591856,1.98645902 15.6026327,1.78062295 C14.1722625,0.63442623 12.3025894,0.398278689 10.1918269,1.09967213 C9.48402212,1.33440984 8.97653942,1.90891803 8.8359625,2.63780328 C8.69257404,3.37796721 8.96599615,4.14562295 9.5486875,4.64118033 C10.3014769,5.27983607 11.4542077,7.18170492 11.6580442,7.77383607 L11.6580442,7.77383607 Z M10.2164279,2.90637705 C10.2417317,2.77455738 10.3302952,2.53911475 10.6339413,2.43831148 C11.287624,2.22119672 11.897025,2.11334426 12.4607385,2.11334426 C13.3280981,2.11334426 14.0858077,2.36993443 14.7247298,2.88240984 C15.4943885,3.50062295 16.5698019,3.49921311 17.3380548,2.88240984 C18.3930846,2.0365082 19.7686298,1.88706557 21.4288433,2.43831148 C21.7324894,2.53911475 21.82035,2.7752623 21.8456538,2.90637705 C21.8927471,3.15098361 21.8027779,3.397 21.6045644,3.56547541 C20.5305567,4.47763934 19.5704163,6.79118033 19.3904779,7.31493443 C19.3005087,7.57716393 19.0629337,7.75339344 18.8007577,7.75339344 L13.5776221,7.75339344 C13.3147433,7.75339344 13.0778712,7.57716393 12.9879019,7.31493443 C12.694799,6.46339344 11.3909481,4.3585082 10.4582202,3.56547541 C10.2593038,3.39629508 10.1686317,3.15027869 10.2164279,2.90637705 L10.2164279,2.90637705 Z" id="Shape"></path> <path d="M22.1633577,10.5723607 C22.1633577,10.1832459 21.8484654,9.86744262 21.4604731,9.86744262 C21.3297365,9.86744262 21.2137606,9.9132623 21.1090308,9.97529508 C21.004301,9.91255738 20.888325,9.86744262 20.7575885,9.86744262 L12.3229731,9.86744262 C11.9349808,9.86744262 11.6200885,10.1832459 11.6200885,10.5723607 C11.6200885,10.9614754 11.9349808,11.2772787 12.3229731,11.2772787 L20.7575885,11.2772787 L20.7575885,11.9821967 L13.0258577,11.9821967 C12.6378654,11.9821967 12.3229731,12.298 12.3229731,12.6871148 C12.3229731,13.0762295 12.6378654,13.3920328 13.0258577,13.3920328 L21.4077567,13.3920328 C22.0375413,13.9179016 22.813526,14.2189016 23.6422269,14.2189016 C24.5805779,14.2189016 25.463401,13.8516393 26.1276269,13.1854918 C26.4024548,12.9098689 26.4024548,12.4643607 26.1276269,12.1887377 C25.852799,11.9131148 25.408576,11.9131148 25.1337481,12.1887377 C24.3394885,12.9852951 22.9632404,12.9874098 22.1633577,12.1986066 L22.1633577,10.5723607 L22.1633577,10.5723607 Z" id="Shape"></path> <path d="M15.1345115,19.031377 C10.6283183,19.031377 5.29412692,24.7630656 5.29412692,29.6051475 C5.29412692,29.9942623 5.60901923,30.3100656 5.99701154,30.3100656 C6.38500385,30.3100656 6.69989615,29.9942623 6.69989615,29.6051475 C6.69989615,25.5800656 11.4296067,20.4412131 15.1345115,20.4412131 C15.5225038,20.4412131 15.8373962,20.1254098 15.8373962,19.7362951 C15.8373962,19.3471803 15.5225038,19.031377 15.1345115,19.031377 L15.1345115,19.031377 Z" id="Shape"></path> <path d="M34.8152808,23.2608852 C34.0906067,23.2608852 33.2274644,23.3031803 32.3572933,23.4025738 C31.4105077,21.6642459 30.1621846,20.1691148 28.5863173,18.9587705 L23.5241423,15.5081967 C22.6870067,14.8639016 21.3676923,14.0969508 19.8368096,14.0969508 L14.370476,14.0969508 C13.018126,14.0969508 11.6882683,14.5586721 10.6451875,15.3813115 L5.67017019,19.0165738 C0.484990385,23.1050984 -1.15624519,30.2698852 1.76845769,36.0530328 C2.832625,38.1572131 4.61022019,40.6998525 7.04079519,40.8648033 C7.23127692,40.8774918 7.42386731,40.884541 7.61786346,40.884541 L21.2952952,40.884541 C22.3271298,42.1717213 23.9065115,42.9992951 25.6777808,42.9992951 C27.7147404,42.9992951 29.4972558,41.9031475 30.4841058,40.2719672 C31.7401606,40.6631967 33.2801808,40.884541 34.8152808,40.884541 C38.1954529,40.884541 41.8441269,39.8067213 41.8441269,38.0648689 L41.8441269,34.1878197 L41.788599,34.1878197 C41.8223375,34.073623 41.8441269,33.9566066 41.8441269,33.8353607 L41.8441269,29.6058525 L41.8441269,25.7288033 C41.8441269,23.7804098 37.4257942,23.2608852 34.8152808,23.2608852 L34.8152808,23.2608852 Z M40.3849385,25.7217541 C40.3701779,25.7365574 40.3582288,25.7513607 40.3378452,25.7675738 C40.3104327,25.7894262 40.2773971,25.8126885 40.2401442,25.8366557 C40.1937538,25.8662623 40.1375231,25.8972787 40.0763721,25.9282951 C40.0264673,25.9536721 39.9744538,25.9797541 39.9147087,26.0058361 C39.8409058,26.0389672 39.7537481,26.0720984 39.6644817,26.1059344 C39.5927875,26.1327213 39.5203904,26.1595082 39.4388558,26.187 C39.3362346,26.2208361 39.21815,26.2546721 39.0993625,26.2878033 C39.0065817,26.3138852 38.9152067,26.3406721 38.8125856,26.3660492 C38.6790375,26.3991803 38.5286202,26.4294918 38.3789058,26.4598033 C38.2657413,26.4830656 38.1582,26.5070328 38.0358981,26.5288852 C37.8672058,26.5584918 37.6788327,26.5838689 37.4925683,26.6092459 C37.3653462,26.6268689 37.2465587,26.6466066 37.1109019,26.6621148 C36.8894933,26.6874918 36.6455923,26.7051148 36.4023942,26.7227377 C36.2786865,26.7319016 36.166225,26.7445902 36.0368942,26.7523443 C35.6531192,26.7734918 35.2468519,26.7861803 34.8131721,26.7861803 C34.3794923,26.7861803 33.973225,26.7734918 33.58945,26.7523443 C33.4601192,26.7452951 33.3476577,26.7326066 33.22395,26.7227377 C32.9807519,26.7044098 32.736851,26.6867869 32.5154423,26.6621148 C32.3797856,26.6466066 32.2609981,26.6268689 32.133776,26.6092459 C31.9475115,26.5838689 31.7591385,26.5584918 31.5904462,26.5288852 C31.4681442,26.5070328 31.3606029,26.4830656 31.2474385,26.4598033 C31.097724,26.4287869 30.9473067,26.3984754 30.8137587,26.3660492 C30.7111375,26.3406721 30.6204654,26.3145902 30.5269817,26.2878033 C30.4081942,26.2546721 30.2908125,26.2208361 30.1874885,26.187 C30.1059538,26.1602131 30.0335567,26.1327213 29.9618625,26.1059344 C29.8725962,26.0720984 29.7854385,26.0389672 29.7116356,26.0058361 C29.6518904,25.9797541 29.5998769,25.9536721 29.5499721,25.9282951 C29.4888212,25.8965738 29.4325904,25.8655574 29.3862,25.8366557 C29.3489471,25.8126885 29.3159115,25.7901311 29.288499,25.7675738 C29.2695212,25.7527705 29.2589779,25.739377 29.2449202,25.7252787 C29.2533548,25.7182295 29.2589779,25.7111803 29.2688183,25.7034262 C29.294825,25.6815738 29.3320779,25.6569016 29.3686279,25.6329344 C29.4255615,25.5955738 29.4965529,25.5560984 29.5801962,25.5138033 C29.6258837,25.490541 29.6708683,25.4679836 29.7242875,25.4447213 C29.7798154,25.4200492 29.8437779,25.395377 29.9077404,25.37 C29.9836519,25.3403934 30.0665923,25.3107869 30.1544529,25.2811803 C30.2177125,25.2600328 30.2788635,25.2381803 30.3491519,25.2170328 C30.5065981,25.1690984 30.6788048,25.1218689 30.8678808,25.0760492 C30.9550385,25.0549016 31.0562538,25.0358689 31.1511433,25.0161311 C31.2657135,24.991459 31.3830952,24.9674918 31.5075058,24.9449344 C31.6445683,24.9202623 31.7900654,24.897 31.9404827,24.8744426 C32.7326337,24.7546066 33.680825,24.6714262 34.8117663,24.6714262 C38.133599,24.6707213 39.9913231,25.3580164 40.3849385,25.7217541 L40.3849385,25.7217541 Z M29.666651,31.5211148 C29.7299106,31.5479016 29.7952788,31.5732787 29.86135,31.5993607 C29.9836519,31.6472951 30.1087654,31.6924098 30.2380962,31.7368197 C30.306276,31.760082 30.37305,31.7826393 30.4426356,31.8044918 C30.5909442,31.8510164 30.7434702,31.8940164 30.8995106,31.9356066 C30.9543356,31.9504098 31.0070519,31.966623 31.0625798,31.9800164 C31.2755538,32.0335902 31.4934481,32.0829344 31.7169654,32.1266393 C31.7633558,32.1358033 31.8118548,32.1428525 31.8589481,32.1520164 C32.0381837,32.1858525 32.2195279,32.2168689 32.4036837,32.2443607 C32.4824067,32.2563443 32.5618327,32.2662131 32.6412587,32.2767869 C32.7994077,32.2979344 32.9582596,32.3169672 33.1192202,32.3338852 C33.2035663,32.3423443 33.2879125,32.3508033 33.3722587,32.3585574 C33.5381394,32.3733607 33.7047231,32.3846393 33.8720096,32.3945082 C33.9465154,32.3987377 34.0210212,32.404377 34.0955269,32.4079016 C34.3359135,32.4184754 34.5755971,32.4255246 34.8145779,32.4255246 C35.0535587,32.4255246 35.2932423,32.4184754 35.5336288,32.4079016 C35.6095404,32.404377 35.6854519,32.3987377 35.7613635,32.3945082 C35.9265413,32.3846393 36.0917192,32.3733607 36.2561942,32.3592623 C36.342649,32.3515082 36.4291038,32.3430492 36.5148558,32.3338852 C36.6730048,32.3176721 36.8297481,32.2986393 36.9857885,32.2774918 C37.0673231,32.266918 37.1488577,32.2563443 37.2296894,32.2443607 C37.4110337,32.2175738 37.5895663,32.1865574 37.7659904,32.1534262 C37.8158952,32.1442623 37.8665029,32.1365082 37.9164077,32.1266393 C38.1385192,32.0822295 38.3557106,32.0335902 38.5672788,31.9807213 C38.6263212,31.965918 38.6825519,31.949 38.7408913,31.9334918 C38.8934173,31.8926066 39.0431317,31.8503115 39.187926,31.8044918 C39.2589173,31.7819344 39.3270971,31.7586721 39.3959798,31.7354098 C39.5246077,31.6917049 39.6497212,31.6458852 39.7713202,31.5986557 C39.8366885,31.5732787 39.9020567,31.5471967 39.9653163,31.5204098 C40.0918356,31.4668361 40.2120288,31.4104426 40.3280048,31.3526393 C40.3645548,31.3343115 40.406025,31.3188033 40.4411692,31.3004754 L40.4453865,33.7846066 C40.2802087,34.1857049 38.4639548,35.079541 35.5982942,35.2226393 C35.3410385,35.2318033 35.0922173,35.2444918 34.8145779,35.2444918 C33.2661231,35.2444918 31.7366462,35.0062295 30.5684519,34.5875082 C30.5642346,34.580459 30.5593144,34.5734098 30.5550971,34.5663607 C30.4721567,34.4211475 30.3842962,34.279459 30.2894067,34.1427049 C30.275349,34.1222623 30.2591827,34.1032295 30.2444221,34.0827869 C30.1565615,33.9594262 30.0658894,33.8388852 29.9681885,33.7232787 C29.9386673,33.6887377 29.9070375,33.6570164 29.8768135,33.6224754 C29.7903587,33.5244918 29.703201,33.427918 29.6104202,33.3362787 C29.562624,33.2890492 29.5113135,33.2467541 29.4621115,33.2009344 C29.3805769,33.1262131 29.3004481,33.0514918 29.215399,32.9817049 C29.2069644,32.9746557 29.1999356,32.9669016 29.191501,32.9605574 C29.191501,32.6849344 29.1922038,32.0723607 29.1929067,31.3018852 C29.2287538,31.320918 29.2716298,31.3371311 29.3081798,31.355459 C29.4241558,31.4125574 29.5422404,31.4682459 29.666651,31.5211148 L29.666651,31.5211148 Z M20.3808423,39.474 L7.61786346,39.474 C7.45549712,39.474 7.29383365,39.4683607 7.13427885,39.4577869 C5.75311058,39.3640328 4.29251635,37.9281148 3.02170096,35.415082 C0.399238462,30.2297049 1.87881058,23.7987377 6.51784904,20.1402131 L11.4928663,16.5049508 C12.3096183,15.8613607 13.3316125,15.5067869 14.3697731,15.5067869 L19.8361067,15.5067869 C20.9726712,15.5067869 22.0031,16.1158361 22.7010644,16.6508689 L27.7632394,20.1007377 C29.0207,21.0678852 30.068701,22.2507377 30.8875615,23.6260328 C29.9977096,23.8100164 29.1373788,24.0905738 28.5462529,24.5022459 C28.5300865,24.5135246 28.5139202,24.5248033 28.4977538,24.536082 C28.4084875,24.6009344 28.3269529,24.6693115 28.2524471,24.7412131 C28.2208173,24.7715246 28.1927019,24.802541 28.1638837,24.8342623 C28.1083558,24.8955902 28.0549365,24.957623 28.0113577,25.0238852 C27.9748077,25.0781639 27.9480981,25.1366721 27.9199827,25.1944754 C27.8953817,25.2466393 27.8658606,25.2966885 27.8482885,25.3516721 C27.8096298,25.4708033 27.7857317,25.5955738 27.7857317,25.7280984 L27.7857317,29.6051475 L27.7857317,32.1350984 C27.5488596,32.0385246 27.3035529,31.9609836 27.0519202,31.897541 C27.0188846,31.889082 26.985849,31.879918 26.9528135,31.8721639 C26.7068038,31.8143607 26.455874,31.7706557 26.1993212,31.7466885 C26.1705029,31.7438689 26.1416846,31.7445738 26.1128663,31.742459 C25.968775,31.7311803 25.8239808,31.7206066 25.6770779,31.7206066 C25.5997606,31.7206066 25.5252548,31.7290656 25.4486404,31.7318852 C25.3888952,31.734 25.32915,31.7368197 25.2694048,31.7410492 C25.0191779,31.759377 24.7717625,31.7882787 24.531376,31.8383279 C24.5264558,31.8390328 24.5222385,31.8390328 24.5173183,31.8404426 C24.4983404,31.8446721 24.4807683,31.8524262 24.4617904,31.8566557 C24.2417875,31.9052951 24.0274077,31.9694426 23.8179481,32.0441639 C23.7420365,32.0709508 23.666125,32.0977377 23.5916192,32.1273443 C23.3828625,32.2112295 23.179026,32.3042787 22.9829212,32.4121311 C22.9091183,32.4523115 22.8402356,32.4988361 22.7685413,32.542541 C22.6314788,32.6264262 22.4979308,32.714541 22.3693029,32.8097049 C22.2933913,32.8653934 22.2167769,32.9196721 22.1436769,32.9788852 C21.978499,33.1128197 21.8210529,33.255918 21.6720413,33.4081803 C21.6066731,33.4744426 21.5469279,33.5449344 21.485074,33.6147213 C21.3796413,33.7331475 21.2791288,33.8565082 21.1842394,33.9833934 C21.1329288,34.0524754 21.0788067,34.1180328 21.0303077,34.1892295 C20.9066,34.3703934 20.7962471,34.5607213 20.6943288,34.7559836 C20.6549673,34.8321148 20.6191202,34.9096557 20.5825702,34.9879016 C20.5024413,35.1606066 20.4307471,35.3368361 20.3681904,35.5187049 C20.3499154,35.5715738 20.3274231,35.621623 20.3112567,35.6751967 C20.2388596,35.9064098 20.1861433,36.146082 20.1439702,36.3885738 C20.1383471,36.4195902 20.127101,36.4491967 20.1221808,36.4802131 C20.1165577,36.5182787 20.1165577,36.5591639 20.1116375,36.5972295 C20.0891452,36.7628852 20.0750875,36.9306557 20.0673558,37.100541 C20.0645442,37.1611639 20.0589212,37.221082 20.0582183,37.2824098 C20.0582183,37.3084918 20.054001,37.3338689 20.054001,37.3599508 C20.054001,37.4720328 20.0645442,37.5812951 20.0708702,37.6912623 C20.0982827,38.3003115 20.1973894,38.9121803 20.3808423,39.474 L20.3808423,39.474 Z M25.6777808,41.5887541 C23.3688048,41.5887541 21.4899942,39.7179016 21.4632846,37.4092951 C21.4632846,37.3543115 21.4646904,37.3000328 21.466799,37.2450492 C21.4689077,37.1675082 21.4724221,37.0906721 21.4787481,37.0138361 C21.4836683,36.9489836 21.4914,36.8848361 21.4991317,36.8206885 C21.5075663,36.7551311 21.5174067,36.6902787 21.5286529,36.6261311 C21.5602827,36.4428525 21.60105,36.2616885 21.6565779,36.0861639 C21.662201,36.0671311 21.6706356,36.0495082 21.6769615,36.0311803 C21.7360038,35.8542459 21.8069952,35.681541 21.8892327,35.5144754 C21.8969644,35.4982623 21.9046962,35.4820492 21.9124279,35.466541 C22.2912827,34.7207377 22.8894375,34.090541 23.6141115,33.6753443 C23.6169231,33.6739344 23.6190317,33.6718197 23.6218433,33.6704098 C23.7863183,33.5766557 23.9592279,33.4977049 24.134949,33.4272131 C24.1806365,33.4088852 24.2270269,33.3926721 24.2727144,33.376459 C24.4287548,33.3207705 24.5876067,33.2721311 24.7513788,33.2361803 C24.7738712,33.2312459 24.7949577,33.2234918 24.81745,33.2192623 C25.0205837,33.1776721 25.2244202,33.1551148 25.4275538,33.1431311 C25.4662125,33.1410164 25.5048712,33.1381967 25.5442327,33.1374918 C25.7515837,33.1311475 25.9582317,33.1367869 26.1620683,33.1607541 C26.1740173,33.1621639 26.1852635,33.1642787 26.1965096,33.1663934 C26.4115923,33.1931803 26.6245663,33.2361803 26.834026,33.2968033 C26.8368375,33.2975082 26.8403519,33.2982131 26.8431635,33.298918 C27.058949,33.3616557 27.2705173,33.4427213 27.4771654,33.5407049 C27.6669442,33.6309344 27.8518029,33.7317377 28.0247125,33.8480492 L28.0528279,33.8677869 C28.0774288,33.8847049 28.0999212,33.9037377 28.1238192,33.9206557 C28.2404981,34.004541 28.3522567,34.0933607 28.4597981,34.1885246 C28.4858048,34.211082 28.5111087,34.2350492 28.5364125,34.2583115 C28.6439538,34.3584098 28.746575,34.4627377 28.8428702,34.5727049 C28.8527106,34.5839836 28.862551,34.5938525 28.8723913,34.6051311 C29.0959087,34.8659508 29.288499,35.1542623 29.4431337,35.4637213 C29.4789808,35.5342131 29.5148279,35.6054098 29.5464577,35.6780164 C29.5998769,35.801377 29.6462673,35.9261475 29.6877375,36.0523279 C29.690549,36.0614918 29.6947663,36.0706557 29.6975779,36.0798197 C29.7383452,36.2074098 29.7713808,36.3371148 29.7994962,36.4675246 C29.8016048,36.4780984 29.8051192,36.4879672 29.8072279,36.4978361 C29.8339375,36.627541 29.8536183,36.7586557 29.8683788,36.8904754 C29.8697846,36.902459 29.8725962,36.9130328 29.8740019,36.9250164 C29.8887625,37.0688197 29.8964942,37.2133279 29.8964942,37.3592459 C29.8964942,37.5086885 29.8880596,37.6574262 29.8725962,37.805459 C29.8704875,37.8273115 29.8655673,37.8477541 29.8627558,37.8696066 C29.8472923,37.9971967 29.8283144,38.124082 29.8009019,38.2488525 C29.7980904,38.2629508 29.7931702,38.2763443 29.7903587,38.2904426 C29.7601346,38.424377 29.7242875,38.5569016 29.6807087,38.6880164 C29.6786,38.6936557 29.6764913,38.6992951 29.6743827,38.7049344 C29.6279923,38.8416885 29.5745731,38.9763279 29.514125,39.1095574 C28.8470875,40.5694426 27.3801673,41.5887541 25.6777808,41.5887541 L25.6777808,41.5887541 Z M34.8152808,39.474 C33.4812058,39.474 32.1534567,39.2956557 31.0625798,38.9763279 C31.0632827,38.974918 31.0632827,38.9735082 31.0632827,38.9720984 C31.1314625,38.7437049 31.1813673,38.5082623 31.2207288,38.2685902 C31.2298663,38.2114918 31.2390038,38.1550984 31.2467356,38.0972951 C31.2783654,37.8548033 31.3008577,37.6101967 31.3008577,37.3592459 C31.3008577,37.1766721 31.2910173,36.9955082 31.2734452,36.8157541 C31.2671192,36.7509016 31.2558731,36.6881639 31.2474385,36.6240164 C31.2354894,36.533082 31.2270548,36.4414426 31.2108885,36.351918 C32.2771644,36.5492951 33.5156471,36.6543279 34.8152808,36.6543279 C36.495175,36.6543279 38.9236413,36.4393279 40.4411692,35.7668361 L40.4453865,38.0141148 C40.2654481,38.450459 38.1321933,39.474 34.8152808,39.474 L34.8152808,39.474 Z M34.8152808,31.0149836 C31.5096144,31.0149836 29.3812798,29.9991967 29.1957183,29.609377 C29.1964212,28.8057705 29.197124,27.9901803 29.197124,27.3106393 C29.2146962,27.3183934 29.2357827,27.3247377 29.2540577,27.3324918 C29.4220471,27.4043934 29.5977683,27.4720656 29.7847356,27.5340984 C29.794576,27.537623 29.8044163,27.5411475 29.8149596,27.5439672 C30.0061442,27.606 30.2078721,27.6616885 30.4138173,27.7131475 C30.4812942,27.7300656 30.5508798,27.7455738 30.6197625,27.761082 C30.7701798,27.795623 30.9220029,27.8287541 31.0773404,27.8583607 C31.152549,27.8731639 31.2270548,27.8872623 31.3029663,27.9006557 C31.4737673,27.9309672 31.6452712,27.9577541 31.8188837,27.9831311 C31.8737087,27.9908852 31.9278308,28.0000492 31.9826558,28.0078033 C32.2096875,28.0381148 32.4367192,28.0649016 32.6623452,28.0867541 C32.7192788,28.0923934 32.7748067,28.096623 32.8317404,28.1015574 C33.0053529,28.1170656 33.1768567,28.1311639 33.3469548,28.1424426 C33.4207577,28.147377 33.4924519,28.1516066 33.564849,28.1558361 C33.7222952,28.165 33.875524,28.1720492 34.0273471,28.1776885 C34.0913096,28.1798033 34.1552721,28.182623 34.2178288,28.1847377 C34.423774,28.190377 34.624799,28.1939016 34.8145779,28.1939016 C35.0036538,28.1939016 35.2046788,28.190377 35.410624,28.1847377 C35.4745865,28.182623 35.5392519,28.1798033 35.6039173,28.1776885 C35.7543346,28.1720492 35.9068606,28.165 36.0636038,28.1558361 C36.1374067,28.1516066 36.2098038,28.147377 36.2843096,28.1424426 C36.4544077,28.1311639 36.6266144,28.1170656 36.8002269,28.1008525 C36.8564577,28.095918 36.9112827,28.0916885 36.9675135,28.0860492 C37.1938423,28.0634918 37.420874,28.0374098 37.6479058,28.0063934 C37.7034337,27.9986393 37.7582587,27.9894754 37.8137865,27.9817213 C37.9866962,27.9570492 38.1582,27.9295574 38.3282981,27.8992459 C38.4049125,27.8858525 38.4794183,27.8710492 38.5546269,27.8569508 C38.7099644,27.8266393 38.8624904,27.7942131 39.0136106,27.7589672 C39.0824933,27.7427541 39.151376,27.7279508 39.2188529,27.7110328 C39.4290154,27.6581639 39.6342577,27.6017705 39.8289567,27.5383279 C39.8387971,27.5348033 39.8472317,27.5312787 39.8570721,27.528459 C40.040525,27.4678361 40.2141375,27.4008689 40.3793154,27.330377 C40.3989962,27.321918 40.4221913,27.3148689 40.4418721,27.3064098 L40.4460894,29.5536885 C40.2654481,29.9914426 38.1321933,31.0149836 34.8152808,31.0149836 L34.8152808,31.0149836 Z" id="Shape"></path> </g> </g> </g> </g> </g> </g> </svg>',
		'wl-plants' => '<svg width="43px" height="43px" viewBox="0 0 43 43" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g id="Welcome" stroke="none" stroke-width="1" fill="none" fill-rule="evenodd"> <g id="Home-page" transform="translate(-1002.000000, -711.000000)" fill="'.esc_attr($color).'"> <g id="Header-featured-Copy" transform="translate(0.000000, 679.000000)"> <g id="growth" transform="translate(1002.000000, 32.000000)"> <g id="Layer_1"> <g id="Group"> <path d="M10.7290448,41.5617676 L1.80893372,41.5617676 C2.03851852,40.8128789 2.17942105,39.7421621 1.78320078,38.5002012 C1.38404678,37.2503457 1.69594347,36.1674512 2.61788694,35.604168 C3.07563158,35.3239961 3.58274659,35.2530293 3.99623392,35.3591016 C3.6221423,36.0836348 3.27311306,37.2689902 4.00050877,38.5303516 C4.79948733,39.9185293 6.16417154,40.1263906 6.90665497,40.1263906 C7.27219688,40.1263906 7.52751462,40.076252 7.5554269,40.070457 C7.70781287,40.0389629 7.84511111,39.9593457 7.94812671,39.8432793 C8.01392593,39.7687012 9.55035867,37.9942793 8.39371735,35.9890684 C7.79792008,34.9556406 6.72216569,34.3636348 5.44180507,34.3636348 C5.36309747,34.3636348 5.29084405,34.3658184 5.22646979,34.3693457 C4.32095517,33.706457 2.99910331,33.6928516 1.87330799,34.3800957 C0.696717349,35.098918 -0.302508772,36.673457 0.4198577,38.9373398 C0.952035088,40.602834 0.15808577,41.8219512 0.126569201,41.8684785 C0.110810916,41.8907344 0.107961014,41.9171895 0.0958070175,41.940873 C0.0743489279,41.9795898 0.057165692,42.0197344 0.0435867446,42.0634062 C0.02782846,42.1121172 0.0185243665,42.1594004 0.0142495127,42.209623 C0.0114834308,42.2332227 0,42.2540508 0,42.2784062 C0,42.3006621 0.0107290448,42.3185508 0.0129083821,42.3400508 C0.0165126706,42.387334 0.0264873294,42.4317617 0.0400662768,42.4769453 C0.0543996101,42.5242285 0.0694035088,42.5686562 0.0922865497,42.6109844 C0.110894737,42.6460898 0.133023392,42.6769121 0.15808577,42.7084902 C0.192452242,42.7536738 0.22891423,42.7923066 0.272500975,42.828168 C0.286834308,42.838918 0.293959064,42.8553789 0.308962963,42.865457 C0.330421053,42.8804902 0.354729045,42.886957 0.377612086,42.8991348 C0.410553606,42.9170234 0.441231969,42.9342402 0.476352827,42.9471738 C0.537877193,42.9686738 0.600826511,42.9801797 0.664446394,42.9844629 C0.682300195,42.9858906 0.697387914,42.9952129 0.715241715,42.9952129 L10.7290448,42.9952129 C11.1238402,42.9952129 11.4442865,42.6741406 11.4442865,42.2785742 C11.4442865,41.8830078 11.1238402,41.5617676 10.7290448,41.5617676 L10.7290448,41.5617676 Z M5.39100975,35.797584 C5.91673294,35.7890176 6.70783236,35.9301953 7.15484795,36.705623 C7.63262573,37.5341289 7.25568421,38.3282012 7.02392008,38.6900898 C6.98745809,38.6915176 6.94881676,38.6929453 6.90665497,38.6929453 C6.37665692,38.6929453 5.65781092,38.5402617 5.23937817,37.8136289 C4.76227096,36.9865508 5.15069591,36.1717344 5.39100975,35.797584 L5.39100975,35.797584 Z" id="Shape"></path> <path d="M23.6038986,41.5617676 L15.7359045,41.5617676 L15.7359045,38.6951289 L16.7373099,38.6951289 C16.819538,38.6951289 18.7650994,38.6793398 20.1040507,37.3384453 C21.4423314,35.9967949 21.4580897,34.0475176 21.4580897,33.9650449 L21.4580897,32.2450449 C21.4580897,31.8494785 21.1376433,31.5284062 20.742848,31.5284062 L19.0262008,31.5284062 C18.9439727,31.5284062 16.9984113,31.5441953 15.65946,32.8850898 C15.0007135,33.5458789 14.6630838,34.3521289 14.4892398,35.0121621 C14.3562164,34.8702285 14.2238635,34.733418 14.0958694,34.6050898 C13.4964678,34.0045176 13.007961,33.5136289 12.8984912,32.6328008 C13.7790273,32.0444062 15.7359883,30.3824395 15.7359883,27.2284062 C15.7359883,23.2480508 12.6124113,21.6376504 12.4793879,21.5702949 C12.278386,21.4699336 12.040922,21.4699336 11.8399201,21.5702949 C11.7068967,21.6376504 8.58331969,23.2480508 8.58331969,27.2284062 C8.58331969,30.4426562 10.6182339,32.1096621 11.4722827,32.6686621 C11.6089103,34.1241953 12.417193,34.9498457 13.0844893,35.6184453 C13.7668733,36.3021621 14.3054211,36.8417617 14.3054211,37.9784062 L14.3054211,41.5617676 L13.5901793,41.5617676 C13.195384,41.5617676 12.8749376,41.8828398 12.8749376,42.2784062 C12.8749376,42.6739727 13.195384,42.9950449 13.5901793,42.9950449 L23.6038986,42.9950449 C23.9994483,42.9950449 24.3191404,42.6739727 24.3191404,42.2784062 C24.3191404,41.8828398 23.9994483,41.5617676 23.6038986,41.5617676 L23.6038986,41.5617676 Z M15.7359045,36.2612617 C15.7359045,36.2469004 15.758117,34.8128672 16.6707563,33.8984453 C17.5833957,32.9840234 19.013963,32.9617676 19.026117,32.9617676 L20.0275224,32.9617676 L20.0275224,33.9622734 C20.0275224,33.9766348 20.0053099,35.410668 19.0926706,36.3250898 C18.1871559,37.232373 16.7715926,37.2610957 16.7351306,37.2617676 L15.7359045,37.2617676 L15.7359045,36.2612617 L15.7359045,36.2612617 Z M12.1602827,31.4065449 C11.4936569,30.9442949 10.0137193,29.6457285 10.0137193,27.2284062 C10.0137193,24.8025176 11.4878733,23.5117617 12.1581033,23.0502676 C12.824729,23.5125176 14.3053372,24.8104121 14.3053372,27.2284062 C14.3054211,29.6528672 12.832692,30.943623 12.1602827,31.4065449 L12.1602827,31.4065449 Z" id="Shape"></path> <path d="M42.2009376,41.5617676 L32.9023762,41.5617676 L32.9023762,32.9617676 L34.3329435,32.9617676 C34.4331092,32.9617676 36.793499,32.943123 38.4150097,31.3184453 C40.0365205,29.6937676 40.0551287,27.3287676 40.0551287,27.2284063 L40.0551287,25.0784063 C40.0551287,24.6828398 39.7354366,24.3617676 39.3398869,24.3617676 L37.194078,24.3617676 C37.0939123,24.3617676 34.7335224,24.3804121 33.1120117,26.0050898 C33.0383333,26.079668 32.9703548,26.1570176 32.90246,26.2344512 L32.90246,20.0617676 C32.90246,19.6662012 32.582768,19.3451289 32.1872183,19.3451289 C31.7916686,19.3451289 31.4719766,19.6662012 31.4719766,20.0617676 L31.4719766,30.5344512 C31.4039981,30.4570176 31.3361033,30.379668 31.262425,30.3050898 C29.6409142,28.6804121 27.2805244,28.6617676 27.1803587,28.6617676 L25.0345497,28.6617676 C24.639,28.6617676 24.319308,28.9828398 24.319308,29.3784063 L24.319308,31.5284063 C24.319308,31.6287676 24.3379162,33.9937676 25.9594269,35.6184453 C27.5809376,37.243123 29.9413275,37.2617676 30.0414932,37.2617676 L31.4720604,37.2617676 L31.4720604,41.5617676 L30.7568187,41.5617676 C30.361269,41.5617676 30.041577,41.8828398 30.041577,42.2784063 C30.041577,42.6739727 30.361269,42.9950449 30.7568187,42.9950449 L42.2011053,42.9950449 C42.596655,42.9950449 42.916347,42.6739727 42.916347,42.2784063 C42.916347,41.8828398 42.5964873,41.5617676 42.2009376,41.5617676 L42.2009376,41.5617676 Z M32.9023762,30.0950449 C32.9023762,30.0764004 32.9167096,28.2274004 34.123308,27.0183613 C35.3185068,25.8208281 37.1774815,25.7950449 37.1939942,25.7950449 L38.6245614,25.7950449 L38.6245614,27.2284062 C38.6245614,27.2470508 38.6102281,29.0952949 37.4036296,30.3050898 C36.2169805,31.4940566 34.3758596,31.5277344 34.3315185,31.5284062 L32.9023762,31.5284062 L32.9023762,30.0950449 L32.9023762,30.0950449 Z M31.4718928,35.8284063 L30.0413255,35.8284063 C30.0234717,35.8284063 28.1773216,35.8140449 26.9706394,34.6050898 C25.7754405,33.4075566 25.7497076,31.5449512 25.7497076,31.5284063 L25.7497076,30.0950449 L27.1802749,30.0950449 C27.1981287,30.0950449 29.0435244,30.1086504 30.250961,31.3183613 C31.4461598,32.5158945 31.4718928,34.3785 31.4718928,34.3950449 L31.4718928,35.8284063 L31.4718928,35.8284063 Z" id="Shape"></path> <path d="M27.8955166,15.7617676 C28.0786647,15.7617676 28.261729,15.6915566 28.4012066,15.5518066 L30.7451676,13.2032676 C31.1700546,13.4541289 31.6593158,13.6081563 32.1871345,13.6081563 C32.715037,13.6081563 33.2042144,13.4540449 33.6291014,13.2032676 L35.9730624,15.5518066 C36.11254,15.6915566 36.2956881,15.7617676 36.4787524,15.7617676 C36.6619006,15.7617676 36.8449649,15.6915566 36.9844425,15.5518066 C37.264152,15.2716348 37.264152,14.818623 36.9844425,14.5384512 L34.6419064,12.190668 C34.8937037,11.7635234 35.0481852,11.2718789 35.0481852,10.7416016 C35.0481852,10.2119961 34.8943743,9.72253516 34.6440858,9.29681836 L36.9844425,6.95189063 C37.264152,6.67163477 37.264152,6.21870703 36.9844425,5.93853516 C36.7047329,5.65836328 36.2526881,5.65836328 35.9730624,5.93853516 L33.6333762,8.28279102 C33.2078187,8.02983008 32.7171326,7.87504688 32.1871345,7.87504688 C31.6571365,7.87504688 31.1664503,8.02983008 30.7401384,8.28279102 L28.4012066,5.93853516 C28.1215809,5.65836328 27.6694522,5.65836328 27.3898265,5.93853516 C27.110117,6.21879102 27.110117,6.67171875 27.3898265,6.95189063 L29.7301832,9.29681836 C29.4798109,9.72253516 29.3260838,10.2119961 29.3260838,10.7416016 C29.3260838,11.2719629 29.4805653,11.7636074 29.7323626,12.190668 L27.3898265,14.5384512 C27.110117,14.818707 27.110117,15.2716348 27.3898265,15.5518066 C27.5293041,15.6914727 27.7123684,15.7617676 27.8955166,15.7617676 L27.8955166,15.7617676 Z M31.1636004,9.74319531 C31.1678752,9.73891211 31.173575,9.73815625 31.1779337,9.73387305 C31.182963,9.72883398 31.1836335,9.72312305 31.1879922,9.71808398 C31.4462437,9.46512305 31.7981228,9.30815625 32.1872183,9.30815625 C32.5763138,9.30815625 32.9282768,9.46512305 33.1857739,9.71808398 C33.1908031,9.72312305 33.1914737,9.72883398 33.1965029,9.73387305 C33.2007778,9.73815625 33.2065614,9.73891211 33.2108363,9.74319531 C33.4612086,10.0011953 33.6177856,10.3530898 33.6177856,10.7415176 C33.6177856,11.5319785 32.9762222,12.1748789 32.1872183,12.1748789 C31.3982982,12.1748789 30.7566511,11.5320625 30.7566511,10.7415176 C30.7565673,10.3530898 30.9132281,10.0011953 31.1636004,9.74319531 L31.1636004,9.74319531 Z" id="Shape"></path> <path d="M27.8955166,41.5617676 L26.4649493,41.5617676 C26.0693996,41.5617676 25.7497076,41.8828398 25.7497076,42.2784063 C25.7497076,42.6739727 26.0693996,42.9950449 26.4649493,42.9950449 L27.8955166,42.9950449 C28.2910663,42.9950449 28.6107583,42.6739727 28.6107583,42.2784063 C28.6107583,41.8828398 28.2910663,41.5617676 27.8955166,41.5617676 L27.8955166,41.5617676 Z" id="Shape"></path> <path d="M21.4673938,16.1351621 C21.3951404,17.425918 21.9480214,18.6707344 23.1103626,19.8353457 C25.3749454,22.1043516 27.9971072,22.0291016 30.4204464,19.6010293 C31.0949513,18.9259629 31.7336647,17.8402129 32.1871345,16.9658516 C32.6406043,17.839457 33.2793177,18.9259629 33.9538226,19.6010293 C35.204846,20.8537402 36.4944269,21.489418 37.7869415,21.489418 L37.7876959,21.489418 C38.998653,21.489418 40.1681189,20.9332734 41.2639064,19.8353457 C42.4262476,18.6707344 42.9791287,17.4251621 42.9068752,16.1330625 C42.8382261,14.9118457 42.2052125,13.6935684 41.0256881,12.5117402 C40.3526082,11.835918 39.269729,11.2038516 38.3978265,10.7566348 C39.2690585,10.2965684 40.352692,9.65014063 41.0256881,8.97499023 C42.2051287,7.79324609 42.8381423,6.57412891 42.9068752,5.35148438 C42.9791287,4.05787305 42.4262476,2.81162891 41.2639064,1.64701758 C39.0022573,-0.619804687 36.3793411,-0.540271484 33.9538226,1.88922852 C33.2793177,2.56429492 32.6406043,3.65080078 32.1871345,4.52440625 C31.7336647,3.65080078 31.0949513,2.56429492 30.4204464,1.88922852 C27.9956823,-0.540271484 25.3727661,-0.619132812 23.1103626,1.64701758 C21.9480214,2.81162891 21.3951404,4.05787305 21.4673938,5.35148438 C21.5360429,6.57412891 22.1690565,7.79316211 23.3485809,8.97499023 C24.0223314,9.6508125 25.1067193,10.2901016 25.9786218,10.7430293 C25.1067193,11.1981406 24.0223314,11.8402852 23.3485809,12.5153516 C22.1690565,13.6970117 21.5360429,14.915373 21.4673938,16.1351621 L21.4673938,16.1351621 Z M27.9212495,11.4007949 C28.1858713,11.2882559 28.3575361,11.0281562 28.3575361,10.7400059 C28.3567817,10.4519395 28.1844464,10.1925117 27.9190702,10.0806445 C27.8947622,10.0698945 25.4092281,9.01353906 24.3598772,7.9614668 C23.4371793,7.03629492 22.9436433,6.13111133 22.8956979,5.27035547 C22.8470819,4.40246094 23.2598148,3.52457227 24.1224133,2.66028906 C25.8368811,0.943900391 27.5485828,1.03989453 29.4089825,2.9025 C30.4590039,3.95524414 31.517575,6.44496094 31.5283041,6.47007227 C31.6398694,6.73521094 31.9002164,6.90721094 32.1870507,6.90721094 C32.4745556,6.90721094 32.734232,6.73521094 32.8457973,6.47007227 C33.1390858,5.77417773 34.0911209,3.77828906 34.9651189,2.9025 C36.824848,1.04056641 38.5371365,0.943144531 40.2516881,2.66096094 C41.1142865,3.52457227 41.5270195,4.40246094 41.4784035,5.27035547 C41.4304581,6.13111133 40.936922,7.03621094 40.0142242,7.9614668 C38.9627778,9.01572266 36.4736394,10.0992891 36.448577,10.1092832 C36.1846257,10.2239219 36.0151404,10.4855332 36.0165653,10.7735996 C36.0194152,11.061666 36.1939298,11.3204219 36.4600604,11.4301055 C36.4843684,11.4408555 38.9663821,12.4742832 40.0142242,13.5249277 C40.9376764,14.4494277 41.4304581,15.3546113 41.4784035,16.2138555 C41.5270195,17.0803223 41.1143704,17.9575391 40.2516881,18.8218223 C39.4348558,19.6410059 38.6058694,20.0558887 37.7876121,20.0558887 C36.8871267,20.0558887 35.9379415,19.5621445 34.9651189,18.5874219 C33.9150975,17.5353496 32.8557719,15.0449609 32.8457973,15.0198496 C32.734232,14.7547109 32.473885,14.5819551 32.1870507,14.5819551 C31.8995458,14.5819551 31.6398694,14.7547109 31.5283041,15.0198496 C31.2350156,15.7157441 30.2829805,17.7123887 29.4089825,18.5874219 C27.5514327,20.4485996 25.8376355,20.5410664 24.1224133,18.8217383 C23.2598148,17.9574551 22.8470819,17.0809941 22.8956979,16.2159551 C22.9436433,15.3573828 23.436425,14.4537109 24.3598772,13.5284551 C25.4099825,12.4757949 27.896271,11.4115449 27.9212495,11.4007949 L27.9212495,11.4007949 Z" id="Shape"></path> </g> </g> </g> </g> </g> </g> </svg>'
	);

	if ( isset($all_icons[$icon]) ) {
		return 'data:image/svg+xml;charset=utf-8;base64,'.base64_encode($all_icons[$icon]);
	}
}

function db_book_listing_func() {
	$settings = (isset($_POST['db-settings'])?json_decode(stripslashes($_POST['db-settings']), true):array());

	if ( !empty($settings) ) {
		global $wpdb;

		$listings_hop = $wpdb->get_results( $wpdb->prepare( "SELECT meta_value FROM $wpdb->postmeta WHERE post_id='%d' && meta_key='hop'", $settings['listing_id'] ) );
		if ( !empty($listings_hop) ) {
			$listing_hours = json_decode($listings_hop['0']->meta_value, true);

			$booking_table = $wpdb->prefix . 'directory_booking';
			$current_listing = get_post( $settings['listing_id'] );
			$user_booked_date = strtotime($settings['date'].' '.$settings['time']) - db_convert_utc( $listing_hours['0'] );
			$booked_date = ( strtotime($settings['date'].' '.$settings['time']) + db_convert_utc( $_SESSION['db_tz'] ) ) - db_convert_utc( $listing_hours['0'] );
			$book_query = $wpdb->query( $wpdb->prepare( "INSERT INTO $booking_table (`listing_id`,`user_id`,`timestamp`,`booking_info`,`status`) VALUES('%d','%d','%d','%s','%s')", $settings['listing_id'], $current_listing->post_author, $booked_date, json_encode($settings), 'active') );

			if ( $book_query ) {
				$listing_email = get_post_meta( $settings['listing_id'], 'listingcontact', true );
				$main_settings = get_option( 'db_main_settings', array());
				db_send_notification_email( '0', 'new_booking', array( 'listing_url' => '<a href="'.get_the_permalink( $settings['listing_id'] ).'">'.get_the_title( $settings['listing_id'] ).'</a>', 'calendar_url' => '<a href="'.add_query_arg('bookings', $settings['listing_id'], get_permalink( $main_settings['account_page_id'] )).'">'.get_the_title( $settings['listing_id'] ).'</a>', 'app_date' => $settings['date'].' '.$settings['time'], 'app_name' => $settings['name'], 'app_email' => $settings['email'], 'app_comment' => $settings['comments'] ), $settings['email'], $listing_email );

				db_insert_activity( $settings['listing_id'], 'newbooking', $settings );
				echo json_encode( array( 'status' => true, 'booking' => strtotime($settings['date'].' '.$settings['time']) ) );
			} else {
				echo json_encode( array( 'status' => false ) );
			}
		} else {
			echo json_encode( array( 'status' => false ) );
		}
	} else {
		echo json_encode( array( 'status' => false ) );
	}

	die(0);
}
add_action( 'wp_ajax_db_book_listing', 'db_book_listing_func' );
add_action( 'wp_ajax_nopriv_db_book_listing', 'db_book_listing_func' );

function db_booking_email( $to_whom, $type, $settings ) {
	switch ( $type ) {
		case 'cancel':
			$subject = sprintf( __( '[%s] - Appointment with %s is cancelled', 'directory-builder' ), get_bloginfo('name'), get_the_title( $settings['listing_id'] ) );
			$message = sprintf( __( 'Your appointment at %s with %s has been cancelled!', 'directory-builder' ), $settings['date'].' '.$settings['time'], '<a href="'.get_permalink($settings['listing_id']).'">'.get_the_title($settings['listing_id']).'</a>' );
			break;
		
		default: break;
	}

	add_filter( 'wp_mail_content_type','db_set_content_type' );
	add_filter( 'wp_mail_from_name', 'db_custom_wp_mail_from_name' );
	add_filter( 'wp_mail_from', 'db_custom_wp_mail_from' );
	wp_mail( $to_whom, $subject, $message );
	remove_filter( 'wp_mail_content_type','db_set_content_type' );
	remove_filter( 'wp_mail_from_name', 'db_custom_wp_mail_from_name' );
	remove_filter( 'wp_mail_from', 'db_custom_wp_mail_from' );
}

function db_cancel_booking_func() {
	$booking_id = (isset($_POST['booking_id'])?intval($_POST['booking_id']):0);

	if ( $booking_id > 0 ) {
		global $wpdb;
		$booking_table = $wpdb->prefix . 'directory_booking';
		$cancel_booking = $wpdb->query( $wpdb->prepare( "UPDATE $booking_table SET status='cancelled' WHERE ID='%d'", $booking_id ) );
		
		if ( $cancel_booking ) {
			$booking_data = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM $booking_table WHERE ID='%d'", $booking_id ) );
			if ( !empty($booking_data) ) {
				$booking_info = json_decode( $booking_data['0']->booking_info, true );
				db_booking_email( $booking_info['email'], 'cancel', $booking_info );
			}
			echo json_encode( array( 'status' => true ) );
		} else {
			echo json_encode( array( 'status' => false ) );
		}
	}

	die(0);
}
add_action( 'wp_ajax_db_cancel_booking', 'db_cancel_booking_func' );
add_action( 'wp_ajax_nopriv_db_cancel_booking', 'db_cancel_booking_func' );